import React from 'react';
import { IconButton, SxProps, Theme, Tooltip } from '@mui/material';
import ContentCopyIcon from '@mui/icons-material/ContentCopy';
import { useSnackbar } from '@/shared/components/snackbar';

interface CopyButtonProps {
  value: string;
  sx?: SxProps<Theme>;
}

const CopyButton: React.FC<CopyButtonProps> = ({ value, sx }) => {
  const { enqueueSnackbar } = useSnackbar();
  const handleCopy = async () => {
    try {
      await navigator.clipboard.writeText(value);
      enqueueSnackbar('Copied to clipboard', { variant: 'success' });
    }
    catch (err) {
      console.error(err);
      enqueueSnackbar('Failed to copy to clipboard', { variant: 'error' });
    }
  };

  return (
    <Tooltip title="Copy to clipboard">
      <IconButton sx={sx} onClick={handleCopy}>
        <ContentCopyIcon />
      </IconButton>
    </Tooltip>
  );
};

export default CopyButton;
