import { useState, useEffect, useCallback } from "react";

import { paths } from "@/routes/paths";
import { useRouter } from "@/hooks";

import { SplashScreen } from "@/shared/components/loading-screen";

import { useAuthContext } from "@/hooks";
import { getTokenInfo } from "@/utils/token";
import { RequestLoginActivity, TokenPayload } from "@/shared/types/user";
import { ChangingLogingActivity, useGetUsersByIDs, UserByEmail } from "@/shared/api/user";

// ----------------------------------------------------------------------

const loginPaths: Record<string, string> = {
  jwt: paths.auth.jwt.login,
};

// ----------------------------------------------------------------------

type Props = {
  children: React.ReactNode;
};

export default function AuthGuard({ children }: Props) {
  const { loading } = useAuthContext();

  return <>{loading ? <SplashScreen /> : <Container>{children}</Container>}</>;
}

// ----------------------------------------------------------------------

function Container({ children }: Props) {
  const router = useRouter();
  const [checked, setChecked] = useState(false);

  const handleLogout = useCallback(() => {
    localStorage.removeItem("token");
    localStorage.removeItem("chatbotToken");
    localStorage.removeItem("refreshToken");
    localStorage.removeItem("expirationDurationInSec");
    router.push(loginPaths.jwt);
    setChecked(false);
  }, []);

  const checkToken = useCallback(async () => {
    const token = localStorage.getItem("token");

    if (token) {
      const userInfo: TokenPayload = getTokenInfo(token);

      if (!userInfo.isValid) {
        const user= await UserByEmail(userInfo.email);
        const requestLoginActivity: RequestLoginActivity = {
          email: user.data.email,
          activityLog: false,
        };

        const result = await ChangingLogingActivity(requestLoginActivity);

        if (result.status === 200) {
          handleLogout();
        }
      } else {
        setChecked(true);
      }
    } else {
      handleLogout();
    }
  }, []);

  useEffect(() => {
    checkToken();
  }, []);

  if (!checked) {
    return null;
  }

  return <>{children}</>;
}
