import { useEffect, useCallback, useState } from 'react';

import { paths } from '@/routes/paths';
import { useRouter, useSearchParams } from '@/hooks';

import { SplashScreen } from '@/shared/components/loading-screen';

import { useAuthContext } from '@/hooks';
import { TokenPayload } from '@/shared/types/user';
import { getTokenInfo } from '@/utils/token';

// ----------------------------------------------------------------------

type Props = {
  children: React.ReactNode;
};

export default function GuestGuard({ children }: Props) {
  const { loading } = useAuthContext();

  return <>{loading ? <SplashScreen /> : <Container>{children}</Container>}</>;
}

// ----------------------------------------------------------------------

function Container({ children }: Props) {
  const router = useRouter();
  const [checked, setChecked] = useState(false);

  const check = useCallback(() => {
    const token = localStorage.getItem("token");
    if (token) {
      const userInfo: TokenPayload = getTokenInfo(token);
      if(userInfo.isValid){
        setChecked(true);
      }
    } else {
      setChecked(false);
      localStorage.removeItem("token");
      localStorage.removeItem("chatbotToken");
      localStorage.removeItem("refreshToken");
      localStorage.removeItem("expirationDurationInSec");
      router.push("/auth/jwt/login")
    }
    setChecked(true);
  }, []);

  useEffect(() => {
    check();
  }, [check]);

  return <>{children}</>;
}
