"use client";

import { useEffect, useReducer, useState } from "react";
import { AuthUserType, ActionMapType, AuthStateType } from "../types";
import { getTokenInfo } from "@/utils/token";
import { useRouter } from "next/navigation";
import { IUser, RequestLoginActivity } from "@/shared/types/user";
import {
  ChangingLogingActivity,
  UserByEmail,
} from "@/shared/api/user";

// ----------------------------------------------------------------------

type Props = {
  children: React.ReactNode;
};

export const AuthProvider = ({ children }: Props) => {
  const router = useRouter();

  // State to hold fetched user data
  const [userState, setUserState] = useState<IUser | null>(null);

  const accessToken =
    typeof window !== "undefined" ? localStorage.getItem("token") : null;
  const storedUserInfo = accessToken ? getTokenInfo(accessToken) : null;

  useEffect(() => {
    const fetchUserData = async () => {
      try {
        if (storedUserInfo) {
          if (storedUserInfo?.email !== "") {
            const response = await UserByEmail(storedUserInfo.email);
            const fetchedUserData = response.data;
            setUserState(fetchedUserData);
          }
        }
      } catch (error) {
        console.error("Error fetching user data:", error);
      }
    };

    fetchUserData();
  }, []);

  useEffect(() => {
    const initialize = async () => {
      if (accessToken && storedUserInfo) {
        if (userState?.activityLog !== undefined) {
          if (!storedUserInfo.isValid || !userState.activityLog) {
            try {
              const requestLoginActivity: RequestLoginActivity = {
                email: storedUserInfo.email,
                activityLog: false,
              };
              const result = await ChangingLogingActivity(requestLoginActivity);
              if (result.status === 200) {
                localStorage.removeItem("token");
                localStorage.removeItem("chatbotToken");
                localStorage.removeItem("refreshToken");
                localStorage.removeItem("expirationDurationInSec");
                router.push("/auth/jwt/login"); 
              } else {
                console.error(
                  "Failed to update activity log. Status:",
                  result.status
                );
              }
            } catch (error) {
              console.error("Error updating activity log:", error);
            }
          }
        }
      } else {
        router.push("/auth/jwt/login");
      }
    };

    initialize();
  }, [accessToken, storedUserInfo, userState?.activityLog]);

  return <>{children}</>;
};
