"use client"

import React, { createContext, useContext, useState, useEffect, ReactNode, useCallback } from "react";

import usePolling from "@/hooks/use-polling";
import { ILive } from "@/shared/types/live";
import { SnackbarProvider } from "notistack";
import { SplashScreen } from "@/shared/components/loading-screen";
import { useGetLive } from "@/shared/api/live";

type LiveDetailsContextType = {
    liveData: ILive | null;
}

const LiveDetailsContext = createContext<LiveDetailsContextType>({ liveData: null });

interface LiveStatisticsProviderProps {
    liveId: string;
    children: ReactNode;
}

export const LiveDetailsProvider: React.FC<LiveStatisticsProviderProps> = ({ children, liveId }) => {
    const { liveData, liveIsLoading } = useGetLive(liveId);

    return (
        <LiveDetailsContext.Provider value={{ liveData }}>
            <>{
                liveIsLoading ? <SplashScreen /> : <SnackbarProvider>

                    {children}
                </SnackbarProvider>
            }</>
        </LiveDetailsContext.Provider>
    );
};


export const useLiveData = (): ILive => {
    const { liveData } = useContext(LiveDetailsContext);
    return liveData as ILive;
}

