export enum ShippingMethodType {
  FreeShipping = 'FreeShipping',
  FlatRate = 'FlatRate',
  PointOfSale = 'PointOfSale',
  ColissimoWithoutSignature = 'ColissimoWithoutSignature',
  ColissimoWithSignature = 'ColissimoWithSignature',
  MondialRelay = 'MondialRelay',
}

export const shippingMethodTypeLabels = {
  [ShippingMethodType.FreeShipping]: 'Livraison gratuite',
  [ShippingMethodType.FlatRate]: 'Forfait',
  [ShippingMethodType.PointOfSale]: 'Point de vente',
  [ShippingMethodType.ColissimoWithoutSignature]: 'Colissimo sans signature',
  [ShippingMethodType.ColissimoWithSignature]: 'Colissimo avec signature',
  [ShippingMethodType.MondialRelay]: 'Mondial Relay - InPost',
};



export type IShippingAreaItem = {
  id: string;
  name: string;
  order: number;
  regionList: string[];
  shippingMethodList: ShippingMethod[];
};


export interface ShippingMethod {
  id: string;
  name: string;
  description: string;
  active: boolean;
  ordre?: number;
  type: ShippingMethodType;
  shippingAreasName: string[];
  shippingAreaRegions: string[];
};

export interface FreeShipping extends ShippingMethod {
  requires: RequiresFreeShipping;
  minOrderAmount: number;
  applyMinOrderRuleBeforePromoCodeDiscount: boolean;
};

export interface FlatRate extends ShippingMethod {
  tvaStatut: boolean;
  cost: number;
  costHeavyShippingClass: number;
  costNoShippingClass: number;
  calculationType: CalculationType;
};


export interface Colissimo extends ShippingMethod {
  signature: boolean;
  alwaysFree: boolean;
  nameFreeShipping: string;
  shippingClassExcludedList: ShippingClass[];
  freeShippingClassList: ShippingClass[];
  freeIfOneProductHaveFreeShippingClass: boolean;
  deliveryCostColissimoList: DeliveryCostColissimo[];
  deliveryReductionColissimoList: DeliveryReductionColissimo[];
};

export type DeliveryCostColissimo = {
  id: string | null;
  fromWeight: number | null;
  toWeight: number | null;
  fromPrice: number | null;
  toPrice: number | null;
  shippingClassId: string | null;
  cost: number | null;
  checked?: boolean;
}

export type DeliveryReductionColissimo = {
  id: string | null;
  nbrProducts: number | null;
  percentageReduction: number | null;
  checked?: boolean;
}

export interface MondialRelay extends ShippingMethod {
  amountFreeShipping: number;
  nameFreeShipping: string;
  mondialRelayMode: MondialRelayMode;
  deliveryCostMondialRelayList: DeliveryCostMondialRelay[];
};

export type DeliveryCostMondialRelay = {
  id: string | null;
  weightCart: number | null;
  weightPackaging: number | null;
  cost: number | null;
  checked?: boolean;
}

export interface PointOfSale extends ShippingMethod {

  tvaStatut: boolean;
  cost: number;
};

export type MondialRelayCostDelivery = {
  id: string;
  weightCart: number;
  weightPackaging: number;
  cost: number
}

export type ShippingClass = {
  id: string;
  name: string;
  code: string;
  description: string;
  productAssigned?: number;
};

export type ShippingRules = {
  shippingDestinationType: ShippingDestinationType;
  shippingCostCalculatorCartPage: boolean;
  hideShippingCostsUntilAnAddressIsProvided: boolean;
};

export enum ShippingDestinationType {
  SHIPPING_ADRESS_DEFAULT = 'SHIPPING_ADRESS_DEFAULT',
  FACTURATION_ADRESS_DEFAULT = 'FACTURATION_ADRESS_DEFAULT',
  FACTURATION_ADRESS_FORCE = 'FACTURATION_ADRESS_FORCE',
}

//Select components value
export enum RequiresFreeShipping {
  NOTHING = 'NOTHING',
  PROMO_CODE = 'PROMO_CODE',
  MINIMUM_ORDER_AMOUNT = 'MINIMUM_ORDER_AMOUNT',
  PROMO_CODE_OR_MINIMUM_ORDER_AMOUNT = 'PROMO_CODE_OR_MINIMUM_ORDER_AMOUNT',
  PROMO_CODE_AND_MINIMUM_ORDER_AMOUNT = 'PROMO_CODE_AND_MINIMUM_ORDER_AMOUNT',
}

export const requiresFreeShippingLabels = {
  [RequiresFreeShipping.NOTHING]: 'Aucun prérequis',
  [RequiresFreeShipping.PROMO_CODE]: 'Un code promo d’expédition gratuite valide',
  [RequiresFreeShipping.MINIMUM_ORDER_AMOUNT]: 'Montant minimum de commande',
  [RequiresFreeShipping.PROMO_CODE_OR_MINIMUM_ORDER_AMOUNT]: 'Montant minimum de commande ou un code promo',
  [RequiresFreeShipping.PROMO_CODE_AND_MINIMUM_ORDER_AMOUNT]: 'Montant minimum de commande et un code promo',
};

export enum CalculationType {
  BY_CLASS = 'BY_CLASS',
  BY_ORDER = 'BY_ORDER',
}

export const calculationTypeLabels = {
  [CalculationType.BY_CLASS]: 'Par classe : frais d’envoi pour chaque classe d’expédition',
  [CalculationType.BY_ORDER]: 'Par commande : frais d’envoi pour la classe d’expédition la plus coûteuse',
};

export enum MondialRelayMode {
  MED = 'MED',
  APM = 'APM',
  HOM = 'HOM',
  PRL = 'PRL',
  HOC = 'HOC',
  HOD = 'HOD',
  OMR = 'OMR'
}

export const MondialRelayModeLabels = {
  [MondialRelayMode.MED]: '24R/MED - livraison en Point Relais®',
  [MondialRelayMode.APM]: '24R/APM - livraison en Lockers',
  [MondialRelayMode.HOM]: 'HOM - livraison domicile HOME',
  [MondialRelayMode.PRL]: '(obsolète) 24R - livraison en Point Relais® et lockers',
  [MondialRelayMode.HOC]: 'HOC - livraison HOC (indisponible avec l’offre Start)',
  [MondialRelayMode.HOD]: 'HOD - livraison HOD (indisponible avec l’offre Start)',
  [MondialRelayMode.OMR]: 'Livraison hors Mondial Relay - InPost',
};




// ----------------------------------------------------------------------

export type IOrderColissimoItem = {
  id: string;
  date: Date;
  idClient: string;
  adresse: string;
  pays: string;
  shippingMethod: ShippingMethodType;
  status: string;
};

export type IOrderColissimoTableFilterValue = string | string[] | Date | null;

export type IOrderColissimoTableFilters = {
  country: string[];
  method: string[];
  status: string[];
  etiquette: string[];
  startDate: Date | null;
  endDate: Date | null;
};


//----------------

export type IColisColissimoItem = {
  id: string;
  trackingNumber: string;
  etiquetteCreatedAt: Date;
  orderCreatedAt: Date;
  country: string;
  shippingMethod: ShippingMethodType;
};



//-----------------

export type IHistoricBordereauColissimoItem = {
  id: string;
  colisNumber: number;
  orderIds: string[];
  trackingNumber: string;
  createdAt: Date;
};

//---------------

export type EmailConfig = {
  subject: string;
  description: string;
}

// ----------------------------------------------------------------------

export enum MethodMondialRelayType {
  PointVente = 'Point de vente',
  FlexibleShipping = 'Flexible Shipping',
  MondialRelayInPostOfficiel = 'Mondial Relay - InPost Officiel',
  NotApplicable = 'N/A',
}
export type IMethodMondialRelayItem = {
  id: string;
  name: string;
  type: MethodMondialRelayType;
  shippingArea: IShippingAreaItem;
  shippingMode: MondialRelayMode;
};


// ----------------------------------------------------------------------

export type IOrderMondialRelayItem = {
  id: string;
  status: IOrderMondialRelayStatus;
  shippingMode: MondialRelayMode;
  dateCreation: Date;
  expedition: string;
  address: string;
  weight: number;
  expeditionNumber: string;
  delivery: string;
};

export type IOrderMondialRelayTableFilterValue = string | string[] | Date | null;

export type IOrderMondialRelayTableFilters = {
  shippingMode: string[];
  status: string[];
  dateCreation: Date | null;
};

export enum IOrderMondialRelayStatus {
  WaitingForPayment = "Attente paiement",
  InProgress = "En cours",
  Pending = "En attente",
};

//-------------------------------

export type ExpeditionMondialRelayTableFilterValue = string | string[] | Date | null;

export type ExpeditionMondialRelayTableFilters = {
  shippingMode: string[];
  status: string[];
  startDate: Date | null;
  endDate: Date | null;
};