import { AddressType } from "@/shared/types/user";
import { ShippingMethodType } from "./Shipping";
import { AttributeType, ILiveProductConfig, IStockConfig, ProductType } from "@/shared/types/product";
import { Giftcard } from "./giftcard";
import { IVoucher } from "@/shared/types/voucher";
import { RefundOrderItem } from "./refundOrder";

export enum NoteType {
    PRIVATE = 'PRIVATE',
    TO_CLIENT = 'TO_CLIENT',
    FROM_CLIENT = "FROM_CLIENT"
}

export const noteTypeLabels: Record<NoteType, string> = {
    [NoteType.PRIVATE]: 'Privé',
    [NoteType.TO_CLIENT]: 'Pour le client',
    [NoteType.FROM_CLIENT]: 'du client',
};
export const order_options = {
    FAILED: "Échoué",
    ON_HOLD: "En attente",
    IN_PROGRESS: "En cours",
    FINISHED: "Terminé",
    CANCELED: "Annulé",
    PARTIALLY_REFUNDED: "Remboursé partiellement",
    REFUNDED: "Remboursé",
    DELETED: "Supprimé",
};

export enum ItemSource {
    LIVE = 'LIVE',
    WEB = 'WEB',
}

export const itemSourceLabels = {
    [ItemSource.LIVE]: 'Live',
    [ItemSource.WEB]: 'Site',
};

export enum OrderStatus {
    FAILED = 'FAILED',
    ON_HOLD = 'ON_HOLD',
    IN_PROGRESS = 'IN_PROGRESS',
    FINISHED = 'FINISHED',
    CANCELED = 'CANCELED',
    REFUNDED = 'REFUNDED',
    PARTIALLY_REFUNDED = 'PARTIALLY_REFUNDED',
    DELETED = 'DELETED',
}

export const orderStatusLabels = {
    [OrderStatus.FAILED]: 'Échoué',
    [OrderStatus.ON_HOLD]: 'En attente',
    [OrderStatus.IN_PROGRESS]: 'En cours',
    [OrderStatus.FINISHED]: 'Terminé',
    [OrderStatus.CANCELED]: 'Annulé',
    [OrderStatus.PARTIALLY_REFUNDED]: 'Remboursé partiellement',
    [OrderStatus.REFUNDED]: 'Remboursé',
    [OrderStatus.DELETED]: 'Supprimé',
};

export const OrderStatusList = [
    OrderStatus.FAILED,
    OrderStatus.ON_HOLD,
    OrderStatus.IN_PROGRESS,
    OrderStatus.FINISHED,
    OrderStatus.CANCELED,
    OrderStatus.PARTIALLY_REFUNDED,
    OrderStatus.REFUNDED,
    OrderStatus.DELETED
];

export enum OrderOrigin {
    LIVE = 'LIVE',
    WEB = 'WEB',
}

export const orderOriginLabels = {
    [OrderOrigin.LIVE]: 'Live',
    [OrderOrigin.WEB]: 'Web',
};

export interface EditHistory {
    id: number;
    message: string;
    userId: number;
    createdAt: Date;
    order: Order;
}

export interface Note {
    id: number;
    order: Order;
    content: string;
    createdAt: Date;
    noteType: NoteType;
}

export interface OrderLine {
    id: string;
    order: Order;
    productId: string;
    productName: string;
    productUgs: string;
    productImagePath: string;
    quantity: number;
    subTotalPrice: number;
    totalPrice: number;
    totalPromoCodeDiscounts: number;
    source: ItemSource;
    productType: ProductType;
}

export interface OrderStatusHistory {
    id: string;
    oldOrderStatus: OrderStatus;
    newOrderStatus: OrderStatus;
    createdAt: Date;
    userId: string;
    OrderId: string;
}

export type OrderAddress = {
    id?: number;
    firstName: string;
    lastName: string;
    companyName: string;
    email: string;
    phoneNumber: number;
    street: string;
    home: string;
    city: string;
    zipCode: string;
    country: string;
    addressType: AddressType;
}


export interface OrderWithClientDetails extends Order {
    clientFullName: string;
    clientEmail: string;
}
export interface Order {
    id: string;
    clientId: string;
    userId: string;
    createdAt: Date;
    status: OrderStatus;
    weight: number;
    width: number;
    length: number;
    height: number;
    orderLines: OrderLine[];
    sousTotal: number;
    totalPriceHT: number;
    tva: number;
    total: number;
    totalPromoCodeDiscounts: number;
    shippingMethodId: string;
    shippingMethodType: ShippingMethodType;
    shippingPrice: number;
    shippingAddress: OrderAddress;
    relayRef: string;
    relayPointName: string;
    relayPointAddress1: string;
    relayPointAddress2: string;
    relayPointZipCode: string;
    relayPointCity: string;
    relayPointCountry: string;
    billingAddress: OrderAddress;
    paymentMethodType: string;
    transactionId?: string;
    notes: Note[];
    promoCodeId: string;
    origin: OrderOrigin;
    deviceType: string;
    editHistory: EditHistory[];
    orderStatusHistories: OrderStatusHistory[];
    refundOrders: RefundOrderItem[];
    refunded: boolean;
    giftCards: Giftcard[];
    appliedGiftCardCode: string;
    giftCardBalanceUsed: number;
    appliedVoucher: IVoucher;
    appliedVoucherCode: string;
    voucherBalanceUsed: number;
}
export interface IOrderPage {
    content: OrderWithClientDetails[];
    pageable: {
        sort: {
            empty: boolean;
            sorted: boolean;
            unsorted: boolean;
        };
        offset: number;
        pageNumber: number;
        pageSize: number;
        unpaged: boolean;
        paged: boolean;
    };
    totalPages: number;
    totalElements: number;
    last: boolean;
    sort: {
        empty: boolean;
        sorted: boolean;
        unsorted: boolean;
    };
}


export interface IVariationItem {
    id?: string;
    ugs: string;
    name: string;
    description: string;
    image?: number;
    mainImagePath?: string;
    imagesIDs?: number[];
    imagesPaths?: string[];
    productId?: number;
    regularPrice: number;
    promoPrice?: number;
    purchasePrice?: number;
    stockAlert: number;
    publishWeb: boolean;
    publishLive: boolean;
    weight: number;
    lengthP: number;
    widthP: number;
    heightP: number;
    shippingClassId?: number;
    emplacement: string,
    stockLiveConfig?: IStockConfig;
    stockWebConfig?: IStockConfig;
    liveProductConfigs?: ILiveProductConfig;
    variationAttributes: IVariationAttribute[];
}

export interface IVariationAttribute {
    id: string;
    attribute: IAttribute;
    termColor: IDetailsTermColorDTO | null;
    termLabel: IDetailsTermLabelDTO | null;
    termImage: IDetailsTermImageDTO | null;
    termChoix: IDetailsTermChoixDTO | null;
}

export interface IAttribute {
    id: string;
    name: number;
    identifiant: string;
    attributeType: AttributeType;
}

export interface IDetailsTermColorDTO {
    id: string;
    nom: string;
    color: string;
    description: string;
    slug: string;
}

export interface IDetailsTermLabelDTO {
    id: string;
    nom: string;
    description: string;
    slug: string;
}

export interface IDetailsTermImageDTO {
    id: string;
    nom: string;
    image: string;
    description: string;
    slug: string;
}

export interface IDetailsTermChoixDTO {
    id: string;
    nom: string;
    description: string;
    slug: string;
}
