import { ICategory } from "@/shared/types/category";
import { IProductListItem } from "@/shared/types/product";

export type IPromocodeFilterValue = string | string[] | Date | null;

export type IPromocodeFilter = {
   
    promoCodeType: string[];
    Category: string[];
    startDate: Date | null;
    endDate: Date | null;

};

export type Promocode = {
    
    id?: number;
    code: string;
    promoCodeType: PromocodeType ;
    valueCode: number;
    description: string;
    productsIncludedIds: number[];
    usage: number;
    usageLimit: number;
    startDate: Date;
    freeShipping: boolean;
    uniquePromoCode: boolean;
    expirationDate: Date;
    categoriesIncludedIds: number[];
    categoriesIncluded: ICategory[];
    categoriesExcluded: ICategory[];
    productsIncluded: IProductListItem[];
    productsExcluded: IProductListItem[];
    minAmount: number;
    productsExcludedIds: number[];
    categoriesExcludedIds: number[];
    isReferral:boolean;
};

export enum PromocodeType {
    Remisepanier = 'DISCOUNT_PER_CART',
    RemiseProduit = 'DISCOUNT_PER_PRODUCT',
    RemisePourcentage = 'PERCENTAGE_PER_CART',
};

export function getPromoCodeLabel(promoCodeType: PromocodeType): string {
    switch (promoCodeType) {
      case PromocodeType.Remisepanier:
        return 'Remise sur Panier';
      case PromocodeType.RemiseProduit:
        return 'Remise sur Produit';
      case PromocodeType.RemisePourcentage:
        return 'Remise en Pourcentage';
      default:
        return 'Type de promotion inconnu'; 
    }
  }

export enum Category {
    tous = 'tous',
    vetements = 'vetements',
    chaussures = 'chaussures',
    accessoires = 'accessoires',
    bijoux = 'bijoux',
};