import { ICategory } from "@/shared/types/category";
import { ProductType } from "@/shared/types/product";

export type PromoCodeTableFilterValue = string | string[] | Date | null;

export type PromoCodeTableFilters = {
  name: string;
  promoCodeType: string;
  category: string[];
  startDate: Date | null;
  endDate: Date | null;
};

export type PromoCodeItem = {
  id?: string;
  code: string;
  promoCodeType: PromoCodeType;
  valueCode: number;
  description: string;
  usage: number;
  usageLimit: number;
  usageLimitPerClient: number;
  minAmount: number;
  startDate: Date;
  expirationDate: Date;
  uniquePromoCode: boolean;
  productsIncludedIds: string[];
  productsExcludedIds: string[];
  variationsIncludedIds: string[];
  variationsExcludedIds: string[];
  categoriesIncludedIds: string[];
  categoriesExcludedIds: string[];
  productsIncluded: ProductPromoCode[];
  productsExcluded: ProductPromoCode[];
  variationsIncluded: ProductPromoCode[];
  variationsExcluded: ProductPromoCode[];
  categoriesIncluded: ICategory[];
  categoriesExcluded: ICategory[];
  referral:boolean;
};

export enum PromoCodeType {
  DISCOUNT_PER_CART = 'DISCOUNT_PER_CART',
  DISCOUNT_PER_PRODUCT = 'DISCOUNT_PER_PRODUCT',
  PERCENTAGE_PER_CART = 'PERCENTAGE_PER_CART',
};

export const promoCodeTypeLabels = {
  [PromoCodeType.DISCOUNT_PER_CART]: 'Remise sur Panier',
  [PromoCodeType.DISCOUNT_PER_PRODUCT]: 'Remise sur Produit',
  [PromoCodeType.PERCENTAGE_PER_CART]: 'Remise en Pourcentage sur Panier',
};

export const getPromoCodeTypeColor = (promoCodeType: PromoCodeType) => {
  return promoCodeType === PromoCodeType.DISCOUNT_PER_CART ? 'info' : promoCodeType === PromoCodeType.DISCOUNT_PER_PRODUCT ? 'secondary' : 'success';
};

export interface ProductPromoCode {
  id: string;
  name: string;
  ugs: string;
  productType: ProductType;
  regularPrice?: number;
  mainImagePath: string;
  variations: VariationPromoCode[];
}

export interface VariationPromoCode {
  id: string;
  name: string;
  ugs: string;
  productType: ProductType;
  mainImagePath: string;
}

export enum Category {
  tous = 'tous',
  vetements = 'vetements',
  chaussures = 'chaussures',
  accessoires = 'accessoires',
  bijoux = 'bijoux',
};
