export enum RefundMethod {
    MANUAL = "MANUAL",
    PAYPAL = "PAYPAL",
    CREDIT_CARD = "CREDIT_CARD",
    PAYPLUG = "PAYPLUG"
}

export const refundMethodLabels = {
    [RefundMethod.MANUAL]: 'Manuel',
    [RefundMethod.PAYPAL]: 'PayPal',
    [RefundMethod.CREDIT_CARD]: 'Carte de crédit',
    [RefundMethod.PAYPLUG]: 'PayPlug'
};

export const getRefundMethodColor = (refundMethod: RefundMethod) => {
    switch (refundMethod) {
        case RefundMethod.MANUAL:
            return "info";
        case RefundMethod.PAYPAL:
            return "success";
        case RefundMethod.CREDIT_CARD:
            return "warning";
    }
}

export enum RefundReason {
    CUSTOMER_RETURN = "CUSTOMER_RETURN",
    STOCK_ERROR = "STOCK_ERROR",
    DEFECT = "DEFECT"
}

export const refundReasonLabels = {
    [RefundReason.CUSTOMER_RETURN]: 'Retour client',
    [RefundReason.STOCK_ERROR]: 'Erreur de stock',
    [RefundReason.DEFECT]: 'Défaut',
};

export const getRefundReasonColor = (refundReason: RefundReason) => {
    switch (refundReason) {
        case RefundReason.CUSTOMER_RETURN:
            return "error";
        case RefundReason.STOCK_ERROR:
            return "warning";
        case RefundReason.DEFECT:
            return "info";
    }
}

export type IRefundOrderTableFilterValue = string | Date | RefundMethod[] | null;

export type IRefundOrderTableFilters = {
    keyword: string;
    refundMethods: RefundMethod[];
    startDate: Date | null;
    endDate: Date | null;
    page: number;
    pageSize: number;
};

export interface RefundOrderLineRequest {
    amountToRefund: number;
    quantityToRefund: number;
    orderLineId: string;
}

export type CreateRefundOrderRequest = {
    userId: string;
    clientId: string;
    refundOrderLines: RefundOrderLineRequest[];
    shippingAmountToRefund: number;
    totalAmountToRefund: number;
    refundMethod: RefundMethod;
    refundReason: RefundReason;
    orderId: string;
}

export interface RefundOrderItem {
    id: string;
    createdAt: Date;
    updatedAt: Date;
    userId: string;
    userName: string;
    clientId: string;
    clientName: string;
    refundOrderLines: RefundOrderLineItem[];
    shippingAmountToRefund: number;
    totalAmountToRefund: number;
    totalPriceHT: number;
    tva: number;
    refundMethod: RefundMethod;
    refundReason: RefundReason;
    orderId: string;
}

export type RefundOrderLineItem = {
    id: string;
    refundOrderId: string;
    amountToRefund: number;
    quantityToRefund: number;
    orderLineId: string;
}
