import { ProductType } from "@/shared/types/product";

export interface SaleOrder {
    id: string;
    createdUserId?: string;
    confirmedUserId?: string;
    createdAt: Date;
    deliveryDate?: Date;
    totalPrice: number;
    totalQuantity: number;
    confirmationDate?: Date;
    supplierId?: string;
    supplierName?: string;
    driverId?: string;
    saleOrderItems: SaleOrderItem[];
}

export interface SaleOrderItem {
    id: string;
    productId: string;
    productName: string;
    productUgs: string;
    productType: ProductType;
    productPrice: number;
    quantity: number;
    totalPrice: number;
    saleOrderId?: string;
}

export interface SaleOrderPage
{
    saleOrder:SaleOrder;
    supplierName:string;

}


export interface ISaleOrderPage {
  content: SaleOrderPage[];
  pageable: {
    sort: {
      empty: boolean;
      sorted: boolean;
      unsorted: boolean;
    };
    offset: number;
    pageNumber: number;
    pageSize: number;
    unpaged: boolean;
    paged: boolean;
  };
  totalPages: number;
  totalElements: number;
  last: boolean;
  sort: {
    empty: boolean;
    sorted: boolean;
    unsorted: boolean;
  };
}

export type SearchSaleOrderParams ={
    name?: string;
    creationDate?: Date | null;
    page?: number;
    size?: number;
    sortBy?: string;
    sortDir?: string;
  }


export interface ConfirmSaleOrderRequest {
    id?: string;
    saleOrderId: string;
    confirmedBy: string;
    deliveryDate: string;
    supplierId: string;
    driverId: string;
    orderItems: ConfirmSaleOrderItemRequest[];
}

export interface ConfirmSaleOrderItemRequest {
    productId: string;
    quantity: number;
}
