
import { MondialRelayMode, ShippingMethodType } from "@/contexts/types/Shipping";

export enum ShipmentStatus {
    FAILED = 'FAILED',
    WAITING_FOR_PAYMENT = 'WAITING_FOR_PAYMENT',
    PENDING = 'PENDING',
    IN_PROGRESS = 'IN_PROGRESS',
    SHIPPED = 'SHIPPED',
    DELIVERED = 'DELIVERED',
    CANCELED = 'CANCELED',
}

export const shipmentStatusLabels = {
    [ShipmentStatus.FAILED]: 'Échec de l\'expédition',
    [ShipmentStatus.WAITING_FOR_PAYMENT]: 'En attente de paiement',
    [ShipmentStatus.PENDING]: 'En attente',
    [ShipmentStatus.IN_PROGRESS]: 'En cours',
    [ShipmentStatus.SHIPPED]: 'Expédié',
    [ShipmentStatus.DELIVERED]: 'Livré',
    [ShipmentStatus.CANCELED]: 'Annulé',
};

export enum MondialRelayShipmentStatus {
    SHIPMENT_CREATED = 'SHIPMENT_CREATED',
    REGISTERED_PACKAGE = 'REGISTERED_PACKAGE',
}

export const mondialRelayShipmentStatusLabels = {
    [MondialRelayShipmentStatus.SHIPMENT_CREATED]: 'Expédition créée',
    [MondialRelayShipmentStatus.REGISTERED_PACKAGE]: 'Colis enregistré',
};

export interface Shipment {
    id: number;
    createdAt: Date;
    updatedAt: Date;
    clientId: number;
    userId: number;
    orderId: number;
    shipmentStatus: ShipmentStatus;
    total: number;
    shippingMethodType: ShippingMethodType;
    shippingFirstName: string;
    shippingLastName: string;
    shippingCompanyName?: string;
    shippingEmail: string;
    shippingPhoneNumber: string;
    shippingStreet: string;
    shippingHome: string;
    shippingCity: string;
    shippingZipCode: string;
    shippingCountry: string;
    trackingNumber: string;
}

export interface ShipmentMondialRelay extends Shipment {
    mondialRelayMode: MondialRelayMode;
    mondialRelayShipmentStatus: MondialRelayShipmentStatus;
}

export interface ShipmentColissimo extends Shipment {
    labelCreatedAt: Date;
}


export type ShipmentTableFilterValue = string | string[] | Date | null;

export type ShipmentTableFilters = {
    country: string[];
    shippingMethod: string[];
    status: string[];
    startDate: Date | null;
    endDate: Date | null;
};
