import { LabelColor } from "@/shared/components/label";
import { ProductType } from "@/shared/types/product";

export enum SupplierOrderStatus {
    TO_BE_COLLECTED = 'TO_BE_COLLECTED',
    DELIVERED = 'DELIVERED',
    RECEIVED = 'RECEIVED'
}

export const supplierOrderStatusLabels = {
    [SupplierOrderStatus.TO_BE_COLLECTED]: 'À collecter',
    [SupplierOrderStatus.DELIVERED]: 'Livré',
    [SupplierOrderStatus.RECEIVED]: 'Réceptionné'
};

export const getSupplierOrderStatusColor = (status: SupplierOrderStatus) => {
    switch (status) {
        case SupplierOrderStatus.TO_BE_COLLECTED: return 'warning';
        case SupplierOrderStatus.DELIVERED: return 'success';
        case SupplierOrderStatus.RECEIVED: return 'info';
        default: return 'default';
    }
};

export enum SupplierOrderType {
    NEW_RELEASE_VARIANCE = 'NEW_RELEASE_VARIANCE',
    PREORDER = 'PREORDER',
    PURCHASES = 'PURCHASES',
    MISSING_ITEMS = 'MISSING_ITEMS',
    SECOND_SHIPMENT = 'SECOND_SHIPMENT',
    LIVE_URGENCY = 'LIVE_URGENCY',
    CLAIM = 'CLAIM'
}

export const supplierOrderTypeLabels = {
    [SupplierOrderType.NEW_RELEASE_VARIANCE]: 'Écart nouveauté',
    [SupplierOrderType.PREORDER]: 'Précommande',
    [SupplierOrderType.PURCHASES]: 'Achats',
    [SupplierOrderType.MISSING_ITEMS]: 'Manquants',
    [SupplierOrderType.SECOND_SHIPMENT]: '2e envoi',
    [SupplierOrderType.LIVE_URGENCY]: 'Urgence live',
    [SupplierOrderType.CLAIM]: 'Réclamation'
};

export const getSupplierOrderTypeColor = (type: SupplierOrderType) => {
    switch (type) {
        case SupplierOrderType.NEW_RELEASE_VARIANCE: return 'warning';
        case SupplierOrderType.PREORDER: return 'info';
        case SupplierOrderType.PURCHASES: return 'success';
        case SupplierOrderType.MISSING_ITEMS: return 'default';
        case SupplierOrderType.SECOND_SHIPMENT: return 'error';
        case SupplierOrderType.LIVE_URGENCY: return 'warning';
        case SupplierOrderType.CLAIM: return 'error';
        default: return undefined;
    }
};

export enum GapType {
    LOWER = 'LOWER',
    UPPER = 'UPPER',
    NORMAL = 'NORMAL'
}

export const gapTypeLabels = {
    [GapType.LOWER]: 'Inférieur',
    [GapType.UPPER]: 'Supérieur',
    [GapType.NORMAL]: 'Normal'
};

export enum ReceiptStatus {
    PRODUCT_WILL_BE_COLLECTED_LATER = 'PRODUCT_WILL_BE_COLLECTED_LATER',
    PRODUCT_HAS_BEEN_COLLECTED = 'PRODUCT_HAS_BEEN_COLLECTED',
    PRODUCT_WILL_NEVER_BE_COLLECTED = 'PRODUCT_WILL_NEVER_BE_COLLECTED',
    PRODUCT_RECEIVED_INCOMPLETELY = 'PRODUCT_RECEIVED_INCOMPLETELY'
}

export const receiptStatusLabels = {
    [ReceiptStatus.PRODUCT_WILL_BE_COLLECTED_LATER]: 'Le produit sera récupéré plus tard',
    [ReceiptStatus.PRODUCT_HAS_BEEN_COLLECTED]: 'Le produit a été récupéré',
    [ReceiptStatus.PRODUCT_WILL_NEVER_BE_COLLECTED]: 'Le produit ne sera jamais récupéré',
    [ReceiptStatus.PRODUCT_RECEIVED_INCOMPLETELY]: 'Le produit a été reçu de manière incomplète'
};

export const getReceiptStatusColor = (status: ReceiptStatus) => {
    switch (status) {
        case ReceiptStatus.PRODUCT_HAS_BEEN_COLLECTED:
            return "success";
        case ReceiptStatus.PRODUCT_WILL_BE_COLLECTED_LATER:
            return "info";
        case ReceiptStatus.PRODUCT_WILL_NEVER_BE_COLLECTED:
            return "error";
        case ReceiptStatus.PRODUCT_RECEIVED_INCOMPLETELY:
            return "warning";
        default:
            return "default";
    }
};

export enum CollectionStatus {
    PRODUCT_WILL_BE_COLLECTED_LATER = 'PRODUCT_WILL_BE_COLLECTED_LATER',
    PRODUCT_HAS_BEEN_COLLECTED = 'PRODUCT_HAS_BEEN_COLLECTED',
    PRODUCT_WILL_NEVER_BE_COLLECTED = 'PRODUCT_WILL_NEVER_BE_COLLECTED',
    PRODUCT_RECEIVED_INCOMPLETELY = 'PRODUCT_RECEIVED_INCOMPLETELY'
}

export const collectionStatusLabels = {
    [CollectionStatus.PRODUCT_WILL_BE_COLLECTED_LATER]: 'Le produit sera récupéré plus tard',
    [CollectionStatus.PRODUCT_HAS_BEEN_COLLECTED]: 'Le produit a été récupéré',
    [CollectionStatus.PRODUCT_WILL_NEVER_BE_COLLECTED]: 'Le produit ne sera jamais récupéré',
    [CollectionStatus.PRODUCT_RECEIVED_INCOMPLETELY]: 'Le produit a été reçu de manière incomplète'
};

export const getCollecteStatusColor = (status: CollectionStatus) => {
    switch (status) {
        case CollectionStatus.PRODUCT_HAS_BEEN_COLLECTED:
            return "success";
        case CollectionStatus.PRODUCT_WILL_BE_COLLECTED_LATER:
            return "info";
        case CollectionStatus.PRODUCT_WILL_NEVER_BE_COLLECTED:
            return "error";
        case CollectionStatus.PRODUCT_RECEIVED_INCOMPLETELY:
            return "warning";
        default:
            return "default";
    }
};

export interface SupplierOrder {
    id: string;
    createdAt: Date;
    createdBy: string;
    deliveryDate?: Date;
    totalPrice: number;
    totalQuantity: number;
    supplierOrderStatus: SupplierOrderStatus;
    supplierOrderType: SupplierOrderType;
    supplierOrderHistories?: SupplierOrderHistory[];
    supplierId?: string;
    supplierName?: string;
    supplierEmail?: string;
    supplierFullAddress?: string;
    supplierPhoneNumber?: string;
    driverId?: string;
    driverName?: string
    supplierOrderItems: SupplierOrderItem[];
    comment?: string;
    zebraFileGenerated?: boolean;
}

export interface SupplierOrderHistory {
    id: string;
    createdAt: Date;
    newStatus: SupplierOrderStatus;
    oldStatus: SupplierOrderStatus;
    userId: string;
    supplierOrderId: number;
}

export interface SupplierOrderItem {
    id: string;
    productId: string;
    productName: string;
    productUgs: string;
    productType: ProductType;
    productPrice: number;
    quantity: number;
    totalPrice: number;
    receiptStatus: ReceiptStatus;
    collectionStatus: CollectionStatus;
    gapType: GapType;
    gap: number;
    comment?: string;
    supplierOrderId: string;
}

export type ISupplierOrderTableFilterValue = string | string[] | Date | null;

export type ISupplierOrderTableFilters = {
    product?: string;
    driverEmail?: string;
    supplierEmail?: string;
    status?: string;
    startDate?: Date | null;
    endDate?: Date | null;
    page?: number;
    size?: number;
};


export interface SaveSupplierOrderRequest {
    id?: string;
    supplierId: string;
    driverId: string;
    createdAt: Date;
    deliveryDate: Date;
    supplierOrderStatus: SupplierOrderStatus;
    supplierOrderItems: SaveSupplierOrderProductItem[];
    supplierOrderType: SupplierOrderType;
}

export type SaveSupplierOrderProductItem = {
    id?: string;
    productId: string;
    productName: string;
    productType: ProductType;
    productPrice: number;
    totalPrice: number;
    quantity: number;
    comment: string;
    receiptStatus?: ReceiptStatus;
    collectionStatus?: CollectionStatus;
    gap?: number;
    gapType?: GapType;
};


export interface SupplierOrderProduct {
    id: string;
    name: string;
    ugs: string;
    mainImagePath: string;
    productType: ProductType;
    regularPrice: number;
    purchasePrice: number;
    variations: SupplierOrderProductVariation[];
}

export interface SupplierOrderProductVariation {
    id: string;
    name: string;
    ugs: string;
    quantity: number;
    mainImagePath: string;
    regularPrice: number;
    purchasePrice: number;
    productId: string;
}



export type ISupplierOrderTableToDriverFilterValue = string | string[] | Date | null;

export type ISupplierOrderTableToDriverFilters = {
    name: string;
    status: string;
    startDate: Date | null;
    endDate: Date | null;
    supplier: string[];
    deliveryDate: Date | null;
};

export interface UpdateSupplierOrderStatus {
    userId: string;
    supplierOrderId: string;
    supplierOrderStatus: SupplierOrderStatus;
}

export interface UpdateCollectionStatuses {
    supplierOrderId: string;
    updateCollectionStatusList: UpdateCollectionStatusList[];
}

export interface UpdateCollectionStatusList {
    supplierOrderItemId: string;
    collectionStatus: CollectionStatus;
}

export interface UpdateReceiptStatuses {
    supplierOrderId: string;
    updateReceiptStatusListList: UpdateReceiptStatusList[];
}

export interface UpdateReceiptStatusList {
    supplierOrderItemId: string;
    receiptStatus: ReceiptStatus;
}

export interface UpdateAllStatuses {
    userId: string;
    supplierOrderId: string;
    supplierOrderStatus?: SupplierOrderStatus;
    itemCollectionStatuses?: UpdateCollectionStatusList[];
}

export interface DiscrepancyDeclaration {
    userId: string;
    supplierOrderId: string;
    supplierOrderItemId: string;
    declaredGap: number;
    gapType: GapType;
    deliveryDate: string;
}


export type SaveSupplierItemRequest = {
    pseudo: string;
    firstName: string | null;
    lastName: string | null;
    phoneNumber: string;
    email: string;
    password: string;
    status: string | null;
    street: string;
    city: string;
    country: string;
};
export type SaveSupplierRequest = {
    companyName: string;
    companyEmail: string;
    companyPhoneNumber: string;
    companyStreet: string;
    companyCity: string;
    companyCountry: string;
    siretNumber: number;
    supplierName: string;
    supplierLastName: string;
    supplierPhoneNumber: string;
    supplierEmail: string;
    supplierZone: string;
};

export type SupplierDTO = {
    id: string;
    companyName: string;
    companyEmail: string;
    companyPhoneNumber: string;
    companyStreet: string;
    companyCity: string;
    companyCountry: string;
    siretNumber: number;
    supplierName: string;
    supplierLastName: string;
    supplierPhoneNumber: string;
    supplierEmail: string;
};
export type IDriverSupplierItem = {
    id?: string;
    name: string;
    company?: string;
    primary?: boolean;
    fullAddress: string;
    phoneNumber?: string;
    addressType?: string;
    supplier?: string;
};
export type ISupplierItemTableFilterValue = string | string[] | Date | null;

export type ISupplierItemTableFilters = {
    name: string;
};

export interface IDriverDto {
    id: number,
    name: string

}

export interface ISupplierOrderDetails {
    supplierOrderDTO: SupplierOrder,
    supplierDTO?: SupplierDTO,
    driverDTO?: IDriverDto

}


export type SearchSupplierOrderParams = {
    product?: string;
    driverEmail?: string;
    supplierEmail?: string;
    status?: string;
    startDate?: Date | null;
    endDate?: Date | null;
    page?: number;
    size?: number;
}

export interface ISupplierOrderPage {
    content: ISupplierOrderDetails[];
    pageable: {
        sort: {
            empty: boolean;
            sorted: boolean;
            unsorted: boolean;
        },
        offset: number;
        pageNumber: number;
        pageSize: number;
        unpaged: boolean;
        paged: boolean;
    },
    totalPages: number,
    totalElements: number,
    last: boolean;
    sort: {
        empty: boolean;
        sorted: boolean;
        unsorted: boolean;
    };
}
