//@hook/use-async

import { useState, useCallback } from 'react';

type AsyncFunction = (...args: any[]) => Promise<void>;

const useAsync = (asyncFunction: AsyncFunction) => {
  const [loading, setLoading] = useState<boolean>(false);

  const execute = useCallback(
    async (...args: any[]) => {
      setLoading(true);
      try {
        await asyncFunction(...args);
      } catch (error) {
        console.error('Error executing async function:', error);
      } finally {
        setLoading(false);
      }
    },
    [asyncFunction]
  );

  return { loading, execute };
};

export default useAsync;
