import { useRef, useEffect, useCallback } from 'react';

export default function useScroll<T>(items: T[]) {
  const endRef = useRef<HTMLDivElement>(null);
  const isEndVisibleRef = useRef(true);

  const scrollToBottom = useCallback(() => {
    if (endRef.current && isEndVisibleRef.current) {
      endRef.current.scrollIntoView({ behavior: 'smooth' });
    }
  }, []);

  useEffect(() => {
    scrollToBottom();
  }, [items, scrollToBottom]);

  useEffect(() => {
    const observer = new IntersectionObserver(
      (entries) => {
        const [entry] = entries;
        isEndVisibleRef.current = entry.isIntersecting;
      },
      {
        root: null, // relative to the viewport
        threshold: 0.1, // trigger when 10% of endRef is in view
      }
    );

    if (endRef.current) {
      observer.observe(endRef.current);
    }

    return () => {
      if (endRef.current) {
        observer.unobserve(endRef.current);
      }
    };
  }, []);

  return {
    endRef,
  };
}
