import { useState, useEffect, useCallback } from 'react';

const useTimer = (startDate: Date) => {
  const [elapsedTime, setElapsedTime] = useState('00:00:00');

  const calculateTime = useCallback(() => {
    const now = new Date();
    const difference = now.getTime() - startDate.getTime();
    
    const hours = Math.floor(difference / (1000 * 60 * 60));
    const minutes = Math.floor((difference % (1000 * 60 * 60)) / (1000 * 60));
    const seconds = Math.floor((difference % (1000 * 60)) / 1000);

    return `${hours.toString().padStart(2, '0')}:${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}`;
  }, [startDate]);

  const start = useCallback(() => {
    const timer = setInterval(() => {
      setElapsedTime(calculateTime());
    }, 1000);

    return () => clearInterval(timer);
  }, [calculateTime]);

  useEffect(() => {
    const cleanup = start();
    return cleanup;
  }, [start]);

  return [elapsedTime, start] as const;
};

export default useTimer;
