import { useEffect, useState } from "react";
import { IMessageSocketItem } from "@/shared/types/chat-bot";

const SOCKET_URL = process.env.NEXT_PUBLIC_BASE_URL_WEB_SOCKET_URL as string;

export function useWebSocket(userId: string) {
  const [ws, setWs] = useState<WebSocket | null>(null);
  const [messages, setMessages] = useState<{ senderId: string; content: string; timestamp: string }[]>([]);

  useEffect(() => {
    if (!userId) return;

    const websocket = new WebSocket(`${SOCKET_URL}?userId=${userId}`);

    websocket.onopen = () => {
      console.log("✅ WebSocket Connected");
    };

    websocket.onmessage = (event) => {
      console.log("📩 New message:", event.data);
      setMessages((prevMessages) => [...prevMessages, JSON.parse(event.data)]);
    };

    websocket.onclose = () => {
      console.log("❌ WebSocket Disconnected");
    };

    setWs(websocket);

    return () => {
      if (websocket.readyState === 1) { // <-- This is important
        websocket.close();
      }
  }
  }, [userId]);

  const sendMessage = (message: IMessageSocketItem) => {
    if (ws) {
      ws.send(JSON.stringify(message));
    }
  };

  return { messages, sendMessage };
}
