import { add, subDays } from 'date-fns';

import { _mock } from './_mock';
import { _addressBooks } from './_others';
import { IInvoice, IInvoiceItem } from '@/shared/types/invoice';

// ----------------------------------------------------------------------

export const INVOICE_STATUS_OPTIONS = [
  { value: 'attendue', label: 'Attendue' },
  { value: 'reçue', label: 'Reçue' },
];

export const INVOICE_SERVICE_OPTIONS = [...Array(8)].map((_, index) => ({
  id: _mock.id(index),
  name: _mock.productName(index),
  price: _mock.number.price(index),
  image: _mock.image.product(index),

}));

const ITEMS: IInvoiceItem[] = [...Array(3)].map((__, index) => {
  const total = INVOICE_SERVICE_OPTIONS[index].price * _mock.number.nativeS(index);

  return {
    id: _mock.number.nativeS(index), // Ensure id is a number
    total,
    title: _mock.productName(index),
    description: _mock.sentence(index),
    price: INVOICE_SERVICE_OPTIONS[index].price,
    service: INVOICE_SERVICE_OPTIONS[index].name,
    quantity: _mock.number.nativeS(index),
    sizes : _mock.isVariable(index) ? _mock.sizes(index) : [],
    colors : _mock.isVariable(Math.floor(index/2)) ? _mock.colors(index) : [],
    variations: _mock.isVariable(index) ? _mock.variations(index) : [],
    productName: _mock.productName(index),
    productId: Number(_mock.id(index)),
    type: 'SIMPLE', 
  };
});

export const _invoices: IInvoice[] = [...Array(20)].map((_, index) => {
  const taxes = _mock.number.price(index + 1);
  const discount = _mock.number.price(index + 2);
  const shipping = _mock.number.price(index + 3);

  const subTotal = ITEMS.reduce((accumulator, item) => accumulator + item.price * item.quantity, 0);
  const totalAmount = subTotal + taxes - discount - shipping;

  const statusOptions = ['A faire', 'Terminée', 'En cours'];
  const status = statusOptions[index % statusOptions.length];

  return {
    id: _mock.id(index),
    sent: _mock.number.nativeS(index),
    dueDate: add(new Date(), { days: index + 15, hours: index }),
    taxes,
    status,
    subTotal,
    createDate: subDays(new Date(), index),
    discount,
    driver: _mock.fullName(index),
    totalAmount,
    invoiceNumber: `INV-199${index}`,
    shipping,
    items: ITEMS,
    invoiceFrom: _addressBooks[index % _addressBooks.length],
    invoiceTo: _addressBooks[(index + 1) % _addressBooks.length],
  };
});
