
import { _mock } from './_mock';
import { addDays, formatISO, sub } from 'date-fns';
import { ILiveComment, ILiveStatistic, ILiveStatisticsSummary, LiveStatus } from '@/shared/types/live';


const liveStatus = [LiveStatus.ONGOING, LiveStatus.REPLAY, LiveStatus.COMING]

const liveDescriptions = [
  "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam auctor, nunc nec ultricies ultricies, nunc.",
  "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam auctor, nunc nec ultricies ultricies, nunc.",
  "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam auctor, nunc nec ultricies ultricies, nunc.",
]
export const _lives = [...Array(2)].map((_, index) => ({
  id: _mock.id(index),
  title: `test ${index + 1}`,
  moderator: _mock.fullName(index),
  description: liveDescriptions[index],
  startDate: _mock.time(index),
  status: liveStatus[index % 3],
  tags: [...Array(3)].map((_, index) => _mock.tags(index)),
  staging: _mock.boolean(index),
  chat: _mock.boolean(index + 1),
  cache: _mock.boolean(index + 2),
  image: _mock.image.cover(index),
  videoFormat: ['1080p', '720p', '4K'][index % 3]
}));


export type IProduct = {
  id: string;
  image: string;
  reference: string;
  title: string;
  description: string;
  price: number;
};

export const _products = [...Array(20)].map((_, index) => ({
  id: getRandomInteger(1000, 9999).toString(),
  image: _mock.image.cover(index),
  reference: _mock.id(index),
  title: _mock.productName(index),
  description: _mock.sentence(index),
  price: _mock.number.price(index),
}));


function getRandomInteger(min: number, max: number): number {
  return Math.floor(Math.random() * (max - min + 1)) + min;
}

function getRandomFloat(min: number, max: number): number {
  return Math.random() * (max - min + 1) + min;
}


export const generateSingleLiveStatistics = (count: number): ILiveStatisticsSummary => {
  let totalViewers = 0;
  let totalMessages = 0;
  let totalPurchases = 0;

  const totalDurationMinutes = 6 * 60;
  const intervalMinutes = count > 1 ? Math.floor(totalDurationMinutes / (count - 1)) : totalDurationMinutes;

  const statistics: ILiveStatistic[] = Array.from({ length: count }, (_, index) => {
    const viewerCount = getRandomInteger(100, 300);
    const messageCount = getRandomInteger(10, 100);
    const cartAdditionCount = getRandomInteger(10, 90);

    totalViewers += viewerCount;
    totalMessages += messageCount;
    totalPurchases += cartAdditionCount;


    const timestamp = sub(new Date(), { minutes: totalDurationMinutes - (index * intervalMinutes) });

    return {
      timestamp,
      purchases: cartAdditionCount,
      numberOfMessages: messageCount,
      numberOfViewers: viewerCount,
    };
  });

  return {
    totalViewers,
    totalMessages,
    totalPurchases,
    statistics
  };
};


export function generateStatisticsForLives(count: number) {
  const initialStartDate = new Date();
  const stats = [];
  let totalViewers = 0;
  let totalRevenu = 0;
  let totalMessages = 0;
  let totalCartAdditions = 0;
  let totalWatchingHours = 0;



  for (let i = 0; i < count; i++) {
    const startDate = addDays(initialStartDate, i);
    const viewers = 1;
    const revenu = getRandomInteger(40, 100);
    const messages = getRandomInteger(3,5);
    const cartAdditions = getRandomInteger(3, 5);
    const watchingHours = getRandomFloat(0, 0.1);


    totalCartAdditions += cartAdditions;
    totalMessages += messages;
    totalRevenu += revenu;
    totalViewers += viewers;
    totalWatchingHours += watchingHours;


    stats.push({
      id: `${i + 1}`,
      title: `test ${i + 1}`,
      startDate: formatISO(startDate),
      viewers,
      revenu,
      messages,
      cartAdditions,
      watchingHours
    });
  }

  return { stats, total: { totalCartAdditions, totalMessages, totalRevenu, totalViewers, totalWatchingHours, avgWatchingHours: totalWatchingHours / count } };
}


export function generateCommentsForLive(count: number, liveId: string) {
  const comments: ILiveComment[] = []
  for (let i = 0; i < count; i++) {
    let comment: ILiveComment = {
      senderName: _mock.fullName(i),
      content: _mock.sentence(i),
      liveStream: liveId,
      id: i.toString(),
    }
    comments.push(comment);
  }
  return comments;
}