import { sub } from "date-fns";
import { ASSETS_API } from "../../config-global";

import {
  _id,
  _ages,
  _roles,
  _prices,
  _emails,
  _ratings,
  _nativeS,
  _nativeM,
  _nativeL,
  _percents,
  _booleans,
  _sentences,
  _lastNames,
  _fullNames,
  _tourNames,
  _jobTitles,
  _taskNames,
  _postTitles,
  _firstNames,
  _fullAddress,
  _companyNames,
  _productNames,
  _descriptions,
  _phoneNumbers,
  _tags,
  _status,
  _origine,
  _pseudo,
  _categoryName,
  _sector,
  _zone,
  _supplier,
  _commentaire,
} from "./assets";

// Fonction pour générer un ID unique
function generateId() {
  return Math.floor(Math.random() * 1000000);
}

// Fonction pour générer un SKU aléatoire
function generateSku() {
  return Math.random().toString(36).substr(2, 9).toUpperCase();
}

// Fonctions pour générer des couleurs et des tailles aléatoires
function generateRandomColors(): { id: number, value: string }[] {
  const colors = ["Red", "Blue", "Green", "Purple", "Pink"];
  const numberOfColors = Math.floor(Math.random() * (colors.length - 1)) + 1;
  const randomColors: { id: number, value: string }[] = [];

  for (let i = 0; i < numberOfColors; i++) {
    const randomIndex = Math.floor(Math.random() * colors.length);
    if (randomColors.map(color => color.value).includes(colors[randomIndex])) {
      continue;
    }
    randomColors.push({ id: generateId(), value: colors[randomIndex] });
  }

  return randomColors;
}

function generateRandomSizes(): { id: number, value: string }[] {
  const sizes = ["XS", "S", "M", "L", "XL"];
  const numberOfSizes = Math.floor(Math.random() * (sizes.length - 1)) + 1;
  const randomSizes: { id: number, value: string }[] = [];

  for (let i = 0; i < numberOfSizes; i++) {
    const randomIndex = Math.floor(Math.random() * sizes.length);
    if (randomSizes.map(size => size.value).includes(sizes[randomIndex])) {
      continue;
    }
    randomSizes.push({ id: generateId(), value: sizes[randomIndex] });
  }

  return randomSizes;
}

// Fonction pour générer des variations en utilisant les couleurs et tailles générées
function generateRandomVariations() {
  const colors = generateRandomColors();
  const sizes = generateRandomSizes();
  const variations = [];

  for (let i = 0; i < sizes.length; i++) {
    for (let j = 0; j < colors.length; j++) {
      variations.push({
        id: generateId(),
        name: `${sizes[i].value} ${colors[j].value}`,
        quantity: Math.floor(Math.random() * 100), 
        sku: generateSku(),
        price: _prices[Math.floor(Math.random() * _prices.length)], 
        color: colors[j],
        size: sizes[i],
      });
    }
  }

  return variations;
}

export const _mock = {
  id: (index: number) => _id[index],
  time: (index: number) => sub(new Date(), { days: index, hours: index }),
  boolean: (index: number) => _booleans[index],
  role: (index: number) => _roles[index],
  categoryName: (index: number) => _categoryName[index],
  slug: (index: number) => _categoryName[index],
  sector: (index: number) => _sector[index],
  zone: (index: number) => _zone[index],
  supplier: (index: number) => _supplier[index],

  // Text
  taskNames: (index: number) => _taskNames[index],
  pseudo: (index: number) => _pseudo[index],
  postTitle: (index: number) => _postTitles[index],
  jobTitle: (index: number) => _jobTitles[index],
  tourName: (index: number) => _tourNames[index],
  productName: (index: number) => _productNames[index],
  sentence: (index: number) => _sentences[index],
  description: (index: number) => _descriptions[index],
  tags: (index: number) => _tags[index],
  status: (index: number) => _status[index],
  // Contact
  email: (index: number) => _emails[index],
  phoneNumber: (index: number) => _phoneNumbers[index],
  fullAddress: (index: number) => _fullAddress[index],
  origine: (index: number) => _origine[index],
  commentaire: (index: number) => _commentaire[index],
  // Name
  firstName: (index: number) => _firstNames[index],
  lastName: (index: number) => _lastNames[index],
  fullName: (index: number) => _fullNames[index],
  companyName: (index: number) => _companyNames[index],
  // Number
  number: {
    percent: (index: number) => _percents[index],
    rating: (index: number) => _ratings[index],
    age: (index: number) => _ages[index],
    price: (index: number) => _prices[index],
    nativeS: (index: number) => _nativeS[index],
    nativeM: (index: number) => _nativeM[index],
    nativeL: (index: number) => _nativeL[index],
  },
  // Image
  image: {
    cover: (index: number) =>
      `${ASSETS_API}/assets/images/cover/cover_${index + 1}.jpg`,
    avatar: (index: number) =>
      `${ASSETS_API}/assets/images/avatar/avatar_${index + 1}.jpg`,
    travel: (index: number) =>
      `${ASSETS_API}/assets/images/travel/travel_${index + 1}.jpg`,
    company: (index: number) =>
      `${ASSETS_API}/assets/images/company/company_${index + 1}.png`,
    product: (index: number) =>
      `${ASSETS_API}/assets/images/m_product/product_${index + 1}.jpg`,
    portrait: (index: number) =>
      `${ASSETS_API}/assets/images/portrait/portrait_${index + 1}.jpg`,
  },

  // Fonctions pour les couleurs et les tailles
  colors: (index: number) => generateRandomColors(),
  sizes: (index: number) => generateRandomSizes(),
  color: generateRandomColors(),
  size: generateRandomSizes(),
  variations: (index: number) => generateRandomVariations(),
  isVariable: (index: number) => _booleans[index],
};

