import { IOrderStatus, IOrderProductItem, ISupplierOrderItem, IOrderStatusHistory } from "../types/supplierOrder";
import { _mock } from "./_mock";
import {} from "date-fns";

// ----------------------------------------------------------------------

export const OrderStatus = [
  IOrderStatus.Completed,
  IOrderStatus.Pending,
  IOrderStatus.Ongoing
];

export const ORDER_STATUS_OPTIONS = [
  { value: IOrderStatus.Completed, label: "livré" },
  { value: IOrderStatus.Pending, label: "à collecter" },
  { value: IOrderStatus.Ongoing, label: "réceptionné" }
];

const ITEMS = [...Array(3)].map((_, index) => ({
  id: _mock.id(index),
  sku: `16H9UR${index}`,
  quantity: index + 1,
  name: _mock.productName(index),
  coverUrl: _mock.image.product(index),
  price: _mock.number.price(index),
  origine: _mock.origine(index),
}));

export const ETAT_ORDER = [
  {
    group: "État",
    classify: [
      "terminé",
      "à faire",
      "en cours"
    ],
  },
];


export const _orders: ISupplierOrderItem[] = [
  {
    id: '6010',
    orderNumber: '6010',
    createdAt: new Date(),
    deliveryDate: new Date('2024-08-01T11:33:00'), // Add delivery date
    status: IOrderStatus.Completed,
    fullAddress: "19034 Verna Unions Apt. 164 - Honolulu, RI",
    customer: {
      id: '1',
      name: 'Jayvion Simon',
      email: 'nannie_abernathy70@yahoo.com',
      numberphone: '365-374-4961',
      avatarUrl: 'https://example.com/avatar1.jpg',
    },
    items: [
      {
        id: '1',
        sku: '16H9UR0',
        name: 'Nike Air Force 1 NDESTRUKT',
        price: 83.74,
        coverUrl: '',
        quantity: 2,
        origine: 'US',
        variations: [
          {
            color: 'Black',
            quantity: 1,
          },
          {
            color: 'White',
            quantity: 1,
          },
        ],
      },
      {
        id: '2',
        sku: '16H9UR1',
        name: 'Foundations Matte Flip Flop',
        price: 97.14,
        coverUrl: '',
        quantity: 3,
        origine: 'US',
        variations: [
          {
            color: 'Red',
            quantity: 2,
          },
          {
            color: 'Blue',
            quantity: 1,
          },
        ],
      },
    ],
    statusHistory: [
      { status: 'En cours', date: '2024-07-24 10:00' },
      { status: 'Terminé', date: '2024-07-25 15:30' },
    ],
    taxes: 0, // Ensure taxes property is included
  },
  {
    id: '6011',
    orderNumber: '6011',
    createdAt: new Date('2024-07-27T11:33:00'),
    deliveryDate: new Date('2024-08-05T14:00:00'),
    status: IOrderStatus.Pending,
    fullAddress: "1234 Elm Street, Springfield, IL",
    customer: {
      id: '2',
      name: 'Ava Martinez',
      email: 'ava.martinez@example.com',
      numberphone: '555-123-4567',
      avatarUrl: 'https://example.com/avatar2.jpg',
    },
    items: [
      {
        id: '3',
        sku: '20J9UR3',
        name: 'Adidas Ultraboost',
        price: 120.00,
        coverUrl: '',
        quantity: 1,
        origine: 'DE',
        variations: [
          {
            color: 'Black',
            quantity: 1,
          },
        ],
      },
      {
        id: '4',
        sku: '20J9UR4',
        name: 'Reebok Classic',
        price: 75.00,
        coverUrl: '',
        quantity: 2,
        origine: 'UK',
        variations: [
          {
            color: 'White',
            quantity: 2,
          },
        ],
      },
    ],
    statusHistory: [
      { status: 'En cours', date: '2024-07-26 09:00' },
    ],
    taxes: 5.00,
  },
  {
    id: '6012',
    orderNumber: '6012',
    createdAt: new Date('2024-07-25T11:33:00'),
    deliveryDate: new Date('2024-08-10T16:30:00'),
    status: IOrderStatus.Ongoing,
    fullAddress: "5678 Oak Avenue, San Francisco, CA",
    customer: {
      id: '3',
      name: 'Liam Johnson',
      email: 'liam.johnson@example.com',
      numberphone: '555-987-6543',
      avatarUrl: 'https://example.com/avatar3.jpg',
    },
    items: [
      {
        id: '5',
        sku: '30K9UR5',
        name: 'Puma RS-X',
        price: 110.00,
        coverUrl: '',
        quantity: 1,
        origine: 'US',
        variations: [
          {
            color: 'Green',
            quantity: 1,
          },
        ],
      },
      {
        id: '6',
        sku: '30K9UR6',
        name: 'Converse All Star',
        price: 60.00,
        coverUrl: '',
        quantity: 3,
        origine: 'US',
        variations: [
          {
            color: 'Blue',
            quantity: 2,
          },
          {
            color: 'Red',
            quantity: 1,
          },
        ],
      },
    ],
    statusHistory: [
      { status: 'En cours', date: '2024-07-27 08:30' },
    ],
    taxes: 8.00,
  },
  {
    id: '6013',
    orderNumber: '6013',
    createdAt: new Date(),
    deliveryDate: new Date('2024-08-15T10:15:00'),
    status: IOrderStatus.Pending,
    fullAddress: "9101 Birch Lane, Miami, FL",
    customer: {
      id: '4',
      name: 'Liam Johnson',
      email: 'sophia.brown@example.com',
      numberphone: '555-654-3210',
      avatarUrl: 'https://example.com/avatar4.jpg',
    },
    items: [
      {
        id: '7',
        sku: '40L9UR7',
        name: 'New Balance 574',
        price: 90.00,
        coverUrl: '',
        quantity: 2,
        origine: 'US',
        variations: [
          {
            color: 'Gray',
            quantity: 2,
          },
        ],
      },
    ],
    statusHistory: [
      { status: 'En cours', date: '2024-07-28 11:00' },
      { status: 'Annulé', date: '2024-07-29 14:00' },
    ],
    taxes: 0,
  },
];
