import useSWR from "swr";
import { useMemo } from "react";
import axiosInstance, { endpoints, fetcher } from "./server";
import axios, { AxiosRequestConfig, AxiosResponse } from "axios";
;
import { IConfigReview } from "../types/Config-Review";


const options = {
  revalidateIfStale: true,
  revalidateOnFocus: true,
  revalidateOnReconnect: true,
  revalidateOnMount: true,
};



////////////-----review config API-----//////////////
////////////////////////////////////////////

export function useGetconfig() {
  const URL = endpoints.Reviews.Config.getConfig()
  const { data, isLoading, isValidating, error, mutate } = useSWR<IConfigReview>(
    URL,
    fetcher
  );

  const memoizedValue = useMemo(
    () => ({
      reviewData: (data as IConfigReview) || null,
      reviewLoading: isLoading,
      reviewError: error,
      reviewValidating: isValidating,
      reviewMutate: mutate,
    }),

    [data, error]
  );
  return memoizedValue;
}

export async function useUpdateConfig(
  config: IConfigReview
) {
  try {
    const URL = endpoints.Reviews.Config.editConfig()
    const response: AxiosResponse<IConfigReview> = await axiosInstance.put(
      URL,
      config
    );

    return response;
  } catch (error) {
    console.error("Erreur lors de la mise à jour de la configuration:", error);
    throw error;
  }
}