import type { IFAQGetItem , IFAQItemAddUpdate } from '../types/faq';

import useSWR, { mutate } from 'swr';
import { useMemo } from 'react';

import { endpoints , fetcherchatbot } from './server';

// ----------------------------------------------------------------------

const swrOptions = {
  revalidateIfStale: true,     
  revalidateOnFocus: false,    
  revalidateOnReconnect: true, 
};

// ----------------------------------------------------------------------

type FAQSData = {
  faqs: IFAQGetItem[];
};

// ----------------------------------------------------------------------
export function useGetFaqs() {
  const url = endpoints.chatbot.faq.list;

  const { data, isLoading, error, isValidating } = useSWR<FAQSData>(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      faqs: data?.faqs || [],
      faqsLoading: isLoading,
      faqsError: error,
      faqsValidating: isValidating,
      faqsEmpty: !isLoading && !data?.faqs.length,
      refetchFaqs: () => mutate(url), 
    }),
    [data?.faqs, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------

type FAQData = {
  faq: IFAQGetItem;
};
 
export function useGetFAQ(faqID: string) {
  const url = `${endpoints.chatbot.faq.details}/${faqID}`;

  const { data, isLoading, error, isValidating } = useSWR<FAQData>(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      faq: data,
      faqLoading: isLoading,
      faqError: error,
      faqValidating: isValidating,
      faqEmpty: !isLoading && !data,
      refetchFAQ: () => mutate(url),
    }),
    [data, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------

export function useAddFAQ() {
  const url = endpoints.chatbot.faq.add;

  const addFAQ = async (data: IFAQItemAddUpdate) => {
    const response = await fetcherchatbot(url, 'post', data);
    mutate(endpoints.chatbot.faq.list);
    return response;
  };

  return { addFAQ };
}

// ----------------------------------------------------------------------

export function useDeleteFAQ() {
  const deleteFAQ = async (id: string) => {
    const response = await fetcherchatbot(`${endpoints.chatbot.faq.delete}/${id}`, 'delete');
    mutate(endpoints.chatbot.faq.list);
    return response;
  };

  return { deleteFAQ };
}

// ----------------------------------------------------------------------

export function useUpdateFAQ(id: string) {
  const url = `${endpoints.chatbot.faq.update}/${id}`;

  const updateFAQ = async (data : IFAQItemAddUpdate) => {
    const response = await fetcherchatbot(url, 'put', data);
    mutate(endpoints.chatbot.faq.list);
    return response;
  };

  return { updateFAQ };
}