import useSWR, { mutate } from 'swr';
import { useMemo } from 'react';

import { fetcherchatbot , endpoints } from './server';
import { IFile } from '../types/file';

// ----------------------------------------------------------------------

const swrOptions = {
  revalidateIfStale: true,     
  revalidateOnFocus: false,    
  revalidateOnReconnect: true, 
};

// ----------------------------------------------------------------------

type FilesData = {
  documents: IFile[];
};

// ----------------------------------------------------------------------
export function useGetFiles() {
  const url = endpoints.chatbot.openai.list;

  const { data, isLoading, error, isValidating } = useSWR<FilesData>(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      documents: data?.documents || [],
      documentsLoading: isLoading,
      documentsError: error,
      documentsValidating: isValidating,
      documentsEmpty: !isLoading && !data?.documents.length,
      refetchDocuments: () => mutate(url),
    }),
    [data?.documents, error, isLoading, isValidating]
  );

  return memoizedValue;
} 

// ----------------------------------------------------------------------

export function useDeleteDocuments() {
  const deleteDocuments = async (openaiId: string) => {
    const url = endpoints.chatbot.openai.delete(openaiId);
    const response = await fetcherchatbot(url , 'delete');
    mutate(endpoints.chatbot.openai.list);
    return response;
  };
  return { deleteDocuments };
}