import useSWR ,{ mutate } from 'swr';
import axiosInstance, { endpoints, fetcher } from "./server";
import { IGiftCard} from '../types/giftcard';
import { useMemo } from 'react';



export async function useAddGiftCard(data: IGiftCard): Promise<IGiftCard> {
  try {
    const URL = endpoints.Addons.GiftCart.add
    const URL2 = endpoints.Addons.GiftCart.getAll

    const response = await axiosInstance.post(URL, data);
    const newGiftCard: IGiftCard = response.data;

    await mutate(URL2);

    return newGiftCard;
  } catch (error) {
    console.error('Erreur lors de l\'ajout de la carte cadeau:', error);
    throw error;
  }
}
export async function useAddGiftCardAndSendEmail(data: IGiftCard): Promise<IGiftCard> {
  try {
    const URL = endpoints.Addons.GiftCart.addGiftcardAndSendMail
    const URL2 = endpoints.Addons.GiftCart.getAll

    const response = await axiosInstance.post(URL, data);
    const newGiftCard: IGiftCard = response.data;

    await mutate(URL2);

    return newGiftCard;
  } catch (error) {
    console.error('Erreur lors de l\'ajout de la carte cadeau:', error);
    throw error;
  }
}

export function useGetGiftCards() {
  const URL = [endpoints.Addons.GiftCart.getAll];
  const { data, error, isLoading, mutate } = useSWR<IGiftCard[]>(URL, fetcher);

  return {
    giftcards: data || [],
    isLoading,
    isError: error,
    mutate,
  };
}


export async function deleteGiftCard(giftcardId: number) {
  try {
    const URL = endpoints.Addons.GiftCart.delete(giftcardId)
    const URL2 = endpoints.Addons.GiftCart.getAll
    await axiosInstance.delete(URL);
    await mutate(URL2);
  } catch (error) {
    console.error('Erreur lors de la suppression de la carte cadeau:', error);
    throw error;
  }
}


export async function duplicateGiftCard(giftcardId: number) {
  try {
    const URL = endpoints.Addons.GiftCart.duplicate(giftcardId)
    const URL2 = endpoints.Addons.GiftCart.getAll
    const response = await axiosInstance.post(URL);
    await mutate(URL2);
    return response.data;
  } catch (error) {
    console.error('Erreur lors de la duplication de la carte cadeau:', error);
    throw error;
  }
}

export async function updateGiftCard(giftcardId: number, data: IGiftCard): Promise<IGiftCard> {
  try {
    const URL = endpoints.Addons.GiftCart.update(giftcardId);
    const URL2 = endpoints.Addons.GiftCart.getAll;
    const response = await axiosInstance.put(URL, data, { });
    const updatedGiftCard: IGiftCard = response.data;

    await mutate(URL2);

    return updatedGiftCard;
  } catch (error) {
    console.error('Erreur lors de la mise à jour de la carte cadeau:', error);
    throw error;
  }
}


export function useGetGiftCardById(giftcardId: string) {
  const URL = endpoints.Addons.GiftCart.getById(giftcardId.toString());
  const { data, error, isLoading ,isValidating } = useSWR<IGiftCard>( URL, fetcher);


  const memoizedValue = useMemo(
    ()=> ({
      giftcard: data,
      isLoading,
      isError: error,
      isValidating,
    }),
    [data, error]
  )
  return memoizedValue;
}

export async function sendGiftCardEmail(giftcardId: number) {
  try {
    const URL = endpoints.Addons.GiftCart.sendEmail(giftcardId);
    await axiosInstance.post(URL);
    await mutate(endpoints.Addons.GiftCart.getAll);
  } catch (error) {
    console.error("Erreur lors de l'envoi de l'email de la carte cadeau:", error);
    throw error;
  }
}
