import { IOpenAiGetItem , IOpenAiItemAddUpdate} from '../types/openai';

import useSWR, { mutate } from 'swr';
import { useMemo } from 'react';

import { fetcherchatbot , endpoints } from './server';

// ----------------------------------------------------------------------

const swrOptions = {
  revalidateIfStale: true,     
  revalidateOnFocus: false,    
  revalidateOnReconnect: true, 
};

// ----------------------------------------------------------------------

type OpenAiData = {
  openAi: IOpenAiGetItem;
};
 
export function useGetOpenAiConf(openaiID: string) {
  const url = endpoints.chatbot.openai.details(openaiID);

  const { data, isLoading, error, isValidating } = useSWR<OpenAiData>(url, fetcherchatbot, swrOptions);
  

  const memoizedValue = useMemo(
    () => ({
      openai: data,
      openaiLoading: isLoading,
      openaiError: error,
      openaiValidating: isValidating,
      openaiEmpty: !isLoading && !data,
      refetchOpenai: () => mutate(url),
    }),
    [data, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------

export const updateOpenAIConf = async (openaiID: string ,data: IOpenAiItemAddUpdate) => {
  const url = endpoints.chatbot.openai.update(openaiID);
  return fetcherchatbot([url, {}], 'put', data);
}

// ----------------------------------------------------------------------
export const addInsightDocument = async (file: File) => {
  const formData = new FormData();
  formData.append('file', file);
  const url = endpoints.chatbot.openai.add;
  const result = await fetcherchatbot([url, { headers: { 'Content-Type': 'multipart/form-data' } }], 'post', formData);
  mutate(endpoints.chatbot.openai.list);
  return result;
};