import useSWR from "swr";
import { useMemo } from "react";
import { _orders, userId } from "../_mock";
import axiosInstance, { endpoints } from "./server";
import axios, { AxiosRequestConfig } from "axios";
import { CreateOrderFromBORequest, IOrderItem, OrderStatusHistoryDTO, OrderToUpdateResponse } from "../types/order";

export const fetcher = async (args: string | [string, AxiosRequestConfig]) => {
  const [url, config] = Array.isArray(args) ? args : [args];

  const res = await axiosInstance.get(url, { ...config });

  return res.data;
};

const options = {
  revalidateIfStale: false,
  revalidateOnFocus: false,
  revalidateOnReconnect: false,
};

////////////-----order API-----//////////////
////////////////////////////////////////////
export function useGetOrders() {
  const URL = [endpoints.order.getAll];
  const { data, error } = useSWR<IOrderItem[]>(URL, fetcher, options);
  const memoizedValue = useMemo(
    () => ({
      orderData: (data as IOrderItem[]) || [],
      orderError: error,
    }),
    [data, error]
  );
  return memoizedValue;
}

export function useGetOrder(orderId: string) {
  const URL = [endpoints.media.getById(orderId)];
  const { data, error } = useSWR<IOrderItem[]>(
    orderId ? URL : null,
    fetcher,
    options
  );

  const memoizedValue = useMemo(
    () => ({
      orderData: (data as IOrderItem[]) || [],
      orderError: error,
    }),
    [data, error]
  );
  return memoizedValue;
}

export const addCommande = async (command: CreateOrderFromBORequest) => {
  try {
    const response = await axiosInstance.post(
      endpoints.order.addOrder,
      command
    );
    return response;
  } catch (error) {
    throw error;
  }
};
export const getOrderHistory = async (
  orderId: number,
  size: number,
  page: number
) => {
  try {
    const response = await axiosInstance.get(
      endpoints.order.getOrderHistory(orderId, size, page)
    );
    return response.data;
  } catch (error: any) {
    console.error("Error fetching order history:", error);
    throw new Error(error.response?.data?.message || "Failed to fetch order history.");
  }
};
export const getlastOrderHistory = async (
  orderId: number,
) => {
  try {
    const response = await axiosInstance.get(
      endpoints.order.getlastOrderHistory(orderId)
    );
    return response;
  } catch (error: any) {
    console.error("Error fetching order history:", error);
    throw new Error(error.response?.data?.message || "Failed to fetch order history.");
  }
};
export const deleteNote = async (
  noteId: number
) => {
  try {
    const response = await axiosInstance.delete(
      endpoints.order.deleteNote(noteId)
    );
    return response.data;
  } catch (error: any) {
    console.error("Error fetching order history:", error);
    throw new Error(error.response?.data?.message || "Failed to fetch order history.");
  }
};

export const getOrderToUpdate = async (
  orderId: number,
): Promise<OrderToUpdateResponse> => {
  try {
    const response = await axiosInstance.get(
      endpoints.order.getOrderToUpdate(orderId)
    );
    return response.data;
  } catch (error: any) {
    console.error("Error fetching order history:", error);
    throw new Error(error.response?.data?.message || "Failed to fetch order history.");
  }
};
export const updateOrder = async (
  order: OrderToUpdateResponse,
)=> {
  try {
    const response = await axiosInstance.put(
      endpoints.order.updateOrder,
      order
    );
    return response;
  } catch (error: any) {
    console.error("Error fetching order history:", error);
    throw new Error(error.response?.data?.message || "Failed to fetch order history.");
  }
};
