import { _paymentMethods, mockBankAccounts } from "../_mock/_payment";
import { IBankTransferConfig, ICreditCardConfig, IPaymentMethod, IPayPalConfig, IPaypalConnexionConf, IPayPlugConfig, IPayPlugPaymentConfig, PaymentPayPlugResponse, RefundPayPlugRequest, RefundPayPlugResponse } from "../types/payment";
import { IBankTransferConf } from "../types/payment";
import useSWR, { mutate } from 'swr';
import { useMemo } from 'react';
import axiosInstance, { fetcher, endpoints } from './server';

const options = {
    revalidateIfStale: false,
    revalidateOnFocus: false,
    revalidateOnReconnect: false,
};




////////////////general comfiguration//////////////////////


export function useGetPaymentMethods() {
    const URL = [endpoints.payment.methods.all];

    const { data, isLoading, error, isValidating } = useSWR<IPaymentMethod[]>(URL, fetcher, options);

    return useMemo(
        () => ({
            paymentMethodsData: data,
            paymentMethodsLoading: isLoading,
            paymentMethodsError: error,
            paymentMethodsValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}


export async function changePaymentMethodStatus(paymentMethod: string) {
    await axiosInstance.post(endpoints.payment.methods.changeStatus(paymentMethod));
    mutate([endpoints.payment.methods.all],
        async (data: IPaymentMethod[] | undefined) => {
            if (!data) return data;
            return data.map((item) => {
                if (item.type == paymentMethod) {
                    return { ...item, active: !item.active };
                }
                return item;
            });
        },
        false
    );
    mutate([endpoints.payment.methods.type(paymentMethod)], async (data: any) => {
        if (!data) return data;
        return { ...data, active: !data.active };
    }, false);
}


//////////////////////bank transfer configuration//////////////////////

export function useGetBankTranferConfig() {
    const URL = [endpoints.payment.methods.type("bank_transfer")];
    console.log(URL);
    const { data, isLoading, error, isValidating } = useSWR<IBankTransferConfig>(URL, fetcher, options);

    return useMemo(
        () => ({
            bankTranferConfigData: data,
            bankTranferConfigLoading: isLoading,
            bankTranferConfigError: error,
            bankTranferConfigValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}





export async function updateBankTrasnferConf(config: IBankTransferConfig) {
    const response = await axiosInstance.post(endpoints.payment.bankTransferConfig.edit, config);
    console.log("updateBankTrasnferConf", response.data);
    mutate([endpoints.payment.methods.type("bank_transfer")], response.data, false);
}





//////////////////////credit card configuration//////////////////////

export function useGetCreditCardConfig() {

    const URL = [endpoints.payment.methods.type("credit_card")];
    const { data, isLoading, error, isValidating } = useSWR<ICreditCardConfig>(URL, fetcher, options);

    return useMemo(
        () => ({
            creditCardConfigData: data,
            creditCardConfigLoading: isLoading,
            creditCardConfigError: error,
            creditCardConfigValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}

export async function updateCreditCardConfig(config: ICreditCardConfig) {
    const response = await axiosInstance.post(endpoints.payment.creditCardConfig.edit, config);
    console.log("updateCreditCardConfig", response.data);
    mutate([endpoints.payment.methods.type("credit_card")], response.data, false);

}


//////////////////////paypal configuration//////////////////////
export function useGetPaypalConfig() {
    const URL = [endpoints.payment.methods.type("paypal")];
    const { data, isLoading, error, isValidating } = useSWR<IPayPalConfig>(URL, fetcher, options);

    return useMemo(
        () => ({
            paypalConfigData: data,
            paypalConfigLoading: isLoading,
            paypalConfigError: error,
            paypalConfigValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}

export async function updatePaypalConfig(config: IPayPalConfig) {
    const response = await axiosInstance.post(endpoints.payment.paypalConfig.edit, config);
    console.log("updatePaypalConfig", response.data);
    mutate([endpoints.payment.methods.type("paypal")], response.data, false);
}





/////////////////////////paypal connexion///////////////////////
export function useGetPaypalConnexion() {
    const URL = [endpoints.payment.paypalConfig.getConnexionParams];
    const { data, isLoading, error, isValidating } = useSWR<IPaypalConnexionConf>(URL, fetcher, options);

    return useMemo(
        () => ({
            paypalConnexionData: data,
            paypalConnexionLoading: isLoading,
            paypalConnexionError: error,
            paypalConnexionValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}


export async function updatePaypalConnexion(config: IPaypalConnexionConf) {
    const response = await axiosInstance.post(endpoints.payment.paypalConfig.updateConnexionParams, config);
    mutate([endpoints.payment.paypalConfig.getConnexionParams], response.data, false);
}

/////////////////////////payplug configuration///////////////////////

export function useGetPayPlugConfig() {
    const URL = [endpoints.payment.payPlug.getConfig];
    const { data, isLoading, error, isValidating } = useSWR<IPayPlugConfig>(URL, fetcher, options);

    return useMemo(
        () => ({
            payPlugConfigData: data,
            payPlugConfigLoading: isLoading,
            payPlugConfigError: error,
            payPlugConfigValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}

    
export async function updatePayPlugConfig(config: IPayPlugConfig) {
    const response = await axiosInstance.post(endpoints.payment.payPlug.updateConfig, config);
    mutate([endpoints.payment.payPlug.getConfig], response.data, false);  
}


//////////////////////payplug payment configuration//////////////////////

export function useGetPayPlugPaymentConfig() {
    const URL = [endpoints.payment.payPlug.fetchPaymentConfig];
    const { data, isLoading, error, isValidating } = useSWR<IPayPlugPaymentConfig>(URL, fetcher, options);

    return useMemo(
        () => ({
            payPlugPaymentConfigData: data,
            payPlugPaymentConfigLoading: isLoading,
            payPlugPaymentConfigError: error,
            payPlugPaymentConfigValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}

export async function updatePayPlugPaymentConfig(config: IPayPlugPaymentConfig) {
    const response = await axiosInstance.post(endpoints.payment.payPlug.savePaymentConfig, config);
    mutate([endpoints.payment.payPlug.fetchPaymentConfig], response.data, false);
}


//////////////////////payplug payment//////////////////////

export async function getPayPlugPayment(paymentId: string) {
    const URL = [endpoints.payment.payPlug.getPayment(paymentId)];
    const { data, isLoading, error, isValidating } = useSWR<PaymentPayPlugResponse>(URL, fetcher, options);
    return useMemo(
        () => ({
            payPlugPaymentData: data,
            payPlugPaymentLoading: isLoading,
            payPlugPaymentError: error,
            payPlugPaymentValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}

//////////////////////payplug refund//////////////////////

export async function createPayPlugRefund(paymentId: string, refund: RefundPayPlugRequest) {
    const response = await axiosInstance.post(endpoints.payment.payPlug.createRefund(paymentId), refund);
    mutate([endpoints.payment.payPlug.getRefund(paymentId, response.data.id)], response.data, false);
    return response.data;
}

export async function getPayPlugRefund(paymentId: string, refundId: string) {
    const URL = [endpoints.payment.payPlug.getRefund(paymentId, refundId)];
    const { data, isLoading, error, isValidating } = useSWR<RefundPayPlugResponse>(URL, fetcher, options);
    return useMemo(
        () => ({
            payPlugRefundData: data,
            payPlugRefundLoading: isLoading,
            payPlugRefundError: error,
            payPlugRefundValidating: isValidating,
        }),
        [data, error, isLoading, isValidating]
    );
}
