import { useMemo } from "react";
import useSWR, { mutate } from "swr";
import axiosInstance, { endpoints, fetcher } from "./server";
import { Order, OrderStatus } from "@/contexts/types/main-order";
import { Shipment } from "@/contexts/types/shipment";


const options = {
  revalidateIfStale: false,
  revalidateOnFocus: false,
  revalidateOnReconnect: false,
};

///////////////////-----------Order Management----------///////////////////////
//////////////////////////////////////////////////////////////////////////////
export function getAllShipments() {
  const URL = [endpoints.shipping.shipments.getAll];
  const { data, error, isLoading, isValidating, mutate } = useSWR<Shipment[]>(URL, fetcher, options);

  console.log("data of order : "+data);

  const memoizedValue = useMemo(
    () => ({
      shipmentsData: (data as Shipment[]) || [],
      shipmentsError: error,
      shipmentsLoading: isLoading,
      shipmentsValidating: isValidating,
      mutateShipments: mutate,
    }),
    [data, error]
  );

  return memoizedValue;
}

export function getShipmentById(shipmentId: string) {
  const { data, error, isLoading, isValidating, mutate } = useSWR<Shipment>(
    shipmentId ? endpoints.shipping.shipments.getById(shipmentId) : null,
    fetcher,
    options
  );

  const memoizedValue = useMemo(
    () => ({
      shipmentData: data,
      shipmentError: error,
      shipmentLoading: isLoading,
      shipmentValidating: isValidating,
      mutateShipment: mutate,
    }),
    [data, error]
  );

  return memoizedValue;
}


