import useSWR from "swr";
import { useMemo } from "react";
import axiosInstance, { endpoints, fetcher } from "./server";
import axios, { AxiosRequestConfig, AxiosResponse } from "axios";
import { GATEWAY_API_URL } from "@/config-global";
import { ITag } from "../types/tag";



const options = {
  revalidateIfStale: true,
  revalidateOnFocus: true,
  revalidateOnReconnect: true,
  revalidateOnMount: true,
};

////////////-----Tag API-----//////////////
////////////////////////////////////////////

export function useGetTags() {
  const URL = [endpoints.stock_management.tags.getAll()];
  const { data, error, isLoading, isValidating, mutate } = useSWR<ITag[]>(
    URL,
    fetcher
  );

  const memoizedValue = useMemo(
    () => ({
      tagsData: (data as ITag[]) || [],
      tagsLoading: isLoading,
      tagsError: error,
      tagsValidating: isValidating,
      tagsMutate: mutate,
    }),

    [data, error]
  );
  return memoizedValue;
}

export function useGetTag(tagId: string) {
  const URL = [endpoints.stock_management.tags.getById(tagId)];
  const { data, error, isLoading, isValidating } = useSWR<ITag>(URL, fetcher);

  const memoizedValue = useMemo(
    () => ({
      tagData: (data as ITag) || null,
      tagLoading: isLoading,
      tagError: error,
      tagValidating: isValidating,
    }),

    [data, error]
  );
  return memoizedValue;
}

export async function useAddTag(tag: ITag) {
  try {
    const URL = endpoints.stock_management.tags.add();
    const response: AxiosResponse<ITag> = await axiosInstance.post(URL, tag);
  } catch (error) {
    console.error("Erreur lors de l'ajout de l'étiquette:", error);
    throw error;
  }
}

export async function useUpdateTag(tag: ITag, tagId: string) {
  try {
    const URL = endpoints.stock_management.tags.edit(tagId);
    const response: AxiosResponse<ITag> = await axiosInstance.put(URL, tag);
    return response;
  } catch (error) {
    console.error("Erreur lors de la mise à jour de l'étiquette:", error);
    throw error;
  }
}

export async function useDeleteTag(tagId: string) {
  try {
    const URL = endpoints.stock_management.tags.delete(tagId);
    const response = await axiosInstance.delete(URL);
    return response;
  } catch (error) {
    console.error("Erreur lors de la suppression de l'étiquette:", error);
    throw error;
  }
}

export async function useDeleteTags(tagIds: string[]) {
  try {
    const URL = endpoints.stock_management.tags.deleteBunch();
    const response = await axiosInstance.delete(URL, {
      data: tagIds,
    });
    return response;
  } catch (error) {
    console.error("Erreur lors de la suppression des étiquettes:", error);
    throw error;
  }
}
