import { ITiketItem } from '../types/ticket';

import useSWR, { mutate } from 'swr';
import { useMemo } from 'react';

import { fetcherchatbot , endpoints } from './server';

// ----------------------------------------------------------------------

const swrOptions = {
  revalidateIfStale: true,     
  revalidateOnFocus: false,    
  revalidateOnReconnect: true, 
};

// ----------------------------------------------------------------------

type TicketsData = {
  tickets: ITiketItem[];
};

// ----------------------------------------------------------------------
export function useGetTickets() {
  const url = endpoints.chatbot.ticket.list;

  const { data, isLoading, error, isValidating } = useSWR<TicketsData>(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      tickets: data?.tickets || [],
      ticketsLoading: isLoading,
      ticketsError: error,
      ticketsValidating: isValidating,
      ticketsEmpty: !isLoading && !data?.tickets.length,
      refetchTickets: () => mutate(url),
    }),
    [data?.tickets, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------
export function useGetTicketById(id: string) {
  const url = endpoints.chatbot.ticket.details(id);

  const { data, isLoading, error, isValidating } = useSWR(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      ticket: data || {},
      ticketLoading: isLoading,
      ticketError: error,
      ticketValidating: isValidating,
      ticketEmpty: !isLoading && !data,
      refetchTicket: () => mutate(url),
    }),
    [data, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------
export function useGetSupportUsers(){
  const url = endpoints.chatbot.support.list

  const { data, isLoading, error, isValidating } = useSWR(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      support: data?.support || [],
      supportLoading: isLoading,
      supportError: error,
      supportValidating: isValidating,
      supportEmpty: !isLoading && !data?.support.length,
      refetchSupport: () => mutate(url),
    }),
    [data?.support, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------
export function useGetUserById(id : string){
  const url = endpoints.chatbot.support.details(id);

  const { data, isLoading, error, isValidating } = useSWR(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      user: data || {},
      userLoading: isLoading,
      userError: error,
      userValidating: isValidating,
      userEmpty: !isLoading && !data,
      refetchUser: () => mutate(url),
    }),
    [data, error, isLoading, isValidating]
  );

  return memoizedValue;
}
// ----------------------------------------------------------------------
export function useGetTicketBySupportId(id : string){
  const url = endpoints.chatbot.ticket.support(id);

  const { data, isLoading, error, isValidating } = useSWR(url, fetcherchatbot, swrOptions);

  const memoizedValue = useMemo(
    () => ({
      tickets: data?.tickets || [],
      ticketsLoading: isLoading,
      ticketsError: error,
      ticketsValidating: isValidating,
      ticketsEmpty: !isLoading && !data?.tickets.length,
      refetchTickets: () => mutate(url),
    }),
    [data?.tickets, error, isLoading, isValidating]
  );

  return memoizedValue;
}

// ----------------------------------------------------------------------

export function useUpdateTicket() {

  const updateTicket = async (id : string, data : ITiketItem) => {
    const url = endpoints.chatbot.ticket.update(id);
    const response = await fetcherchatbot(url, 'put', data);
    mutate(endpoints.chatbot.ticket.list);
    return response;
  };

  return { updateTicket };
}