import useSWR from 'swr';
import axiosInstance from './server'; 
import { ChartConfig } from '../types/statistics';

export const useUsersCount = (
  startDate?: Date,
  endDate?: Date,
  roleNames?: string[]
) => {
        const params = {
          startDate: startDate?.toISOString(),
          endDate: endDate?.toISOString(),
          roleName: roleNames?.join(","), 
        };

  const { data, error } = useSWR(['/api/user/statistics/count', params], async ([url, params]) => {
    const response = await axiosInstance.get<number>(url, { params });
    return response.data;
  });

  return {
    usersCount: data,
    isLoading: !error && !data,
    isError: error,
  };
};

export const useUsersCountByTag = (
  startDate?: Date,
  endDate?: Date
) => {
  const params: Record<string, any> = {};
  if (startDate) params.startDate = startDate.toISOString().split('T')[0];
  if (endDate) params.endDate = endDate.toISOString().split('T')[0];

  const { data, error } = useSWR(['/api/user/statistics/countByTag', params], async ([url, params]) => {
    const response = await axiosInstance.get<number>(url, { params });
    return response.data;
  });

  return {
    usersCountByTag: data,
    isLoading: !error && !data,
    isError: error,
  };
};
function toIsoString(date: Date): string {
    return date.toISOString().split('.')[0]; 
  }
  
  // Hook pour récupérer le CA brut
  export const useGrossRevenue = (startDate?: Date, endDate?: Date) => {
    const params: Record<string, string> = {};
    if (startDate) params.startDate = toIsoString(startDate);
    if (endDate) params.endDate = toIsoString(endDate);
  
    const { data, error } = useSWR(startDate && endDate ? ['/api/orders/statistics/gross-revenue', params] : null,
      async ([url, params]) => {
        const response = await axiosInstance.get<number>(url, { params });
        return response.data;
      }
    );
  
    return {
      grossRevenue: data,
      isLoading: !error && !data && startDate && endDate,
      isError: error,
    };
  };
  
  // Hook pour récupérer le nombre de clients actifs
  export const useActiveClients = (startDate?: Date, endDate?: Date) => {
    const params: Record<string, string> = {};
    if (startDate) params.startDate = toIsoString(startDate);
    if (endDate) params.endDate = toIsoString(endDate);
  
    const { data, error } = useSWR(startDate && endDate ? ['/api/orders/statistics/active-clients', params] : null,
      async ([url, params]) => {
        const response = await axiosInstance.get<number>(url, { params });
        return response.data;
      }
    );
  
    return {
      activeClients: data,
      isLoading: !error && !data && startDate && endDate,
      isError: error,
    };
  };
  
  // Hook pour le CA moyen
  export const useAverageRevenue = (startDate?: Date, endDate?: Date) => {
    const params: Record<string, string> = {};
    if (startDate) params.startDate = toIsoString(startDate);
    if (endDate) params.endDate = toIsoString(endDate);
  
    const { data, error } = useSWR(startDate && endDate ? ['/api/orders/statistics/average-revenue', params] : null,
      async ([url, params]) => {
        const response = await axiosInstance.get<number>(url, { params });
        return response.data;
      }
    );
  
    return {
      averageRevenue: data,
      isLoading: !error && !data && startDate && endDate,
      isError: error,
    };
  };
  
  // Hook pour le nombre total d'articles vendus
  export const useTotalArticlesSold = (startDate?: Date, endDate?: Date) => {
    const params: Record<string, string> = {};
    if (startDate) params.startDate = toIsoString(startDate);
    if (endDate) params.endDate = toIsoString(endDate);
  
    const { data, error } = useSWR(startDate && endDate ? ['/api/orders/statistics/total-articles-sold', params] : null,
      async ([url, params]) => {
        const response = await axiosInstance.get<number>(url, { params });
        return response.data;
      }
    );
  
    return {
      totalArticlesSold: data,
      isLoading: !error && !data && startDate && endDate,
      isError: error,
    };
  };
  
  // Hook pour le nombre moyen d’articles par client actif
  export const useAverageArticlesPerActiveClient = (startDate?: Date, endDate?: Date) => {
    const params: Record<string, string> = {};
    if (startDate) params.startDate = toIsoString(startDate);
    if (endDate) params.endDate = toIsoString(endDate);
  
    const { data, error } = useSWR(startDate && endDate ? ['/api/orders/statistics/average-articles-per-active-client', params] : null,
      async ([url, params]) => {
        const response = await axiosInstance.get<number>(url, { params });
        return response.data;
      }
    );
  
    return {
      averageArticlesPerActiveClient: data,
      isLoading: !error && !data && startDate && endDate,
      isError: error,
    };
}

export function useActiveClientsCompare(startDate?: Date, endDate?: Date) {
  const shouldFetch = Boolean(startDate && endDate);

  const params: Record<string, string> = {};
  if (startDate) params.startDate = toIsoString(startDate);
  if (endDate) params.endDate = toIsoString(endDate);

  const { data, error } = useSWR<ChartConfig>(
    shouldFetch ? ['/api/orders/statistics/active-clients-compare', params] : null,
    async ([url, params]) => {
      const response = await axiosInstance.get<ChartConfig>(url, { params });
      return response.data;
    }
  );

  return {
    activeClientsCompare: data,
    isLoading: !error && !data && shouldFetch,
    isError: error,
  };
}