import useSWR, { mutate } from 'swr';
import axiosInstance, { endpoints, fetcher } from './server';
import { IVoucher } from '../types/voucher';
import { useMemo } from 'react';

// Add a new voucher
export async function useAddVoucher(data: IVoucher): Promise<IVoucher> {
  try {
    const URL = endpoints.Addons.Vouchers.add; 
    const URL2 = endpoints.Addons.Vouchers.getAll; 

    const response = await axiosInstance.post(URL, data);
    const newVoucher: IVoucher = response.data;

    await mutate(URL2);

    return newVoucher;
  } catch (error) {
    console.error('Error adding voucher:', error);
    throw error;
  }
}

// Get all vouchers
export function useGetVouchers() {
  const URL = endpoints.Addons.Vouchers.getAll; 
  const { data, error, isLoading, mutate } = useSWR<IVoucher[]>(URL, fetcher);

  return {
    vouchers: data || [],
    isLoading,
    isError: error,
    mutate,
  };
}

// Delete a voucher
export async function deleteVoucher(voucherId: number) {
  try {
    const URL = endpoints.Addons.Vouchers.delete(voucherId); 
    const URL2 = endpoints.Addons.Vouchers.getAll; 
    await axiosInstance.delete(URL);
    await mutate(URL2);
  } catch (error) {
    console.error('Error deleting voucher:', error);
    throw error;
  }
}

// Duplicate a voucher
export async function duplicateVoucher(voucherId: number) {
  try {
    const URL = endpoints.Addons.Vouchers.duplicate(voucherId); 
    const URL2 = endpoints.Addons.Vouchers.getAll; 
    const response = await axiosInstance.post(URL);
    await mutate(URL2);
    return response.data;
  } catch (error) {
    console.error('Error duplicating voucher:', error);
    throw error;
  }
}

// Update a voucher
export async function updateVoucher(voucherId: number, data: IVoucher): Promise<IVoucher> {
  try {
    const URL = endpoints.Addons.Vouchers.update(voucherId); 
    const URL2 = endpoints.Addons.Vouchers.getAll; 

    const response = await axiosInstance.put(URL, data);
    const updatedVoucher: IVoucher = response.data;

    await mutate(URL2);

    return updatedVoucher;
  } catch (error) {
    console.error('Error updating voucher:', error);
    throw error;
  }
}

export function useGetVoucherById(voucherId: string) {
  const URL = endpoints.Addons.Vouchers.getById(voucherId.toString()); 
  const { data, error, isLoading, isValidating } = useSWR<IVoucher>(URL, fetcher);

  const memoizedValue = useMemo(
    () => ({
      voucher: data,
      isLoading,
      isError: error,
      isValidating,
    }),
    [data, error]
  );
  return memoizedValue;
}


///// Send Email

export async function sendVoucherEmail(voucherId: number) {
  try {
    const URL = endpoints.Addons.Vouchers.sendEmail(voucherId);
    await axiosInstance.post(URL);
    await mutate(endpoints.Addons.Vouchers.getAll);
  } catch (error) {
    console.error("Erreur lors de l'envoi de l'email de la carte cadeau:", error);
    throw error;
  }
}