import React, { CSSProperties } from 'react';

type AlertProps = {
  message?: string; 
  type?: 'success' | 'error'; 
  onClose: () => void;
  style?: CSSProperties; 
};

const CustomAlert: React.FC<AlertProps> = ({
  message = "Default message", 
  type = 'success', 
  onClose,
  style = {},
}) => {
  return (
    <div style={{
      padding: '10px',
      backgroundColor: type === 'success' ? 'green' : 'red',
      color: 'white',
      position: 'fixed',
      top: '10px',
      right: '10px',
      zIndex: 2000, 
      borderRadius: '5px',
      boxShadow: '0 2px 10px rgba(0, 0, 0, 0.1)',
      ...style, 
    }}>
      {message}
      <button onClick={onClose} style={{
        marginLeft: '10px',
        backgroundColor: 'transparent',
        border: 'none',
        color: 'white',
        cursor: 'pointer',
      }}>
        Close
      </button>
    </div>
  );
};

export default CustomAlert;