import { useState } from 'react';
import { TextField, IconButton } from '@mui/material';
import { Search } from 'lucide-react';

interface ProductSearchProps {
  onSearch: (searchTerm: string) => void;
}

const ProductSearch = ({ onSearch }: ProductSearchProps) => {
  const [searchTerm, setSearchTerm] = useState('');

  const handleSearch = () => {
    onSearch(searchTerm);
  };

  const handleKeyPress = (event: React.KeyboardEvent) => {
    if (event.key === 'Enter') {
      handleSearch();
    }
  };

  return (
    <div className="flex items-center gap-2">
      <TextField
        size="small"
        placeholder="Recherche..."
        value={searchTerm}
        onChange={(e) => setSearchTerm(e.target.value)}
        onKeyPress={handleKeyPress}
        className="min-w-[200px]"
      />
      <IconButton onClick={handleSearch} size="small" className="bg-gray-100">
        <Search className="h-5 w-5" />
      </IconButton>
    </div>
  );
};

export default ProductSearch;