import React, { useState, useEffect, useRef } from "react";

import { TextField, IconButton } from "@mui/material";
import EmojiPicker from "emoji-picker-react";
import Iconify from "../iconify";



type InputEmojiProps = {
    value: string;
    onChange: (value: string) => void;
    placeholder: string;
    key: string;
    height: number | string;
    width?: number | string;
    keepOpened: boolean;
    onEnter?: () => void;
}

export const InputEmoji = ({ value, onChange, placeholder, key, width, keepOpened, onEnter }: InputEmojiProps) => {
    const [showEmojiPicker, setShowEmojiPicker] = useState(false);
    const pickerRef = useRef<HTMLDivElement>(null);

    useEffect(() => {
        function handleClickOutside(event: MouseEvent) {
            if (pickerRef.current && !pickerRef.current.contains(event.target as Node)) {
                setShowEmojiPicker(false);
            }
        }

        document.addEventListener("mousedown", handleClickOutside);
        return () => {
            document.removeEventListener("mousedown", handleClickOutside);
        };
    }, []);

    function handleEmojiClick(emojiData: any) {
        onChange(value + emojiData.emoji);
        !keepOpened && setShowEmojiPicker(false);
    }

    const handleEnter = () => {
        onEnter?.();
        !keepOpened && setShowEmojiPicker(false);
    }

    return (
        <div key={key} style={{marginLeft: 6, paddingBottom: 3, position: "relative", display: "flex", alignItems: "center",justifyContent: "center", width: width }} ref={pickerRef}>
            <TextField
                value={value}
                onChange={(e) => onChange(e.target.value)}
                placeholder={placeholder}
                variant="outlined"
                InputProps={{ sx: { borderRadius: 100 } }}
                sx={{ width: '100%'}}
                onKeyDown={(e) => e.key === 'Enter' && handleEnter()}
            />
            <IconButton
                onClick={() => setShowEmojiPicker((prev) => !prev)}
               
            >
                <Iconify icon="fluent:emoji-20-filled" width="20" height="20" />
            </IconButton>
            {showEmojiPicker && (
                <div style={{ position: "absolute", bottom: "100%", right: 0, left: 0, zIndex: 1000, width: '100%' }}>
                    <EmojiPicker onEmojiClick={handleEmojiClick} width="100%" />
                </div>
            )}
        </div>
    );
}