import { m } from 'framer-motion';
import Avatar from '@mui/material/Avatar';
import { alpha } from '@mui/material/styles';
import MenuItem from '@mui/material/MenuItem';
import IconButton from '@mui/material/IconButton';
import { useRouter } from '@/hooks';
import { useMockedUser } from '@/hooks';
import { useAuthContext } from '@/hooks';
import { varHover } from '@/shared/components/animate';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';
import { useEffect, useState } from 'react';
import { ChangingLogingActivity, UserByEmail } from '@/shared/api/user';
import { IUser, RequestLoginActivity, TokenPayload } from '@/shared/types/user';
import { Box, Typography } from '@mui/material';
import { getTokenInfo } from '@/utils/token';
import { paths } from '@/routes/paths';

// ----------------------------------------------------------------------

const OPTIONS = [
  {
    label: 'Accueil',
    linkTo: '/',
  },
  {
    label: 'Compte',
    linkTo: '/dashboard/user/account',
  },
  {
    label: 'Paramètres',
    linkTo: '/#2',
  },
];
const link = { title: "Compte", path: paths.dashboard.admin.user.account };

// ----------------------------------------------------------------------

export default function AccountPopover() {
  const router = useRouter();
  const { user } = useMockedUser();
  const { logout } = useAuthContext();
  const popover = usePopover();

  const [userData, setUserData] = useState<IUser | null>(null);
  const [userError, setUserError] = useState<Error | null>(null);

  const token = localStorage.getItem("token");
  const storedUserInfo: TokenPayload = token ? getTokenInfo(token) : {
    exp: 0,
    iat: 0,
    name: '',
    email: '',
    realm_access: { roles: [] },
    isValid: false,
  };


  useEffect(() => {
    const fetchUserData = async () => {
      if (storedUserInfo.email !== "") {
        try {
          const response = await UserByEmail(storedUserInfo.email);
          localStorage.setItem("userId", response.data.id);

          setUserData(response.data);
        } catch (error) {
          console.error('Error fetching user data:', error);
        }
      }
    };

    fetchUserData();
  }, [storedUserInfo.email]);

  const handleLogout = async () => {
    const token = localStorage.getItem("token");
    if (token) {
      const infosUser: TokenPayload = getTokenInfo(token);

      const user= await UserByEmail(infosUser.email);
      try {
        const requestLoginActivity: RequestLoginActivity = {
          email: user.data.email,
          activityLog: false,
        };
        const result = await ChangingLogingActivity(requestLoginActivity);


        if (result.status === 200) {
          localStorage.removeItem("token");
          localStorage.removeItem("chatbotToken");
          localStorage.removeItem("refreshToken");
          localStorage.removeItem("expirationDurationInSec");
          localStorage.removeItem("userId");

          popover.onClose();
          router.replace('/auth/jwt/login');
        } else {
          console.error("Échec de la déconnexion. Statut:", result.status);
        }
      } catch (error) {
        console.error("Une erreur s'est produite lors de la déconnexion:", error);
      }
    }
  };


  const handleClickItem = (path: string) => {
    popover.onClose();
    router.push(path);
  };

  return (
    <>
    <Box  onClick={popover.onOpen} sx={{ display: 'flex', alignItems: 'center' }}>
    <Typography sx={{ marginRight: 1}}>{userData?.firstName} {userData?.lastName}</Typography>
      <IconButton
        component={m.button}
        whileTap="tap"
        whileHover="hover"
        variants={varHover(1.05)}

        sx={{
          width: 40,
          height: 40,
          background: (theme) => alpha(theme.palette.grey[500], 0.08),
          ...(popover.open && {
            background: (theme) =>
              `linear-gradient(135deg, ${theme.palette.primary.light} 0%, ${theme.palette.primary.main} 100%)`,
          }),
        }}
      >
        <Avatar
          src={userData?.imageUrl || undefined}
          sx={{
            width: 36,
            height: 36,
            border: (theme) => `solid 2px ${theme.palette.background.default}`,
          }}
        >

        </Avatar>
      </IconButton>

      </Box>

      <CustomPopover open={popover.open} onClose={popover.onClose} sx={{ width: 200, p: 0 }}>
        {/* <Divider sx={{ borderStyle: 'dashed' }} /> */}
        <MenuItem onClick={() => handleClickItem(link.path)} sx={{ m: 1 }}>
          {link.title}
        </MenuItem>
        <MenuItem
          onClick={handleLogout}
          sx={{ m: 1, fontWeight: 'fontWeightBold', color: 'error.main' }}
        >
          Déconnexion
        </MenuItem>
      </CustomPopover>
    </>
  );
}
