import { useMemo } from "react";
import { paths } from "@/routes/paths";
import SvgColor from "@/shared/components/svg-color";
import { useAuthContext } from "@/hooks";
import { TokenPayload } from "@/shared/types/user";
import { getTokenInfo } from "@/utils/token";
import { time } from "console";

const icon = (name: string) => (
  <SvgColor
    src={`/assets/icons/navbar/${name}.svg`}
    sx={{ width: 1, height: 1 }}
  />
);

const ICONS = {
  job: icon("ic_job"),
  blog: icon("ic_blog"),
  chat: icon("ic_chat"),
  mail: icon("ic_mail"),
  user: icon("ic_user"),
  file: icon("ic_file"),
  lock: icon("ic_lock"),
  tour: icon("ic_tour"),
  order: icon("ic_order"),
  label: icon("ic_label"),
  blank: icon("ic_blank"),
  kanban: icon("ic_kanban"),
  folder: icon("ic_folder"),
  banking: icon("ic_banking"),
  booking: icon("ic_booking"),
  invoice: icon("ic_invoice"),
  product: icon("ic_product"),
  calendar: icon("ic_calendar"),
  disabled: icon("ic_disabled"),
  external: icon("ic_external"),
  menuItem: icon("ic_menu_item"),
  ecommerce: icon("ic_ecommerce"),
  analytics: icon("ic_analytics"),
  dashboard: icon("ic_dashboard"),
  driver: icon("ic_driver"),
  supplier: icon("ic_supplier"),
  comment: icon("ic_comment"),
  suppliers: icon("ic_suppliers"),
  achats: icon("ic_achats"),
  goodShoping: icon("ic_goodshoping"),
  giftCard: icon("ic_giftCard"),
  promotions: icon("ic_promotions"),
  delivry: icon("ic_delivery"),
};

export function useNavData() {
  const defaultUserInfo: TokenPayload = {
    exp: 0,
    iat: 0,
    name: "",
    email: "",
    realm_access: {
      roles: [],
    },
    isValid: false,
  };
  const token: string | null = localStorage.getItem("token");

  const data = useMemo(() => {
    const userInfo: TokenPayload | undefined = token
      ? getTokenInfo(token)
      : undefined;
    if (
      userInfo !== defaultUserInfo &&
      userInfo?.realm_access?.roles?.includes("ADMIN")
    ) {
      return [
        {
          subheader: "MyDressin",
          items: [
            {
              title: "Accueil",
              path: paths.dashboard.admin.root,
              icon: ICONS.dashboard,
              children: [
                {
                  title : "Chiffre d’affaires",
                  path : paths.dashboard.admin.chiffreStatistics,
                },
                {
                  title : "Chiffres Live",
                  path : paths.dashboard.admin.liveStatistics,
                },
                {
                  title: "Produits",
                  path: paths.dashboard.admin.productStatistics,
                },
                {
                  title: "Clients",
                  path: paths.dashboard.admin.userStatistics,
                },
              ],
            },
            {
              title: "Chat",
              path: paths.dashboard.admin.chat,
              icon: ICONS.chat,
            },
          ],
        },
        {
          subheader: "Gestion",
          items: [
            {
              title: "Produits",
              path: paths.dashboard.admin.product.root,
              icon: ICONS.product,

              children: [
                {
                  title: "Tous les produits",
                  path: paths.dashboard.admin.product.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.product.new },
                {
                  title: "Catégories",
                  path: paths.dashboard.admin.product.category,
                },
                {
                  title: "Étiquettes",
                  path: paths.dashboard.admin.product.tags,
                },
                {
                  title: "Attributs",
                  path: paths.dashboard.admin.product.attribut,
                },
                {
                  title: "Migration de stock",
                  path: paths.dashboard.admin.product.migration,
                },
              ],
            },
            {
              title: "Lives",
              path: paths.dashboard.admin.live.root,
              icon: ICONS.calendar,
              children: [
                {
                  title: "Tous les lives",
                  path: paths.dashboard.admin.live.all_lives,
                },
                { title: "Ajouter", path: paths.dashboard.admin.live.new },
                {
                  title: "Sessions de vente",
                  path: paths.dashboard.admin.live.saleSession,
                },
                {
                  title: "Sessions de vente Supprimées",
                  path: paths.dashboard.admin.live.saleSessionDeleted,
                },
                {
                  title: "Statistiques sessions de vente",
                  path: paths.dashboard.admin.cart.statistics,
                },
              ],
            },
            {
              title: "Paniers",
              path: paths.dashboard.admin.cart.UserCart,
              icon: ICONS.ecommerce,
              children: [
                {
                  title: "Paniers  clients",
                  path: paths.dashboard.admin.cart.UserCart,
                },
                {
                  title: "Paramètres",
                  path: paths.dashboard.admin.cart.CartConfiguration,
                },
              ],
            },
            {
              title: "Promotions",
              path: paths.dashboard.admin.giftcard.all_giftcard,
              icon: ICONS.promotions,
              children: [
                {
                  title: "Cartes cadeaux",
                  path: paths.dashboard.admin.giftcard.root,
                  icon: ICONS.giftCard,
                  children: [
                    {
                      title: "Toutes les cartes cadeaux",
                      path: paths.dashboard.admin.giftcard.all_giftcard,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.giftcard.new,
                    },
                  ],
                },
                {
                  title: "Codes promo",
                  path: paths.dashboard.admin.promoCode.root,
                  icon: ICONS.label,
                  children: [
                    {
                      title: "Tous les codes promo",
                      path: paths.dashboard.admin.promoCode.root,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.promoCode.new,
                    },
                  ],
                },
                {
                  title: "Bons d'achat",
                  path: paths.dashboard.admin.voucher.root,
                  icon: ICONS.goodShoping,
                  children: [
                    {
                      title: "Tous les bons d'achat",
                      path: paths.dashboard.admin.voucher.root,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.voucher.new,
                    },
                  ],
                },
              ],
            },
            {
              title: "Commandes",
              path: paths.dashboard.admin.order.all_orders,
              icon: ICONS.order,
              children: [
                {
                  title: "Toutes les commandes",
                  path: paths.dashboard.admin.order.all_orders,
                },
                {
                  title: "Tous les remboursements",
                  path: paths.dashboard.admin.order.refund.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.order.create },

                {
                  title: "Statistiques commandes",
                  path: paths.dashboard.admin.order.statistics,
                },
              ],
            },
            {
              title: "Avis",
              path: paths.dashboard.admin.review.all_reviews,
              icon: ICONS.comment,
              children: [
                {
                  title: "Tous les avis",
                  path: paths.dashboard.admin.review.all_reviews,
                },
                {
                  title: "Configuration",
                  path: paths.dashboard.admin.review.config,
                },
              ],
            },

            {
              title: "Fournisseurs",
              path: paths.dashboard.admin.supplier.root,
              icon: ICONS.suppliers,
              children: [
                {
                  title: "Tous les fournisseurs",
                  path: paths.dashboard.admin.supplier.list,
                },
                {
                  title: "Fournisseurs archivés",
                  path: paths.dashboard.admin.supplier.archivedList,
                },
                { title: "Ajouter", path: paths.dashboard.admin.supplier.new },
              ],
            },
            {
              title: "Achats",
              path: paths.dashboard.admin.supplierOrder.root,
              icon: ICONS.achats,
              children: [
                {
                  title: "Commandes d'achats ",
                  path: paths.dashboard.admin.supplierOrder.root,
                  children: [
                    {
                      title: "Toutes les commandes",
                      path: paths.dashboard.admin.supplierOrder.root,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.supplierOrder.new,
                    },
                  ],
                },
                {
                  title: "Commandes de préco",
                  path: paths.dashboard.admin.saleOrder.root,
                },
              ],
            },
            {
              title: "Utilisateurs",
              path: paths.dashboard.admin.user.all_users,
              icon: ICONS.user,
              children: [
                {
                  title: "Tous les utilisateurs",
                  path: paths.dashboard.admin.user.all_users,
                },
                { title: "Ajouter", path: paths.dashboard.admin.user.new },
                {
                  title: "Editeur de rôles",
                  path: paths.dashboard.admin.user.role,
                },
              ],
            },

            {
              title: "Médiathèque",
              path: paths.dashboard.admin.media.root,
              icon: ICONS.file,
            },
          ],
        },
        {
          subheader: "Configuration",
          items: [
            {
              title: "Livraison",
              path: paths.dashboard.admin.shipping.general.root,
              icon: ICONS.delivry,
            },
            {
              title: "Paiement",
              path: paths.dashboard.admin.payment.root,
              icon: ICONS.banking,
            },
            {
              title: "Parrainage",
              path: paths.Referral.root,
              icon: ICONS.menuItem,
            },
          ],
        },
        {
          subheader: 'Chatbot Configuration',
          items: [
            {
              title: 'Manage FAQ',
              path: paths.dashboard.chatbot.faq.root,
              icon: ICONS.user,
              children: [
                { title: 'Liste FAQ', path: paths.dashboard.chatbot.faq.root },
                { title: 'Nouvelle FAQ', path: paths.dashboard.chatbot.faq.new },
              ],
            },
            {
              title: 'Centre Aide',
              path: paths.dashboard.chatbot.help.root,
              icon: ICONS.blog,
              children: [
                { title: 'Liste Collection', path: paths.dashboard.chatbot.help.root },
                { title: 'Nouvelle Collection', path: paths.dashboard.chatbot.help.new },
              ],
            },
            {
              title: 'OpenAi API',
              path: paths.dashboard.chatbot.openai.list('1'),
              icon: ICONS.chat,
              children: [
                { title: 'Base de Données Vecteur', path: paths.dashboard.chatbot.openai.root },
                { title: 'Configuration API', path: paths.dashboard.chatbot.openai.list('1') },
              ],
            },
            {
              title: 'Gestion Des Tickets',
              path: paths.dashboard.chatbot.ticket.root,
              icon: ICONS.mail,
              children: [
                { title: 'Liste Des Tickets', path: paths.dashboard.chatbot.ticket.root },
                { title : 'Voir Les Conversations', path: paths.dashboard.chatbot.ticket.conversations },
              ],
            },
          ],
        },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("SALES_MANAGER")) {
      return [
        {
          subheader: "MyDressin",
          items: [
            {
              title: "Accueil",
              path: paths.dashboard.admin.root,
              icon: ICONS.dashboard,
            },
            {
              title: "Chat",
              path: paths.dashboard.admin.chat,
              icon: ICONS.chat,
            },
          ],
        },
        {
          subheader: "Gestion",
          items: [
            {
              title: "Lives",
              path: paths.dashboard.admin.live.root,
              icon: ICONS.calendar,
              children: [
                {
                  title: "Tous les lives",
                  path: paths.dashboard.admin.live.all_lives,
                },
                { title: "Ajouter", path: paths.dashboard.admin.live.new },
                {
                  title: "Sessions de vente",
                  path: paths.dashboard.admin.live.saleSession,
                },
                {
                  title: "Statistiques sessions de vente",
                  path: paths.dashboard.admin.cart.statistics,
                },
              ],
            },
            {
              title: "Paniers",
              path: paths.dashboard.admin.cart.UserCart,
              icon: ICONS.ecommerce,
              children: [
                {
                  title: "Paniers  clients",
                  path: paths.dashboard.admin.cart.UserCart,
                },
                {
                  title: "Paramètres",
                  path: paths.dashboard.admin.cart.CartConfiguration,
                },
              ],
            },
            {
              title: "Promotion",
              path: paths.dashboard.admin.giftcard.all_giftcard,
              icon: ICONS.promotions,
              children: [
                {
                  title: "Cartes cadeaux",
                  path: paths.dashboard.admin.giftcard.root,
                  icon: ICONS.giftCard,
                  children: [
                    {
                      title: "Toutes les cartes cadeaux",
                      path: paths.dashboard.admin.giftcard.all_giftcard,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.giftcard.new,
                    },
                  ],
                },
                {
                  title: "Codes promo",
                  path: paths.dashboard.admin.promoCode.root,
                  icon: ICONS.label,
                  children: [
                    {
                      title: "Tous les codes promo",
                      path: paths.dashboard.admin.promoCode.root,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.promoCode.new,
                    },
                  ],
                },
                {
                  title: "Bons d'achat",
                  path: paths.dashboard.admin.voucher.root,
                  icon: ICONS.goodShoping,
                  children: [
                    {
                      title: "Tous les bons d'achat",
                      path: paths.dashboard.admin.voucher.root,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.voucher.new,
                    },
                  ],
                },
              ],
            },
            {
              title: "Commandes",
              path: paths.dashboard.admin.order.all_orders,
              icon: ICONS.order,
              children: [
                {
                  title: "Toutes les commandes",
                  path: paths.dashboard.admin.order.all_orders,
                },
                {
                  title: "Tous les remboursements",
                  path: paths.dashboard.admin.order.refund.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.order.create },
                {
                  title: "Statistiques commandes",
                  path: paths.dashboard.admin.order.statistics,
                },
              ],
            },
            {
              title: "Utilisateurs",
              path: paths.dashboard.admin.user.all_users,
              icon: ICONS.user,
              children: [
                {
                  title: "Tous les utilisateurs",
                  path: paths.dashboard.admin.user.all_users,
                },
                { title: "Ajouter", path: paths.dashboard.admin.user.new },
                {
                  title: "Editeur de rôles",
                  path: paths.dashboard.admin.user.role,
                },
              ],
            },

            {
              title: "Médiathèque",
              path: paths.dashboard.admin.media.root,
              icon: ICONS.file,
            },
          ],
        },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("LIVE_MANAGER")) {
      return [
        {
          subheader: "MyDressin",
          items: [
            {
              title: "Accueil",
              path: paths.dashboard.admin.root,
              icon: ICONS.dashboard,
            },
            {
              title: "Chat",
              path: paths.dashboard.admin.chat,
              icon: ICONS.chat,
            },
          ],
        },
        {
          subheader: "Gestion",
          items: [
            {
              title: "Produits",
              path: paths.dashboard.admin.product.root,
              icon: ICONS.product,

              children: [
                {
                  title: "Tous les produits",
                  path: paths.dashboard.admin.product.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.product.new },
                {
                  title: "Catégories",
                  path: paths.dashboard.admin.product.category,
                },
                {
                  title: "Étiquettes",
                  path: paths.dashboard.admin.product.tags,
                },
                {
                  title: "Attributs",
                  path: paths.dashboard.admin.product.attribut,
                },
                {
                  title: "Migration de stock",
                  path: paths.dashboard.admin.product.migration,
                },
              ],
            },
            {
              title: "Utilisateurs",
              path: paths.dashboard.admin.user.all_users,
              icon: ICONS.user,
              children: [
                {
                  title: "Tous les utilisateurs",
                  path: paths.dashboard.admin.user.all_users,
                },
                { title: "Ajouter", path: paths.dashboard.admin.user.new },
                {
                  title: "Editeur de rôles",
                  path: paths.dashboard.admin.user.role,
                },
              ],
            },
            {
              title: "Lives",
              path: paths.dashboard.admin.live.root,
              icon: ICONS.calendar,
              children: [
                {
                  title: "Tous les lives",
                  path: paths.dashboard.admin.live.all_lives,
                },
                { title: "Ajouter", path: paths.dashboard.admin.live.new },
                {
                  title: "Sessions de vente",
                  path: paths.dashboard.admin.live.saleSession,
                },
                {
                  title: "Statistiques sessions de vente",
                  path: paths.dashboard.admin.cart.statistics,
                },
              ],
            },
            {
              title: "Paniers",
              path: paths.dashboard.admin.cart.UserCart,
              icon: ICONS.ecommerce,
              children: [
                {
                  title: "Paniers  clients",
                  path: paths.dashboard.admin.cart.UserCart,
                },
                {
                  title: "Paramètres",
                  path: paths.dashboard.admin.cart.CartConfiguration,
                },
              ],
            },
            {
              title: "Médiathèque",
              path: paths.dashboard.admin.media.root,
              icon: ICONS.file,
            },
          ],
        },
        {
              subheader: 'Chatbot Configuration',
              items: [
                {
                  title: 'Gestion Des Tickets',
                  path: paths.dashboard.chatbot.ticket.root,
                  icon: ICONS.mail,
                  children: [
                    { title: 'Liste Des Tickets', path: paths.dashboard.chatbot.ticket.root },
                    { title : 'Voir Les Conversations', path: paths.dashboard.chatbot.ticket.conversations },
                  ],
                },
              ],
            },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("GESTIONNAIRE_DE_PRECO")) {
      return [
        {
          subheader: "MyDressin",
          items: [
            {
              title: "Accueil",
              path: paths.dashboard.admin.root,
              icon: ICONS.dashboard,
            },
            {
              title: "Chat",
              path: paths.dashboard.admin.chat,
              icon: ICONS.chat,
            },
          ],
        },
        {
          subheader: "Gestion",
          items: [
            {
              title: "Produits",
              path: paths.dashboard.admin.product.root,
              icon: ICONS.product,

              children: [
                {
                  title: "Tous les produits",
                  path: paths.dashboard.admin.product.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.product.new },
                {
                  title: "Catégories",
                  path: paths.dashboard.admin.product.category,
                },
                {
                  title: "Étiquettes",
                  path: paths.dashboard.admin.product.tags,
                },
                {
                  title: "Attributs",
                  path: paths.dashboard.admin.product.attribut,
                },
                {
                  title: "Migration de stock",
                  path: paths.dashboard.admin.product.migration,
                },
              ],
            },
            {
              title: "Lives",
              path: paths.dashboard.admin.live.root,
              icon: ICONS.calendar,
              children: [
                {
                  title: "Tous les lives",
                  path: paths.dashboard.admin.live.all_lives,
                },
                { title: "Ajouter", path: paths.dashboard.admin.live.new },
                {
                  title: "Sessions de vente",
                  path: paths.dashboard.admin.live.saleSession,
                },
                {
                  title: "Statistiques sessions de vente",
                  path: paths.dashboard.admin.cart.statistics,
                },
              ],
            },
            {
              title: "Commandes",
              path: paths.dashboard.admin.order.all_orders,
              icon: ICONS.order,
              children: [
                {
                  title: "Toutes les commandes",
                  path: paths.dashboard.admin.order.all_orders,
                },
                {
                  title: "Tous les remboursements",
                  path: paths.dashboard.admin.order.refund.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.order.create },
                {
                  title: "Statistiques commandes",
                  path: paths.dashboard.admin.order.statistics,
                },
              ],
            },

            {
              title: "Fournisseurs",
              path: paths.dashboard.admin.supplier.root,
              icon: ICONS.suppliers,
              children: [
                {
                  title: "Tous les fournisseurs",
                  path: paths.dashboard.admin.supplier.list,
                },
                {
                  title: "Fournisseurs archivés",
                  path: paths.dashboard.admin.supplier.archivedList,
                },
                { title: "Ajouter", path: paths.dashboard.admin.supplier.new },
              ],
            },
            {
              title: "Achats",
              path: paths.dashboard.admin.supplierOrder.root,
              icon: ICONS.achats,
              children: [
                {
                  title: "Commandes d'achats ",
                  path: paths.dashboard.admin.supplierOrder.root,
                  children: [
                    {
                      title: "Toutes les commandes",
                      path: paths.dashboard.admin.supplierOrder
                        .root,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.supplierOrder.new,
                    },
                  ],
                },
                {
                  title: "Commandes de préco",
                  path: paths.dashboard.admin.saleOrder.root,
                },
              ],
            },
            {
              title: "Utilisateurs",
              path: paths.dashboard.admin.user.all_users,
              icon: ICONS.user,
              children: [
                {
                  title: "Tous les utilisateurs",
                  path: paths.dashboard.admin.user.all_users,
                },
                { title: "Ajouter", path: paths.dashboard.admin.user.new },
                {
                  title: "Editeur de rôles",
                  path: paths.dashboard.admin.user.role,
                },
              ],
            },
            {
              title: "Médiathèque",
              path: paths.dashboard.admin.media.root,
              icon: ICONS.file,
            },
          ],
        },
        {
          subheader: 'Chatbot Configuration',
          items: [
            {
              title: 'Gestion Des Tickets',
              path: paths.dashboard.chatbot.ticket.root,
              icon: ICONS.mail,
              children: [
                { title: 'Liste Des Tickets', path: paths.dashboard.chatbot.ticket.root },
                { title : 'Voir Les Conversations', path: paths.dashboard.chatbot.ticket.conversations },
              ],
            },
          ],
        },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("STOCK_MANAGER")) {
      return [
        {
          subheader: "MyDressin",
          items: [
            {
              title: "Accueil",
              path: paths.dashboard.admin.root,
              icon: ICONS.dashboard,
            },
            {
              title: "Chat",
              path: paths.dashboard.admin.chat,
              icon: ICONS.chat,
            },
          ],
        },
        {
          subheader: "Gestion",
          items: [
            {
              title: "Produits",
              path: paths.dashboard.admin.product.root,
              icon: ICONS.product,

              children: [
                {
                  title: "Tous les produits",
                  path: paths.dashboard.admin.product.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.product.new },
                {
                  title: "Catégories",
                  path: paths.dashboard.admin.product.category,
                },
                {
                  title: "Étiquettes",
                  path: paths.dashboard.admin.product.tags,
                },
                {
                  title: "Attributs",
                  path: paths.dashboard.admin.product.attribut,
                },
                {
                  title: "Migration de stock",
                  path: paths.dashboard.admin.product.migration,
                },
              ],
            },
            {
              title: "Fournisseurs",
              path: paths.dashboard.admin.supplier.root,
              icon: ICONS.suppliers,
              children: [
                {
                  title: "Tous les fournisseurs",
                  path: paths.dashboard.admin.supplier.list,
                },
                {
                  title: "Fournisseurs archivés",
                  path: paths.dashboard.admin.supplier.archivedList,
                },
                { title: "Ajouter", path: paths.dashboard.admin.supplier.new },
              ],
            },
            {
              title: "Achats",
              path: paths.dashboard.admin.supplierOrder.root,
              icon: ICONS.achats,
              children: [
                {
                  title: "Commandes d'achats ",
                  path: paths.dashboard.admin.supplierOrder.root,
                  children: [
                    {
                      title: "Toutes les commandes",
                      path: paths.dashboard.admin.supplierOrder
                        .root,
                    },
                    {
                      title: "Ajouter",
                      path: paths.dashboard.admin.supplierOrder.new,
                    },
                  ],
                },
                {
                  title: "Commandes de préco",
                  path: paths.dashboard.admin.saleOrder.root,
                },
              ],
            },
            {
              title: "Médiathèque",
              path: paths.dashboard.admin.media.root,
              icon: ICONS.file,
            },
          ],
        },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("GESTIONNAIRE_RETOUR")) {
      return [
        {
          subheader: "MyDressin",
          items: [
            {
              title: "Accueil",
              path: paths.dashboard.admin.root,
              icon: ICONS.dashboard,
            },
            {
              title: "Chat",
              path: paths.dashboard.admin.chat,
              icon: ICONS.chat,
            },
          ],
        },
        {
          subheader: "Gestion",
          items: [
            {
              title: "Commandes",
              path: paths.dashboard.admin.order.all_orders,
              icon: ICONS.order,
              children: [
                {
                  title: "Toutes les commandes",
                  path: paths.dashboard.admin.order.all_orders,
                },
                {
                  title: "Tous les remboursements",
                  path: paths.dashboard.admin.order.refund.root,
                },
                { title: "Ajouter", path: paths.dashboard.admin.order.create },
                {
                  title: "Statistiques commandes",
                  path: paths.dashboard.admin.order.statistics,
                },
              ],
            },
            {
              title: "Médiathèque",
              path: paths.dashboard.admin.media.root,
              icon: ICONS.file,
            },
          ],
        },
        {
          subheader: 'Chatbot Configuration',
          items: [
            {
              title: 'Gestion Des Tickets',
              path: paths.dashboard.chatbot.ticket.root,
              icon: ICONS.mail,
              children: [
                { title: 'Liste Des Tickets', path: paths.dashboard.chatbot.ticket.root },
                { title : 'Voir Les Conversations', path: paths.dashboard.chatbot.ticket.conversations },
              ],
            },
          ],
        },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("DRIVER")) {
      return [
        {
          subheader: "DRIVER",
          items: [
            {
              title: "Home",
              path: paths.dashboard.driver.root,
              icon: ICONS.dashboard,
            },
            {
              title: "Commandes Fournisseur",
              path: paths.dashboard.driver.listSupplierOrder,
              icon: ICONS.order,
            },
            {
              title: "Fournisseurs",
              path: paths.dashboard.driver.supplier,
              icon: ICONS.supplier,
            },
          ],
        },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("SUPPORT")) {
      return [
        {
          subheader: "SUPPORT",
          items: [
            {
              title: 'Support Agent',
              path: paths.dashboard.chatbot.support.root,
              icon: ICONS.user,
              children: [
                { title: 'Liste des tickets', path: paths.dashboard.chatbot.support.root },
                { title : 'Voir Les Conversations', path: paths.dashboard.chatbot.support.conversation },
              ],
            },
          ]
        },
      ];
    } else if (userInfo?.realm_access?.roles?.includes("LEADER")) {
      return [
        {
          subheader: "LEADER",
          items: [
            {
              title: 'Gestion Des Tickets',
              path: paths.dashboard.chatbot.ticket.root,
              icon: ICONS.mail,
              children: [
                { title: 'Liste Des Tickets', path: paths.dashboard.chatbot.ticket.root },
                { title : 'Voir Les Conversations', path: paths.dashboard.chatbot.ticket.conversations },
              ],
            },
          ]
        }
      ]
    }
  }, []);

  return data;
}
