import Box, { BoxProps } from '@mui/material/Box';

import { useResponsive } from '@/hooks';
import { useSettingsContext } from '@/shared/components/settings';

import { NAV, HEADER } from '../config-layout';
import { useEffect, useState } from 'react';
import { generateToken, messaging } from '@/utils/firebase';
import { onMessage } from 'firebase/messaging';
import toast, { Toaster } from 'react-hot-toast';
import NotificationToastContent from '@/shared/components/notification-popup';
import { TokenPayload } from '@/shared/types/user';
import { getTokenInfo } from '@/utils/token';

// ----------------------------------------------------------------------

const SPACING = 8;

export default function Main({ children, sx, ...other }: BoxProps) {
  const settings = useSettingsContext();

  const lgUp = useResponsive('up', 'lg');

  const isNavHorizontal = settings.themeLayout === 'horizontal';

  const isNavMini = settings.themeLayout === 'mini';

  useEffect(() => {
    generateToken();
  }, []);
 
  useEffect(() => {
    onMessage(messaging, (payload) => {
      const payloadRoles = payload?.data?.roles ? payload.data.roles.split(',') : [];
      const token = localStorage.getItem("token");
      if (token) {
        const infosUser: TokenPayload = getTokenInfo(token);
        const userHasMatchingRole = infosUser.realm_access?.roles.some((role: string) =>
          payloadRoles.includes(role)
        );
  
        if (userHasMatchingRole) {
          toast.custom(
            (toastInfo) => (
              <NotificationToastContent
                toastInfo={toastInfo}
                toast={toast}
                payload={payload}
              />
            ),
            { position: 'bottom-right' }
          );
        }
      }
    });
  }, []);
  ;

  if (isNavHorizontal) {
    return (
      <Box
        component="main"
        sx={{
          minHeight: 1,
          display: 'flex',
          flexDirection: 'column',
          pt: `${HEADER.H_MOBILE + 24}px`,
          pb: 10,
          ...(lgUp && {
            pt: `${HEADER.H_MOBILE * 2 + 40}px`,
            pb: 15,
          }),
        }}
      >
        {children}
      </Box>
    );
  }

  return (
    <>
      <Toaster />
      <Box
        component="main"
        sx={{
          flexGrow: 1,
          minHeight: 1,
          display: 'flex',
          flexDirection: 'column',
          py: `${HEADER.H_MOBILE + SPACING}px`,
          ...(lgUp && {
            px: 2,
            py: `${HEADER.H_DESKTOP + SPACING}px`,
            width: `calc(100% - ${NAV.W_VERTICAL}px)`,
            ...(isNavMini && {
              width: `calc(100% - ${NAV.W_MINI}px)`,
            }),
          }),
          ...sx,
        }}
        {...other}
      >
        {children}
      </Box>
    </>
  );
}
