'use client';

import React, { useState, useEffect, ReactNode, Children } from 'react';
import Box from '@mui/material/Box';
import Tab from '@mui/material/Tab';
import TabContext from '@mui/lab/TabContext';
import TabList from '@mui/lab/TabList';
import { Container, useTheme } from '@mui/material';
import { usePathname, useRouter } from 'next/navigation';
import { useSettingsContext } from '@/shared/components/settings';


interface Props {
    children: ReactNode;

}


const TABS = [
    { label: "Connexion Paypal", value: "paypal_connexion" },
    { label: "Configuration Paypal", value: "paypal" },
    { label: "Carte bancaire", value: "credit_card" },
    { label: "Virement bancaire", value: "bank_transfer" },
    { label: "PayPlug", value: "payplug" },
    { label: "Configuration externe de PayPlug", value: "payplug_configuration" },
]

export default function PaymentMethodsLayout({ children }: Props) {
    const theme = useTheme();
    const router = useRouter();
    const pahname = usePathname();
    const [value, setValue] = useState<string>(pahname?.split('/').pop() as string);
    const settings = useSettingsContext();

    const handleClick = (link: string) => {
        router.push(link)
        setValue(link)
    }
    const handleChange = (event: React.SyntheticEvent, newValue: string) => {
        if (!isNaN(parseInt(newValue))) {
            setValue(newValue);
        }
    };

    return (

        <TabContext value={value}>
            <Box sx={{ width: '100%', typography: 'subtitle1' }}>
                <Box sx={{
                    borderBottom: 1,
                    borderColor: 'divider',
                    display: 'flex',
                    justifyContent: 'center',
                    alignItems: 'center'
                }}>
                    <TabList onChange={handleChange} aria-label="lab API tabs example" sx={{
                        '& .MuiTab-root': {
                            color: 'inherit', '&.Mui-selected': { color: theme.palette.primary.main, },
                        }, '& .MuiTabs-indicator': { backgroundColor: theme.palette.primary.main, },
                    }}>
                        {TABS.map((tab) => (
                            <Tab key={tab.value} label={tab.label} value={tab.value} onClick={() => handleClick(tab.value)} />
                        ))}
                    </TabList>
                </Box>
                <Container maxWidth={settings.themeStretch ? false : 'lg'} sx={{ paddingY: 4 }}>
                    {children}
                </Container>
            </Box>
        </TabContext>
    );
}
