import { useEffect, useState } from "react";
import Box from "@mui/material/Box";
import Card from "@mui/material/Card";
import Grid from "@mui/material/Unstable_Grid2";
import TextField from "@mui/material/TextField";
import { useSnackbar } from "@/components/snackbar";
import {UserByEmail } from "@/shared/api/user";
import { Avatar } from "@mui/material";
import Label from "@/shared/components/label";
import { IUser } from "@/shared/types/user";

export default function AccountGeneral() {
  const { enqueueSnackbar } = useSnackbar();
  const [email, setEmail] = useState<string | null>(null);

  useEffect(() => {
    const storedEmail = localStorage.getItem("email");
    setEmail(storedEmail);
  }, []);
  const [user, setUser] = useState<IUser | null>(null);

  useEffect(() => {
    const fetchUserData = async () => {
      if (email !== "" && email !== null) {
        try {
          const response = await UserByEmail(email);

          setUser(response.data);
        } catch (error) {
          console.error("Error fetching user data:", error);
        }
      }
    };

    fetchUserData();
  }, [email]);

  const translateStatus = (status: string) => {
    switch (status) {
      case "APPROVED":
        return "Approuvé";
      case "PENDING":
        return "En attente";
      case "BANNED":
        return "Banni";
      default:
        return "Indéfini";
    }
  };

  return (
    <Grid container spacing={3}>
      <Grid xs={12} md={4}>
        <Card
          sx={{
            pb: 10,
            px: 3,
            textAlign: "center",
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
          }}
        >
          <Label
            variant="soft"
            color={
              user?.status === "APPROVED"
                ? "success"
                : user?.status === "PENDING"
                ? "warning"
                : user?.status === "BANNED"
                ? "error"
                : "default"
            }
            sx={{ position: "absolute", right: 16, top: 6 }}
          >
            {user?.status && translateStatus(user.status)}
          </Label>
          <Avatar
            alt={user?.firstName}
            src={user?.imageUrl || undefined}
            sx={{ width: 120, height: 120, top: 35 }}
          />
        </Card>
      </Grid>

      <Grid xs={12} md={8}>
        <Card sx={{ p: 3 }}>
          <Box rowGap={3} columnGap={2} display="grid">
            <TextField
              disabled
              name="firstName"
              label="Prénom"
              value={user?.firstName || ""}
              InputProps={{ readOnly: true, style: { color: "#888" } }}
              fullWidth
            />
            <TextField
              disabled
              name="lastName"
              label="Nom de famille"
              value={user?.lastName || ""}
              InputProps={{ readOnly: true, style: { color: "#888" } }}
              fullWidth
            />
            <TextField
              disabled
              name="uid"
              label="UID"
              value={user?.uid || ""}
              InputProps={{ readOnly: true, style: { color: "#888" } }}
              fullWidth
            />
            <TextField
              disabled
              name="email"
              label="Adresse e-mail"
              value={user?.email || ""}
              InputProps={{ readOnly: true, style: { color: "#888" } }}
              fullWidth
            />
            <TextField
              disabled
              name="pseudo"
              label="Pseudo"
              value={user?.pseudo || ""}
              InputProps={{ readOnly: true, style: { color: "#888" } }}
              fullWidth
            />
            <TextField
              disabled
              name="phoneNumber"
              label="Numéro de téléphone"
              value={user?.phoneNumber || ""}
              InputProps={{ readOnly: true, style: { color: "#888" } }}
              fullWidth
            />
            <TextField
              disabled
              name="role"
              label="Rôle"
              value={user?.roles?.value || ""}
              InputProps={{ readOnly: true, style: { color: "#888" } }}
              fullWidth
            />
          </Box>
        </Card>
      </Grid>
    </Grid>
  );
}
