"use client";
import * as Yup from "yup";
import { useState } from "react";
import { useForm } from "react-hook-form";
import { yupResolver } from "@hookform/resolvers/yup";

import Alert from "@mui/material/Alert";
import Stack from "@mui/material/Stack";
import IconButton from "@mui/material/IconButton";
import LoadingButton from "@mui/lab/LoadingButton";
import InputAdornment from "@mui/material/InputAdornment";

import { useRouter, useSearchParams } from "@/hooks";

import { useBoolean } from "@/hooks";

import { useAuthContext } from "@/hooks";
import { 
  PATH_AFTER_LOGIN, 
  PATH_AFTER_LOGIN_DRIVER, 
  PATH_AFTER_LOGIN_GESTIONNAIRE_DE_PRECO, 
  PATH_AFTER_LOGIN_GESTIONNAIRE_RETOUR, 
  PATH_AFTER_LOGIN_LIVE_MANAGER, 
  PATH_AFTER_LOGIN_SALES_MANAGER, 
  PATH_AFTER_LOGIN_STOCK_MANAGER , 
  PATH_AFTER_LOGIN_LEADER,
  PATH_AFTER_LOGIN_SUPPORT
} from "@/config-global";

import Iconify from "@/shared/components/iconify";
import FormProvider, { RHFTextField } from "@/shared/components/hook-form";
import { loginUser } from "@/shared/api/user";
import { getTokenInfo } from "@/utils/token";

// ----------------------------------------------------------------------

export default function JwtLoginView() {
  const { login } = useAuthContext();

  const router = useRouter();

  const [errorMsg, setErrorMsg] = useState("");

  const searchParams = useSearchParams();

  const returnTo = searchParams.get("returnTo");

  const password = useBoolean();

  const LoginSchema = Yup.object().shape({
    username: Yup.string().required("Le nom d'utilisateur est requis"),
    password: Yup.string().required("Le mot de passe est requis"),
  });

  const defaultValues = {
    username: "",
    password: "",
  };

  const methods = useForm({
    resolver: yupResolver(LoginSchema),
    defaultValues,
  });

  const {
    reset,
    handleSubmit,
    formState: { isSubmitting },
  } = methods;

  const onSubmit = handleSubmit(async (data) => {
    try {
      const response = await loginUser(data);
  
      if (response.status === 200) {
        const { token, refreshToken, expirationDurationInSec } = response.data.mainResponse;
  
        // Stocker les informations dans localStorage
        localStorage.setItem("token", token);
        localStorage.setItem("chatbotToken", response.data.chatbotResponse.token);
        localStorage.setItem("refreshToken", refreshToken);
        localStorage.setItem("expirationDurationInSec", expirationDurationInSec.toString());
        localStorage.setItem("email", data.username);
        // Récupérer les informations du token
        const informations = getTokenInfo(token);
  
        // Déterminer la redirection en fonction des rôles
        const userRoles = informations.realm_access.roles;

        if (userRoles.includes("DRIVER")) {
          router.push(returnTo || PATH_AFTER_LOGIN_DRIVER);
        } else if (userRoles.includes("LIVE_MANAGER")) {
          router.push(returnTo || PATH_AFTER_LOGIN_LIVE_MANAGER);
        } else if (userRoles.includes("SALES_MANAGER")) {
          router.push(returnTo || PATH_AFTER_LOGIN_SALES_MANAGER);
        } else if (userRoles.includes("STOCK_MANAGER")) {
          router.push(returnTo || PATH_AFTER_LOGIN_STOCK_MANAGER);
        } else if (userRoles.includes("GESTIONNAIRE_DE_PRECO")) {
          router.push(returnTo || PATH_AFTER_LOGIN_GESTIONNAIRE_DE_PRECO);
        } else if (userRoles.includes("GESTIONNAIRE_RETOUR")) {
          router.push(returnTo || PATH_AFTER_LOGIN_GESTIONNAIRE_RETOUR);
        } else if (userRoles.includes("ADMIN")) {
            router.push(returnTo || PATH_AFTER_LOGIN);
        } else if (userRoles.includes("LEADER")) {
          router.push(returnTo || PATH_AFTER_LOGIN_LEADER);
        } else if (userRoles.includes("SUPPORT")) {
          router.push(returnTo || PATH_AFTER_LOGIN_SUPPORT);
        }
        else {
          router.push(returnTo || PATH_AFTER_LOGIN);
        }
      }
    } catch (error: any) {
      reset();
  
      const errorMessage = typeof error === "string" ? error : error.message;
  
      if (errorMessage !== "Information incorrecte, veuillez réessayer" && errorMessage !== "Utilisateur non trouvé") {
        setErrorMsg("Une erreur est survenue, veuillez réessayer plus tard.");
      } else {
        setErrorMsg(errorMessage);
      }
    }
  });  

  const renderForm = (
    <Stack
      spacing={2.5}
      onKeyDown={(e) => {
        if (e.key === "Enter") {
          onSubmit();
        }
      }}
    >
      <RHFTextField name="username" label="Nom d'utilisateur" />
      <RHFTextField
        name="password"
        label="Mot de passe"
        type={password.value ? "text" : "password"}
        InputProps={{
          endAdornment: (
            <InputAdornment position="end">
              <IconButton onClick={password.onToggle} edge="end">
                <Iconify
                  icon={
                    password.value ? "solar:eye-bold" : "solar:eye-closed-bold"
                  }
                />
              </IconButton>
            </InputAdornment>
          ),
        }}
      />
      <LoadingButton
        fullWidth
        color="secondary"
        size="large"
        type="button"
        variant="contained"
        loading={isSubmitting}
        onClick={onSubmit}
        sx={{
          backgroundColor: '#A66FD5',
          '&:hover': {
            backgroundColor: (theme) => theme.palette.secondary.main,
          },
        }}
      >
        Se connecter
      </LoadingButton>
    </Stack>
  );

  return (
    <>

      {!!errorMsg && (
        <Alert severity="error" sx={{ mb: 3 }}>
          {errorMsg}
        </Alert>
      )}

      <FormProvider methods={methods} onSubmit={onSubmit}>
        {renderForm}
      </FormProvider>
    </>
  );
}
