import { Box, Button, Stack, Chip, Paper } from "@mui/material";
import React from "react";
import Iconify from "@/shared/components/iconify";

type Props = {
  filters: {
    nameOrUGS: string;
    termColor: string[];
    termLabel: string[];
    termChoice: string[];
  };
  onFilters: (name: string, value: any) => void;
  onResetFilters: () => void;
  results: number;
  sx?: object; // Si vous avez des styles supplémentaires
};

export default function VariationTableFiltersResult({
  filters,
  onFilters,
  onResetFilters,
  results,
  sx,
}: Props) {
  const handleRemoveTermColor = (color: string) => {
    const updatedColors = filters.termColor.filter((c) => c !== color);
    onFilters("termColor", updatedColors);
  };

  const handleRemoveTermLabel = (label: string) => {
    const updatedLabels = filters.termLabel.filter((l) => l !== label);
    onFilters("termLabel", updatedLabels);
  };

  const handleRemoveTermChoice = (choice: string) => {
    const updatedChoices = filters.termChoice.filter((c) => c !== choice);
    onFilters("termChoice", updatedChoices);
  };

  return (
    <Stack spacing={1.5} sx={sx}>
      <Box sx={{ typography: "body2" }}>
        <strong>{results}</strong>
        <Box component="span" sx={{ color: "text.secondary", ml: 0.25 }}>
          résultats trouvés
        </Box>
      </Box>

      <Stack direction="row" flexWrap="wrap" alignItems="center" spacing={1}>
        {/* Affichage des filtres de couleur */}
        {!!filters.termColor.length && (
          <FilterBlock label="Couleur:">
            {filters.termColor.map((color) => (
              <Chip key={color} label={color} size="small" onDelete={() => handleRemoveTermColor(color)} />
            ))}
          </FilterBlock>
        )}

        {/* Affichage des filtres de label */}
        {!!filters.termLabel.length && (
          <FilterBlock label="Label:">
            {filters.termLabel.map((label) => (
              <Chip key={label} label={label} size="small" onDelete={() => handleRemoveTermLabel(label)} />
            ))}
          </FilterBlock>
        )}

        {/* Affichage des filtres de choix */}
        {!!filters.termChoice.length && (
          <FilterBlock label="Choix:">
            {filters.termChoice.map((choice) => (
              <Chip key={choice} label={choice} size="small" onDelete={() => handleRemoveTermChoice(choice)} />
            ))}
          </FilterBlock>
        )}

        {/* Bouton pour réinitialiser les filtres */}
        {
          (filters.nameOrUGS ||
            !!filters.termChoice.length ||
            !!filters.termLabel.length ||
            !!filters.termColor.length) && (
            <Button
              color="error"
              onClick={onResetFilters}
              startIcon={<Iconify icon="solar:trash-bin-trash-bold" />}
            >
              Réinitialiser
            </Button>
          )
        }
      </Stack>
    </Stack>
  );
}

type FilterBlockProps = {
  label: string;
  children: React.ReactNode;
};

function FilterBlock({ label, children }: FilterBlockProps) {
  return (
    <Stack
      component={Paper}
      variant="outlined"
      spacing={1}
      direction="row"
      sx={{ p: 1, borderRadius: 1, overflow: "hidden", borderStyle: "dashed" }}
    >
      <Box component="span" sx={{ typography: "subtitle2" }}>
        {label}
      </Box>
      <Stack direction="row" spacing={1}>
        {children}
      </Stack>
    </Stack>
  );
}
