import React, { useCallback } from "react";
import Stack from "@mui/material/Stack";
import TextField from "@mui/material/TextField";
import InputAdornment from "@mui/material/InputAdornment";
import Iconify from "../../../components/iconify";
import { IUserCartTableFilters, IUserCartTableFilterValue } from "@/shared/types/saleSession";

// ----------------------------------------------------------------------

type Props = {
  filters: IUserCartTableFilters;
  onFilters: (name: string, value: IUserCartTableFilterValue) => void;

};

export default function UserCartTableToolbar({ filters, onFilters }: Props) {

  const handleFilterName = useCallback(
    (event: React.ChangeEvent<HTMLInputElement>) => {
      onFilters("keyword", event.target.value);
    },
    [onFilters]
  );

  const handleFilterProduct = useCallback(
    (event: React.ChangeEvent<HTMLInputElement>) => {
      onFilters("productKeyword", event.target.value);
    },
    [onFilters]
  );

  return (
    <>
      <Stack
        spacing={2}
        alignItems={{ xs: "flex-end", md: "center" }}
        direction={{
          xs: "column",
          md: "row",
        }}
        sx={{
          p: 2.5,
          pr: { xs: 2.5, md: 1 },
        }}
      >
        <Stack
          direction="row"
          alignItems="center"
          spacing={2}
          flexGrow={1}
          sx={{ width: 1 }}
        >
          <TextField
            fullWidth
            value={filters.keyword}
            onChange={handleFilterName}
            placeholder="Rechercher un client ...
"
            InputProps={{
              startAdornment: (
                <InputAdornment position="start">
                  <Iconify
                    icon="eva:search-fill"
                    sx={{ color: "text.disabled" }}
                  />
                </InputAdornment>
              ),
            }}
          />
          <TextField
            fullWidth
            value={filters.productKeyword}
            onChange={handleFilterProduct}
            placeholder="Rechercher un produit ...
"
            InputProps={{
              startAdornment: (
                <InputAdornment position="start">
                  <Iconify
                    icon="eva:search-fill"
                    sx={{ color: "text.disabled" }}
                  />
                </InputAdornment>
              ),
            }}
          />


        
        </Stack>
      </Stack>

    </>
  );
}
