import Tooltip from "@mui/material/Tooltip";
import TableRow from "@mui/material/TableRow";
import DeleteIcon from "@mui/icons-material/Delete";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import ListItemText from "@mui/material/ListItemText";
import Label from "../../../components/label";
import { IOrder } from "@/shared/types/saleSession";
import { Checkbox } from "@mui/material";
import { fDate, fTime } from "@/utils/format-time";
import { useDeleteOrder } from "@/shared/api/saleSession";
import { useSnackbar } from "@/components/snackbar";
import { useBoolean } from "@/hooks/use-boolean";
import QuantityEditForm from "./order-quick-edit-quantity";
import Iconify from "@/components/iconify";
// ----------------------------------------------------------------------

type Props = {
  selected: boolean;
  row: IOrder;
};

export default function OrderTableRow({ row, selected }: Props) {
  const {
    orderId,
    name,
    statutPanier,
    email,
    price,
    id,
    CreatedAt,
    statutOrder,
    UGS,
    title,
    quantity,
    EditDate,
  } = row;

  const { enqueueSnackbar } = useSnackbar();
  const { deleteOrder } = useDeleteOrder();
  const quickEdit = useBoolean();

  const handleDelete = async () => {
    try {
      await deleteOrder(orderId);
      enqueueSnackbar("Commande supprimée avec succès", { variant: "success" });

    } catch (error) {
      enqueueSnackbar("Échec de la suppression de la commande", { variant: "error" });
    }
  };
  const shouldShowActions = statutPanier !== "DELETED_BO" && statutPanier !== "PAYED";

  const getStatutPanierLabel = (status: string) => {
    switch (status) {
      case "CONSULTED":
        return "Consulter";
      case "NOT_CONSULTED":
        return "Non Consulter";
      case "DELETED_SITE":
        return "Supprimer depuis Site";
      case "DELETED_BO":
        return "Supprimer depuis Bo";
      case "PAYED" : 
        return "payer"
      default:
        return "Inconnu";
    }
  };
  const getStatutOrderLabel = (status: string) => {
    switch (status) {
      case "EN_ATTENTE":
        return "En attente";
      case "EN_COURS":
        return "En cours";
      case "TERMINEE":
        return "payer";
      default:
        return "Inconnu";
    }
  };
  return (
    <>
      <TableRow hover selected={selected}>
        <TableCell padding="checkbox">
          <Checkbox checked={selected} />
        </TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>[{id}] {email}</TableCell>
        <TableCell sx={{ display: "flex", alignItems: "center" }}>
          <ListItemText
            primary={name}
            secondary={email}
            primaryTypographyProps={{ typography: "body2" }}
            secondaryTypographyProps={{
              component: "span",
              color: "text.disabled",
            }}
          />
        </TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{title}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{UGS}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{quantity}</TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(CreatedAt)}
            secondary={fTime(CreatedAt)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{price}</TableCell>

        <TableCell>
          <Label
            variant="soft"
            color={
              (statutPanier === "CONSULTED" && "success") ||
              (statutPanier === "NOT_CONSULTED" && "warning") ||
              (statutPanier === "DELETED_BO" && "error") ||
              (statutPanier === "DELETED_SITE" && "error") ||
              (statutPanier === "PAYED" && "success") ||
              "default"
            }
          >
            {getStatutPanierLabel(statutPanier)}
          </Label>
        </TableCell>
        <TableCell>
          <Label
            variant="soft"
            color={
              (statutOrder === "EN_COURS" && "success") ||
              (statutOrder === "EN_ATTENTE" && "warning") ||
              (statutOrder === "TERMINEE" && "success") ||
              "default"
            }
          >
            {getStatutOrderLabel(statutOrder)}
          </Label>
        </TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(EditDate)}
            secondary={fTime(EditDate)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell align="right" sx={{ px: 1, whiteSpace: "nowrap" }}>
        {shouldShowActions ? (
          <>
            <Tooltip title="Modifier la quantité" placement="top" arrow>
              <IconButton
                color="primary"
                onClick={() => {
                  quickEdit.onTrue();
                }}
              >
                <Iconify icon="solar:pen-bold" />
              </IconButton>
            </Tooltip>

            <Tooltip title="Supprimer" placement="top" arrow>
              <IconButton color="error" onClick={handleDelete}>
                <DeleteIcon />
              </IconButton>
            </Tooltip>
          </>
            ) : null}
        </TableCell>
      </TableRow>
      <QuantityEditForm
        open={quickEdit.value}
        onClose={quickEdit.onFalse}
        orderId={orderId}
        initialQuantity={quantity}
      />
    </>
  );
}
