import * as Yup from "yup";
import { useMemo,useEffect } from "react";
import { useForm } from "react-hook-form";
import { yupResolver } from "@hookform/resolvers/yup";


import { useUpdateClient } from "@/shared/api/saleSession"; // Assurez-vous que le chemin est correct

import Box from "@mui/material/Box";
import Alert from "@mui/material/Alert";
import Button from "@mui/material/Button";
import Dialog from "@mui/material/Dialog";
import MenuItem from "@mui/material/MenuItem";
import LoadingButton from "@mui/lab/LoadingButton";
import DialogTitle from "@mui/material/DialogTitle";
import DialogActions from "@mui/material/DialogActions";
import DialogContent from "@mui/material/DialogContent";
import { USER_STATUS_OPTIONS } from "@/shared/types/saleSession";

import { useSnackbar } from "@/components/snackbar";
import FormProvider, { RHFSelect, RHFTextField } from "@/components/hook-form";

import { IUserItem } from "@/shared/types/saleSession";
import Typography from "@mui/material/Typography";
import TextField from "@mui/material/TextField";

// ----------------------------------------------------------------------

type Props = {
  open: boolean;
  onClose: VoidFunction;
  currentUser?: IUserItem;
};

export default function UserQuickEditForm({
  currentUser,
  open,
  onClose,
}: Props) {
  const { enqueueSnackbar } = useSnackbar();

  const { updateClient } = useUpdateClient();

  const NewUserSchema = Yup.object().shape({
    firstName: Yup.string().required("le nom est requis"),
    lastName: Yup.string().required("le prenom est requis"),
    pseudo: Yup.string().required("le pseudo est requis"),
  
  });

  const defaultValues = useMemo(
    () => ({
      firstName: currentUser?.firstName ||"",
      lastName: currentUser?.lastName || "",
      pseudo: currentUser?.pseudo || "",
     
    }),
    [currentUser]
  );

  const methods = useForm({
    resolver: yupResolver(NewUserSchema),
    defaultValues,
  });

  const {
    reset,
    handleSubmit,
    formState: { isSubmitting },
  } = methods;

   const onSubmit = handleSubmit(async (data) => {
    try {

      if (!currentUser?.id) {
        throw new Error("User ID is missing");
      }
  
      const updatedClient = {
        ...currentUser,
        firstName: data.firstName,
        lastName: data.lastName ,
        pseudo: data.pseudo,
       
      };

      await updateClient(currentUser?.id || "", updatedClient);
      

      reset();
      onClose();
      enqueueSnackbar("Mise à jour réussie !");
    } catch (error) {
      console.error(error);
      enqueueSnackbar("Échec de la mise à jour", { variant: "error" });
    }
  });
  useEffect(() => {
    reset({
      firstName: currentUser?.firstName || "" ,
      lastName: currentUser?.lastName || "",
      pseudo: currentUser?.pseudo || "",
     
      
    });
  }, [currentUser, reset]);
  

  return (
    <Dialog
      fullWidth
      maxWidth={false}
      open={open}
      onClose={onClose}
      PaperProps={{
        sx: { maxWidth: 720 },
      }}
    >
      <FormProvider methods={methods} onSubmit={onSubmit}>
        <DialogTitle>Modifier le client</DialogTitle>

        <DialogContent>
          <Typography variant="subtitle2" component="h2">
            Nom d'utilisateur : [{currentUser?.id}] {currentUser?.email}
          </Typography>
          <Box
            rowGap={3}
            columnGap={3}
            display="grid"
            gridTemplateColumns={{
              xs: "repeat(1, 1fr)",
              sm: "repeat(2, 1fr)",
            }}
            sx={{ marginTop: 4 }}
          >
           

            <RHFTextField name="firstName" label="Nom " />
            <RHFTextField name="lastName" label="Prenom" />
            <RHFTextField name="pseudo" label="Pseudo" />
          </Box>
        </DialogContent>

        <DialogActions>
          <Button variant="outlined" onClick={onClose}>
            Annuler
          </Button>

          <LoadingButton
            type="submit"
            variant="contained"
            loading={isSubmitting}
          >
            Mettre à jour
          </LoadingButton>
        </DialogActions>
      </FormProvider>
    </Dialog>
  );
}
