import Tooltip from "@mui/material/Tooltip";
import TableRow from "@mui/material/TableRow";

import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import ListItemText from "@mui/material/ListItemText";
import { useBoolean } from "@/hooks/use-boolean";

import Label from "../../../components/label";
import Iconify from "@/components/iconify";

import { IUserItem } from "@/shared/types/saleSession";
import { USER_STATUS_OPTIONS } from "@/shared/types/saleSession";
import { useBanClient ,useAddProductToCartFromLive,useUnbanClient} from "@/shared/api/saleSession";
import { useSnackbar } from "@/components/snackbar";

import UserQuickEditForm from "./user-quick-edit-form";
import ShoppingCartIcon from "@mui/icons-material/ShoppingCart";
import BlockIcon from "@mui/icons-material/Block";
import CheckCircleIcon from "@mui/icons-material/CheckCircle"; 
import { fDate } from "@/utils/format-time";


// ----------------------------------------------------------------------

type Props = {
  row: any; 
  onAddToCart: (clientId: string,isRegistred:boolean,clientEmail:string) => void;};

export default function UserTableRow({ row ,onAddToCart}: Props) {
  const { firstName,lastName, status, email, pseudo, imageUrl, id, uid,createdAt } = row;

  const quickEdit = useBoolean();
  const { enqueueSnackbar } = useSnackbar();
  const { banClient } = useBanClient();
  const { unbanClient } = useUnbanClient();

 
  const handleToggleBan = async (userId: any) => {
    const userName = `${row.firstName} ${row.lastName}`;

    try {
      if (status === "BANNED") {
        await unbanClient(userId);
        enqueueSnackbar(`${userName} a été débanni avec succès`, { variant: "success" });
      } else {
        await banClient(userId);
        enqueueSnackbar(`${userName} a été banni avec succès`, { variant: "success" });
      }
    } catch (error) {
      enqueueSnackbar(`Échec de l'opération sur ${userName}`, { variant: "error" });
    }
  };

  const handleAddToCart = () => {
    onAddToCart(row.uid,true,row.email); 
  };
  const getStatusLabel = (status: string) => {
    const statusOption = USER_STATUS_OPTIONS.find(option => option.value === status);
    return statusOption ? statusOption.label : status;
  };
  const getStatusColor = (status: string) => {
    switch (status) {
      case "APPROVED":
        return "success"; // Green
      case "BANNED":
        return "error"; // Red
      case "PENDING":
        return "warning"; // Yellow or Orange
      default:
        return "default"; // Grey or any other default color
    }
  };
  

  return (
    <TableRow
      sx={{ backgroundColor: status === "BANNED" ? "#FFEBEE" : "inherit" }}
    >
      <TableCell>
        <Tooltip title="Ajouter au panier">
          <IconButton sx={{ color: "#00e676" }} onClick={()=>handleAddToCart()}>
            <ShoppingCartIcon />
          </IconButton>
        </Tooltip>
      </TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>[{uid}] {email}</TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>{pseudo}</TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>{firstName}</TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>{lastName}</TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>
      {createdAt ? fDate(createdAt) : "--/--/----"}
      </TableCell>
      <TableCell sx={{ whiteSpace: "nowrap" }}>{email}</TableCell>
      <TableCell>
        <Label
          variant="soft"
          color={getStatusColor(status)}
        >
           {getStatusLabel(status)}
        </Label>
      </TableCell>

      <TableCell align="right" sx={{ px: 1, whiteSpace: "nowrap" }}>
        <Tooltip title="Modifier" placement="top" arrow>
          <IconButton
            color={quickEdit.value ? "inherit" : "default"}
            onClick={quickEdit.onTrue}
          >
            <Iconify icon="solar:pen-bold" />
          </IconButton>
        </Tooltip>
       
        <Tooltip title={status === "BANNED" ? "Débannir" : "Bannir"} placement="top" arrow>
          <IconButton onClick={() => handleToggleBan(row.id)} color={status === "BANNED" ? "primary" : "error"}>
            {status === "BANNED" ? <CheckCircleIcon /> : <BlockIcon />} {/* Icône changeante */}
          </IconButton>
        </Tooltip>

      </TableCell>

      <UserQuickEditForm
        currentUser={row}
        open={quickEdit.value}
        onClose={quickEdit.onFalse}
      />
    </TableRow>
  );
}
