import Box from "@mui/material/Box";
import Stack from "@mui/material/Stack";
import { CardProps } from "@mui/material/Card";
import Typography from "@mui/material/Typography";
import { alpha, useTheme } from "@mui/material/styles";

import { fNumber } from "@/utils/format-number";

import { bgGradient } from "@/theme/css";
import { ColorSchema } from "@/theme/palette";

// ----------------------------------------------------------------------

interface Props extends CardProps {
  title: string;
  total: number;
  icon: React.ReactNode;
  color?: ColorSchema;
  showEuroSymbol?: boolean;
}

export default function AnalyticsWidgetSummary({
  title,
  total,
  icon,
  color = "primary",
  sx,
  showEuroSymbol = false,
  ...other
}: Props) {
  const theme = useTheme();

  return (
    <Stack
      direction="row"
      justifyContent="space-between"
      alignItems="center"
      sx={{
        ...bgGradient({
          direction: "135deg",
          startColor: alpha(theme.palette[color].light, 0.2),
          endColor: alpha(theme.palette[color].main, 0.2),
        }),
        p: 3,
        borderRadius: 2,
        color: `${color}.darker`,
        backgroundColor: "common.white",
        ...sx,
      }}
      {...other}
    >
      <Box sx={{ textAlign: "left" }}>
        <Typography variant="h5">
          {total?.toString() }
          {showEuroSymbol && " €"}
        </Typography>

        <Typography variant="subtitle2" sx={{ opacity: 0.72 }}>
          {title}
        </Typography>
      </Box>

      {icon && <Box sx={{ width: 64, height: 64 }}>{icon}</Box>}
    </Stack>
  );
}
