"use client";
import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Grid } from "@mui/material";
import { useEffect, useState } from "react";
import OrderFilters from "./statistics-filters";
import BasketAmountChart from "./EcartAmount-chart";
import SalesNetteChart from "./SalesNettechart";
import AnalyticsNetSales from "./ProductRateChart";
import AnalyticsAbandonedCarts from "./Analytics-AbandonedCarts";
import AppWidgetSummary from "./statistics-widget-summary";
import { useTheme } from "@mui/material/styles";
import BestSalesProduct from "./Best-salesProduct";
import { ChartData, ChartDataDTO, fetchAddToCartTrends, fetchBasketComparisonChartData, fetchNetSalesData, fetchRealRevenue, fetchTopSellingProducts, fetchTotalCarts, fetchTotalOrders, getTheoreticalRevenue, ProductStatisticsDTO } from "@/shared/api/saleSessionStatistics";

export default function AllStatisticsView() {
  const settings = useSettingsContext();
  const theme = useTheme();

  const [startDate, setStartDate] = useState<Date>(() => {
    const oneMonthAgo = new Date();
    oneMonthAgo.setMonth(oneMonthAgo.getMonth() - 1);
    return oneMonthAgo;
  });
  const [endDate, setEndDate] = useState<Date>(new Date());
  const [selectedOrders, setSelectedOrders] = useState<string[]>([]);

  const [theoreticalRevenue, setTheoreticalRevenue] = useState<number>(0);
  const [realRevenue, setRealRevenue] = useState<number>(0);
  const [topSellingProducts, setTopSellingProducts] = useState<ProductStatisticsDTO[]>([]);
  const [conversionRate, setConversionRate] = useState<number>(0);
  const [addToCartTrendsData, setAddToCartTrendsData] = useState<ChartDataDTO | null>(null);
  const [totalCarts, setTotalCarts] = useState<number>(0);
  const [totalOrders, setTotalOrders] = useState<number>(0);
  const [abandonedCarts, setAbandonedCarts] = useState<number>(0);
  const [abandonmentRate, setAbandonmentRate] = useState<number>(0);
  const [basketComparisonData, setBasketComparisonData] = useState<ChartData | null>(null);


  const [netSalesData, setNetSalesData] = useState<{
    categories?: string[];
    series: {
      type: string;
      data: { name: string; data: number[] }[];
    }[];
  } | null>(null);



  const statsFiltersProps = {
    startDate,
    endDate,
    onChangeStartDate: (date: Date) => {
      setStartDate(date);
    },
    onChangeEndDate: (date: Date) => {
      setEndDate(date);
    },
    selectedOrders,
    setSelectedOrders,
  };

  useEffect(() => {
    const fetchBasketComparisonData = async () => {
      try {
        const data = await fetchBasketComparisonChartData(startDate, endDate, selectedOrders);
        setBasketComparisonData(data);
      } catch (error) {
        console.error("Erreur lors de la récupération des données du graphique de comparaison du panier :", error);
      }
    };
  
    fetchBasketComparisonData();
  }, [startDate, endDate, selectedOrders]);
  useEffect(() => {
    const fetchNetSales = async () => {
      try {
        const data = await fetchNetSalesData(startDate, endDate, selectedOrders);
        setNetSalesData(data);
      } catch (error) {
        console.error("Erreur lors de la récupération des ventes nettes :", error);
      }
    };

    fetchNetSales();
  }, [startDate, endDate, selectedOrders]);
  useEffect(() => {
    const fetchTotals = async () => {
      try {
        const carts = await fetchTotalCarts(startDate, endDate, selectedOrders);
        setTotalCarts(carts);
        const orders = await fetchTotalOrders(startDate, endDate, selectedOrders);
        setTotalOrders(orders);
      } catch (error) {
        console.error("Erreur lors de la récupération des totaux :", error);
      }
    };

    fetchTotals();
  }, [startDate, endDate, selectedOrders]);

  useEffect(() => {
    const abandoned = totalCarts - totalOrders;
    setAbandonedCarts(abandoned >= 0 ? abandoned : 0);
    setAbandonmentRate(totalCarts > 0 ? ((abandoned >= 0 ? abandoned : 0) / totalCarts) * 100 : 0);
  }, [totalCarts, totalOrders]);


  useEffect(() => {
    const fetchTheoreticalRevenue = async () => {
      try {
        const data = await getTheoreticalRevenue({
          sources: selectedOrders,
          startDate: startDate.toISOString(),
          endDate: endDate.toISOString(),
        });
        setTheoreticalRevenue(data);
      } catch (error) {
        console.error("Erreur lors de la récupération du chiffre d'affaires théorique :", error);
      }
    };

    const fetchRealRevenueData = async () => {
      try {
        const data = await fetchRealRevenue(startDate, endDate, selectedOrders);
        console.log("check :",data);
        setRealRevenue(data);
      } catch (error) {
        console.error("Erreur lors de la récupération du chiffre d'affaires réel :", error);
      }
    };

    const fetchTopProducts = async () => {
      try {
        const data = await fetchTopSellingProducts(startDate, endDate, selectedOrders);
        setTopSellingProducts(data);
      } catch (error) {
        console.error("Erreur lors de la récupération des produits les plus vendus :", error);
      }
    };

    fetchTheoreticalRevenue();
    fetchRealRevenueData();
    fetchTopProducts();
  }, [startDate, endDate, selectedOrders]);

  useEffect(() => {
    if (theoreticalRevenue !== 0) {
      const rate = (realRevenue / theoreticalRevenue) * 100;
      setConversionRate(rate);
    } else {
      setConversionRate(0);
    }
  }, [realRevenue, theoreticalRevenue]);

  useEffect(() => {
    const fetchAddToCartTrendsData = async () => {
      try {
        const data = await fetchAddToCartTrends({
          source: selectedOrders.map((order) => order.toUpperCase()).join(","),
          startDate: startDate.toISOString().split("T")[0],
          endDate: endDate.toISOString().split("T")[0],
        });
        setAddToCartTrendsData(data);
      } catch (error) {
        console.error("Erreur lors de la récupération des tendances d'ajout au panier :", error);
      }
    };

    fetchAddToCartTrendsData();
  }, [startDate, endDate, selectedOrders]);

  return (
    <Container
      sx={{ gap: 3, display: "flex", flexDirection: "column" }}
      maxWidth={settings.themeStretch ? false : "lg"}
    >
      <CustomBreadcrumbs
        heading="Statistique session de vente"
        links={[
          {
            name: "Tableau de bord",
            href: paths.dashboard.root,
          },
          {
            name: "Paniers",
            href: paths.dashboard.admin.cart.root,
          },
          {
            name: "Statistiques",
          },
        ]}
        rollbackLink={paths.dashboard.admin.live.saleSession} 
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <OrderFilters {...statsFiltersProps} />

      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Taux de transformation"
            percent={conversionRate}
            total={conversionRate}
            color={theme.palette.error.light}
            chart={{
              colors: [theme.palette.primary.main, theme.palette.primary.dark],
              series: [conversionRate],
            }}
            showPercentage={true}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaires réel"
            percent={0.2}
            total={realRevenue}
            color={theme.palette.info.dark}
            chart={{
              colors: [theme.palette.warning.dark, theme.palette.warning.dark],
              series: [realRevenue],
            }}
            showEuroSymbol={true}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaires théorique"
            percent={0}
            total={theoreticalRevenue}
            color={theme.palette.primary.main}
            chart={{
              colors: [theme.palette.info.dark, theme.palette.info.dark],
              series: [theoreticalRevenue],
            }}
            showEuroSymbol={true}
          />
        </Grid>
      </Grid>

      <Grid container spacing={1}>
        <Grid item xs={4} md={4} lg={4}>
          <AnalyticsAbandonedCarts
            title="Paniers Abandonnés"
            chart={{
              series: [
                { label: "Paniers abandonnés", value: abandonedCarts },
                { label: "paniers créés", value: totalOrders },
              ],
            }}
          />

        </Grid>

        <Grid item xs={8} md={6} lg={8}>
          {addToCartTrendsData ? (
            <AnalyticsNetSales
              title="Taux d’ajout des produits au panier"
              chart={addToCartTrendsData}
            />
          ) : (
            <div>Chargement des données...</div>
          )}
        </Grid>
      </Grid>

      {netSalesData ? (
        <SalesNetteChart
          title="Montant total des ventes nettes"
          chart={netSalesData}
        />
      ) : (
        <div>Chargement des données...</div>
      )}


{basketComparisonData ? (
      <BasketAmountChart
        title="Écart entre montant théorique et montant réel des paniers"
        chart={basketComparisonData}
      />
    ) : (
      <div>Chargement des données...</div>
    )}

      <Grid xs={12} md={6} lg={8}>
        <BestSalesProduct
          title="Les Produits les plus vendus"
          tableData={topSellingProducts}
          tableLabels={[
            { id: "name", label: "Produits" },
            { id: "category", label: "Catégorie" },
            { id: "totalRevenue", label: "Chiffre d'affaires", align: "right" },
            { id: "quantitySold", label: "Quantité Vendue", align: "right" },
          ]}
        />
      </Grid>
    </Container>
  );
}
