import React from 'react';
import Table from "@mui/material/Table";
import Avatar from "@mui/material/Avatar";
import TableRow from "@mui/material/TableRow";
import TableCell from "@mui/material/TableCell";
import TableBody from "@mui/material/TableBody";
import CardHeader from "@mui/material/CardHeader";
import Card, { CardProps } from "@mui/material/Card";
import TableContainer from "@mui/material/TableContainer";

import { fCurrency } from "@/utils/format-number";

import Scrollbar from "@/components/scrollbar";
import { TableHeadCustom } from "@/shared/components/table";

// ----------------------------------------------------------------------

interface ProductStatisticsDTO {
  id: number;
  name: string;
  imagePath: string;
  category: string;
  quantitySold: number;
  totalRevenue: number;
  productType: string;
}

type RowProps = ProductStatisticsDTO;

interface Props extends CardProps {
  title?: string;
  subheader?: string;
  tableData: RowProps[];
  tableLabels: any;
}

export default function BestSalesProduct({
  title,
  subheader,
  tableData,
  tableLabels,
  ...other
}: Props) {
  return (
    <Card {...other}>
      <CardHeader title={title} subheader={subheader} sx={{ mb: 3 }} />

      <TableContainer sx={{ overflow: "unset" }}>
        <Scrollbar>
          <Table sx={{ minWidth: 640 }}>
            <TableHeadCustom headLabel={tableLabels} />

            <TableBody>
              {tableData.map((row) => (
                <ProductRow key={row.id} row={row} />
              ))}
            </TableBody>
          </Table>
        </Scrollbar>
      </TableContainer>
    </Card>
  );
}

type ProductRowProps = {
  row: ProductStatisticsDTO;
};

function ProductRow({ row }: ProductRowProps) {
  return (
    <TableRow>
      <TableCell sx={{ display: "flex", alignItems: "center" }}>
        <Avatar alt={row.name} src={row.imagePath} sx={{ mr: 2 }} />
        {row.name}
      </TableCell>

      <TableCell>{row.category}</TableCell>

      <TableCell align="right">{fCurrency(row.totalRevenue)}</TableCell>

      <TableCell align="right">{row.quantitySold}</TableCell>
    </TableRow>
  );
}
