import type { GridCellParams } from '@mui/x-data-grid';

import Box from '@mui/material/Box';
import Link from '@mui/material/Link';
import Stack from '@mui/material/Stack';
import ListItemText from '@mui/material/ListItemText';
import { fTime , fDate } from '@/utils/format-time';
import Label from '@/shared/components/label';

// ----------------------------------------------------------------------

type ParamsProps = {
  params: GridCellParams;
};

export function RenderCellCategory({ params }: ParamsProps) {

  const categories: { [key: string]: string } = {
    BILLING: 'Facturation',
    GENERAL: 'Général',
    TECHNICAL_SUPPORT: 'Support Technique',
    PRODUCT_INFO: 'Information Produit',
    DELETED: 'Supprimé',
  };

  return (
    <Label
      variant="soft"
      color={
        (params.row.category === 'BILLING' && 'info') ||
        (params.row.category === 'GENERAL' && 'success') ||
        (params.row.category === 'TECHNICAL_SUPPORT' && 'warning') ||
        (params.row.category === 'PRODUCT_INFO' && 'primary') ||
        (params.row.category === 'DELETED' && 'error') ||
        'default'
      }
      sx={{ minWidth: 200 }} // Adjust the width as needed
    >
      {categories[params.row.category]}
    </Label>
  );
}

export function RenderCellCreatedAt({ params }: ParamsProps) {
  return (
    <Stack spacing={0.5}>
      <Box component="span">{fDate(params.row.createdAt)}</Box>
      <Box component="span" sx={{ typography: 'caption', color: 'text.secondary' }}>
        {fTime(params.row.createdAt)}
      </Box>
    </Stack>
  );
}

export function RenderCellUpdatedAt({ params }: ParamsProps) {
  return (
    <Stack spacing={0.5}>
      <Box component="span">{fDate(params.row.updatedAt)}</Box>
      <Box component="span" sx={{ typography: 'caption', color: 'text.secondary' }}>
        {fTime(params.row.updatedAt)}
      </Box>
    </Stack>
  );
}

export function RenderCellFAQQuestion({params,}: ParamsProps ) {
  return (
    <Stack direction="row" alignItems="center" sx={{ py: 2, width: 1 }}>

      <ListItemText
        disableTypography
        primary={
          <Link
            noWrap
            color="inherit"
            variant="subtitle2"
            sx={{ cursor: 'pointer' }}
          >
            {params.row.question}
          </Link>
        }
        sx={{ display: 'flex', flexDirection: 'column' }}
      />
    </Stack>
  );
}

export function RenderCellFAQAnswer({params,}: ParamsProps) {
  return (
    <Stack direction="row" alignItems="center" sx={{ py: 2, width: 1 }}>

      <ListItemText
        disableTypography
        primary={
          <Link
            noWrap
            color="inherit"
            variant="subtitle2"
            sx={{ cursor: 'pointer' }}
          >
            {params.row.answer}
          </Link>
        }
        sx={{ display: 'flex', flexDirection: 'column' }}
      />
    </Stack>
  );
}