import { Card, Stack, Typography, Divider, Box, Chip } from '@mui/material';
import { IHelpGetItem } from '@/shared/types/help';

type Props = {
  currentCollection: IHelpGetItem;
};

export function CollectionDetailData({ currentCollection }: Props): JSX.Element {
  return (
    <Box sx={{ mx: 'auto', maxWidth: { xs: 800, xl: 1000 }, p: 3 }}>
      {/* Collection Details */}
      <Card
        sx={{
          p: 4,
          mb: 5
        }}
      >
        <Typography variant="h4" sx={{ mb: 2, fontWeight: 600 }}>
          {currentCollection.name}
        </Typography>
        <Typography variant="body1" color="text.secondary" sx={{ fontSize: '1rem' }}>
          {currentCollection.description}
        </Typography>
      </Card>

      {/* Articles Section */}
      <Typography variant="h5" sx={{ mb: 3, fontWeight: 500 }}>
        Articles
      </Typography>

      <Stack spacing={4}>
        {currentCollection.articles && currentCollection.articles.length > 0 ? (
          currentCollection.articles.map((article, index) => (
            <Card
              key={article.id}
              sx={{
                p: 4,
                borderRadius: 2
              }}
            >
              <Box display="flex" alignItems="center" justifyContent="space-between" mb={1}>
                <Typography variant="h6" sx={{ mb: 2, fontWeight: 600 }}>
                {`Article ${index + 1}`}
                </Typography>
                <Typography variant="caption" color="text.secondary">
                  ID: {article.id}
                </Typography>
              </Box>
              <Divider sx={{ my: 2 }} />
              <Typography variant="subtitle1" sx={{ mb: 1, fontWeight: 600 }}>
                {article.question}
              </Typography>
              <Typography variant="body2" color="text.secondary" sx={{ lineHeight: 1.6 }}>
                {article.answer}
              </Typography>
            </Card>
          ))
        ) : (
          <Typography variant="body2" color="text.secondary">
            No articles added to this collection.
          </Typography>
        )}
      </Stack>
    </Box>
  );
}
