import type { IHelpItem } from '@/shared/types/help';

import Box from '@mui/material/Box';
import Pagination, { paginationClasses } from '@mui/material/Pagination';

import { CollectionItemSkeleton } from './help-skeleton';
import { CollectionItemHorizontal } from './help-item-horizontal';

// ----------------------------------------------------------------------

type Props = {
  collection: IHelpItem[];
  loading?: boolean;
};

export function CollectionListHorizontal({ collection, loading }: Props) {
  const renderLoading = <CollectionItemSkeleton variant="horizontal" />;

  const renderList = collection.map((collection) => <CollectionItemHorizontal key={collection.id} collection={collection} />);

  return (
    <>
      <Box
        gap={3}
        display="grid"
        gridTemplateColumns={{ xs: 'repeat(1, 1fr)', md: 'repeat(2, 1fr)' }}
      >
        {loading ? renderLoading : renderList}
      </Box>

      {collection.length > 8 && (
        <Pagination
          count={8}
          sx={{
            mt: { xs: 5, md: 8 },
            [`& .${paginationClasses.ul}`]: { justifyContent: 'center' },
          }}
        />
      )}
    </>
  );
}
