'use client';

import RouterLink from '@/routes/router-link';
import Button from '@mui/material/Button';
import TextField from '@mui/material/TextField';  
import Iconify from '@/shared/components/iconify';
import { paths } from '@/routes/paths';
import Container from "@mui/material/Container";
import { useGetHelps } from '@/shared/api/help';
import CustomBreadcrumbs from '@/shared/components/custom-breadcrumbs';
import { CollectionListHorizontal } from '../help-list-horizontal';
import { useState } from 'react';  

// ----------------------------------------------------------------------

export function CollectionListView() {
  const { helps, helpsLoading } = useGetHelps();

  const [searchQuery, setSearchQuery] = useState('');  

  // Filter collections based on the search query
  const filteredHelps = helps.filter((help) =>
    help.name.toLowerCase().includes(searchQuery.toLowerCase()) ||
    help.description.toLowerCase().includes(searchQuery.toLowerCase())
  );

  return (
    <Container maxWidth={false}>
      <CustomBreadcrumbs
        heading="Liste Collection"
        links={[
          { name: 'Tableau de bord'},
          { name: 'Liste Collection'}
        ]}
        action={
          <Button
            component={RouterLink}
            href={paths.dashboard.chatbot.help.new}
            variant="contained"
            startIcon={<Iconify icon="mingcute:add-line" />}
          >
            Nouvelle Collection
          </Button>
        }
        sx={{ mb: { xs: 3, md: 5 } }}
      />

      {/* Search input field */}
      <TextField
        label="Rechercher"
        variant="outlined"
        value={searchQuery}
        onChange={(e) => setSearchQuery(e.target.value)}
        fullWidth
        sx={{ mb: 3 }}
      />

      {/* Pass the filteredHelps to the list component */}
      <CollectionListHorizontal collection={filteredHelps} loading={helpsLoading} />
    </Container>
  );
}