import type { StackProps } from '@mui/material/Stack';
import type { Theme, SxProps } from '@mui/material/styles';

import Box from '@mui/material/Box';
import Stack from '@mui/material/Stack';
import Typography from '@mui/material/Typography';
import { varAlpha } from '@/shared/theme/css';

import React from 'react';


export type EmptyContentProps = StackProps & {
  title?: string;
  imgUrl?: string;
  filled?: boolean;
  description?: string;
  action?: React.ReactNode;
  slotProps?: {
    img?: SxProps<Theme>;
    title?: SxProps<Theme>;
    description?: SxProps<Theme>;
  };
};

export function ChatEmptyState(
  {
    sx,
    imgUrl,
    action,
    filled,
    slotProps,
    description,
    title = 'No data',
    ...other
  }: EmptyContentProps) {
  return (
    <Stack
    flexGrow={1}
    alignItems="center"
    justifyContent="center"
    sx={{
      px: 3,
      height: 1,
      ...(filled && {
        borderRadius: 2,
        bgcolor: (theme) => varAlpha(theme.palette.grey[500], 0.04),
        border: (theme) => `dashed 1px ${varAlpha(theme.palette.grey[500], 0.08)}`,
      }),
      ...sx,
    }}
    {...other}
  >
    {title ? (
      <Typography
        variant="h6"
        component="span"
        sx={{ mt: 1, textAlign: 'center', ...slotProps?.title, color: 'text.disabled' }}
      >
        {title}
      </Typography>
    ) : null}

    {description ? (
      <Typography
        variant="caption"
        sx={{ mt: 1, textAlign: 'center', color: 'text.disabled', ...slotProps?.description }}
      >
        {description}
      </Typography>
    ) : null}

    {action ? action : null}
  </Stack>
  );
}
 