import React, { useState } from "react";
import InputBase from '@mui/material/InputBase';
import IconButton from '@mui/material/IconButton';
import Box from '@mui/material/Box';
import Iconify from "@/components/iconify";
import { useGetTicketByConversation } from "@/shared/api/chat-bot";
import { IMessageSocketItem } from "@/shared/types/chat-bot";
import { is } from "date-fns/locale";

type Props = {
  conversationId: string;
  onSendMessage: (message: IMessageSocketItem) => void;
  userid: string;
  ticketFilter?: string;
};

export function ChatMessageInput({ conversationId, onSendMessage, userid, ticketFilter }: Props) {
  const [message, setMessage] = useState("");
  const { ticket } = useGetTicketByConversation(conversationId);

  const isDisabled = ticketFilter !== "me";
  const placeholderText = isDisabled 
    ? "Vous ne faites pas partie de cette conversation" 
    : "Commencer Votre Conversation ...";

  const sendMessage = () => {
    if (message.trim() && !isDisabled) {
      onSendMessage({
        ticketId: ticket?.id || "",
        senderId: userid,
        content: message,
        owner: "ai",
      });
      setMessage("");
    }
  };

  const handleSendMessage = (e: React.KeyboardEvent<HTMLInputElement>) => {
    if (e.key === "Enter") {
      sendMessage();
    }
  };

  const handleSendMessageClick = (e: React.MouseEvent<HTMLButtonElement>) => {
    sendMessage();
  };

  return (
    <Box
      sx={{
        display: 'flex',
        alignItems: 'center',
        borderTop: (theme) => `solid 1px ${theme.palette.divider}`,
      }}
    >
      <InputBase
        name="chat-message"
        id="chat-message-input"
        placeholder={placeholderText}
        value={message}
        disabled={isDisabled}
        onChange={(e) => setMessage(e.target.value)}
        onKeyUp={handleSendMessage}
        sx={{
          px: 1,
          pl: 5,
          height: 56,
          flexShrink: 0,
          flexGrow: 1,
        }}
      />
      {!isDisabled ? (
          <IconButton onClick={handleSendMessageClick}>
        <Iconify icon="mdi:send" />
      </IconButton>
      ) : (
        null
      )}   
    </Box>
  );
}
