import React from "react";
import { Box, Stack, Avatar, Typography } from "@mui/material";
import { IMessageItem } from "@/shared/types/chat-bot";
import { fToNow } from "@/utils/format-time";

type Props = {
  message: IMessageItem
};

export function ChatMessageItem({ message }: Props) {
  const senderDetails = {
    firstName: message.owner === "user" ? "You" : "Sender",
    avatarUrl: "", 
  };

  return (
    <Stack
      direction="row"
      justifyContent={message.owner === "user" ? "flex-start" : "flex-end"}
      sx={{ mb: 3 }}
    >
      {/* If message sender is not user, show the sender's avatar */}
      {message.owner === "user" ? (
        <Avatar
          alt={senderDetails.firstName}
          src={senderDetails.avatarUrl}
          sx={{ width: 32, height: 32, mr: 2 }}
        />
      ) : null}

      <Stack alignItems={message.owner === "user" ? "flex-start" : "flex-end"}>
        {/* Display message timestamp */}
        <Typography
          variant="caption"
          sx={{
            mb: 1,
            color: "text.disabled",
            ...(message.owner === "user" && { mr: "auto" }),
          }}
        >
          {/* You can add actual time formatting here */}
          {fToNow(message.timestamp)}
        </Typography>

        {/* Message content */}
        <Stack
          direction="row"
          alignItems="center"
          sx={{
            position: "relative",
            "&:hover .message-actions": {
              opacity: 1,
            },
          }}
        >
          <Box
            sx={{
              p: 1.5,
              minWidth: 48,
              maxWidth: 640,
              borderRadius: 1,
              typography: "body2",
              bgcolor: message.owner === "user" ? "background.neutral" : "primary.lighter",
              color: message.owner === "user" ? "text.primary" : "grey.800",
            }}
          >
            {message.content}
          </Box>

          {/* Action buttons on hover */}
          <Stack
            direction="row"
            className="message-actions"
            sx={{
              pt: 0.5,
              left: 0,
              opacity: 0,
              top: "100%",
              position: "absolute",
              transition: (theme) =>
                theme.transitions.create(["opacity"], { duration: theme.transitions.duration.shorter }),
              ...(message.owner === "user" && { right: 0, left: "unset" }),
            }}
          >
            {/* Action buttons can go here */}
          </Stack>
        </Stack>
      </Stack>
    </Stack>
  );
}
