"use client";
import type { SelectChangeEvent } from "@mui/material/Select";
import { useCallback } from "react";
import Stack from "@mui/material/Stack";
import Avatar from "@mui/material/Avatar";
import Select from "@mui/material/Select";
import Divider from "@mui/material/Divider";
import MenuList from "@mui/material/MenuList";
import MenuItem from "@mui/material/MenuItem";
import ListItemText from "@mui/material/ListItemText";
import Badge from "@mui/material/Badge";
import FormControl from "@mui/material/FormControl";
import { usePopover } from "@/shared/components/custom-popover";
import CustomPopover from "@/shared/components/custom-popover";

type Props = {
  user: any;
  users: any;
  ticketFilter: string;
  onChangeTicketFilter: (value: string) => void;
};

export function ChatNavAccount({ user, users, ticketFilter, onChangeTicketFilter }: Props) {
  const popover = usePopover();

  const handleChangeTicket = useCallback(
    (event: SelectChangeEvent) => {
      onChangeTicketFilter(event.target.value);
    },
    [onChangeTicketFilter]
  );

  const otherUsers = users.filter((u: any) => u.id !== user.id && u.role !== "CLIENT");

  return (
    <>
      <Badge variant="dot" anchorOrigin={{ vertical: "bottom", horizontal: "right" }}>
        <Avatar
          src={user?.firstName}
          alt={user?.firstName}
          onClick={popover.onOpen}
          sx={{ cursor: "pointer", width: 48, height: 48 }}
        >
          {user?.displayName?.charAt(0).toUpperCase()}
        </Avatar>
      </Badge>

      <CustomPopover
        open={popover.open}
        anchorEl={popover.open}
        onClose={popover.onClose}
        slotProps={{
          paper: { sx: { p: 0 } },
        }}
      >
        <Stack direction="row" alignItems="center" spacing={2} sx={{ py: 2, pr: 1, pl: 2, mr: 2 }}>
          <ListItemText
            primary={user?.firstName + " " + user?.lastName}
            secondary={user?.email}
            secondaryTypographyProps={{ component: "span" }}
          />
        </Stack>

        <Divider sx={{ borderStyle: "dashed" }} />

        {(users?.length && (
        <MenuList sx={{ my: 0.5, px: 0.5 }}>
          <MenuItem>
            <FormControl fullWidth sx={{ m: 1 }}>
              <Select
                value={ticketFilter}
                onChange={handleChangeTicket}
                variant="outlined"
                displayEmpty
                inputProps={{ "aria-label": "Select ticket filter" }}
                sx={{
                  textTransform: "capitalize",
                  padding: "0px",
                  borderRadius: 1,
                  "& .MuiOutlinedInput-notchedOutline": { borderColor: "divider" },
                  "&:hover .MuiOutlinedInput-notchedOutline": { borderColor: "text.primary" },
                  "&.Mui-focused .MuiOutlinedInput-notchedOutline": { borderColor: "primary.main" },
                  "& .MuiSvgIcon-root": { right: 8 },
                }}
              >
                {(user.role === "ADMIN" || user.role === "LEADER") && (
                  <MenuItem value="all">Tout Les Ticket</MenuItem>
                )}
                <MenuItem value="me">Me Ticket</MenuItem>
                {(user.role === "ADMIN" || user.role === "LEADER") &&
                  otherUsers.map((u: any) => (
                    <MenuItem key={u.id} value={u.id}>
                      {u.firstName + " " + u.lastName}
                    </MenuItem>
                  ))}
              </Select>
            </FormControl>
          </MenuItem>
        </MenuList>
        )) || <Stack />}
      </CustomPopover>
    </>
  );
}