import Stack from '@mui/material/Stack';
import Avatar from '@mui/material/Avatar';
import Collapse from '@mui/material/Collapse';
import Typography from '@mui/material/Typography';

import { useBoolean } from '@/hooks';
import Iconify from '@/components/iconify';
import { CollapseButton } from './styles';
import { useGetUserById } from '@/shared/api/ticket';

// ----------------------------------------------------------------------

type Props = {
  support_id: string;
};

export function ChatRoomSingle({ support_id }: Props) {

  const collapse = useBoolean(true);
  const { user } = useGetUserById(support_id);

  const renderInfo = (
    <Stack alignItems="center" sx={{ py: 5 }}>
      <Avatar
        alt={user?.firstName}
        src={user?.firstName}
        sx={{ width: 96, height: 96, mb: 2 }}
      />
      <Typography variant="subtitle1">{user?.firstName  + " " + user?.lastName}</Typography>
      <Typography variant="body2" sx={{ color: 'text.secondary', mt: 0.5 }}>
        {user?.role}
      </Typography>
    </Stack>
  );

  const renderContact = (
    <Stack spacing={2} sx={{ px: 2, py: 2.5 }}>
      {[
      { icon: 'fluent:mail-24-filled', value: user?.email },
      { icon: 'mdi:account', value: user?.username },
      { icon: 'mdi:account-check-outline', value: user?.status },
      ].map((item) => (
      <Stack
        key={item.icon}
        spacing={1}
        direction="row"
        sx={{ typography: 'body2', wordBreak: 'break-all' }}
      >
        <Iconify icon={item.icon} sx={{ flexShrink: 0, color: 'text.disabled' }} />
        {item.value}
      </Stack>
      ))}
    </Stack>
  );

  return (
    <>
      {renderInfo}

      <CollapseButton selected={collapse.value} onClick={collapse.onToggle}>
        Information
      </CollapseButton>

      <Collapse in={collapse.value}>
        {renderContact}
      </Collapse>
    </>
  );
}
