import Stack from '@mui/material/Stack';
import Drawer from '@mui/material/Drawer';
import { useTheme } from '@mui/material/styles';

import Scrollbar from '@/components/scrollbar';

import { ChatRoomSingle } from './chat-room-single';

import { CircularProgress } from '@mui/material';

import { useCollapseNav } from '@/hooks';
import { useGetConversation } from '@/shared/api/chat-bot';
import { useGetTicketByConversation } from '@/shared/api/chat-bot';

// ----------------------------------------------------------------------

const NAV_WIDTH = 280;
const NAV_DRAWER_WIDTH = 320;

type Props = {
  collapseNav: ReturnType<typeof useCollapseNav>;
  conversationId : string;
  user : any;
};

export function ChatRoom({ collapseNav, conversationId , user }: Props) {
  const theme = useTheme();
  const { conversation, conversationLoading } = useGetConversation(conversationId);
  const { ticket } = useGetTicketByConversation(conversationId);
  const { collapseDesktop, openMobile, onCloseMobile } = collapseNav;

  const renderContent = conversationLoading ? (
    <Stack
      sx={{
        height: '100%',
        alignItems: 'center',
        justifyContent: 'center',
      }}
    >
      <CircularProgress />
    </Stack>
  ) : (
    <Scrollbar>
          <ChatRoomSingle support_id={ticket?.support_id || ""} />
    </Scrollbar>
  );

  return (
    <>
      <Stack
        sx={{
          minHeight: 0,
          flex: '1 1 auto',
          display: { xs: 'none', lg: 'flex' },
          borderLeft: `solid 1px ${theme.palette.divider}`,
          transition: theme.transitions.create(['width'], {
            duration: theme.transitions.duration.shorter,
          }),
        }}
      >
        {renderContent}
      </Stack>

      <Drawer
        anchor="right"
        open={openMobile}
        onClose={onCloseMobile}
        slotProps={{ backdrop: { invisible: true } }}
        PaperProps={{ sx: { width: NAV_DRAWER_WIDTH } }}
      >
        {renderContent}
      </Drawer>
    </>
  );
}
