import React, { useRef, useEffect, useState } from "react";
import { Box, CircularProgress } from "@mui/material";
import { ChatMessageItem } from "./chat-message-item";
import Scrollbar from '@/components/scrollbar';
import { useGetConversation } from '@/shared/api/chat-bot';
import { ChatEmptyState } from "./chat-empty-state";

type Props = {
  conversationId: string;
  socketMessages: any;
};

export function ChatWindow({ conversationId, socketMessages }: Props) {
  const { conversation, conversationLoading } = useGetConversation(conversationId);
  const [messages, setMessages] = useState<any[]>([]);
  const scrollbarsRef = useRef<HTMLDivElement>(null);

  const scrollToBottom = () => {
    if (scrollbarsRef.current) {
      scrollbarsRef.current.scrollTo({ top: scrollbarsRef.current.scrollHeight, behavior: "auto" });
    }
  };

  useEffect(() => {
    if (conversation) {
      setMessages(conversation.messages || []);
    } else {
      setMessages([]);
    }
  }, [conversationId, conversation]);

  useEffect(() => {
    if (conversation && socketMessages) {
      setMessages((prevMessages) => [...prevMessages, ...socketMessages]);
    }
  }, [socketMessages, conversationId]);

  useEffect(() => {
    scrollToBottom();
  }, [messages]);

  if (!conversation || !messages.length) {
    return (
      <ChatEmptyState
          title="Bonjour!"
          description="Merci de sélectionner une conversation pour commencer à discuter."
          imgUrl={`/assets/icons/empty/ic-content.svg`}
        />
    );
  }

  return (
    <Scrollbar ref={scrollbarsRef} sx={{ px: 3, pt: 5, pb: 3, flex: "1 1 auto" }}>
      {conversationLoading ? (
        <Box sx={{ display: "flex", justifyContent: "center", alignItems: "center", height: "100%" }}>
          <CircularProgress />
        </Box>
      ) : (
        messages.map((message, index) => <ChatMessageItem key={index} message={message} />)
      )}
    </Scrollbar>
  );
}
