import type { GridCellParams } from '@mui/x-data-grid';

import Box from '@mui/material/Box';
import Link from '@mui/material/Link';
import Stack from '@mui/material/Stack';
import ListItemText from '@mui/material/ListItemText';

import { fTime , fDate } from '@/utils/format-time';
import Label from '@/shared/components/label';

// ----------------------------------------------------------------------

type ParamsProps = {
  params: GridCellParams;
};

export function RenderCellStatus({ params }: ParamsProps) {

  const categories: { [key: string]: string } = {
    OPEN: 'Ouvert',
    IN_PROGRESS: 'En cours',
    RESOLVED: 'Résolu',
    REJECTEED: 'Rejeté',
    WAITING: 'En attente',
    REASSIGNED: 'Réassigné',
  };

  return (
    <Label variant="soft" color={
      (params.row.ticketstatus === 'OPEN' && 'info') ||
      (params.row.ticketstatus === 'IN_PROGRESS' && 'warning') ||
      (params.row.ticketstatus === 'WAITING' && 'success') ||
      (params.row.ticketstatus === 'REASSIGNED' && 'warning') ||
      (params.row.ticketstatus === 'RESOLVED' && 'primary') ||
      (params.row.ticketstatus === 'REJECTEED' && 'error')
      || 'default'}>
      {categories[params.row.ticketstatus]}
    </Label>    
  );
}

export function RenderCellCreatedAt({ params }: ParamsProps) {
  return (
    <Stack spacing={0.5}>
      <Box component="span">{fDate(params.row.createdAt)}</Box>
      <Box component="span" sx={{ typography: 'caption', color: 'text.secondary' }}>
        {fTime(params.row.createdAt)}
      </Box>
    </Stack>
  );
}

export function RenderCellUpdatedAt({ params }: ParamsProps) {
  return (
    <Stack spacing={0.5}>
      <Box component="span">{fDate(params.row.updatedAt)}</Box>
      <Box component="span" sx={{ typography: 'caption', color: 'text.secondary' }}>
        {fTime(params.row.updatedAt)}
      </Box>
    </Stack>
  );
}

export function RenderCellAssignedAt({ params }: ParamsProps) {
  return (
    <Stack spacing={0.5}>
      <Box component="span">{fDate(params.row.updatedAt)}</Box>
      <Box component="span" sx={{ typography: 'caption', color: 'text.secondary' }}>
        {fTime(params.row.updatedAt)}
      </Box>
    </Stack>
  );
}

export function RenderCellTicketTitle({params,}: ParamsProps ) { 
  return (
    <Stack direction="row" alignItems="center" sx={{ py: 2, width: 1 }}>

      <ListItemText
        disableTypography
        primary={
          <Link
            noWrap
            color="inherit"
            variant="subtitle2"
            sx={{ cursor: 'pointer' }}
          >
            {params.row.title}
          </Link>
        }
        sx={{ display: 'flex', flexDirection: 'column'  , px : 4}}
      />
    </Stack>
  );
}

export function RenderCellTicketAsigned({params,}: ParamsProps) {
  return (
    <Stack direction="row" alignItems="center" sx={{ py: 2, width: 1 }}>

      <ListItemText
        disableTypography
        primary={
          <Link
            noWrap
            color="inherit"
            variant="subtitle2"
            sx={{ cursor: 'pointer' }}
          >
            {params.row.assignedTo ? params.row.assignedTo : 'Non assigné'}
          </Link>
        }
        sx={{ display: 'flex', flexDirection: 'column' }}
      />
    </Stack>
  );
}