// ----------------------------------------------------------------------
import Box from '@mui/material/Box';
import Typography from '@mui/material/Typography';
import CircularProgress from '@mui/material/CircularProgress';
import Iconify from '@/components/iconify';
import { ITiketItem } from '@/shared/types/ticket';

// New component to display ticket status statistics
export function TicketStatistics({ data }: { data: ITiketItem[] }) {
    const total = data.length;
    const stats = {
      OPEN: data.filter(ticket => ticket.ticketstatus === 'OPEN').length,
      IN_PROGRESS: data.filter(ticket => ticket.ticketstatus === 'IN_PROGRESS').length,
      RESOLVED: data.filter(ticket => ticket.ticketstatus === 'RESOLVED').length,
      REJECTEED: data.filter(ticket => ticket.ticketstatus === 'REJECTEED').length,
      WAITING: data.filter(ticket => ticket.ticketstatus === 'WAITING').length,
      REASSIGNED: data.filter(ticket => ticket.ticketstatus === 'REASSIGNED').length,
    };
  
    // Define status display details with French labels and added spacing
    const statusInfo = [
      { status: 'OPEN', label: 'Ouvert', icon: 'mdi:ticket', color: '#1976d2' },
      { status: 'IN_PROGRESS', label: 'En cours', icon: 'mdi:progress-clock', color: '#388e3c' },
      { status: 'RESOLVED', label: 'Résolu', icon: 'mdi:check-circle', color: '#2e7d32' },
      { status: 'REJECTEED', label: 'Rejeté', icon: 'mdi:close-circle', color: '#d32f2f' },
      { status: 'WAITING', label: 'En attente', icon: 'mdi:clock-outline', color: '#ff9800' },
      { status: 'REASSIGNED', label: 'Réassigné', icon: 'mdi:account-switch', color: '#f57c00' },
    ];
  
    return (
      <Box display="flex" justifyContent="flex-end" width="70%" mt={2} px={2} gap={3}>
        {statusInfo.map(info => {
          const count = stats[info.status as keyof typeof stats] || 0;
          const percentage = total ? Math.round((count / total) * 100) : 0;
          return (
            <Box key={info.status} display="flex" flexDirection="column" alignItems="center" px={2}>
              <Iconify icon={info.icon} style={{ fontSize: 32, color: info.color }} />
              <Typography variant="subtitle2" mt={1}>{info.label}</Typography>
              <Typography variant="h6">{count}</Typography>
              <Box position="relative" display="inline-flex" mt={1}>
                <CircularProgress variant="determinate" value={percentage} size={40} style={{ color: info.color }} />
                <Box
                  top={0}
                  left={0}
                  bottom={0}
                  right={0}
                  position="absolute"
                  display="flex"
                  alignItems="center"
                  justifyContent="center"
                >
                  <Typography variant="caption" component="div" color="textSecondary">
                    {`${percentage}%`}
                  </Typography>
                </Box>
              </Box>
            </Box>
          );
        })}
      </Box>
    );
  }