import Box from '@mui/material/Box';
import MenuItem from '@mui/material/MenuItem';
import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import IconButton from '@mui/material/IconButton';
import ListItemText from '@mui/material/ListItemText';
import { useBoolean } from '../../../../../hooks/use-boolean';
import { fDate, fTime } from '../../../../../utils/format-time';
import Label from '../../../../components/label';
import Iconify from '../../../../components/iconify';
import CustomPopover, { usePopover } from '../../../../components/custom-popover';
import { SupplierOrder, SupplierOrderStatus, supplierOrderStatusLabels } from '@/contexts/types/supplierOrder';

type Props = {
  row: SupplierOrder;
  selected: boolean;
  onViewRow: VoidFunction;
  onSelectRow: VoidFunction;
  onDeleteRow: VoidFunction;
};

export default function SupplierOrderTableRow({
  row,
  selected,
  onViewRow,
  onSelectRow,
}: Props) {
  
  const { supplierOrderStatus, id, createdAt, deliveryDate, supplierName, supplierFullAddress, supplierPhoneNumber } = row;

  const popover = usePopover();

  const renderPrimary = (
    <TableRow hover selected={selected} sx={{ cursor: 'pointer' }}>
      <TableCell onClick={onViewRow}>
        <Box
          sx={{
            cursor: 'pointer',
            textAlign: 'center',
            '&:hover': {
              textDecoration: 'underline',
            },
          }}
        >
          {id}
        </Box>
      </TableCell>

      <TableCell onClick={onViewRow} sx={{ display: 'flex', alignItems: 'center' }}>
        <ListItemText
          primary={supplierName || 'N/A'}
          secondary={supplierPhoneNumber || 'N/A'}
          primaryTypographyProps={{ typography: 'body2' }}
          secondaryTypographyProps={{
            component: 'span',
            color: 'text.disabled',
          }}
        />
      </TableCell>

      <TableCell onClick={onViewRow}>
        <ListItemText
          primary={fDate(createdAt)}
          secondary={fTime(createdAt)}
          primaryTypographyProps={{ typography: 'body2', noWrap: true }}
          secondaryTypographyProps={{
            mt: 0.5,
            typography: 'caption',
          }}
        />
      </TableCell>

      <TableCell onClick={onViewRow}>
        <ListItemText
          primary={fDate(deliveryDate)}
          secondary={fTime(deliveryDate)}
          primaryTypographyProps={{ typography: 'body2', noWrap: true }}
          secondaryTypographyProps={{
            mt: 0.5,
            typography: 'caption',
          }}
        />
      </TableCell>

      <TableCell onClick={onViewRow}>
        <ListItemText
          primary={supplierFullAddress}
          primaryTypographyProps={{ typography: 'body2', noWrap: true }}
          secondaryTypographyProps={{
            mt: 0.5,
            typography: 'caption',
          }}
        />
      </TableCell>

      <TableCell onClick={onViewRow}>
        <Label
          variant="soft"
          color={
            (supplierOrderStatus === SupplierOrderStatus.DELIVERED && 'success') ||
            (supplierOrderStatus === SupplierOrderStatus.TO_BE_COLLECTED && 'warning') ||
            (supplierOrderStatus === SupplierOrderStatus.RECEIVED && 'info') ||
            'default'
          }
        >
          {supplierOrderStatusLabels[supplierOrderStatus] || 'Statut inconnu'}
        </Label>
      </TableCell>

      <TableCell align="right" sx={{ px: 1, whiteSpace: 'nowrap' }}>
        <IconButton color={popover.open ? 'inherit' : 'default'} onClick={popover.onOpen}>
          <Iconify icon="eva:more-vertical-fill" />
        </IconButton>
      </TableCell>
    </TableRow>
  );

  return (
    <>
      {renderPrimary}

      <CustomPopover
        open={popover.open}
        onClose={popover.onClose}
        sx={{ width: 200 }}
      >
        <MenuItem
          onClick={() => {
            onViewRow();
            popover.onClose();
          }}
        >
          <Iconify icon="solar:eye-bold" />
          Voir
        </MenuItem>


      </CustomPopover>
    </>
  );
}
