import React, { useCallback } from "react";
import Stack from "@mui/material/Stack";
import TextField from "@mui/material/TextField";
import InputAdornment from "@mui/material/InputAdornment";
import Iconify from "../../../../components/iconify";
import {
  SupplierOrderTableFilters2,
  ISupplierOrderTableFilterValue,
} from "../../../../types/supplierOrder";
import { Button, Dialog, DialogActions, DialogContent } from "@mui/material";
import ColumnView from "../column-view";


type Props = {
  filters: SupplierOrderTableFilters2;
  onFilters: (name: string, value: ISupplierOrderTableFilterValue) => void;
  dateError: boolean;
};

export default function OrderTableToolbar({
  filters,
  onFilters,
}: Props) {
  const handleFilterName = useCallback(
    (event: React.ChangeEvent<HTMLInputElement>) => {
      onFilters("name", event.target.value);
    },
    [onFilters]
  );

  const [open, setOpen] = React.useState(false);

  const handleClickOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };
  const [openColumn, setOpenColumn] = React.useState(false);

  const handleClickOpenColumn = () => {
    setOpenColumn(true);
  };

  const handleCloseColumn = () => {
    setOpenColumn(false);
  };

  return (
    <>
      <Stack
        spacing={2}
        alignItems={{ xs: "flex-end", md: "center" }}
        direction={{
          xs: "column",
          md: "row",
        }}
        sx={{
          p: 2.5,
          pr: { xs: 2.5, md: 1 },
        }}
      >
        <Stack
          direction="row"
          alignItems="center"
          spacing={2}
          flexGrow={1}
          sx={{ width: 1 }}
        >
          <TextField
            fullWidth
            value={filters.name}
            onChange={handleFilterName}
            placeholder="Search supplier or order number..."
            InputProps={{
              startAdornment: (
                <InputAdornment position="start">
                  <Iconify
                    icon="eva:search-fill"
                    sx={{ color: "text.disabled" }}
                  />
                </InputAdornment>
              ),
            }}
          />

          <React.Fragment>
            <Dialog
              open={openColumn}
              onClose={handleCloseColumn}
              PaperProps={{
                component: "form",
                onSubmit: (event: React.FormEvent<HTMLFormElement>) => {
                  event.preventDefault();
                  const formData = new FormData(event.currentTarget);
                  const formJson = Object.fromEntries(
                    (formData as any).entries()
                  );
                  const email = formJson.email;
                  console.log(email);
                  handleCloseColumn();
                },
                sx: {
                  position: "absolute",
                  right: 0,
                  top: "300px",
                  maxWidth: "300px",
                },
              }}
            >
              <DialogContent>
                <ColumnView />
              </DialogContent>
              <DialogActions>
                <Button onClick={handleCloseColumn}>Annuler</Button>
              </DialogActions>
            </Dialog>
          </React.Fragment>
         
        </Stack>
      </Stack>

    </>
  );
}
