import { useEffect, useState } from 'react';
import Box from '@mui/material/Box';
import Card from '@mui/material/Card';
import CardHeader from '@mui/material/CardHeader';
import TextField from '@mui/material/TextField';
import Button from '@mui/material/Button';
import { addOrderComment } from '@/shared/api/supplierOrders';

type Props = {
  orderId: string;
  comment: string;
  onMutate: () => void;
  areStatusesSaved: boolean;
};

export default function OrderComment({ orderId, comment, onMutate, areStatusesSaved }: Props) {
  const [commentInput, setCommentInput] = useState('');
  const [isSubmitting, setIsSubmitting] = useState(false);

  const handleCommentChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    setCommentInput(event.target.value);
  };

  const handleCommentSubmit = async () => {
    setIsSubmitting(true);
    try {
      await addOrderComment(orderId, commentInput);
      setCommentInput('');
      onMutate();
    } catch (error) {
      console.error('Failed to submit comment:', error);
    } finally {
      setIsSubmitting(false);
    }
  };

  useEffect(() => {
    setCommentInput(comment);
  }, [comment]);

  return (
    <Card>
      <CardHeader
        title="Commentaire"
        action={
          <Button
            variant="contained"
            color="primary"
            onClick={handleCommentSubmit}
            disabled={!commentInput || isSubmitting || !areStatusesSaved}
          >
            Envoyer
          </Button>
        }
      />

      <Box sx={{ color: 'text.secondary', p: 3 }}> {"Commentaire actuel: " + comment}</Box>

      <Box sx={{ p: 3 }}>
        <TextField
          fullWidth
          multiline
          rows={4}
          placeholder="Ajouter votre commentaire ici..."
          variant="outlined"
          value={commentInput}
          onChange={handleCommentChange}
        />
      </Box>
    </Card>
  );
}
