import Box from '@mui/material/Box';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import { SupplierDTO } from '@/contexts/types/supplierOrder';
import { getSupplierById } from '@/shared/api/supplierOrders';
import { useState } from 'react';
import { useEffect } from 'react';
import { enqueueSnackbar } from 'notistack';
import { ConcatFullAddress } from '@/shared/api/supplier';


type Props = {
  supplierId: string;
};

export default function OrderDetailsInfo({ supplierId }: Props) {
  const [supplier, setSupplier] = useState<SupplierDTO>();

  useEffect(() => {
    const loadDriverAndSupplier = async () => {
      if (!supplierId) return;

      try {
        const supplierData = await getSupplierById(Number(supplierId!));
        if (supplierData) {
          setSupplier({
            id: supplierData.id,
            companyName: supplierData.companyName,
            companyEmail: supplierData.companyEmail,
            companyPhoneNumber: supplierData.companyPhoneNumber,
            companyStreet: supplierData.companyStreet,
            companyCity: supplierData.companyCity,
            companyCountry: supplierData.companyCountry,
            siretNumber: supplierData.siretNumber,
            supplierName: supplierData.supplierName,
            supplierLastName: supplierData.supplierLastName,
            supplierPhoneNumber: supplierData.supplierPhoneNumber,
            supplierEmail: supplierData.supplierEmail,
          });
        }
      } catch (error) {
        enqueueSnackbar("Failed to fetch supplier", { variant: "error" });
      }
    };

    loadDriverAndSupplier();
  }, [supplierId]);

  const renderCustomer = (
    <>
      <CardHeader title="Information sur le Fournisseur" />
      <Stack direction="row" sx={{ p: 3 }}>
        <Stack spacing={0.5} alignItems="flex-start" sx={{ typography: 'body2' }}>
          <Typography variant="subtitle2">{supplier?.supplierName! || 'N/A'}</Typography>
          <Box>
            Email :
            <Box component="span" sx={{ color: 'text.secondary', ml: 0.25 }}>
              {supplier?.supplierEmail! || 'N/A'}
            </Box>
          </Box>
          <Box>
            N° Téléphone:
            <Box component="span" sx={{ color: 'text.secondary', ml: 0.25 }}>
              {supplier?.supplierPhoneNumber! || 'N/A'}
            </Box>
          </Box>
          <Box>
            Addresse:
            <Box component="span" sx={{ color: 'text.secondary', ml: 0.25 }}>
              {ConcatFullAddress(supplier!) || 'N/A'}
            </Box>
          </Box>
        </Stack>
      </Stack>
    </>
  );

  return (
    <Card>
      {renderCustomer}
    </Card>
  );
}
