import React, { useState } from 'react';
import { Table, TableBody, TableCell, TableContainer, TableHead, TableRow, Card, Stack, Typography, TablePagination } from '@mui/material';
import { styled } from '@mui/material/styles';
import { SupplierOrderHistory, supplierOrderStatusLabels } from '@/contexts/types/supplierOrder';
import { fDateTime } from '@/utils/format-time';


type Props = {
  history: SupplierOrderHistory[];
};

const StyledTableContainer = styled(TableContainer)(({ theme }) => ({
  borderRadius: theme.shape.borderRadius,
  overflow: 'hidden',
}));

const StyledTableCell = styled(TableCell)(({ theme }) => ({
  backgroundColor: theme.palette.background.paper,
  color: theme.palette.text.primary,
  fontWeight: 500,
}));

const StyledTableRow = styled(TableRow)(({ theme }) => ({
  '&:nth-of-type(odd)': {
    backgroundColor: theme.palette.action.hover,
  },
  '&:last-child td, &:last-child th': {
    border: 0,
  },
}));

const StyledTableHeadCell = styled(TableCell)(({ theme }) => ({
  backgroundColor: theme.palette.grey[200],
  color: theme.palette.text.secondary,
  fontWeight: 'bold',
}));

export default function OrderStatusHistory({ history }: Props) {
  const [page, setPage] = useState(0);
  const rowsPerPage = 5;

  const handleChangePage = (event: unknown, newPage: number) => {
    setPage(newPage);
  };

  const paginatedHistory = history.slice().reverse().slice(page * rowsPerPage, page * rowsPerPage + rowsPerPage);

  return (
    <Card>
      <Stack spacing={2} sx={{ p: 3 }}>
        <Typography variant="h6">Historique des statuts</Typography>
        <StyledTableContainer>
          <Table>
            <TableHead>
              <TableRow>
                <StyledTableHeadCell>Ancien Status</StyledTableHeadCell>
                <StyledTableHeadCell>Nouveau Status</StyledTableHeadCell>
                <StyledTableHeadCell>Date de changement</StyledTableHeadCell>
              </TableRow>
            </TableHead>
            <TableBody>
              {paginatedHistory.map((item, index) => (
                <StyledTableRow key={index}>
                  <StyledTableCell>{supplierOrderStatusLabels[item.oldStatus]}</StyledTableCell>
                  <StyledTableCell>{supplierOrderStatusLabels[item.newStatus]}</StyledTableCell>
                  <StyledTableCell>
                    {fDateTime(item.createdAt!, 'dd/MM/yyyy HH:mm:ss')}
                  </StyledTableCell>
                </StyledTableRow>
              ))}
            </TableBody>
          </Table>
        </StyledTableContainer>
        <TablePagination
          component="div"
          count={history.length}
          page={page}
          onPageChange={handleChangePage}
          rowsPerPage={rowsPerPage}
          rowsPerPageOptions={[5]}
        />
      </Stack>
    </Card>
  );
}
