import Box from "@mui/material/Box";
import MenuItem from "@mui/material/MenuItem";
import TableRow from "@mui/material/TableRow";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import VisibilityIcon from '@mui/icons-material/Visibility';
import EditIcon from '@mui/icons-material/Edit';
import ArchiveIcon from '@mui/icons-material/Archive';
import React from "react";
import Iconify from "../../../../components/iconify";
import CustomPopover, {
  usePopover,
} from "../../../../components/custom-popover";

export type SupplierDTO = {
  id: number;
  companyName: string;
  companyEmail: string;
  companyPhoneNumber: string;
  companyStreet: string;
  companyCity: string;
  companyCountry: string;
  siretNumber: number;
  supplierName: string;
  supplierLastName: string;
  supplierPhoneNumber: string;
  supplierEmail: string;
};

type Props = {
  row: SupplierDTO;
  selected: boolean;
  onViewRow: VoidFunction;
  onSelectRow: VoidFunction;
  onEditRow: VoidFunction;
  onDeleteRow: VoidFunction;
  onArchiveRow: VoidFunction;
  isNotDriver: boolean;
};

export default function SupplierTableRow({
  row,
  selected,
  onViewRow,
  onEditRow,
  onArchiveRow,
  isNotDriver,
}: Props) {
  const {
    supplierName,
    supplierLastName,
    supplierPhoneNumber,
    companyCity,
    companyStreet,
    companyCountry,
  } = row;

  const popover = usePopover();

  return (
    <>
      <TableRow hover selected={selected} sx={{ cursor: "pointer" }}>
        {/* Supplier Name */}
        <TableCell onClick={onViewRow}>
          <Box
            sx={{
              cursor: "pointer",
              "&:hover": {
                textDecoration: "underline",
              },
            }}
          >
            {supplierName} {supplierLastName}
          </Box>
        </TableCell>

        <TableCell onClick={onViewRow} sx={{ whiteSpace: "nowrap" }}>
          {`${companyStreet}, ${companyCity}, ${companyCountry}`}
        </TableCell>
        {/* Supplier Phone Number */}
        <TableCell onClick={onViewRow}>{supplierPhoneNumber}</TableCell>

        {/* Actions */}
        <TableCell align="right" sx={{ px: 1, whiteSpace: "nowrap" }}>
          <IconButton
            color={popover.open ? "inherit" : "default"}
            onClick={popover.onOpen}
          >
            <Iconify icon="eva:more-vertical-fill" />
          </IconButton>
        </TableCell>
      </TableRow>

      {/* Popover Menu */}
      <CustomPopover
        open={popover.open}
        onClose={popover.onClose}
        sx={{ width: 200 }}
      >
        <MenuItem
          onClick={() => {
            onViewRow();
            popover.onClose();
          }}
        >
         <VisibilityIcon />
          Voir
        </MenuItem>

        {isNotDriver && (
          <MenuItem
            onClick={() => {
              onEditRow();
              popover.onClose();
            }}
          >
            <EditIcon />
            Modifier
          </MenuItem>
        )}
        {isNotDriver && (
          <MenuItem
            onClick={() => {
              onArchiveRow();
              popover.onClose();
            }}
            sx={{ color: "error.main" }}
          >
            <ArchiveIcon color="error" />
            Archiver
          </MenuItem>
        )}
      </CustomPopover>
    </>
  );
}
