'use client';

import { useParams } from 'next/navigation';
import Container from '@mui/material/Container';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import CardContent from '@mui/material/CardContent';
import Typography from '@mui/material/Typography';
import { useSettingsContext } from '../../../../components/settings';
import CustomBreadcrumbs from '../../../../components/custom-breadcrumbs';
import { paths } from '../../../../../routes/paths';
import { useGetSupplierById } from '@/shared/api/supplier';

// ----------------------------------------------------------------------

export default function SupplierDetailsView() {
  const settings = useSettingsContext();
  const { id } = useParams();
  const supplierId = Array.isArray(id) ? id[0] : id;
  const { supplier, supplierError, supplierLoading } = useGetSupplierById(supplierId);

  if (supplierLoading) {
    return <div>Loading...</div>;
  }

  if (supplierError || !supplier) {
    return <div>Fournisseur non trouvé</div>;
  }

  return (
    <Container maxWidth={settings.themeStretch ? false : 'lg'}>
      <CustomBreadcrumbs
        heading="Détails du fournisseur"
        links={[
          {
            name: "Tableau de bord",
            href: paths.dashboard.driver.root,
          },
          {
            name: "Liste des fournisseurs",
            href: paths.dashboard.driver.supplier,
          },
          {
            name: supplier.supplierName + ' ' + supplier.supplierLastName,
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <Grid container spacing={3}>
        {/* Informations du fournisseur */}
        <Grid xs={12} md={6}>
          <Card>
            <CardContent>
              <Typography variant="h6" gutterBottom>
                Informations du Fournisseur
              </Typography>
              <Typography variant="body2">
                <strong>Nom:</strong> {supplier.supplierName + ' ' + supplier.supplierLastName}
              </Typography>
              <Typography variant="body2">
                <strong>Email:</strong> {supplier.supplierEmail}
              </Typography>
              <Typography variant="body2">
                <strong>Téléphone:</strong> {supplier.supplierPhoneNumber}
              </Typography>
            </CardContent>
          </Card>
        </Grid>

        {/* Informations de l'entreprise */}
        <Grid xs={12} md={6}>
          <Card>
            <CardContent>
              <Typography variant="h6" gutterBottom>
                Informations de l'Entreprise
              </Typography>
              <Typography variant="body2">
                <strong>Nom de l'entreprise:</strong> {supplier.companyName}
              </Typography>
              <Typography variant="body2">
                <strong>Email:</strong> {supplier.companyEmail}
              </Typography>
              <Typography variant="body2">
                <strong>Téléphone:</strong> {supplier.companyPhoneNumber}
              </Typography>
              <Typography variant="body2">
                <strong>Adresse:</strong> {supplier.companyStreet + ', ' + supplier.companyCity + ', ' + supplier.companyCountry}
              </Typography>
              <Typography variant="body2">
                <strong>SIRET:</strong> {supplier.siretNumber}
              </Typography>
            </CardContent>
          </Card>
        </Grid>
      </Grid>
    </Container>
  );
}
