import MenuItem from "@mui/material/MenuItem";
import Iconify from "@/shared/components/iconify";
import CustomPopover, { usePopover } from "@/shared/components/custom-popover";
import { IGiftCardvalue, IGiftcardFilter } from "@/contexts/types/giftcard";
import Box from "@mui/material/Box";
import { GridToolbarExport, GridToolbarFilterButton } from '@mui/x-data-grid';
import { Button} from "@mui/material";

// ----------------------------------------------------------------------

type Props = {
  filters: IGiftcardFilter;
  onFilters: (name: string, value: IGiftCardvalue) => void;
  dateError: boolean;
  children?: React.ReactNode;
};

export default function GiftcardTableToolbar({
  children,
}: Props) {
  const popover = usePopover();


  return (
    <>
      <Box sx={{ display: 'flex', justifyContent: 'space-between', mb: 2 }}>
        {children}
        <Box>
          <GridToolbarFilterButton />
          <GridToolbarExport />
          <Button
            onClick={popover.onOpen}
            startIcon={<Iconify icon="solar:ellipsis-vertical-bold" />}
          >
            Options
          </Button>
          <CustomPopover
            open={popover.open}
            onClose={popover.onClose}
            arrow="right-top"
            sx={{ width: 140 }}
          >
            <MenuItem
              onClick={() => {
                popover.onClose();
                
              }}
            >
              <Iconify icon="solar:printer-minimalistic-bold" />
              Imprimer
            </MenuItem>

            <MenuItem
              onClick={() => {
                popover.onClose();
              }}
            >
              <Iconify icon="solar:import-bold" />
              Importer
            </MenuItem>

            <MenuItem
              onClick={() => {
                popover.onClose();
                
              }}
            >
              <Iconify icon="solar:export-bold" />
              Exporter
            </MenuItem>
          </CustomPopover>
        </Box>
      </Box>
    </>
  );
}

// ----------------------------------------------------------------------

type BlockProps = {
  label: string;
  children?: React.ReactNode;
  sx?: object;
};

function Block({ label, children, sx, ...other }: BlockProps) {
  return (
    <Box
      component="div"
      sx={{
        p: 1,
        borderRadius: 1,
        overflow: "hidden",
        borderStyle: "dashed",
        ...sx,
      }}
      {...other}
    >
      <Box component="span" sx={{ typography: "subtitle2" }}>
        {label}
      </Box>

      <Box sx={{ display: 'flex', gap: 1 }}>
        {children}
      </Box>
    </Box>
  );
}
