"use client";
import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Grid } from "@mui/material";
import { useState } from "react";
import OrderFilters from "./statistics-filters";
import AppWidgetSummary from "./statistics-widget-summary";
import { useTheme } from "@mui/material/styles";
import AnalyticsActiveClient from "./ReceivedItemsRate";


import { useActiveClientsCompare, useActiveClientsWithLiveItems, useLivesCount } from "@/shared/api/chiffreLiveStatistics";
import { useSumViewers } from "@/shared/api/chiffreLiveStatistics";

export default function AllLivesStatisticsView() {
  const settings = useSettingsContext();
  const theme = useTheme();


  const [startDate, setStartDate] = useState<Date>(() => {
    const oneMonthAgo = new Date();
    oneMonthAgo.setMonth(oneMonthAgo.getMonth() - 1);
    return oneMonthAgo;
  });
  const [endDate, setEndDate] = useState<Date>(new Date());

  const [selectedLiveIds, setSelectedLiveIds] = useState<number[]>([]);

  const { livesCount } = useLivesCount(startDate, endDate);

  const { sumViewers } = useSumViewers(selectedLiveIds);
  const { activeClientsCount } = useActiveClientsWithLiveItems(startDate, endDate);
  const { data, isLoading, isError } = useActiveClientsCompare(startDate, endDate);

  const conversionRate = sumViewers && sumViewers > 0
    ? (activeClientsCount! / sumViewers) * 100
    : 0;
 

 
  const statsFiltersProps = {
    startDate,
    endDate,
    onChangeStartDate: (date: Date) => setStartDate(date),
    onChangeEndDate: (date: Date) => setEndDate(date),
    selectedLiveIds,
    setSelectedLiveIds,
  };

  const itemsAveragePerCart  = sumViewers && sumViewers > 0
    ? (activeClientsCount! / sumViewers) * 100
    : 0;

  return (
    <Container
      sx={{ gap: 3, display: "flex", flexDirection: "column" }}
      maxWidth={settings.themeStretch ? false : "lg"}
    >
      <CustomBreadcrumbs
        heading="Chiffres Live"
        links={[
          {
            name: "Tableau de bord",
            href: paths.dashboard.root,
          },
          {
            name: "Chiffre Lives",
            href: paths.dashboard.admin.liveStatistics,
          },
          {
            name: "Statistiques",
          },
        ]}
        sx={{ mb: { xs: 3, md: 5 } }}
      />

      
      <OrderFilters {...statsFiltersProps} />

      <Grid container spacing={3}>
       
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Nombre de lives"
            total={livesCount ?? 0}
            color={theme.palette.error.light}
          />
        </Grid>

       
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Nombre de viewers"
            total={sumViewers ?? 0}
            color={theme.palette.info.dark}
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Nombre de clients actifs"
            total={activeClientsCount ?? 0}
            color={theme.palette.error.light}
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Taux de conversion (%)"
            total={conversionRate}
            color={theme.palette.info.dark}
            showPercentage
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Nombre moyen d’articles par panier"
            total={46}
            color={theme.palette.error.light}
          />
        </Grid>

      </Grid>

     
      <Grid item xs={8} md={6} lg={8}>
      {!isLoading && !isError && data ?(
          <AnalyticsActiveClient
            title="Nombre de clients actifs"
            chart={{
              labels: data.labels,
              series: data.series,
    
            }}
          />
        ): (
          <div>Chargement en cours...</div>
        )}
      </Grid>
    </Container>
  );
}
