"use client";

import isEqual from "lodash/isEqual";
import { useState, useCallback, useMemo } from "react";

import Tab from "@mui/material/Tab";
import Tabs from "@mui/material/Tabs";
import Card from "@mui/material/Card";
import Table from "@mui/material/Table";
import Button from "@mui/material/Button";
import { alpha } from "@mui/material/styles";
import Container from "@mui/material/Container";
import TableBody from "@mui/material/TableBody";
import TableContainer from "@mui/material/TableContainer";

import { paths } from "@/routes/paths";
import { useRouter } from "../../../../../hooks/use-router";

import { useBoolean } from "@/hooks/use-boolean";

import Label from "../../../../components/label";
import Iconify from "@/components/iconify";
import Scrollbar from "@/components/scrollbar";
import { useSnackbar } from "@/components/snackbar";
import { ConfirmDialog } from "../../../../components/custom-dialog";
import { useSettingsContext } from "@/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import {
  useTable,
  emptyRows,
  TableNoData,
  getComparator,
  TableEmptyRows,
  TableHeadCustom,
  TableSelectedAction,
  TablePaginationCustom,
} from "@/shared/components/table";
import {
  _livesInf,
  ILiveItem,
  SalesSessionTableFilters,
  SalesSessionTableFilterValue,
  LiveTyple,
} from "@/shared/_mock/_cartLive";

import SalesSessionTableRow from "./LiveSession-table-row";
import SalesSessionTableToolbar from "./LiveSession-table-toolbar";
import SalesSessionTableFiltersResult from "./LiveSession-table-filters-result";
import {
  Autocomplete,
  Box,
  Dialog,
  DialogActions,
  DialogContent,
  DialogTitle,
  FormControl,
  InputLabel,
  MenuItem,
  Select,
  TextField,
} from "@mui/material";
import { _lives } from "@/shared/_mock/_live";
import React from "react";

// ----------------------------------------------------------------------

const Type_OPTIONS = [{ value: "all", label: "All" }, ...LiveTyple];

const TABLE_HEAD = [
  { id: "id", label: "id", width: 60 },
  { id: "Live", label: "Live", width: 80 },
  { id: "createdAt", label: "Date création ", width: 80 },
  { id: "editedAt", label: "Dernière mise a jour", width: 80 },
  { id: "produit", label: "produits Vendu", width: 80 },
  { id: "client", label: "Nombre Client", width: 80 },
  { id: "totalSales", label: "Total Vente", width: 80 },
  { id: "endDate", label: "Date d'expiration", width: 80 },
  { id: "description", label: "Description", width: 60 },
  { id: "Type", label: "Type Live", width: 80 },

  { id: "", width: "30" },
];

const defaultFilters: SalesSessionTableFilters = {
  title: "",
  type: "all",
};

// ----------------------------------------------------------------------

export default function AllSalesSessionView() {
  const { enqueueSnackbar } = useSnackbar();

  const table = useTable();

  const settings = useSettingsContext();

  const router = useRouter();

  const confirm = useBoolean();

  const [tableData, setTableData] = useState<ILiveItem[]>(_livesInf);

  const [filters, setFilters] = useState(defaultFilters);
  const memoizedApplyFilter = useMemo(() => applyFilter, []);

  const dataFiltered = memoizedApplyFilter({
    inputData: tableData,
    comparator: getComparator(table.order, table.orderBy),
    filters,
  });

  const dataInPage = dataFiltered.slice(
    table.page * table.rowsPerPage,
    table.page * table.rowsPerPage + table.rowsPerPage
  );

  const denseHeight = table.dense ? 56 : 56 + 20;

  const canReset = !isEqual(defaultFilters, filters);

  const notFound = (!dataFiltered.length && canReset) || !dataFiltered.length;

  const handleFilters = useCallback(
    (title: string, value: SalesSessionTableFilterValue) => {
      table.onResetPage();
      setFilters((prevState) => ({
        ...prevState,
        [title]: value,
      }));
    },
    [table]
  );
  const handleResetFilters = useCallback(() => {
    setFilters(defaultFilters);
  }, []);

  const handleDeleteRow = useCallback(
    (id: string) => {
      const deleteRow = tableData.filter((row) => row.id !== id);

      enqueueSnackbar("Delete success!");

      setTableData(deleteRow);

      table.onUpdatePageDeleteRow(dataInPage.length);
    },
    [dataInPage.length, enqueueSnackbar, table, tableData]
  );

  const handleDeleteRows = useCallback(() => {
    const deleteRows = tableData.filter(
      (row) => !table.selected.includes(row.id)
    );

    enqueueSnackbar("Delete success!");

    setTableData(deleteRows);

    table.onUpdatePageDeleteRows({
      totalRowsInPage: dataInPage.length,
      totalRowsFiltered: dataFiltered.length,
    });
  }, [
    dataFiltered.length,
    dataInPage.length,
    enqueueSnackbar,
    table,
    tableData,
  ]);

  const handleEditRow = useCallback(
    (id: string) => {
      router.push(paths.dashboard.admin.user.edit(id));
    },
    [router]
  );

  const handleFiltertype = useCallback(
    (event: React.SyntheticEvent, newValue: string) => {
      handleFilters("type", newValue);
    },
    [handleFilters]
  );

  const [openAddDialog, setOpenAddDialog] = useState(false);
  const [selectedType, setSelectedType] = useState("");

  const handleOpenAddDialog = () => {
    setOpenAddDialog(true);
  };

  const handleCloseAddDialog = () => {
    setOpenAddDialog(false);
  };

  return (
    <>
      <Container maxWidth={settings.themeStretch ? false : "lg"}>
        <CustomBreadcrumbs
          heading="LIST"
          links={[
            { name: "Tableau de bord", href: paths.dashboard.root },
            { name: "Vente", href: paths.dashboard.admin.live.saleSession },
            { name: "Listes" },
          ]}
          action={
            <Button
              variant="contained"
              startIcon={<Iconify icon="mingcute:add-line" />}
              onClick={handleOpenAddDialog}
            >
              Ajouter
            </Button>
          }
          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />
        <Dialog
          open={openAddDialog}
          onClose={handleCloseAddDialog}
          fullWidth
          maxWidth="sm"
        >
          <DialogTitle>{"Ajouter une session de live"}</DialogTitle>
          <DialogContent>
            <FormControl fullWidth margin="normal">
              <InputLabel id="type-live-label">Type de Live</InputLabel>
              <Select
                labelId="type-live-label"
                value={selectedType}
                onChange={(e) => setSelectedType(e.target.value)}
                label="Type de Live"
              >
                {LiveTyple.map((option) => (
                  <MenuItem key={option.value} value={option.value}>
                    {option.label}
                  </MenuItem>
                ))}
              </Select>
            </FormControl>

            {selectedType === "Live" ? (
              <>
                <Autocomplete
                  id="live"
                  autoHighlight
                  options={_lives}
                  getOptionLabel={(option) => option.title || option.id}
                  isOptionEqualToValue={(option, value) =>
                    option.title === value.title || option.id === value.id
                  }
                  renderOption={(props, option) => (
                    <Box
                      component="li"
                      sx={{ display: "flex", alignItems: "center" }}
                      {...props}
                    >
                      <img
                        loading="lazy"
                        width="40"
                        src={option.image}
                        alt=""
                        style={{ marginRight: 8 }}
                      />
                      <span>{option.title}</span>
                    </Box>
                  )}
                  renderInput={(params) => (
                    <TextField
                      {...params}
                      label="Choisir un live"
                      InputLabelProps={{ shrink: true }}
                      variant="outlined"
                      margin="normal"
                    />
                  )}
                  sx={{ width: "100%", marginTop: 2 }}
                />
                <TextField
                  fullWidth
                  margin="normal"
                  label="Nom"
                  variant="outlined"
                />
                <TextField
                  fullWidth
                  margin="normal"
                  label="Date début"
                  type="datetime-local"
                  InputLabelProps={{ shrink: true }}
                  variant="outlined"
                />
                <TextField
                  fullWidth
                  margin="normal"
                  label="Date d'expiration"
                  type="datetime-local"
                  InputLabelProps={{ shrink: true }}
                  variant="outlined"
                />
                <TextField
                  fullWidth
                  margin="normal"
                  label="Description"
                  multiline
                  rows={4}
                  variant="outlined"
                />
              </>
            ) : (
              <>
                <TextField
                  fullWidth
                  margin="normal"
                  label="Nom"
                  variant="outlined"
                />
                <TextField
                  fullWidth
                  margin="normal"
                  label="Date début"
                  type="datetime-local"
                  InputLabelProps={{ shrink: true }}
                  variant="outlined"
                />
                <TextField
                  fullWidth
                  margin="normal"
                  label="Date d'expiration"
                  type="datetime-local"
                  InputLabelProps={{ shrink: true }}
                  variant="outlined"
                />
                <TextField
                  fullWidth
                  margin="normal"
                  label="Description"
                  multiline
                  rows={4}
                  variant="outlined"
                />
              </>
            )}
          </DialogContent>
          <DialogActions>
            <Button onClick={handleCloseAddDialog} color="secondary">
              Annuler
            </Button>
            <Button
              color="primary"
              variant="contained"
              onClick={handleCloseAddDialog}
            >
              Ajouter
            </Button>
          </DialogActions>
        </Dialog>

        <Card>
          <Tabs
            value={filters.type}
            onChange={handleFiltertype}
            sx={{
              px: 2.5,
              boxShadow: (theme) =>
                `inset 0 -2px 0 0 ${alpha(theme.palette.grey[500], 0.08)}`,
            }}
          >
            {Type_OPTIONS.map((tab) => (
              <Tab
                key={tab.value}
                iconPosition="end"
                value={tab.value}
                label={tab.label}
                icon={
                  <Label
                    variant={
                      ((tab.value === "all" || tab.value === filters.type) &&
                        "filled") ||
                      "soft"
                    }
                    color={
                      (tab.value === "Live" && "success") ||
                      (tab.value === "Demande MP" && "warning") ||
                      (tab.value === "Article a contrôlé" && "error") ||
                      (tab.value === "Autre" && "default") ||
                      "default"
                    }
                  >
                    {[
                      "Live",
                      "Demande MP",
                      "Article a contrôlé",
                      "Autre",
                    ].includes(tab.value)
                      ? tableData.filter((user) => user.type === tab.value)
                          .length
                      : tableData.length}
                  </Label>
                }
              />
            ))}
          </Tabs>

          <SalesSessionTableToolbar
            filters={filters}
            onFilters={handleFilters}
            //
          />

          {canReset && (
            <SalesSessionTableFiltersResult
              filters={filters}
              onFilters={handleFilters}
              //
              onResetFilters={handleResetFilters}
              //
              results={dataFiltered.length}
              sx={{ p: 2.5, pt: 0 }}
            />
          )}

          <TableContainer sx={{ position: "relative", overflow: "unset" }}>
            <TableSelectedAction
              dense={table.dense}
              numSelected={table.selected.length}
              rowCount={dataFiltered.length}
              onSelectAllRows={(checked) =>
                table.onSelectAllRows(
                  checked,
                  dataFiltered.map((row) => row.id)
                )
              }
            />

            <Scrollbar>
              <Table
                size={table.dense ? "small" : "medium"}
                sx={{ minWidth: 960 }}
              >
                <TableHeadCustom
                  order={table.order}
                  orderBy={table.orderBy}
                  headLabel={TABLE_HEAD}
                  rowCount={dataFiltered.length}
                  numSelected={table.selected.length}
                  onSort={table.onSort}
                />

                <TableBody>
                  {dataFiltered
                    .slice(
                      table.page * table.rowsPerPage,
                      table.page * table.rowsPerPage + table.rowsPerPage
                    )
                    .map((row) => (
                      <SalesSessionTableRow
                        key={row.id}
                        row={row}
                        selected={table.selected.includes(row.id)}
                        onSelectRow={() => table.onSelectRow(row.id)}
                        onDeleteRow={() => handleDeleteRow(row.id)}
                        onEditRow={() => handleEditRow(row.id)}
                      />
                    ))}

                  <TableEmptyRows
                    height={denseHeight}
                    emptyRows={emptyRows(
                      table.page,
                      table.rowsPerPage,
                      dataFiltered.length
                    )}
                  />

                  <TableNoData notFound={notFound} />
                </TableBody>
              </Table>
            </Scrollbar>
          </TableContainer>

          <TablePaginationCustom
            count={dataFiltered.length}
            page={table.page}
            rowsPerPage={table.rowsPerPage}
            onPageChange={table.onChangePage}
            onRowsPerPageChange={table.onChangeRowsPerPage}
            //
            dense={table.dense}
            onChangeDense={table.onChangeDense}
          />
        </Card>
      </Container>

      <ConfirmDialog
        open={confirm.value}
        onClose={confirm.onFalse}
        title="Delete"
        content={
          <>
            Are you sure want to delete{" "}
            <strong> {table.selected.length} </strong> items?
          </>
        }
        action={
          <Button
            variant="contained"
            color="error"
            onClick={() => {
              handleDeleteRows();
              confirm.onFalse();
            }}
          >
            Delete
          </Button>
        }
      />
    </>
  );
}

// ----------------------------------------------------------------------

function applyFilter({
  inputData,
  comparator,
  filters,
}: {
  inputData: ILiveItem[];
  comparator: (a: any, b: any) => number;
  filters: SalesSessionTableFilters;
}) {
  const { title, type } = filters;

  const stabilizedThis = inputData.map((el, index) => [el, index] as const);

  stabilizedThis.sort((a, b) => {
    const order = comparator(a[0], b[0]);
    if (order !== 0) return order;
    return a[1] - b[1];
  });

  inputData = stabilizedThis.map((el) => el[0]);

  if (title) {
    inputData = inputData.filter(
      (user) => user.title.toLowerCase().indexOf(title.toLowerCase()) !== -1
    );
  }

  if (type !== "all") {
    inputData = inputData.filter((user) => user.type === type);
  }

  return inputData;
}
