import { Card, CardHeader } from "@mui/material";
import Chart, { useChart } from "@/components/chart";
import { ApexOptions } from "apexcharts";

interface SeriesData {
  name: string;
  type: string;
  fill?: string;
  data: number[];
}

interface ChartData {
  labels: string[];
  colors?: string[];
  series: SeriesData[];
  options?: ApexOptions;
}

interface Props {
  title?: string;
  subheader?: string;
  chart: ChartData;
}

export default function AnalyticsNetSales({ title, subheader, chart }: Props) {
  const { labels, colors, series, options } = chart;

  const chartOptions = useChart({
    colors,
    plotOptions: {
      bar: {
        columnWidth: "16%",
      },
    },
    fill: {
      type: "solid",
    },
    labels,
    xaxis: {
      type: "datetime",
    },
    tooltip: {
      x: {
        format: "dd/MM/yy",
      },
      shared: true,
      intersect: false,
      y: {
        formatter: (value: number) => {
          if (typeof value !== "undefined") {
            return `${value.toFixed(0)} Produits`;
          }
          return value;
        },
      },
    },
    yaxis: {
      title: {
        text: "Nombre d'ajouts au panier",
      },
      min: 0,
      max: 1000,
    },
    ...options,
  });

  return (
    <Card>
      <CardHeader
        title={title}
        subheader={subheader}
      />
      <Chart
        dir="ltr"
        type="line"
        series={series}
        options={chartOptions}
        width="100%"
        height={426}
      />
    </Card>
  );
}
