"use client";
import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Grid } from "@mui/material";
import { useState } from "react";
import { useGetLivesStatistic } from "@/shared/api/live";
import OrderFilters from "../../cart/statistics/statistics-filters";
import AppWidgetSummary from "../../home/statistics/statistics-widget-summary";
import AnalyticsAbandonedCarts from "../../cart/statistics/Analytics-AbandonedCarts";
import AnalyticsNetSales from "../Live_manger/statistics/ProductRateLive";
import AllLiveSessionView from "@/shared/sections/home/Live_manger/statistics/AllLiveSessionView";
import { _BestSalesProduct1 } from "@/shared/_mock";
import { useTheme } from "@mui/material/styles";

export default function AllStatisticsView() {
  const settings = useSettingsContext();
  const [startDate, setStartDate] = useState<Date>(new Date("2023-03-21"));
  const [endDate, setEndDate] = useState<Date>(new Date("2023-03-23"));
  const [selectedOrders, setSelectedOrders] = useState<string[]>([]);

  const {
    statsData: { stats },
  } = useGetLivesStatistic(startDate, endDate, selectedOrders);
  const theme = useTheme();

  const statsFiltersProps = {
    startDate,
    endDate,
    onChangeStartDate: (startDate: Date) => {
      setStartDate(startDate);
    },
    onChangeEndDate: (endDate: Date) => {
      setEndDate(endDate);
    },
    selectedOrders,
    setSelectedOrders,
  };

  const chartOptions = {
    labels: [
      "04/01/2024",
      "04/06/2024",
      "04/09/2024",
      "04/10/2024",
      "04/15/2024",
      "04/17/2024",
      "04/20/2024",
      "04/29/2024",
    ],
    series: [
      {
        name: "Live",
        type: "line",
        fill: "solid",
        data: [230, 110, 220, 270, 130, 220, 370, 210],
      },
      {
        name: "Site",
        type: "line",
        fill: "solid",
        data: [440, 550, 410, 670, 220, 430, 210, 970],
      },
    ],
  };

  return (
    <Container
      sx={{ gap: 3, display: "flex", flexDirection: "column" }}
      maxWidth={settings.themeStretch ? false : "lg"}
    >
      <CustomBreadcrumbs
        heading="Statistiques du Gestionnaire de Live"
        links={[
          {
            name: "Tableau de bord",
            href: paths.dashboard.root,
          },
          {
            name: "Gestionnaire Live",
            href: paths.dashboard.admin.cart.root,
          },
          {
            name: "Statistiques",
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <OrderFilters {...statsFiltersProps} />
      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Taux de transformation"
            
            total={92}
            color={theme.palette.error.light}
           
            showPercentage={true}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaire réel"
            
            total={7000}
            color={theme.palette.info.dark}
           
            showEuroSymbol={true}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaire théorique"
            
            total={7050}
            color={theme.palette.primary.main}
           
            showEuroSymbol={true}
          />
        </Grid>
      </Grid>
      <Grid container spacing={1}>
        <Grid item xs={4} md={4} lg={4}>
          <AnalyticsAbandonedCarts
            title="Paniers Abandonnés"
            chart={{
              series: [
                { label: "paniers créés", value: 600 },
                { label: "paniers abandonnés", value: 100 },
              ],
            }}
          />
        </Grid>
        <Grid item xs={8} md={6} lg={8}>
          <AnalyticsNetSales
            title="Taux d’ajout des produits au panier pendant le live et pendant le site"
            chart={chartOptions}
          />
        </Grid>
        <AllLiveSessionView/>
      </Grid>
    </Container>
  );
}
