"use client";
import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Grid } from "@mui/material";
import { useEffect, useMemo, useState } from "react";
import AppWidgetSummary from "./statistics-widget-summary";
import { useTheme } from "@mui/material/styles";
import { ChartData, fetchOrdersStatsData, fetchRealRefundRevenue, fetchRealRevenue } from "@/shared/api/saleSessionStatistics";
import { useSnackbar } from "@/shared/components/snackbar";
import AdminFilters from "./statistics-filters-Admin";
import { fetchBasketComparisonChartDataGrossRevenue, sumShippingPrice, useGrossRevenueBySource } from "@/shared/api/chiffreLiveStatistics";
import BasketAmountChartChiffre from "../chiffreStatistics/EcartAmount-Chiffre-chart";
import AnalyticsSalesSource from "./Analytics-SalesSource";
import OrderCommandChart from "../../order/statistics/OrderCommandChart";

export default function AllAdminStatisticsView() {
  const settings = useSettingsContext();
  const theme = useTheme();

  const [startDate, setStartDate] = useState<Date>(() => {
    const oneMonthAgo = new Date();
    oneMonthAgo.setMonth(oneMonthAgo.getMonth() - 1);
    return oneMonthAgo;
  });

  const [endDate, setEndDate] = useState<Date>(new Date());
  const [selectedOrders, setSelectedOrders] = useState<string[]>([]);


  /// I add now 
  const [filterStatus, setFilterLStatus] = useState<string>("period");
  const [realRevenue, setRealRevenue] = useState<number>(0);
  const [totalRefunds, setTotalRefunds] = useState<number>(0);
  const { sumShippingPriceData } = sumShippingPrice(startDate, endDate);
  const [basketComparisonData, setBasketComparisonData] = useState<ChartData | null>(null);
  const { grossRevenueBySourceData, isLoading: isGrossRevenueBySourceLoading } = useGrossRevenueBySource(startDate, endDate, selectedOrders);
  const [selectedShipping, setSelectedShipping] = useState<string[]>([]);

  const { enqueueSnackbar } = useSnackbar();



  const [OrderStats, setOrderStats] = useState<{
    categories?: string[];
    series: {
      type: string;
      data: { name: string; data: number[] }[];
    }[];
  } | null>(null);
  const maxChartX = useMemo(() => {
    const allItem = [
      ...(OrderStats?.series[0].data?.map((d) => d.data)?.[0] || []),
      ...(OrderStats?.series[1].data?.map((d) => d.data)?.[0] || []),
      ...(OrderStats?.series[2].data?.map((d) => d.data)?.[0] || []),
    ];

    return Math.max(
      ...allItem
    )
  }, [OrderStats]);



  const statsFiltersProps = {
    startDate,
    endDate,
    onChangeStartDate: (date: Date) => {
      setStartDate(date);
    },
    onChangeEndDate: (date: Date) => {
      setEndDate(date);
    },
    selectedOrders,
    setSelectedOrders,
    onChangeFilterStatus: (filterStatus: string) => {
      setFilterLStatus(filterStatus);
    },
    filterStatus,
    setSelectedShipping,
    selectedShipping

  };



  useEffect(() => {
    const fetchRealRevenueData = async () => {
      try {
        const data = await fetchRealRevenue(startDate, endDate, selectedOrders);
        console.log("check :", data);
        setRealRevenue(data);
      } catch (error) {
        console.error("Erreur lors de la récupération du chiffre d'affaires réel :", error);
      }
    };

    fetchRealRevenueData();

  }, [startDate, endDate, selectedOrders]);

  useEffect(() => {
    const fetchBasketComparisonData = async () => {
      try {
        const data = await fetchBasketComparisonChartDataGrossRevenue(startDate, endDate, selectedOrders);
        setBasketComparisonData(data);
      } catch (error) {
        console.error("Erreur lors de la récupération des données du graphique de comparaison du panier :", error);
      }
    };

    fetchBasketComparisonData();
  }, [startDate, endDate, selectedOrders]);




  useEffect(() => {
    fetchRealRefundRevenue(startDate, endDate, selectedOrders, filterStatus, selectedShipping).then((data) => {
      setTotalRefunds(data);
    }).catch(() => {
      enqueueSnackbar("error loading Total Refunds");
    });

    fetchOrdersStatsData(startDate, endDate).then((data) => {
      setOrderStats(data);
    }).catch(() => {
      enqueueSnackbar("error loading Refunds Stats");
    });

  }, [startDate, endDate, selectedOrders, filterStatus, selectedShipping]);

  return (
    <Container
      sx={{ gap: 3, display: "flex", flexDirection: "column" }}
      maxWidth={settings.themeStretch ? false : "lg"}
    >
      <CustomBreadcrumbs
        heading="ADMIN"
        links={[
          {
            name: "Tableau de bord",
            href: paths.dashboard.root,
          },
          {
            name: "Acceuil",
            href: paths.dashboard.admin.root,
          },
          {
            name: "Statistiques",
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <AdminFilters {...statsFiltersProps} />

      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Montant ventes nettes"
            total={realRevenue}
            color={theme.palette.error.light}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Montant remboursements"
            total={totalRefunds}
            color={theme.palette.info.dark}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Montant frais d’exp"
            total={sumShippingPriceData ?? 0}
            color={theme.palette.error.light}
          />
        </Grid>

      </Grid>

      <Grid container spacing={1}>
        <Grid item xs={4} md={4} lg={4}>
          {grossRevenueBySourceData ? (
            <AnalyticsSalesSource
              title="Source vente"
              chart={grossRevenueBySourceData}
            />
          ) : (
            <div>Chargement des données...</div>
          )}
        </Grid>

        <Grid item xs={8} md={6} lg={8}>

          <OrderCommandChart
            maxChartX={maxChartX}
            title="Historique des commandes"
            chart={{
              labels: OrderStats?.categories || [],
              series: [
                {
                  name: "Période précédente",
                  type: "line",
                  fill: "solid",
                  data: OrderStats?.series[0].data?.map((d) => d.data)?.[0] || [0, 0, 0, 0, 0, 0, 0, 0],
                },
                {
                  name: "Année précédente",
                  type: "line",
                  fill: "solid",
                  data: OrderStats?.series[1].data?.map((d) => d.data)?.[0] || [0, 0, 0, 0, 0, 0, 0, 0],
                },
                {
                  name: "Mois en cours",
                  type: "line",
                  fill: "solid",
                  data: OrderStats?.series[2].data?.map((d) => d.data)?.[0] || [0, 0, 0, 0, 0, 0, 0, 0],
                },
              ],
            }}
          />

        </Grid>

      </Grid>

      <Grid item xs={8} md={6} lg={8}>


        {basketComparisonData ? (
          <BasketAmountChartChiffre
            title="Ventes attendues Vs réalisées"
            chart={basketComparisonData}
          />
        ) : (
          <div>Chargement des données...</div>
        )}

      </Grid>
    </Container>
  );
}
