"use client";
import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Grid } from "@mui/material";
import { useEffect, useState } from "react";
import OrderFilters from "./statistics-filters-Chiffre";
import AppWidgetSummary from "./statistics-widget-summary";
import { useTheme } from "@mui/material/styles";
import {useAverageRevenue, useGrossRevenue } from "@/shared/api/userStatistics";
import { ChartData, fetchRealRefundRevenue, fetchRealRevenue, getTheoreticalRevenue } from "@/shared/api/saleSessionStatistics";
import { fetchBasketComparisonChartDataGrossRevenue, sumShippingPrice } from "@/shared/api/chiffreLiveStatistics";
import { enqueueSnackbar } from "@/shared/components/snackbar";
import BasketAmountChartChiffre from "./EcartAmount-Chiffre-chart";


export default function AllChiffreStatisticsView() {
  const settings = useSettingsContext();
  const theme = useTheme();

  const [startDate, setStartDate] = useState<Date>(() => {
    const oneMonthAgo = new Date();
    oneMonthAgo.setMonth(oneMonthAgo.getMonth() - 1);
    return oneMonthAgo;
  });
  const [endDate, setEndDate] = useState<Date>(new Date());
  const [selectedOrders, setSelectedOrders] = useState<string[]>([]);
  const [theoreticalRevenue, setTheoreticalRevenue] = useState<number>(0);
  const [realRevenue, setRealRevenue] = useState<number>(0);
  const { grossRevenue, isLoading: isGrossRevenueLoading } = useGrossRevenue(startDate, endDate);
  const [conversionRate, setConversionRate] = useState<number>(0);
  const [basketComparisonData, setBasketComparisonData] = useState<ChartData | null>(null);
  const { sumShippingPriceData } = sumShippingPrice(startDate, endDate);
  const [totalRefunds, setTotalRefunds] = useState<number>(0);
  const [filterStatus, setFilterLStatus] = useState<string>("period");
  const [selectedShipping, setSelectedShipping] = useState<string[]>([]);






  const statsFiltersProps = {
    startDate,
    endDate,
    onChangeStartDate: (date: Date) => {
      setStartDate(date);
    },
    onChangeEndDate: (date: Date) => {
      setEndDate(date);
    },
    selectedOrders,
    setSelectedOrders,
    onChangeFilterStatus: (filterStatus: string) => {
      setFilterLStatus(filterStatus);
    },
    filterStatus,
    setSelectedShipping,
    selectedShipping
  
  };

  useEffect(() => {
    const fetchBasketComparisonData = async () => {
      try {
        const data = await fetchBasketComparisonChartDataGrossRevenue(startDate, endDate, selectedOrders);
        setBasketComparisonData(data);
      } catch (error) {
        console.error("Erreur lors de la récupération des données du graphique de comparaison du panier :", error);
      }
    };

    fetchBasketComparisonData();
  }, [startDate, endDate, selectedOrders]);

  useEffect(() => {
    const fetchTheoreticalRevenue = async () => {
      try {
        const data = await getTheoreticalRevenue({
          sources: selectedOrders,
          startDate: startDate.toISOString(),
          endDate: endDate.toISOString(),
        });
        setTheoreticalRevenue(data);
      } catch (error) {
        console.error("Erreur lors de la récupération du chiffre d'affaires théorique :", error);
      }
    };

    const fetchRealRevenueData = async () => {
      try {
        const data = await fetchRealRevenue(startDate, endDate, selectedOrders);
        console.log("check :", data);
        setRealRevenue(data);
      } catch (error) {
        console.error("Erreur lors de la récupération du chiffre d'affaires réel :", error);
      }
    };
    fetchTheoreticalRevenue();
    fetchRealRevenueData();
  }, [startDate, endDate, selectedOrders]);

  useEffect(() => {
    if (theoreticalRevenue !== 0) {
      const rate = (grossRevenue! / theoreticalRevenue) * 100;
      setConversionRate(rate);
    } else {
      setConversionRate(0);
    }
  }, [grossRevenue, theoreticalRevenue]);

   useEffect(() => {
      fetchRealRefundRevenue(startDate, endDate, selectedOrders, filterStatus,selectedShipping).then((data) => {
        setTotalRefunds(data);
      }).catch(() => {
        enqueueSnackbar("error loading Total Refunds");
      });
  
    }, [startDate, endDate, selectedOrders, filterStatus,selectedShipping]);


  return (
    <Container
      sx={{ gap: 3, display: "flex", flexDirection: "column" }}
      maxWidth={settings.themeStretch ? false : "lg"}
    >
      <CustomBreadcrumbs
        heading="Chiffre d’affaires"
        links={[
          {
            name: "Tableau de bord",
            href: paths.dashboard.root,
          },
          {
            name: "Chiffre d’affaires",
            href: paths.dashboard.admin.userStatistics,
          },
          {
            name: "Statistiques",
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <OrderFilters {...statsFiltersProps} />

      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Montant ventes brutes"
            total={isGrossRevenueLoading ? 0 : (grossRevenue ?? 0)}
            color={theme.palette.error.light}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaires théorique"
            total={theoreticalRevenue}
            color={theme.palette.primary.main}

          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Taux de transformation"
            total={conversionRate}
            color={theme.palette.error.light}
            showPercentage={true}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Montant Remboursements"
            total={totalRefunds ?? 0}
            color={theme.palette.error.light}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Montant Frais d’exp"
            total={sumShippingPriceData ?? 0}
            color={theme.palette.error.light}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaires réel"

            total={realRevenue}
            color={theme.palette.info.dark}

            showEuroSymbol={true}
          />
        </Grid>
      </Grid>


      <Grid item xs={8} md={6} lg={8}>


        {basketComparisonData ? (
          <BasketAmountChartChiffre
            title="Ventes attendues Vs réalisées"
            chart={basketComparisonData}
          />
        ) : (
          <div>Chargement des données...</div>
        )}

      </Grid>


    </Container>
  );
}
