"use client";
import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Grid } from "@mui/material";
import {  useState } from "react";
import OrderFilters from "./statistics-filters-user";
import AppWidgetSummary from "./statistics-widget-summary";
import { useTheme } from "@mui/material/styles";
import AnalyticsActiveClient from "./Analytics-Active-Client";
import { useActiveClients, useActiveClientsCompare, useAverageArticlesPerActiveClient, useAverageRevenue, useGrossRevenue, useTotalArticlesSold, useUsersCount, useUsersCountByTag } from "@/shared/api/userStatistics"; 


export default function AllUsersStatisticsView() {
  const settings = useSettingsContext();
  const theme = useTheme();

  const [startDate, setStartDate] = useState<Date>(() => {
    const oneMonthAgo = new Date();
    oneMonthAgo.setMonth(oneMonthAgo.getMonth() - 1);
    return oneMonthAgo;
  });
  const [endDate, setEndDate] = useState<Date>(new Date());
  const [selectedOrders, setSelectedOrders] = useState<string[]>([]);

  const { usersCount, isLoading: isUsersCountLoading } = useUsersCount(startDate, endDate, selectedOrders);
  const { usersCountByTag, isLoading: isUsersCountByTagLoading } = useUsersCountByTag(startDate, endDate);


  const { grossRevenue, isLoading: isGrossRevenueLoading } = useGrossRevenue(startDate, endDate);
  const { activeClients, isLoading: isActiveClientsLoading } = useActiveClients(startDate, endDate);
  const { averageRevenue, isLoading: isAverageRevenueLoading } = useAverageRevenue(startDate, endDate);
  const { totalArticlesSold, isLoading: isTotalArticlesSoldLoading } = useTotalArticlesSold(startDate, endDate);
  const { averageArticlesPerActiveClient, isLoading: isAverageArticlesPerActiveClientLoading } = useAverageArticlesPerActiveClient(startDate, endDate);
  const { activeClientsCompare, isLoading: isActiveClientsCompareLoading } = useActiveClientsCompare(startDate, endDate);



  const statsFiltersProps = {
    startDate,
    endDate,
    onChangeStartDate: (date: Date) => {
      setStartDate(date);
    },
    onChangeEndDate: (date: Date) => {
      setEndDate(date);
    },
    selectedOrders,
    setSelectedOrders,
  };



  return (
    <Container
      sx={{ gap: 3, display: "flex", flexDirection: "column" }}
      maxWidth={settings.themeStretch ? false : "lg"}
    >
      <CustomBreadcrumbs
        heading="Statistique utilisateur"
        links={[
          {
            name: "Tableau de bord",
            href: paths.dashboard.root,
          },
          {
            name: "utilisateur",
            href: paths.dashboard.admin.userStatistics,
          },
          {
            name: "Statistiques",
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <OrderFilters {...statsFiltersProps} />

      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
        <AppWidgetSummary
            title="Total Nombre de comptes créés"
            total={isUsersCountLoading ? 0 : (usersCount ?? 0)}
            color={theme.palette.error.light}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
        <AppWidgetSummary
            title="Nombre de comptes créés «Pub FB»"
            total={isUsersCountByTagLoading ? 0 : (usersCountByTag ?? 0)}
            color={theme.palette.info.dark}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Source de client"
            total={487}
            color={theme.palette.error.light}
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
        <AppWidgetSummary
            title="CA panier moyen"
            total={isAverageRevenueLoading ? 0 : (averageRevenue ?? 0)}
            color={theme.palette.error.light}
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Nombre d’articles moyen"
            total={isAverageArticlesPerActiveClientLoading  ? 0 : (averageArticlesPerActiveClient ?? 0)}
            color={theme.palette.error.light}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Nombre de clients actifs"
            total={isActiveClientsLoading ? 0 : (activeClients ?? 0)}
            color={theme.palette.info.dark}
          />
        </Grid>
      </Grid>


      <Grid item xs={8} md={6} lg={8}>
        

      {isActiveClientsCompareLoading || !activeClientsCompare ? (
          <div>Chargement en cours...</div>
        ) : (
          <AnalyticsActiveClient
            title="Nombre de clients actifs"
            chart={{
              labels: activeClientsCompare.labels,
              series: activeClientsCompare.series,
            
            }}
          />
        )}
  
      </Grid>


    </Container>
  );
}
