"use client";
import isEqual from "lodash/isEqual";
import { useState, useCallback, useMemo, useEffect } from "react";

import Tab from "@mui/material/Tab";
import Tabs from "@mui/material/Tabs";
import Card from "@mui/material/Card";
import Table from "@mui/material/Table";
import { alpha } from "@mui/material/styles";
import Container from "@mui/material/Container";
import TableBody from "@mui/material/TableBody";
import TableContainer from "@mui/material/TableContainer";

import { paths } from "@/routes/paths";

import { useBoolean } from "@/hooks/use-boolean";

import Label from "../../../components/label";
import Scrollbar from "@/components/scrollbar";
import { useSnackbar } from "@/components/snackbar";
import { useSettingsContext } from "@/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import {
  useTable,
  emptyRows,
  TableNoData,
  getComparator,
  TableEmptyRows,
  TableHeadCustom,
  TableSelectedAction,
  TablePaginationCustom,
} from "@/shared/components/table";

import {
  ILiveItem,
  LiveTyple,
  SalesSessionTableFilters,
  SalesSessionTableFilterValue,
} from "@/shared/types/saleSession";

import SalesSessionTableRow from "./SalesSession-table-row";
import SalesSessionTableToolbar from "./SalesSession-table-toolbar";
import SalesSessionTableFiltersResult from "./SalesSession-table-filters-result";

import {
  restoreSaleSession,
  useSearchDeletedSaleSession,
  useDeletedSaleSessionCountsByType,
  useUpdateSaleSession,
} from "@/shared/api/saleSession";
import { getTokenInfo } from "@/utils/token";
import EditSalesSessionDialog from "./EditSalesSessionDialog";
import { CircularProgress, TableCell, TableRow } from "@mui/material";
import { Grid } from "lucide-react";
// ----------------------------------------------------------------------

const Type_OPTIONS = [{ value: "", label: "Tous" }, ...LiveTyple];

const TABLE_HEAD = [
  { id: "id", label: "id", width: 50 },
  { id: "name", label: "Live", width: 60 },
  { id: "startedDate", label: "Date création ", width: 100 },
  { id: "lastModification", label: "Dernière mise a jour", width: 100 },
  { id: "orderProductsNumber", label: "produits Vendu", width: 40 },
  { id: "clientsNumber", label: "Nombre Client", width: 40 },
  { id: "totalSales", label: "Total Vente", width: 40 },
  { id: "expirationDate", label: "Date d'expiration", width: 80 },
  { id: "description", label: "Description", width: 100 },
  { id: "Type", label: "Type Live", width: 80 },
  { id: "", label: "Action", width: 20 },
];

const defaultFilters: SalesSessionTableFilters = {
  name: "",
  type: "",
  startDate: null,
  endDate: null
};

interface FormErrors {
  name?: string;
  startedDate?: string;
  expirationDate?: string;
  type?: string;
  live?: string;
}

// ----------------------------------------------------------------------

export default function AllSalesSessionDeletedView() {
  const table = useTable();
  const { enqueueSnackbar } = useSnackbar();
  const [formData, setFormData] = useState<ILiveItem>({} as ILiveItem);
  const [openEditDialog, setOpenEditDialog] = useState(false);
  const [selectedRow, setSelectedRow] = useState<ILiveItem | null>(null);
  const { updateSaleSession } = useUpdateSaleSession();
  const [typeCount, setTypeCount] = useState<{ [key: string]: number }>({
    Live: 0,
    Demande_MP: 0,
    Article_a_controle: 0,
    Autre: 0,
  });
  const settings = useSettingsContext();
  const isConfirm = useBoolean();
  const [tableData, setTableData] = useState<ILiveItem[]>([]);
  const [filters, setFilters] = useState(defaultFilters);
  const { saleSessionTypeCount, saleSessionTypeCountError } = useDeletedSaleSessionCountsByType(filters);

  const {
    saleSessions,
    totalSaleSessions,
    totalPages,
    pageNumber,
    pageSize,
    loading,
    revalidatePage,
  } = useSearchDeletedSaleSession({
    name: filters.name,
    type: filters.type,
    startDate: filters.startDate,
    endDate: filters.endDate,
    page: table.page,
    size: table.rowsPerPage,
    sortBy: table.orderBy,
    sortDir: table.order,
  });

  useEffect(() => {
    if (saleSessions && saleSessions.length > 0) {
      setTableData(saleSessions);
    }
  }, [saleSessions, table.page, table.rowsPerPage]);


    useEffect(() => {
      if (saleSessionTypeCountError) {
        console.error("Error fetching status counts:", saleSessionTypeCountError);
        return;
      }
      if (Array.isArray(saleSessionTypeCount)) {
        const statusObj = saleSessionTypeCount.reduce<{ [key: string]: number }>(
          (acc, [status, count]) => {
            acc[status] = count;
            return acc;
          },
          {}
        );
  
        setTypeCount(statusObj);
      } else {
        console.error(
          "Expected counts to be an array, but received:",
          saleSessionTypeCount
        );
      }
    }, [filters, saleSessionTypeCount, saleSessionTypeCountError]);


  const dataInPage = tableData.slice(
    table.page * table.rowsPerPage,
    table.page * table.rowsPerPage + table.rowsPerPage
  );

  useEffect(() => {
    if (
      filters.name ||
      filters.type ||
      filters.startDate ||
      filters.endDate
    ) {
      revalidatePage();
    }
  }, [filters, revalidatePage]);

  const denseHeight = table.dense ? 56 : 56 + 20;
 const canReset = !isEqual(defaultFilters, filters);

  const notFound = totalSaleSessions === 0 && canReset;

  const handleFilters = useCallback(
    (title: string, value: SalesSessionTableFilterValue) => {
      table.onResetPage();
      setFilters((prevState) => ({
        ...prevState,
        [title]: value,
      }));
    },
    [table]
  );
  const handleResetFilters = useCallback(() => {
    setFilters(defaultFilters);
  }, []);


  
  const handleDeleteRow = useCallback(
    (id: string) => {
      const deleteRow = tableData.filter((row) => row.id !== id);
      setTableData(deleteRow);
      table.onUpdatePageDeleteRow(dataInPage.length);
    },
    [dataInPage.length, enqueueSnackbar, table, tableData]
  );

  const handleRestore = useCallback(
    async (id: string) => {
      try {
        await restoreSaleSession(Number(id));
        enqueueSnackbar("Session restaurée avec succès.", { variant: "success" });
        handleDeleteRow(id)
        revalidatePage();
      } catch (error) {
        console.error("Failed to restore sale session", error);
        enqueueSnackbar("Erreur lors de la restauration de la session.", {
          variant: "error",
        });
      }
    },
    [enqueueSnackbar, revalidatePage]
  );
 

  useEffect(() => {
    const { startedDate, expirationDate } = getCurrentDateAndExpiration();
    setFormData({
      ...formData,
      startedDate,
      expirationDate,
    });
  
  }, []);



  const getCurrentDateAndExpiration = () => {
    const now = new Date();

    const expirationDate = new Date(now);

    expirationDate.setDate(expirationDate.getDate() + 5);
    expirationDate.setHours(0, 0, 0, 0);

    return {
      startedDate: now,
      expirationDate,
    };
  };





  const getTypeLabel = (value: string) => {
    const typeOption = LiveTyple.find((option) => option.value === value);
    return typeOption ? typeOption.label : value;
  };

  const handleModifySaleSession = async (updatedData: ILiveItem) => {
    try {
      await updateSaleSession(updatedData.id, {
        name: updatedData.name,
        description: updatedData.description,
      });

      enqueueSnackbar("Session de vente modifiée avec succès", {
        variant: "success",
      });

      // Optionnel : Vous pouvez également mettre à jour localement si nécessaire
      setTableData((prevData) =>
        prevData.map((session) =>
          session.id === updatedData.id ? updatedData : session
        )
      );
    } catch (error) {
      enqueueSnackbar("Erreur lors de la modification de la session de vente", {
        variant: "error",
      });
    }
  };

  const token = localStorage.getItem("token");
  const storedUserInfo = token ? getTokenInfo(token) : null;
  const isAdmin =
    storedUserInfo?.realm_access?.roles?.includes("ADMIN") ?? false;

  return (
    <>
      <Container maxWidth={settings.themeStretch ? false : "xl"}>
        <CustomBreadcrumbs
          heading="Liste session de vente Supprimée"
          links={[
            { name: "Tableau de bord", href: paths.dashboard.root },
            { name: "Vente", href: paths.dashboard.admin.live.saleSession },
            { name: "Listes Supprimées" },
          ]}
          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />

        <EditSalesSessionDialog
          open={openEditDialog}
          onClose={() => setOpenEditDialog(false)}
          initialData={selectedRow}
          onModify={handleModifySaleSession}
        />

        <Card>
        {loading ? (
            <Grid
              style={{
                display: "flex",
                justifyContent: "center",
                alignItems: "center",
              }}
            >
              <CircularProgress />
            </Grid>
          ) : (
            <Tabs
              value={filters.type}
              onChange={(event, newValue) => handleFilters("type", newValue)}
              sx={{
                px: 2.5,
                boxShadow: (theme) =>
                  `inset 0 -2px 0 0 ${alpha(theme.palette.grey[500], 0.08)}`,
              }}
            >
              {Type_OPTIONS.map((tab) => {
                const count =
                  typeCount[tab.value as keyof typeof typeCount] || 0;
                return (
                  <Tab
                    key={tab.value}
                    iconPosition="end"
                    value={tab.value}
                    label={tab.label}
                    icon={
                      <Label
                        variant={
                          ((tab.value === "" ||
                            tab.value === filters.type) &&
                            "filled") ||
                          "soft"
                        }
                        color={
                          (tab.value === "Live" && "success") ||
                          (tab.value === "Demande_MP" && "warning") ||
                          (tab.value === "Article_a_controle" && "error") ||
                          (tab.value === "Autre" && "default") ||
                          "default"
                        }
                      >
                        {tab.value === ""
                          ? Object.values(typeCount).reduce(
                              (acc, count) => acc + Number(count),
                              0
                            )
                          : count}
                      </Label>
                    }
                  />
                );
              })}
            </Tabs>
          )}


          <SalesSessionTableToolbar
            filters={{
              ...filters,
              type: getTypeLabel(filters.type),
            }}
            onFilters={handleFilters}
          />

         {canReset && (
                    <SalesSessionTableFiltersResult
                      filters={{
                        ...filters,
                        type: getTypeLabel(filters.type),
                      }}
                      onFilters={handleFilters}
                      //
                      onResetFilters={handleResetFilters}
                      //
                      results={totalSaleSessions}
                      sx={{ p: 2.5, pt: 0 }}
                    />
                  )}

          <TableContainer sx={{ position: "relative", overflow: "unset" }}>
            <TableSelectedAction
              dense={table.dense}
              numSelected={table.selected.length}
              rowCount={totalSaleSessions}
              onSelectAllRows={(checked) =>
                table.onSelectAllRows(
                  checked,
                  tableData.map((row) => row.id)
                )
              }
              onClickTrash={() => {
                isConfirm.onTrue();
              }}
            />

            <Scrollbar>
              <Table
                size={table.dense ? "small" : "medium"}
                sx={{ minWidth: 960 }}
              >
              <TableHeadCustom
                  order={table.order}
                  orderBy={table.orderBy}
                  headLabel={TABLE_HEAD}
                  rowCount={totalSaleSessions}
                  numSelected={table.selected.length}
                  onSort={table.onSort}
                  onSelectAllRows={
                    isAdmin
                      ? (checked) =>
                        table.onSelectAllRows(
                          checked,
                          tableData.map((row) => row.id)
                        )
                      : undefined
                  }
                />
                <TableBody>
                  {loading ? (
                    <TableRow>
                      <TableCell
                        colSpan={TABLE_HEAD.length}
                        style={{ textAlign: "center", padding: "20px" }}
                      >
                        <CircularProgress />
                      </TableCell>
                    </TableRow>
                  ) : (
                    <>
                      {notFound ? (
                        <TableNoData notFound={notFound} />
                      ) : (
                        tableData.map((row) => (
                          <SalesSessionTableRow
                          key={row.id}
                          row={row}
                          selected={table.selected.includes(row.id)}
                          onSelectRow={() => table.onSelectRow(row.id)}
                          onRestoreRow={() => handleRestore(row.id)}
                          isAdmin={isAdmin}
                        />
                        ))
                      )}

                      <TableEmptyRows
                        height={denseHeight}
                        emptyRows={emptyRows(
                          table.page,
                          table.rowsPerPage,
                          totalSaleSessions
                        )}
                      />
                    </>
                  )}
                </TableBody>
              </Table>
            </Scrollbar>
          </TableContainer>

          <TablePaginationCustom
            count={totalSaleSessions}
            page={pageNumber}
            rowsPerPage={pageSize}
            onPageChange={table.onChangePage}
            onRowsPerPageChange={table.onChangeRowsPerPage}
            //
            dense={table.dense}
            onChangeDense={table.onChangeDense}
          />
        </Card>
      </Container>
    </>
  );
}


