import TableRow from "@mui/material/TableRow";
import Checkbox from "@mui/material/Checkbox";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import ListItemText from "@mui/material/ListItemText";
import { Tooltip } from "@mui/material";
import { useBoolean } from "@/hooks/use-boolean";
import Label from "../../../components/label";
import { ConfirmDialog } from "../../../components/custom-dialog";
import { usePopover } from "../../../components/custom-popover";
import { _livesInf } from "@/shared/_mock/_cartLive";
import { ILiveItem, LiveTyple } from "@/shared/types/saleSession";
import { fDate, fTime } from "@/utils/format-time";
import ShoppingCartIcon from "@mui/icons-material/ShoppingCart";
import { useCallback, useState } from "react";
import { useRouter } from "@/hooks";
import { paths } from "@/routes/paths";
import { restoreSaleSession } from "@/shared/api/saleSession";
import LoadingButton from "@mui/lab/LoadingButton";
import RestoreFromTrashIcon from "@mui/icons-material/RestoreFromTrash";

type Props = {
  selected: boolean;
  //onEditRow: VoidFunction;
  row: ILiveItem;
  onSelectRow: VoidFunction;
  isAdmin: boolean;
  onRestoreRow: VoidFunction;
};

export default function SalesSessionTableRow({
  row,
  selected,
  onSelectRow,
  onRestoreRow,
  isAdmin,
}: Props) {
  const {
    id,
    name,
    startedDate,
    lastModification,
    totalSales,
    clientsNumber,
    paidProductsNumber,
    orderProductsNumber,
    expirationDate,
    type,
    description,
  } = row;

  const router = useRouter();

  const handelPanier = useCallback(() => {
    const nameUrl = name.replace(/ /g, "+");
    router.push(paths.dashboard.admin.live.panier(id, nameUrl));
  }, [router, id, name]);

  const confirmRestore = useBoolean();

  const getTypeLabel = (value: string) => {
    const typeOption = LiveTyple.find((option) => option.value === value);
    return typeOption ? typeOption.label : value;
  };

  return (
    <>
      <TableRow hover selected={selected} onClick={handelPanier}>
        {isAdmin && (
          <TableCell padding="checkbox">
            <Checkbox
              checked={selected}
              onClick={(e) => {
                e.stopPropagation();
                onSelectRow();
              }}
            />
          </TableCell>
        )}

        <TableCell sx={{ whiteSpace: "nowrap" }}>{id}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{name}</TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(startedDate)}
            secondary={fTime(startedDate)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(lastModification)}
            secondary={fTime(lastModification)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>
          {orderProductsNumber}
        </TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{clientsNumber}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{totalSales}</TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(expirationDate)}
            secondary={fTime(expirationDate)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{description}</TableCell>
        <TableCell>
          <Label
            variant="soft"
            color={
              (type === "Live" && "success") ||
              (type === "Demande_MP" && "warning") ||
              (type === "Article_a_controle" && "error") ||
              (type === "Autre" && "default") ||
              "default"
            }
          >
            {getTypeLabel(type)}
          </Label>
        </TableCell>

        <TableCell
          align="right"
          sx={{ px: 1, whiteSpace: "nowrap" }}
          onClick={(e) => e.stopPropagation()}
        >
          <Tooltip title="Panier">
            <IconButton sx={{ color: "#00e676" }} onClick={handelPanier}>
              <ShoppingCartIcon />
            </IconButton>
          </Tooltip>
          <Tooltip title="Restaurer">
            <IconButton
              sx={{ color: "#ff9800" }}
              onClick={() => {
                confirmRestore.onTrue();
              }}
            >
              <RestoreFromTrashIcon />
            </IconButton>
          </Tooltip>
        </TableCell>
      </TableRow>

      <ConfirmDialog
        open={confirmRestore.value}
        onClose={confirmRestore.onFalse}
        title="Confirmer la restauration"
        content="Êtes-vous sûr de vouloir restaurer cette session de vente ?"
        action={
          <LoadingButton
            onClick={() => {
              confirmRestore.onFalse();
              onRestoreRow()
            }}
            variant="contained"
            color="primary"
          >
            Restaurer
          </LoadingButton>
        }
      />
    </>
  );
}
