"use client"

import { generateStatisticsForLives } from "@/shared/_mock";
import Chart, { useChart } from '@/components/chart';
import Container from '@mui/material/Container';
import { paths } from '@/routes/paths';
import { useSettingsContext } from '@/shared/components/settings';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs';
import { Card, Grid } from "@mui/material";
import AnalyticsWidgetSummary from "./statistics-widget-summary";
import { fTime } from '@/utils/format-time';
import LiveFilters from './statistics-filters'
import { useEffect, useMemo, useState } from "react";
import { useGetLivesStatistic, getLiveStatisticsForAllLives } from "@/shared/api/live";
import { AllLivesAnalytics } from "@/shared/types/live";




export default function AllLivesStatistics() {
    const settings = useSettingsContext();
    const [startDate, setStartDate] = useState<Date>(new Date('2023-03-21'))
    const [endDate, setEndDate] = useState<Date>(new Date('2023-03-23'))
    const [selectedLives, setSelectedLives] = useState<string[]>([]);
    const [allLiveStats, setAllLiveStats] = useState<AllLivesAnalytics | null>(null);
    useEffect(() => {
        getLiveStatisticsForAllLives().then((data) => {
            setAllLiveStats(data);
        })
    }, [])


    const { statsData: { stats, total } } = useGetLivesStatistic(startDate, endDate, selectedLives);
    const series = useMemo(() => [{
        name: 'Specatateurs',
        data: stats.map((stat) => ({ x: stat.startDate, y: stat.viewers })),
    }, {
        name: 'Messages',
        data: stats.map((stat) => ({ x: stat.startDate, y: stat.messages })),
    }, {
        name: 'Ajouts au panier',
        data: stats.map((stat) => ({ x: stat.startDate, y: stat.cartAdditions })),
    }, {
        name: 'Durée de visionnage',
        data: stats.map((stat) => ({ x: stat.startDate, y: stat.watchingHours })),
    }, {
        name: 'Revenu',
        data: stats.map((stat) => ({ x: stat.startDate, y: stat.revenu })),
    }], [startDate, endDate, selectedLives]);

    const chartOptions = useChart({
        xaxis: {
            type: 'datetime',
        },
        yaxis: {
            title: {
                text: 'Count',
            },
            labels: {
                formatter: (value) => {
                    return Math.floor(value).toString()
                }
            }
        },
        tooltip: {
            x: {
                format: 'dd/MM/yy',
            },
        },

    });



    const statsFiltersProps = {
        startDate,
        endDate,
        onChangeStartDate: (startDate: Date) => { setStartDate(startDate) },
        onChangeEndDate: (endDate: Date) => { setEndDate(endDate) },
        selectedLives,
        setSelectedLives
    }

    return (
        <Container sx={{ gap: 3, display: 'flex', flexDirection: 'column' }} maxWidth={settings.themeStretch ? false : 'lg'}>
            <CustomBreadcrumbs
                heading="Statistiques des lives"
                rollbackLink={paths.dashboard.admin.live.all_lives}
                links={[
                    {
                        name: 'Tableau de bord',
                        href: paths.dashboard.root,
                    },
                    {
                        name: 'Lives',
                        href: paths.dashboard.admin.live.all_lives,
                    },
                    {
                        name: 'Statistiques',
                    },
                ]}
                sx={{
                    mb: { xs: 3, md: 5 },
                }}
            />
            <Grid container spacing={3}>
                {
                    [
                        {
                            title: 'Spectateurs',
                            total: 2,
                            icon: <img alt="icon" src="/assets/icons/glass/ic_glass_users.png" />,
                        },
                        {
                            title: 'Messages',
                            total: 10,
                            icon: <img alt="icon" src="/assets/icons/glass/ic_glass_message.png" />,
                        }, {
                            title: 'Ajouts au panier',
                            total: 6,
                            icon: <img alt="icon" src="/assets/icons/glass/ic_glass_buy.png" />,
                        }, {
                            title: 'Durée de visionnage',
                            total: `${0.1} heures`,
                            icon: <img alt="icon" src="/assets/icons/glass/ic_glass_live.png" />,
                        }, {
                            title: 'Revenu',
                            total: `${100} €`,
                            icon: <img alt="icon" src="/assets/icons/glass/ic_glass_bag.png" />,
                        }, {
                            title: 'Nombre des lives',
                            total: 2,
                            icon: <img alt="icon" src="/assets/icons/glass/ic_glass_live.png" />,
                        }
                    ].map((widget, index) => (
                        <Grid item xs={12} sm={6} md={4} key={index}>
                            <AnalyticsWidgetSummary {...widget} />
                        </Grid>
                    ))
                }
            </Grid>
            <LiveFilters {...statsFiltersProps} />
            <Card sx={{ p: 4 }}>
                <Chart options={chartOptions} series={series} type="line" height={350} />
            </Card>
        </Container>)
        ;
};

