import React, { useState, useEffect } from 'react';
import { TextField } from '@mui/material';

interface CountdownProps {
    startDate: Date | undefined;
}

const Countdown: React.FC<CountdownProps> = ({ startDate }) => {
    const [timeLeft, setTimeLeft] = useState<string>('00:00:00');

    useEffect(() => {
        if (!startDate) return;

        const timer = setInterval(() => {
            const now = new Date();
            const difference = startDate.getTime() - now.getTime();

            if (difference > 0) {
                const hours = Math.floor(difference / (1000 * 60 * 60));
                const minutes = Math.floor((difference % (1000 * 60 * 60)) / (1000 * 60));
                const seconds = Math.floor((difference % (1000 * 60)) / 1000);

                const formattedTime = [hours, minutes, seconds]
                    .map(unit => unit.toString().padStart(2, '0'))
                    .join(':');

                setTimeLeft(formattedTime);
            } else {
                setTimeLeft('00:00:00');
                clearInterval(timer);
            }
        }, 1000);

        return () => clearInterval(timer);
    }, [startDate]);

    return (
        <TextField
            value={timeLeft}
            label="Début dans"
            size="small"
            variant="outlined"
            sx={{ maxWidth: 100 }}
            InputLabelProps={{ shrink: true }}
            inputProps={{ readOnly: true }}
        />
    );
};

export default Countdown;