"use client";

import React from 'react';
import { IconButton } from '@mui/material';
import Iconify from '@/components/iconify';
import { parse } from 'json2csv';
import { exportCommentsLive } from '@/shared/api/live';
import { useLiveData } from '@/contexts/live-details';


export default function CommentExport() {
    const liveData = useLiveData();


    const handleExportComments = async () => {
        const fields = ['senderName', 'content'];
        const opts = { fields };
        try {
          const allComments = await exportCommentsLive(liveData.id);
          const csv = parse(allComments, opts);
          const blob = new Blob([csv], { type: 'text/csv;charset=utf-8;' });
          const url = URL.createObjectURL(blob);
          const a = document.createElement('a');
          a.href = url;
          a.download = `commentaires-${liveData.startDate}.csv`;
          document.body.appendChild(a);
          a.click();
          a.remove();
        } catch (err) {
          console.error('Error converting JSON to CSV', err);
        }
      };

    return (


        <IconButton
            onClick={handleExportComments}
            sx={{ position: 'absolute', color: 'white', bgcolor: 'black', zIndex: 5, top: 10, right: 10 }}
        >
            <Iconify icon="solar:download-bold" />
        </IconButton>

    );
}
