import Iconify from "@/components/iconify";
import { useBoolean } from "@/hooks";
import { startLive } from "@/shared/api/live";
import { ConfirmDialog } from "@/shared/components/custom-dialog";
import { LiveStatus } from "@/shared/types/live";
import LoadingButton from "@mui/lab/LoadingButton";
import { Card, Grid } from "@mui/material";
import ReactPlayer from 'react-player';
import { useRef, useEffect } from 'react';
import { useLiveData } from "@/contexts/live-details";


export default function VideoPlayerSection() {
    const {id,status,videoLink,keysWork} = useLiveData();
    const liveUrl = status != LiveStatus.ONGOING ? videoLink : keysWork?.hlsServerAddress+':5443/live/streams/'+keysWork?.keyStream + '_adaptive.m3u8';
    const startConfirm = useBoolean();
    const playerRef = useRef<ReactPlayer>(null);

    const handleStart = async () => {
        try {
            await startLive(id);
            startConfirm.onFalse();
        } catch (error) {
            console.error(error);
        }
    };                            

    useEffect(() => {
        const interval = setInterval(() => {
            const pipButton = document.querySelector('button[aria-label="Picture-in-Picture"]');
            if (pipButton) {
                pipButton.textContent = 'Réduire';
                clearInterval(interval);
            }
        }, 1000);

        return () => clearInterval(interval);
    }, []);

    return (
        <Grid item lg={4} md={8} xs={12}>
            <Card sx={{ position: "relative", height: 720, zIndex: 0, p: 0, bgcolor: 'black', display: 'flex', alignItems: 'center', justifyContent: 'center' }}>
                {status != LiveStatus.COMING &&
                    <ReactPlayer
                        ref={playerRef}
                        playing={true}
                        controls={true}
                        muted={true}
                        pip={true}
                        width="100%"
                        height="100%"
                        url={liveUrl}
                    />
                }
                {status == LiveStatus.COMING &&
                    <Iconify
                        color='white'
                        sx={{ position: "absolute", margin: "auto", width: 100, height: 100, cursor: 'pointer' }}
                        onClick={startConfirm.onTrue}
                        icon="solar:play-bold"
                    />
                }
            </Card>
            <ConfirmDialog
                open={startConfirm.value}
                onClose={startConfirm.onFalse}
                title="démarrer"
                content="Voulez-vous démarrer ce live?"
                action={
                    <LoadingButton variant="contained" color="warning" onClick={handleStart}>
                        démarrer
                    </LoadingButton>
                }
            />
        </Grid>
    );
}
