import Button from '@mui/material/Button';
import { useBoolean } from '@/hooks/use-boolean';
import { CSSProperties, useState } from 'react';
import { ButtonProps } from '@mui/material/Button';
import { IMedia } from '@/shared/types/media';
import { Grid, Typography } from '@mui/material';
import IconButton from '@mui/material/IconButton';
import CloseIcon from '@mui/icons-material/Close';
import { useGetMedias } from '@/shared/api/media';
import NewMultiMediaModal from './Multi-image-popup-components/New-multi-media-modal';
import NewSingleMediaModal from './Single-image-popup-components/New-single-media-modal';

interface Props extends ButtonProps {
    multiple?: boolean;
    buttonStyle?: CSSProperties;
    nameBtn?: string;
    returnedSingleMedia?: IMedia[];
    setReturnedSingleMedia?: (medias: IMedia[]) => void;
    returnedMultiMedia?: IMedia[];
    setReturnedMultiMedia?: (medias: IMedia[]) => void;
}

export default function AddMediaButton({ multiple, buttonStyle, returnedSingleMedia, setReturnedSingleMedia, returnedMultiMedia, setReturnedMultiMedia, nameBtn = "Ajouter une image", ...buttonProps }: Props) {

    const OpenAddMedia = useBoolean();

    const [singleMediaList, setSingleMediaList] = useState<IMedia[]>([]);

    const [multiMediaList, setMultiMediaList] = useState<IMedia[]>([]);

    const { mediasData } = useGetMedias();

    const getStoredMedia = (key: string) => {
        const storedMedia = localStorage.getItem(key);
        if (storedMedia) {
            return JSON.parse(storedMedia);
        }
        return null;
    };

    const handleAddSingleImage = () => {
        const value = getStoredMedia('singleMediaID');
        const foundMedia = mediasData.find(media => media.id === value);
        if (foundMedia) {
            setSingleMediaList([]);
            setSingleMediaList([foundMedia]);
            setReturnedSingleMedia?.([foundMedia])
        }
        localStorage.removeItem('singleMediaID');
        OpenAddMedia.onFalse;
    };

    const handleDeleteSingleImage = () => {
        setSingleMediaList([]);
        setReturnedSingleMedia?.([]);
    };

    const handleAddMultiImage = () => {
        setSingleMediaList([]);
        const value = getStoredMedia('multiMediasIDs');
        if (value) {
            const foundMedias = value
                .map((id: string) => mediasData.find((media) => media.id === id))
                .filter((media: IMedia) => media !== undefined)
                .filter((media: IMedia) => !multiMediaList.some((existingMedia) => existingMedia.id === media?.id));

            const updatedMediaList = [...multiMediaList, ...foundMedias];
            setMultiMediaList(updatedMediaList);
            setReturnedMultiMedia?.(updatedMediaList);
        }
        localStorage.removeItem('multiMediasIDs');
        OpenAddMedia.onFalse();
    };

    const handleDeleteMultiImage = (id: string) => {
        const updatedMediaList = multiMediaList.filter(media => media.id !== id);
        setMultiMediaList(updatedMediaList);
        setReturnedMultiMedia?.(updatedMediaList);
    };

    const extractUrl = (url: string) => {
        const match = url.match(/Optional\[(.*)\]/);
        return match ? match[1] : url;
    };

    return (
        <>
            <Grid md={12} xs={12} width={'100%'}>
                <Button {...buttonProps} style={{ ...buttonStyle }} onClick={OpenAddMedia.onTrue}>{nameBtn}</Button>
            </Grid>
            {multiple ? (
                <NewMultiMediaModal
                    open={OpenAddMedia.value}
                    onClose={OpenAddMedia.onFalse}
                    onAddMedias={() => { handleAddMultiImage() }} />
            ) : (
                <NewSingleMediaModal
                    open={OpenAddMedia.value}
                    onClose={OpenAddMedia.onFalse}
                    onAddMedia={() => { OpenAddMedia.onFalse(); handleAddSingleImage(); }}
                />
            )}

            {singleMediaList.length > 0 && (
                <Grid md={12} xs={12} style={{ display: 'flex', flexWrap: 'wrap' }}>
                    <Typography
                        component="span"
                        style={{
                            fontSize: '15px',
                            color: 'text.secondary',
                            marginTop: 4,
                            width: '100%'
                        }}
                    >
                        {singleMediaList.length} Média sélectionné
                    </Typography>
                    {singleMediaList.map((media) => (
                        <Grid key={media.id} style={{ margin: '10px', position: 'relative' }}>
                            <img src={extractUrl(media.url)} alt={media.name} style={{ width: '100px', height: '100px', objectFit: 'contain' }} />
                            <IconButton onClick={() => handleDeleteSingleImage()} style={{ position: 'absolute', top: 0, right: 0 }}>
                                <CloseIcon />
                            </IconButton>
                        </Grid>
                    ))}
                </Grid>
            )}

            {multiMediaList.length > 0 && (
                <Grid md={12} xs={12} style={{ display: 'flex', flexWrap: 'wrap' }}>
                    <Typography
                        component="span"
                        style={{
                            fontSize: '15px',
                            color: 'text.secondary',
                            marginTop: 4,
                            width: '100%'
                        }}
                    >
                        {multiMediaList.length} Médias sélectionnés
                    </Typography>
                    {multiMediaList.map((media) => (
                        <Grid key={media.id} style={{ margin: '10px', position: 'relative' }}>
                            <img src={extractUrl(media.url)} alt={media.name} style={{ width: '100px', height: '100px', objectFit: 'contain' }} />
                            <IconButton onClick={() => handleDeleteMultiImage(media.id)} style={{ position: 'absolute', top: 0, right: 0 }}>
                                <CloseIcon />
                            </IconButton>
                        </Grid>
                    ))}
                </Grid>
            )}
        </>
    );
}