import { useCallback, useEffect, useState } from 'react';
import Box from '@mui/material/Box';
import { CardProps } from '@mui/material/Card';
import IconButton from '@mui/material/IconButton';
import Card from '@mui/material/Card';
import CardMedia from '@mui/material/CardMedia';
import Tooltip from '@mui/material/Tooltip';
import { CardActionArea } from '@mui/material';
import Iconify from '@/components/iconify';
import { IMedia } from '@/shared/types/media';


interface Props extends CardProps {
  file: IMedia;
  selected?: boolean;
  onSelect?: VoidFunction;
  onDelete: VoidFunction;
}

export default function MultiMediaItem({
  file,
  selected,
  onSelect,
  onDelete,
  sx,
  ...other
}: Props) {

  const handleItemClick = useCallback(() => {
    if (onSelect) {
      onSelect();
    }
  }, [onSelect]);

  const [imageUrl, setImageUrl] = useState('');

  useEffect(() => {
    const extractUrl = (url: string) => {
      const match = url.match(/Optional\[(.*)\]/);
      return match ? match[1] : url;
    };

    setImageUrl(extractUrl(file.url));
  }, [file])

  return (
    <>
      <Tooltip title={file.name}>
        <Box>
          <Card onClick={handleItemClick} sx={{ maxWidth: '100%', height: '100%', position: 'relative', border: selected ? '6px solid #228B22' : 'none' }}>
            <CardActionArea
              sx={{
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                width: '100%',
                height: '100%',
              }}
            >
              <CardMedia
                component="img"
                image={imageUrl}
                style={{
                  objectFit: 'contain',
                  objectPosition: 'center',
                  width: '100%',
                  height: '100%',
                }}
              />
              {selected && (
                <IconButton
                  sx={{
                    position: 'absolute',
                    top: '50%',
                    left: '50%',
                    transform: 'translate(-50%, -50%)',
                    backgroundColor: 'rgba(255, 255, 255, 0.5)',
                  }}
                >
                  <Iconify icon="eva:checkmark-circle-fill" sx={{ color: '#228B22' }} />
                </IconButton>
              )}
            </CardActionArea>
          </Card>
        </Box>
      </Tooltip>
    </>
  );
}
