import React, { useState, useCallback } from 'react';
import { Modal, Grid, Tabs, Tab, Box } from '@mui/material';
import SingleMediaUploadView from './Single-media-upload-view';
import SelectSingleMediaView from './Select-single-media-view';


type ModalProps = {
    open: boolean;
    onClose: () => void;
    onAddMedia: VoidFunction;
};

const NewSingleMediaModal: React.FC<ModalProps> = ({ open, onClose, onAddMedia }) => {

    const TABS = [
        {
            value: '1',
            label: 'Téléverser',
        },
        {
            value: '2',
            label: "Médiathèque",
        },
    ];

    const [currentTab, setCurrentTab] = useState<string>('2');

    const handleChangeTab = useCallback((event: React.SyntheticEvent, newValue: string) => {
        setCurrentTab(newValue);
    }, []);

    const handleChangeToMediaLibrary = useCallback((newTabValue: string) => {
        setCurrentTab(newTabValue);
    }, []);

    return (
        <Modal open={open} onClose={onClose}>
            <Box
                style={{
                    width: '70%',
                    maxWidth: '75%',
                    height: '95%',
                    maxHeight: '95%',
                    position: 'absolute',
                    top: '50%',
                    left: '50%',
                    transform: 'translate(-50%, -50%)',
                }}
            >
                <Grid
                    style={{
                        backgroundColor: 'white',
                        padding: '20px',
                        borderRadius: '15px',
                    }}
                >
                    <Grid>
                        <Tabs
                            value={currentTab}
                            onChange={handleChangeTab}
                            sx={{
                                mb: { xs: 3, md: 5 },
                            }}
                        >
                            {TABS.map((tab) => (
                                <Tab key={tab?.value} label={tab?.label} value={tab?.value} />
                            ))}
                        </Tabs>
                    </Grid>
                    <Grid container justifyContent="center" alignItems="center">
                        <Grid item xs={12}>
                            {currentTab === '1' ? (
                                    <SingleMediaUploadView onUploadChangeTab={() => handleChangeToMediaLibrary('2')} />
                            ) : (
                                currentTab === '2' && (
                                    <SelectSingleMediaView onAddMedia={()=> {onAddMedia()} }/>
                                )
                            )}
                        </Grid>
                    </Grid>
                </Grid>
            </Box>
        </Modal>
    );
};

export default NewSingleMediaModal;
