import { useState, useEffect } from 'react';
import Box from '@mui/material/Box';
import Tooltip from '@mui/material/Tooltip';
import { CardProps } from '@mui/material/Card';
import Card from '@mui/material/Card';
import CardMedia from '@mui/material/CardMedia';
import { CardActionArea } from '@mui/material';
import { useBoolean } from '@/hooks/use-boolean';
import { IMedia } from '@/shared/types/media';
import MediaDialogDetails from './New-single-media-confirm-dialog';

interface Props extends CardProps {
  file: IMedia;
  selected?: boolean;
  onSelect?: VoidFunction;
  onAddMedia: VoidFunction;
}

export default function SingleMediaItem({
  file,
  selected,
  onSelect,
  onAddMedia,
  sx,
  ...other
}: Props) {

  const details = useBoolean();
  const [imageUrl, setImageUrl] = useState('');

  useEffect(() => {
    const extractUrl = (url: string) => {
      const match = url.match(/Optional\[(.*)\]/);
      return match ? match[1] : url;
    };

    setImageUrl(extractUrl(file.url));
  }, [file])


  return (
    <>
      <Tooltip title={file.name}>
        <Box>
          <Card sx={{ maxWidth: '100%', height: '100%', position: 'relative' }}>
            <CardActionArea
              sx={{
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'center',
                width: '100%',
                height: '100%',
              }}
            >
              <CardMedia
                onClick={details.onTrue}
                component="img"
                image={imageUrl}
                style={{
                  objectFit: 'contain',
                  objectPosition: 'center',
                  width: '100%',
                  height: '100%',
                }}
              />
            </CardActionArea>
          </Card>
        </Box>
      </Tooltip>

      <MediaDialogDetails
        item={file}
        open={details.value}
        onClose={details.onFalse}
        onAddMedia={() => {
          details.onFalse();
          onAddMedia();
        }}
      />
    </>
  );
}
