import Button from '@mui/material/Button';
import Checkbox from '@mui/material/Checkbox';
import { CardProps } from '@mui/material/Card';
import Card from '@mui/material/Card';
import CardMedia from '@mui/material/CardMedia';
import { CardActionArea } from '@mui/material';
import { useBoolean } from '@/hooks/use-boolean';
import Iconify from '@/components/iconify';
import { ConfirmDialog } from '@/shared/components/custom-dialog';
import { IMedia } from '@/shared/types/media';
import MediaManagerFileDetails from './media-manager-file-details';

interface Props extends CardProps {
  file: IMedia;
  selected?: boolean;
  onSelect?: VoidFunction;
  onEdit: VoidFunction;
  onDelete: VoidFunction;
  onDownload: VoidFunction;
}

export default function MediaManagerFileItem({
  file,
  selected,
  onSelect,
  onEdit,
  onDelete,
  onDownload,
  sx,
  ...other
}: Props) {

  const confirmDeleteOne = useBoolean();

  const details = useBoolean();

  const extractUrl = (url: string) => {
    const match = url.match(/Optional\[(.*)\]/);
    return match ? match[1] : url;
  };

  return (
    <>
      <Card sx={{ maxWidth: 345 }}>
        <CardActionArea>
          <CardMedia
            onClick={details.onTrue}
            component="img"
            height="140"
            image={extractUrl(file.url)}
            style={{
              objectFit: 'cover',
              objectPosition: 'center',
            }}
          />
          <Checkbox
            size="medium"
            checked={selected}
            onClick={onSelect}
            icon={<Iconify icon="eva:radio-button-off-fill" />}
            checkedIcon={<Iconify icon="eva:checkmark-circle-2-fill" />}
            sx={{ p: 0.75 }}
          />
        </CardActionArea>
      </Card>

      <MediaManagerFileDetails
        item={file}
        open={details.value}
        onClose={details.onFalse}
        onEdit={() => onEdit()}
        onDelete={() => {
          details.onFalse();
          confirmDeleteOne.onTrue();
        }}
        onDownload={() => {
          details.onFalse();
          onDownload();
        }}
      />

      <ConfirmDialog
        open={confirmDeleteOne.value}
        onClose={confirmDeleteOne.onFalse}
        title="Delete"
        content="Are you sure want to delete?"
        action={
          <Button variant="contained" color="error" onClick={onDelete}>
            Delete
          </Button>
        }
      />
    </>
  );
}
