import React, { useEffect, useState } from 'react';
import { TextField, Grid, Typography, Autocomplete } from '@mui/material';
import { IAddressItem } from '@/shared/types/user';
import { countries } from '@/shared/assets/data';



// Props du composant
interface AddressFormProps {
  type: 'billing' | 'shipping';
  address: IAddressItem;
  onChange: (updatedAddress: IAddressItem) => void;
}
const AddressForm: React.FC<AddressFormProps> = ({ type, address, onChange }) => {
  const [formData, setFormData] = useState<IAddressItem>(address);
  useEffect(() => {
    setFormData(address)
  }, [address])
  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setFormData((prevData) => {
      const updatedData = { ...prevData, [name]: value };
      onChange(updatedData);
      return updatedData;
    });
  };

  const [selectedCountry, setSelectedCountry] = useState<string | null>(null);

  useEffect(() => {
    setSelectedCountry(formData?.country || countries[0].code);
  }, [formData?.country]);


  return (
    <Grid container spacing={2} alignItems="center">
      <Grid item xs={12}>
        <Typography variant="h6" gutterBottom>
          {type === 'billing' ? 'Facturation' : 'Expédition'}
        </Typography>
        <Grid container spacing={2}>
          <Grid item xs={6}>
            <TextField
              name="firstName"
              label="Nom"
              fullWidth
              value={formData?.firstName}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="lastName"
              label="Prénom"
              fullWidth
              value={formData?.lastName}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="companyName"
              label="Nom de l'entreprise"
              fullWidth
              value={formData?.companyName}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="email"
              label="E-mail"
              fullWidth
              value={formData?.email}
              onChange={handleChange}
              type="email"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="phoneNumber"
              label="Numéro de téléphone"
              fullWidth
              value={formData?.phoneNumber}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="street"
              label="Rue"
              fullWidth
              value={formData?.street}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="home"
              label="Maison"
              fullWidth
              value={formData?.home}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="city"
              label="Ville"
              fullWidth
              value={formData?.city}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <TextField
              name="zipCode"
              label="Code postal"
              fullWidth
              value={formData?.zipCode}
              onChange={handleChange}
              type="text"
              InputLabelProps={{
                shrink: true,
              }}
            />
          </Grid>
          <Grid item xs={6}>
            <Autocomplete
              options={countries.map((country) => country.code)}
              getOptionLabel={(option) => countries.find((country) => country.code === option)?.label ?? ""}
              value={selectedCountry}
              onChange={(event, newValue) => {
                handleChange({
                  target: {
                    name: 'country',
                    value: newValue || "",
                  },
                } as React.ChangeEvent<HTMLInputElement>);
              }}
              renderInput={(params) => (
                <TextField
                  {...params}
                  label="Pays"
                  InputLabelProps={{
                    shrink: true,
                  }}
                />
              )}
              isOptionEqualToValue={(option, value) => option === value}
            />
          </Grid>
        </Grid>
      </Grid>
    </Grid>
  );
};

export default AddressForm;
