"use client";
import React, { useCallback, useState } from "react";
import {
  Grid,
  Card,
  CardHeader,
  Stack,
  Typography,
  TextField,
  Autocomplete,
  TableContainer,
  Table,
  TableHead,
  TableRow,
  TableCell,
  Paper,
  Button,
  Dialog,
  DialogTitle,
  DialogContent,
  TableBody,
  Snackbar,
  Alert,
} from "@mui/material";
import LoadingButton from "@mui/lab/LoadingButton";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs/custom-breadcrumbs";
import { paths } from "@/routes/paths";
import { LocalizationProvider } from "@mui/x-date-pickers";
import DialogActions from "@mui/material/DialogActions";
import ProductForm, { Entry } from "../productForm";
import { useForm, Controller } from "react-hook-form";
import { searchAndFetchRandomClients } from "@/shared/api/user";
import { ClientWithCustomResponse } from "@/shared/types/user";
import AddressDetailsCard from "../order-address";
import {
  CreateOrderFromBORequest,
  ProductToCreateCommandBo,
} from "@/shared/types/order";
import { addCommande } from "@/shared/api/order";
import { order_options } from "@/contexts/types/main-order";

type Note = {
  subDescription: string;
  note: string | null;
};

export default function ProductNewEditForm() {
  const note = ["privée", "au client"];

  const [open, setOpen] = React.useState(false);
  const [isShipping, setIsShipping] = React.useState(false);
  const [isBilling, setIsBilling] = React.useState(false);
  const [creationDateTime, setCreationDateTime] = useState<string | null>(null);
  const handleDateChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    setCreationDateTime(event.target.value);
  };

  const handleClickOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };

  const [clients, setClients] = useState<ClientWithCustomResponse[]>([]);
  const [selectedClient, setSelectedClient] =
    useState<ClientWithCustomResponse | null>(null);

  const [searchClient, setSearchClient] = useState<boolean>(false);
  const handleSearchClient = async (searchKey: string) => {
    setSearchClient(true);
    try {
      const fetchedClients = await searchAndFetchRandomClients(searchKey);
      setClients(fetchedClients);
    } catch (error) {
      console.error("Error fetching clients", error);
    } finally {
      setSearchClient(false);
    }
  };

  const [billingId, setBillingId] = useState<number | null>(null);
  const [shippingId, setShippingId] = useState<number | null>(null);

  const handleAddressSubmitted = (
    billingId: number | null,
    shippingId: number | null
  ) => {
    if (billingId != null) {
      setIsBilling(true);
      setBillingId(billingId);
    } else {
      setBillingId(selectedClient?.billingAddress?.id!);
    }
    if (shippingId != null) {
      setIsShipping(true);
      setShippingId(shippingId);
    } else {
      setShippingId(selectedClient?.shippingAddress?.id!);
    }
  };

  const [snackbarOpen, setSnackbarOpen] = useState(false);
  const [snackbarMessage, setSnackbarMessage] = useState("");
  const [snackbarSeverity, setSnackbarSeverity] = useState<
    "success" | "warning" | "error"
  >("success");

  const handleSnackbarClose = () => {
    setSnackbarOpen(false);
  };

  const [selectedOrderOptions, setSelectedOrderOptions] = useState<string>("");
  const handleAutocompleteChange = useCallback(
    (
      _: React.SyntheticEvent<Element, Event>,
      newValue: ClientWithCustomResponse | null
    ) => {
      setSelectedClient(newValue);

      if (newValue?.shippingAddress != null) {
        setIsShipping(true);
      } else {
        setIsShipping(false);
      }
      if (newValue?.billingAddress != null) {
        setIsBilling(true);
      } else {
        setIsBilling(false);
      }
    },
    []
  );

  const {
    handleSubmit,
    control,
    formState: { errors },
  } = useForm();
  const [saveOrderLoading, setSaveOrderLoading] = useState(false);

  const onSubmit = async () => {
    try {
      setSaveOrderLoading(true);
      if (!selectedClient) {
        setSnackbarMessage("Vous n'avez pas choisi le client");
        setSnackbarSeverity("warning");
        return;
      } else {
        handleAddressSubmitted(
          selectedClient?.billingAddress?.id ?? null,
          selectedClient?.shippingAddress?.id ?? null
        );
      }
      if (!isShipping && !isBilling) {
        setSnackbarMessage("L'adresse de Facturation et l'adresse de livraison sont obligatoires");
        setSnackbarSeverity("warning");
        return;
      }

      if (!isShipping) {
        setSnackbarMessage("L'adresse de livraison est obligatoire");
        setSnackbarSeverity("warning");
        return;
      }

      if (!isBilling) {
        setSnackbarMessage("L'adresse de Facturation est obligatoire");
        setSnackbarSeverity("warning");
        return;
      }

      const productCommandQts: ProductToCreateCommandBo[] = productEntries
        .filter(
          (entry: Entry) =>
            entry.product &&
            entry.product.price !== undefined &&
            entry.quantity !== undefined &&
            entry.quantity > 0
        )
        .map((entry: Entry) => ({
          idProduct: entry.product!.id,
          quantity: entry.quantity!,
          unitPrice: entry.product!.price!,
          productName: entry.product!.productName,
          type:entry.product!.type,
          ugs:entry.product!.ugs,
          image:entry.product!.image
        }));

      if (productCommandQts.length === 0) {
        setSnackbarMessage("Vous n'avez choisi aucun produit");
        setSnackbarSeverity("warning");
        return;
      }

      const createOrderRequest: CreateOrderFromBORequest = {
        clientId: selectedClient.id,
        clientUid: selectedClient.uid,
        whoCreatedCommand: localStorage.getItem("userId")
          ? parseInt(localStorage.getItem("userId")!, 10)
          : 0,
        createdAt: creationDateTime || "",
        orderStatus: selectedOrderOptions || "IN_PROGRESS",
        note: noteData.subDescription || "",
        noteType: noteData.note || "",
        productCommandQts: productCommandQts,
      };
      const response = await addCommande(createOrderRequest);

      if (response.status === 200) {
        setSnackbarMessage("Commande créée avec succès");
        setSnackbarSeverity("success");
      } else {
        setSnackbarMessage("Erreur lors de la création de la commande");
        setSnackbarSeverity("warning");
      }
    } catch (error) {
      console.error("Erreur lors de la création de la commande:", error);
      setSnackbarMessage(
        "Une erreur est survenue lors de la création de la commande"
      );
      setSnackbarSeverity("error");
    } finally {
      setSaveOrderLoading(false);
      setSnackbarOpen(true);
    }
  };
  const [productEntries, setProductEntries] = useState<Entry[]>([]);

  const handleFormSubmit = (entries: any[]) => {
    setProductEntries(entries);
    setOpen(false);
  };
  const [noteData, setNoteData] = useState<Note>({
    subDescription: "",
    note: null,
  });

  const handleDescriptionChange = (
    event: React.ChangeEvent<HTMLInputElement>
  ) => {
    setNoteData((prevState) => ({
      ...prevState,
      subDescription: event.target.value,
    }));
  };

  const handleNoteChange = (event: any, newValue: string | null) => {
    setNoteData((prevState) => ({
      ...prevState,
      note: newValue,
    }));
  };

  return (
    <>
      <LocalizationProvider>
        <CustomBreadcrumbs
          heading="Créer une commande "
          links={[
            {
              name: "Tableau de bord",
              href: paths.dashboard.root,
            },
            {
              name: "Commandes",
              href: paths.dashboard.admin.order.all_orders,
            },
            {
              name: "Ajouter une commande",
            },
          ]}
          rollbackLink={paths.dashboard.admin.order.all_orders}
          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />
        <form onSubmit={handleSubmit(onSubmit)}>
          <Grid container spacing={3}>
            <Grid item xs={12} md={8}>
              <Card>
                <CardHeader title="Informations de la commande" />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TextField
                    name="creationDateTime"
                    label="Date de création"
                    type="datetime-local"
                    value={creationDateTime || ""}
                    onChange={handleDateChange}
                    fullWidth
                    InputLabelProps={{
                      shrink: true,
                    }}
                    inputProps={{
                      max: new Date().toISOString().slice(0, 16),
                    }}
                  />

                  <Controller
                    name="etat"
                    control={control}
                    defaultValue={Object.entries(order_options)[0]?.[0]}
                    rules={{ required: "Veuillez sélectionner un état." }}
                    render={({ field }) => (
                      <Autocomplete
                        id="combo-box-demo"
                        options={Object.entries(order_options)}
                        getOptionLabel={([, value]) => value}
                        isOptionEqualToValue={(option, value) => {
                          if (typeof value === "string") {
                            return option[0] === value;
                          }
                          return false;
                        }}
                        onChange={(_, selectedOption) => {
                          const selectedKey = selectedOption
                            ? selectedOption[0]
                            : "";
                          field.onChange(selectedKey);
                          setSelectedOrderOptions(selectedKey);
                        }}
                        disableClearable
                        fullWidth
                        renderInput={(params) => (
                          <TextField {...params} label="État" />
                        )}
                      />
                    )}
                  />

                  <Controller
                    name="client"
                    control={control}
                    render={({ field }) => (
                      <Autocomplete
                        {...field}
                        id="client-autocomplete"
                        options={clients}
                        loading={searchClient}
                        getOptionLabel={(option: any) =>
                          `[${option.uid}] ${option.firstName} ${option.lastName} - ${option.userEmail}`
                        }
                        onChange={handleAutocompleteChange}
                        fullWidth
                        renderInput={(params) => (
                          <TextField
                            {...params}
                            label="veuillez chercher un Client"
                            placeholder="chercher par nom, prénom, pseudo"
                            error={!!errors.client}
                            onChange={(e) => {
                              if (e.target.value !== "") {
                                handleSearchClient(e.target.value);
                              }
                            }}
                          />
                        )}
                      />
                    )}
                  />
                </Stack>
              </Card>
              <Card sx={{ marginTop: 1 }}>
                <CardHeader title={`Details d'adresse`} />
                <AddressDetailsCard
                  selectedClient={selectedClient || null}
                  onAddressSubmitted={handleAddressSubmitted}
                />
              </Card>
            </Grid>
            <Grid item xs={12} md={4}>
              <Card sx={{ marginBottom: 2 }}>
                <CardHeader title="Notes de commandes" />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TextField
                    name="subDescription"
                    label="Ajouter une note"
                    multiline
                    rows={4}
                    fullWidth
                    onChange={handleDescriptionChange}
                  />
                  <Grid container spacing={2} alignItems="center">
                    <Grid item xs={12}>
                      <Autocomplete
                        id="combo-box-demo"
                        options={note}
                        fullWidth
                        onChange={handleNoteChange}
                        renderInput={(params) => (
                          <TextField {...params} label="Note" />
                        )}
                      />
                    </Grid>
                  </Grid>
                </Stack>
              </Card>
            </Grid>

            <Grid item xs={12} md={8}>
              <Card sx={{ marginTop: 1 }}>
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TableContainer component={Paper}>
                    <Table sx={{ minWidth: 650 }} aria-label="simple table">
                      <TableHead>
                        <TableRow>
                          <TableCell>Article</TableCell>
                          <TableCell align="right">Prix unitaire</TableCell>
                          <TableCell align="right">Qte</TableCell>
                          <TableCell align="right">Total</TableCell>
                        </TableRow>
                      </TableHead>

                      <TableBody>
                        {productEntries.map((entry, index) => (
                          <TableRow key={index}>
                            <TableCell>{entry?.product?.productName}</TableCell>
                            <TableCell align="right">
                              {entry.product?.price} €
                            </TableCell>
                            <TableCell align="right">
                              {entry.quantity}
                            </TableCell>
                            <TableCell align="right">
                              {entry.product?.price !== undefined
                                ? (
                                    entry.product.price * entry.quantity!
                                  ).toFixed(2)
                                : "0.00"}{" "}
                              €
                            </TableCell>
                          </TableRow>
                        ))}
                      </TableBody>
                    </Table>
                  </TableContainer>
                  <Typography variant="subtitle2" align="right">
                    Sous-total des articles:
                    {productEntries
                      .reduce(
                        (total, entry) =>
                          total + (entry.product?.price ?? 0) * entry.quantity!,
                        0
                      )
                      .toFixed(2)}
                    €
                  </Typography>

                  <Grid
                    item
                    xs={12}
                    sx={{ display: "flex", justifyContent: "flex-end" }}
                  >
                    <Stack direction="row" spacing={2}>
                      <React.Fragment>
                        <Button variant="contained" onClick={handleClickOpen}>
                          Ajouter des produits
                        </Button>
                        <Dialog open={open} onClose={handleClose}>
                          <DialogTitle>Ajouter des produits</DialogTitle>
                          <DialogContent>
                            <ProductForm
                              onSubmit={handleFormSubmit}
                              initialEntries={productEntries}
                            />
                          </DialogContent>
                          <DialogActions>
                            <Button onClick={handleClose}>Annuler</Button>
                          </DialogActions>
                        </Dialog>
                      </React.Fragment>
                    </Stack>
                  </Grid>
                </Stack>
              </Card>
            </Grid>

            <Grid
              item
              xs={12}
              md={8}
              sx={{ display: "flex", alignItems: "center" }}
            >
              <Grid container justifyContent="flex-end">
                <LoadingButton
                  loading={saveOrderLoading}
                  onClick={onSubmit}
                  variant="contained"
                >
                  Enregistrer la commande
                </LoadingButton>
              </Grid>
            </Grid>
          </Grid>
        </form>
        <Snackbar
          open={snackbarOpen}
          autoHideDuration={6000}
          onClose={handleSnackbarClose}
          anchorOrigin={{ vertical: "top", horizontal: "right" }}
        >
          <Alert onClose={handleSnackbarClose} severity={snackbarSeverity}>
            {snackbarMessage}
          </Alert>
        </Snackbar>
      </LocalizationProvider>
    </>
  );
}
