import React from 'react';
import { Select, MenuItem, FormControl, SxProps, Theme, SelectChangeEvent, Pagination } from '@mui/material';

interface CustomPaginationProps {
  count: number;
  page: number;
  rowsPerPage: number;
  totalPages: number;
  setPage: (newPage: number) => void;
  setRowsPerPage: (newRowsPerPage: number) => void;
  rowsPerPageOptions: number[];
  sx?: SxProps<Theme>;
}

export default function CustomPagination({
  count,
  page,
  rowsPerPage,
  totalPages,
  setPage,
  setRowsPerPage,
  rowsPerPageOptions,
  sx,
}: CustomPaginationProps) {


  const handlePageChange = (event: React.ChangeEvent<unknown>, newPage: number) => {
    setPage(newPage - 1);
  };

  const handleSizeChange = (event: SelectChangeEvent<number>) => {
    setRowsPerPage(event.target.value as number);
    setPage(0);
  };

  return (
    <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between', width: '100%', padding: 2 }}>
      <Pagination
        count={totalPages}
        page={page + 1}
        onChange={handlePageChange}
        color="primary"
        sx={{ display: 'flex', justifyContent: 'center', marginTop: 2, marginLeft: 2, marginBottom: 2 }}
      />

      <FormControl variant="standard" sx={{ minWidth: 50 }}>
        <Select
          value={rowsPerPage}
          label="Lignes par page"
          onChange={handleSizeChange}
          sx={{ ...sx, marginRight: 2, marginBottom: 2 }}
          defaultValue={rowsPerPage}
          size="small"
        >
          {rowsPerPageOptions.map((option) => (
            <MenuItem key={option} value={option}>
              {option}
            </MenuItem>
          ))}
        </Select>
      </FormControl>
    </div>
  );
}
