import { useState, useEffect } from 'react';
import { Alert } from '@mui/material';
import { RefundOrderItem } from '@/contexts/types/refundOrder';
import RefundOrderDetailsItems from '../refund-order/refund-details/refund-order-details-item';
import LoadingScreen from '@/shared/components/loading-screen/loading-screen';
import { getRefundOrdersByOrderId } from '@/shared/api/refundOrders';


type Props = {
  orderId: string;
  getProductName: (orderLineId: string) => string | undefined;
  getProductImage: (orderLineId: string) => string | undefined;
};

export default function OrderRefundDetails({ orderId, getProductName, getProductImage }: Props) {

  const { refundOrdersData, refundOrdersError, refundOrdersLoading } = getRefundOrdersByOrderId(orderId);
  const [selectedRefundOrders, setSelectedRefundOrders] = useState<RefundOrderItem[]>();

  useEffect(() => {
    if (refundOrdersData) {
      setSelectedRefundOrders(refundOrdersData);
    }
  }, [refundOrdersData]);

  if (refundOrdersLoading) {
    return <LoadingScreen />;
  }

  if (refundOrdersError) {
    return <Alert severity="error">Problème lors du chargement des données.</Alert>;
  }

  return (
    <>
      {selectedRefundOrders && selectedRefundOrders.length > 0 ? (
        <RefundOrderDetailsItems selectedRefundOrders={selectedRefundOrders} getProductName={getProductName} getProductImage={getProductImage} />
      ) : null}
    </>
  );
}
