import Avatar from "@mui/material/Avatar";
import TableRow from "@mui/material/TableRow";
import Checkbox from "@mui/material/Checkbox";
import TableCell from "@mui/material/TableCell";
import Typography from "@mui/material/Typography";
import ListItemText from "@mui/material/ListItemText";
import { useEffect, useState } from "react";
import { fCurrency } from "@/utils/format-number";
import { fDate, fTime } from "@/utils/format-time";
import Label from "@/shared/components/label";
import { useRouter } from "@/hooks";
import { paths } from '@/routes/paths';
import { getRefundMethodColor, getRefundReasonColor, refundMethodLabels, RefundOrderItem, refundReasonLabels } from "@/contexts/types/refundOrder";

type Props = {
  row: RefundOrderItem;
  selected: boolean;
  onSelectRow: VoidFunction;
};

export default function RefundOrderTableRow({
  row,
  selected,
  onSelectRow,
}: Props) {
  const { id, createdAt, clientName, userName, refundMethod, refundReason, totalAmountToRefund, refundOrderLines, orderId } = row;

  const router = useRouter();

  const [totalQuantityRefund, setTotalQuantityRefund] = useState<number>(0);

  function calculateTotalQuantity(order: RefundOrderItem): number {
    return refundOrderLines?.reduce((total, line) => total + line.quantityToRefund, 0);
  }

  useEffect(() => {
    setTotalQuantityRefund(calculateTotalQuantity(row));
  }, [row]);

  const handleViewRefundOrderDetails = () => {
    router.push(paths.dashboard.admin.order.refund.details(orderId));
  }

  return (
    <>
      <TableRow hover selected={selected} className="cursor-pointer" onClick={() => {handleViewRefundOrderDetails();}}>
        <TableCell padding="checkbox" onClick={(event) => event.stopPropagation()}>
          <Checkbox checked={selected} onClick={onSelectRow} />
        </TableCell>

        <TableCell>
          {id}
        </TableCell>

        <TableCell>
          {orderId}
        </TableCell>

        <TableCell>
          <div className="flex items-center">
            <Avatar
              alt={clientName}
              sx={{ mr: 1, width: 25, height: 25 }}
            >
              {(clientName?.charAt(0) || "F").toUpperCase()}
            </Avatar>
            <Typography variant="body2" noWrap>
              {clientName || "Client non trouvé"}
            </Typography>
          </div>
        </TableCell>

        <TableCell>
          <div className="flex items-center">
            <Avatar
              alt={userName}
              sx={{ mr: 1, width: 25, height: 25 }}
            >
              {(userName?.charAt(0) || "F").toUpperCase()}
            </Avatar>
            <Typography variant="body2" noWrap>
              {userName || "Utilisateur non trouvé"}
            </Typography>
          </div>
        </TableCell>

        <TableCell>
          <ListItemText
            primary={fDate(createdAt)}
            secondary={fTime(createdAt)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>

        <TableCell>{fCurrency(totalAmountToRefund)}</TableCell>

        <TableCell>{totalQuantityRefund}</TableCell>

        <TableCell>
          <Label
            variant="soft"
            color={getRefundMethodColor(refundMethod)}
          >
            {refundMethodLabels[refundMethod]}
          </Label>
        </TableCell>

        <TableCell>
          <Label
            variant="soft"
            color={getRefundReasonColor(refundReason)}
          >
            {refundReasonLabels[refundReason]}
          </Label>
        </TableCell>
        
      </TableRow>
    </>
  );
}
