import Box from '@mui/material/Box';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import { fCurrency } from '../../../../../utils/format-number';
import { useEffect, useState } from 'react';
import { CardHeader, TableCell, Table, TableContainer, TableHead, TableBody, TableRow, Avatar, Typography } from '@mui/material';
import { RefundOrderItem } from '@/contexts/types/refundOrder';
import { DEFAULT_IMAGE_URL } from '@/config-global';
import { fDate, fTime } from '@/utils/format-time';

type Props = {
  selectedRefundOrders: RefundOrderItem[];
  getProductName: (orderLineId: string) => string | undefined;
  getProductImage: (orderLineId: string) => string | undefined;
};

export default function RefundOrderDetailsItems({ selectedRefundOrders, getProductName, getProductImage }: Props) {

  const [refundOrdersData, setRefundOrdersData] = useState<RefundOrderItem[]>([]);

  useEffect(() => {
    setRefundOrdersData(selectedRefundOrders);
  }, [selectedRefundOrders]);

  const renderTotal = (refundOrder: RefundOrderItem) => (
    <Stack
      spacing={2}
      alignItems="flex-end"
      sx={{ my: 3, textAlign: 'right', typography: 'body2' }}
    >
      <Stack direction="row">
        <Box sx={{ color: 'text.secondary' }}>Frais d'expédition remboursés (TTC)</Box>
        <Box sx={{ width: 160, typography: 'subtitle2' }}>
          {fCurrency(refundOrder?.shippingAmountToRefund || 0)}
        </Box>
      </Stack>

      <Stack direction="row">
        <Box sx={{ color: 'text.secondary' }}>Total HT</Box>
        <Box sx={{ width: 160, typography: 'subtitle2' }}>
          {fCurrency(refundOrder?.totalPriceHT || 0)}
        </Box>
      </Stack>

      <Stack direction="row">
        <Box sx={{ color: 'text.secondary' }}>TVA</Box>
        <Box sx={{ width: 160, typography: 'subtitle2' }}>
          {fCurrency(refundOrder?.tva || 0)}
        </Box>
      </Stack>

      <Stack direction="row" sx={{ typography: 'subtitle1' }}>
        <Box>Total remboursé (TTC)</Box>
        <Box sx={{ width: 160 }}>{fCurrency(refundOrder?.totalAmountToRefund || 0)}</Box>
      </Stack>
    </Stack>
  );


  return (
    <>
      {refundOrdersData && refundOrdersData.length > 0 && refundOrdersData
        .slice()
        .sort((a, b) => {
          return Number(b.id) - Number(a.id);
        })
        .map((ro) => (
          <Card sx={{ mt: 2 }}>
            <CardHeader
              title={
                <Stack direction="row" justifyContent="space-between" alignItems="center">
                  <Typography variant="h6">{`Remboursement N° ${ro.id}`}</Typography>
                  <Typography variant="body2" color="text.secondary">
                    {`${fDate(ro.createdAt)} - ${fTime(ro.createdAt)} / ${ro.userName}`}
                  </Typography>
                </Stack>
              }
              sx={{ mb: 3 }}
            />
            <Stack sx={{ px: 3 }}>
              <TableContainer>
                <Table>
                  <TableHead>
                    <TableCell sx={{ textAlign: 'center' }}>N°</TableCell>
                    <TableCell sx={{ textAlign: 'center' }}>Produit</TableCell>
                    <TableCell sx={{ textAlign: 'center' }}>Quantité</TableCell>
                    <TableCell sx={{ textAlign: 'center' }}>Prix total rembourssé</TableCell>
                  </TableHead>
                  <TableBody>
                    {ro?.refundOrderLines?.map((refundOrderLine) => (
                      <TableRow>
                        <TableCell sx={{ textAlign: 'center' }}>{refundOrderLine?.id}</TableCell>
                        <TableCell sx={{ textAlign: 'center' }}>
                          <Stack direction="row" alignItems="center" spacing={1}>
                            <Avatar
                              alt={getProductName(refundOrderLine?.orderLineId) || ''}
                              src={getProductImage(refundOrderLine?.orderLineId) || DEFAULT_IMAGE_URL}
                              variant="rounded"
                              sx={{ width: 64, height: 64, mr: 2 }}
                            />
                            {getProductName(refundOrderLine?.orderLineId) || ''}
                          </Stack>
                        </TableCell>
                        <TableCell sx={{ textAlign: 'center' }}>x{refundOrderLine?.quantityToRefund}</TableCell>
                        <TableCell sx={{ textAlign: 'center' }}>{fCurrency(refundOrderLine?.amountToRefund.toFixed(2) || 0)}</TableCell>
                      </TableRow>
                    ))}
                  </TableBody>
                </Table>
              </TableContainer>
              {renderTotal(ro)}
            </Stack>
          </Card>
        ))}
    </>
  );
}
