import Divider from '@mui/material/Divider';
import MenuItem from '@mui/material/MenuItem';
import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import Switch from '@mui/material/Switch';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import { useBoolean, useRouter } from '@/hooks';
import Iconify from '@/shared/components/iconify';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';
import { ShippingMethod } from '@/contexts/types/Shipping';
import React, { useCallback, useState } from 'react';
import { IPaymentMethod } from '@/shared/types/payment';
import { changePaymentMethodStatus } from '@/shared/api/payment';
import { paths } from '@/routes/paths';


type Props = {
    row: IPaymentMethod;
};

export default function PaymentMethodTableRow({
    row,
}: Props) {
    const { id, type, title, active, description } = row;
    const popover = usePopover();
    const [isChecked, setIsChecked] = useState(active);

    const router = useRouter();
    
    const handleViewRow = () => { router.push(paths.dashboard.admin.payment.method(type)); }     

    const  handleToggle = async () => {
        await changePaymentMethodStatus(row.type);
        setIsChecked(!isChecked);
    };


    return (
        <>
            <TableRow hover sx={{ width: '100%' }}>
                <TableCell align='center' sx={{ width: '300px' }}>
                    <Typography variant="body2">
                        {title}
                    </Typography>
                </TableCell>

                <TableCell    align='center'  sx={{ width: '300px' }}>
                    <Switch
                        checked={isChecked}
                        onChange={handleToggle}
                        inputProps={{ 'aria-label': 'controlled' }}
                    />
                </TableCell>

                <TableCell   align='center'  sx={{ width: '520px' }}>{description}</TableCell>

                <TableCell align='center' sx={{ width: "300px" }}>
                    <IconButton color={popover.open ? 'inherit' : 'default'} onClick={handleViewRow}>
                        <Iconify icon="mdi:settings" />
                    </IconButton>
                </TableCell>

            </TableRow>
        </>
    );
}
