import {
  Stack,
  Card,
  Typography,
  Grid,
  CardHeader,
  FormControlLabel,
  Switch,
} from "@mui/material";

interface ProductConfigurationProps {
  mdUp: boolean;
  siteWebPublication: boolean;
  livePublication: boolean;
  handleSiteWebPublicationChange: (
    event: React.ChangeEvent<HTMLInputElement>
  ) => void;
  handleLivePublicationChange: (
    event: React.ChangeEvent<HTMLInputElement>
  ) => void;
}

export default function ProductConfiguration({
  mdUp,
  siteWebPublication,
  livePublication,
  handleSiteWebPublicationChange,
  handleLivePublicationChange,
}: ProductConfigurationProps) {
  return (
    <>
      {mdUp && (
        <Grid md={4}>
          <Typography variant="h6" sx={{ mb: 0.5 }}>
            Configuration Spésifique
          </Typography>
          <Typography variant="body2" sx={{ color: "text.secondary" }}>
            Choisir une Configuration Spésifique
          </Typography>
        </Grid>
      )}

      <Grid xs={12} md={8} sx={{ mb: 3 }}>
        <Card>
          {!mdUp && <CardHeader title="Expedition" />}

          <Stack direction="row" alignItems="center" spacing={3}>
            <FormControlLabel
              control={
                <Switch
                  checked={siteWebPublication}
                  onChange={handleSiteWebPublicationChange}
                />
              }
              label="Publication sur le site web"
            />
            <FormControlLabel
              control={
                <Switch
                  checked={livePublication}
                  onChange={handleLivePublicationChange}
                />
              }
              label="Publication sur le live"
            />
            {siteWebPublication ? (
              <>
                <Stack spacing={3}>
                  <FormControlLabel
                    control={<Switch />}
                    label="Autorisation précommande"
                  />
                  <FormControlLabel
                    control={<Switch />}
                    label="Définir seuil de précommande"
                  />
                </Stack>
              </>
            ):null}
            {livePublication && (
              <>
                <Stack spacing={3}>
                  <FormControlLabel
                    control={<Switch />}
                    label="Définir seuil de précommande"
                  />
                  <FormControlLabel
                    control={<Switch />}
                    label="Configuration modification"
                  />
                  <FormControlLabel
                    control={<Switch />}
                    label="Alimenter le stock depuis le stock web"
                  />
                  <FormControlLabel
                    control={<Switch />}
                    label="Autorisation précommande"
                  />
                </Stack>
              </>
            )}
          </Stack>
        </Card>
      </Grid>
    </>
  );
}
