import { RHFTextField, RHFEditor } from "@/shared/components/hook-form";
import {
  Stack,
  Card,
  Typography,
  Grid,
  CardHeader,
  IconButton,
  MenuItem,
  FormControlLabel,
  Switch,
  Divider,
} from "@mui/material";
import { useEffect, useState } from "react";
import {
  AccessLevel,
  FileType,
  IMedia,
  Visibility,
} from "@/shared/types/media";
import { CloseIcon } from "yet-another-react-lightbox";
import { IProductItem } from "@/shared/types/product";
import AddMediaButton from "../../media/Add-media-button";
import { useGetNotArchivedSuppliers } from "@/shared/api/supplier";
import { RHFSelect } from "@/components/hook-form/rhf-select";
import { useFormContext } from "react-hook-form";

interface ProductDetailsProps {
  mdUp: boolean;
  setMediaId: (id: number | string) => void;
  setPathList: (pathlist: (number | string)[]) => void;
  setMediaIds: (ids: (number | string)[]) => void;
  setPath: (path: string | number) => void;
  isEditing: boolean;
  currentProduct?: IProductItem;
  defaultSupplierName?: string; 
}
export default function ProductDetails({
  mdUp,
  setMediaId,
  setMediaIds,
  setPathList,
  setPath,
  isEditing,
  currentProduct,
  defaultSupplierName,
}: ProductDetailsProps) {
  const [isEditedOnce, setIsEditedOnce] = useState<boolean>(false);
  const [showSecondSupplier, setShowSecondSupplier] = useState<boolean>(false);

  const [isEditedOnceForMultiple, setIsEditedOnceForMultiple] =
    useState<boolean>(false);
  const [returnedMultiMedia, setReturnedMultiMedia] = useState<IMedia[]>([]);
  const [returnedEditMultiMedia, setReturnedEditMultiMedia] = useState<
    IMedia[]
  >([]);
  const { setValue, watch } = useFormContext();
  const supplierId = watch('supplierId');
  const [returnedMainImage, setReturnedMainImage] = useState<IMedia | null>(
    null
  );
  const [returnedEditedMainImage, setReturnedEditedMainImage] =
    useState<IMedia | null>(null);
  const { suppliersData } = useGetNotArchivedSuppliers();
  useEffect(() => {
    if (isEditing && currentProduct) {
      setReturnedEditedMainImage({
        id: currentProduct.mainImageID?.toString() ?? "0",
        url: (currentProduct.mainImagePath.toString()) || "",
        title: "",
        description: "",
        name: "",
        createdAt: "",
        modifiedAt: "",
        size: 0,
        userId: "",
        fileType: FileType.IMAGE,
        visibility: Visibility.PUBLIC,
        permissions: AccessLevel.READ,
        path: "",
        uniqueId: "",
      });

      const multimedia = (currentProduct.imagesIDs || []).map((id, index) => ({
        id: id.toString(),
        url:(currentProduct.imagesPaths?.[index]) || "",
        title: "",
        description: "",
        name: "",
        createdAt: "",
        modifiedAt: "",
        size: 0,
        userId: "",
        fileType: FileType.IMAGE,
        visibility: Visibility.PUBLIC,
        permissions: AccessLevel.READ,
        path: "",
        uniqueId: "",
      }));
      setReturnedEditMultiMedia(multimedia);
    }
    if (currentProduct?.supplierNameSecond) {
      setShowSecondSupplier(true);
    }
  }, [isEditing, currentProduct]);

  useEffect(() => {
    if (returnedMainImage) {
      const mediaId = returnedMainImage.id;
      const mediaUrl = returnedMainImage.url;

      setMediaId(mediaId);
      setPath(mediaUrl);
    }
  }, [returnedMainImage]);

  useEffect(() => {
    if (returnedEditedMainImage) {
      const mediaId = returnedEditedMainImage.id;
      const mediaUrl = returnedEditedMainImage.url;

      setMediaId(mediaId);
      setPath(mediaUrl);
    }
  }, [returnedEditedMainImage]);

  // Mettre à jour les IDs et les chemins des images à chaque changement
  useEffect(() => {
    const allMedia = [...returnedEditMultiMedia, ...returnedMultiMedia];
    const ids = allMedia.map((media) => media.id);
    const paths = allMedia.map((media) => media.url);

    setMediaIds(ids); // Mettre à jour la liste des IDs dans le parent
    setPathList(paths); // Mettre à jour la liste des chemins dans le parent
  }, [returnedEditMultiMedia, returnedMultiMedia, setMediaIds, setPathList]);


  useEffect(() => {
    if (defaultSupplierName && suppliersData) {
      setValue('supplierName', defaultSupplierName);
    } else if (currentProduct && currentProduct.supplierName) {
      setValue('supplierName', currentProduct.supplierName);
    }
  }, [defaultSupplierName, currentProduct, suppliersData, setValue]);

  const toggleEditedOnce = () => {
    setIsEditedOnce(true);
  };


  useEffect(() => {
  if (currentProduct && currentProduct.supplierName) {
    setValue('supplierName', currentProduct.supplierName);
  }
}, [currentProduct, setValue]);

const handleShowSecondSupplierChange = (event: React.ChangeEvent<HTMLInputElement>) => {
  const checked = event.target.checked;
  setShowSecondSupplier(checked);
  if (!checked) {
    setValue('supplierNameSecond', '');
    setValue('supplierRefSecond', '');
    setValue('secondPurchasePrice', '');
  }
};
  return (
    <>
      <Grid container spacing={2}>
        {mdUp && (
          <Grid item md={4}>
            <Typography variant="h6" sx={{ mb: 0.5 }}>
              Détails
            </Typography>
            <Typography variant="body2" sx={{ color: "text.secondary" }}>
              Titre, brève description, image...
            </Typography>
          </Grid>
        )} 
        <Grid item xs={12} md={8} sx={{ mb: 3 }}>
          <Card>
            {!mdUp && <CardHeader title="Détails" />}
            <Stack spacing={3} sx={{ p: 3 }}>
              <RHFTextField name="name" label="Nom du produit" />
              <RHFTextField
                name="shortDescription"
                label="Description courte"
                multiline
                rows={4}
              />
              <Stack spacing={1.5}>
                <Typography variant="subtitle2">Description</Typography>
                <RHFEditor id="description" name="description" simple />
              </Stack>

              <Stack spacing={1.5}>
                <Typography variant="subtitle2">Image Principale</Typography>

                <AddMediaButton
                  variant="outlined"
                  color="success"
                  size="medium"
                  returnedSingleMedia={
                    returnedEditedMainImage ? [returnedEditedMainImage] : []
                  }
                  setReturnedSingleMedia={(media) => {
                    const newMedia = media.length > 0 ? media[0] : null;
                    setReturnedMainImage(newMedia); // Met à jour la nouvelle image
                    setReturnedEditedMainImage(newMedia); // Met à jour l'image modifiée
                    toggleEditedOnce();
                  }}
                  nameBtn={isEditing ? "Modifier l'image" : "Ajouter une image"}
                />

                {returnedEditedMainImage && !isEditedOnce && (
                  <Grid container spacing={1}>
                    <Grid style={{ margin: "10px", position: "relative" }}>
                      <img
                        src={returnedEditedMainImage.url}
                        alt={returnedEditedMainImage.name}
                        style={{
                          width: "100px",
                          height: "100px",
                          objectFit: "contain",
                        }}
                      />
                      <IconButton
                        onClick={() => setReturnedEditedMainImage(null)}
                        style={{ position: "absolute", top: 0, right: 0 }}
                      >
                        <CloseIcon />
                      </IconButton>
                    </Grid>
                  </Grid>
                )}
              </Stack>

              <Stack spacing={1.5}>
                <Typography variant="subtitle2">Images Secondaires</Typography>

                <AddMediaButton
                  multiple
                  variant="outlined"
                  color="success"
                  size="medium"
                  returnedMultiMedia={returnedEditMultiMedia} // Passer les anciennes images ici
                  setReturnedMultiMedia={(newMedia) => {
                    // Fusionner les nouvelles images avec les anciennes
                    const updatedMedia = [
                      ...returnedEditMultiMedia, // Anciennes images
                      ...newMedia, // Nouvelles images
                    ];
                    setReturnedEditMultiMedia(updatedMedia);
                    setIsEditedOnceForMultiple(true);
                  }}
                  nameBtn={
                    isEditing ? "Modifier les images" : "Ajouter des images"
                  }
                />

                {!isEditedOnceForMultiple &&
                  returnedEditMultiMedia.length > 0 && (
                    <Grid container spacing={1}>
                      <Typography>
                        {returnedEditMultiMedia.length} Médias sélectionnés
                      </Typography>
                      {returnedEditMultiMedia.map((media) => (
                        <Grid
                          key={media.id}
                          style={{ margin: "10px", position: "relative" }}
                        >
                          <img
                            src={media.url}
                            alt={media.name}
                            style={{
                              width: "100px",
                              height: "100px",
                              objectFit: "contain",
                            }}
                          />
                          <IconButton
                            onClick={() => {
                              // Supprimer l'image de l'état
                              setReturnedEditMultiMedia(
                                returnedEditMultiMedia.filter(
                                  (m) => m.id !== media.id
                                )
                              );
                            }}
                            style={{ position: "absolute", top: 0, right: 0 }}
                          >
                            <CloseIcon />
                          </IconButton>
                        </Grid>
                      ))}
                    </Grid>
                  )}
              </Stack>
            </Stack>
          </Card>
        </Grid>
      </Grid>
      <Grid container spacing={2}>
        {mdUp ? (
          <Grid item md={4}>
            <Typography variant="h6" sx={{ mb: 0.5 }}>
              Détails Fournisseur
            </Typography>
            <Typography variant="body2" sx={{ color: "text.secondary" }}>
              Nom, Prénom, Référence, prix d'achat ...
            </Typography>
          </Grid>
        ) : null}
        <Grid item xs={12} md={8} sx={{ mb: 3 }}>
          <Card>
          {!mdUp ? <CardHeader title="Détails" /> : null}
            <Stack spacing={3} sx={{ p: 3 }}>
            <RHFSelect
                name="supplierName"
                label="Nom Complet du fournisseur"
                placeholder="Sélectionnez un fournisseur"
              >
                {suppliersData?.map((supplier) => (
                  <MenuItem key={supplier.id} value={`${supplier.supplierName} ${supplier.supplierLastName}`}>
                    {`${supplier.supplierName} ${supplier.supplierLastName}`}
                  </MenuItem>
                ))}
              </RHFSelect>
              <RHFTextField name="supplierRef" label="Réference" />
              <RHFTextField name="purchasePrice" label="Prix d'achat" />
            
            <FormControlLabel
                control={
                  <Switch
                    checked={showSecondSupplier}
                    onChange={handleShowSecondSupplierChange}
                    name="showSecondSupplier"
                  />
                }
                label="Ajouter un fournisseur secondaire"
              />
              {showSecondSupplier && (
                <>
                  <Divider />
                  <Typography variant="subtitle1">Fournisseur Secondaire</Typography>
            <RHFSelect
                name="supplierNameSecond"
                label="Nom Complet du fournisseur"
                placeholder="Sélectionnez un fournisseur"
              >
                {suppliersData?.map((supplier) => (
                  <MenuItem key={supplier.id} value={`${supplier.supplierName} ${supplier.supplierLastName}`}>
                    {`${supplier.supplierName} ${supplier.supplierLastName}`}
                  </MenuItem>
                ))}
              </RHFSelect>
              <RHFTextField name="supplierRefSecond" label="Réference" />
              <RHFTextField name="secondPurchasePrice" label="Prix d'achat" />
              </>
               )}
             </Stack>
          </Card>
        </Grid>
      </Grid>
    </>
  );
}
