import Box from "@mui/material/Box";
import Link from "@mui/material/Link";
import Stack from "@mui/material/Stack";
import Avatar from "@mui/material/Avatar";
import { GridCellParams } from "@mui/x-data-grid";
import ListItemText from "@mui/material/ListItemText";

import { fCurrency } from "@/utils/format-number";
import { fTime, fDate } from "@/utils/format-time";

import Label from "@/shared/components/label";
import { useRouter } from "@/hooks";


// ----------------------------------------------------------------------

type ParamsProps = {
  params: GridCellParams;
};

export function RenderCellPrice({ params }: ParamsProps) {
  const { minPrice, maxPrice, regularPrice } = params.row;
  
  if (minPrice !== undefined && maxPrice !== undefined && minPrice !== maxPrice) {
    return <>{`${fCurrency(minPrice)} – ${fCurrency(maxPrice)}`}</>;
  } 
  else {
    return <>{fCurrency(regularPrice)}</>;
  }
}
export function RenderCellPuchasePrice({ params }: ParamsProps) {
  return <>{fCurrency(params.row.purchasePrice)}</>;
}

export function RenderCellPublish({ params }: ParamsProps) {
  return (
    <Label variant="soft" color={params.row.draft ? "default" : "info"}>
      {params.row.draft ? "Brouillon" : "Publié"}
    </Label>
  );
}

export function RenderCellCreatedAt({ params }: ParamsProps) {
  return (
    <ListItemText
      primary={fDate(params.row.createdAt)}
      secondary={fTime(params.row.createdAt)}
      primaryTypographyProps={{ typography: "body2", noWrap: true }}
      secondaryTypographyProps={{
        mt: 0.5,
        component: "span",
        typography: "caption",
      }}
    />
  );
}

export function RenderCellStock({ quantity }: { quantity: number }) {
  return (
    <Stack sx={{ typography: "caption", color: "text.secondary" }}>
      <Box sx={{ mb: 1, maxWidth: 80, fontWeight: 'bold' }}>
        {quantity} articles
      </Box>
    </Stack>
  );
}

export function RenderCellProduct({ params }: ParamsProps) {
  const router = useRouter();

  const mainImagePath =
    params.row.mainImagePath && params.row.mainImagePath.includes("Optional[")
      ? params.row.mainImagePath.replace("Optional[", "").replace("]", "")
      : params.row.mainImagePath || "";

  const handleViewRow = () => {
    router.push(`/dashboard/product/${params.row.id}`); 
  };

  return (
    <Stack direction="row" alignItems="center" sx={{ py: 2, width: 1 }}>
      <Avatar
        alt={params.row.name}
        src={mainImagePath}
        variant="rounded"
        sx={{ width: 64, height: 64, mr: 2 }}
      />

      <ListItemText
        disableTypography
        primary={
          <Link
            noWrap
            color="inherit"
            variant="subtitle2"
            onClick={handleViewRow} // Use the handler here
            sx={{ cursor: "pointer" }}
          >
            {params.row.name}
          </Link>
        }
        secondary={
          <Box
            component="div"
            sx={{ typography: "body2", color: "text.disabled" }}
          >
            {params.row.categoryNames}
          </Box>
        }
        sx={{ display: "flex", flexDirection: "column" }}
      />
    </Stack>
  );
}
