import Box from "@mui/material/Box";
import Button from "@mui/material/Button";
import Tooltip from "@mui/material/Tooltip";
import IconButton from "@mui/material/IconButton";
import Stack, { StackProps } from "@mui/material/Stack";

import RouterLink from "@/routes/router-link";

import Iconify from "@/shared/components/iconify";
import { usePopover } from "@/shared/components/custom-popover";

// ----------------------------------------------------------------------

type Props = StackProps & {
  backLink: string;
  editLink: string;
  liveLink: string;
  publish: string;
  onChangePublish: (newValue: string) => void;
  onExport: () => void;
};

export default function ProductDetailsToolbar({
  publish,
  backLink,
  editLink,
  liveLink,

  onChangePublish,
  onExport,
  sx,
  ...other
}: Props) {
  const popover = usePopover();

  return (
    <>
      <Stack
        spacing={1.5}
        direction="row"
        sx={{
          mb: { xs: 3, md: 5 },
          ...sx,
        }}
        {...other}
      >
        <Button
          component={RouterLink}
          href={backLink}
          startIcon={<Iconify icon="eva:arrow-ios-back-fill" width={16} />}
        >
          Retour
        </Button>

        <Box sx={{ flexGrow: 1 }} />

        <Button
        variant="contained"
        startIcon={<Iconify icon="mdi:file-export" />}
        onClick={onExport}
      >
        Exporter
      </Button>
        <Tooltip title="Modifier">
          <IconButton component={RouterLink} href={editLink}>
            <Iconify icon="solar:pen-bold" />
          </IconButton>
        </Tooltip>
      </Stack>
    </>
  );
}
