"use client";

import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";

import { useUpdateProduct } from "@/shared/api/product";

import { useSettingsContext } from "@/shared/components/settings";

import CustomBreadcrumbs from "@/shared/components/custom-breadcrumbs";
import ProductNewEditForm from "../add-product/MainForm";
import CircularProgress from "@mui/material/CircularProgress"; // Import CircularProgress

type Props = {
  id: string;
};

export default function ProductEditView({ id }: Props) {
  const settings = useSettingsContext();

  const {
    product: currentProduct,
    productLoading,
    productError,
  } = useUpdateProduct(id);

  if (productLoading) {
    return (
      <Container maxWidth="sm" style={{ display: 'flex', justifyContent: 'center', alignItems: 'center', height: '100vh' }}>
        <CircularProgress /> {/* Display loading spinner */}
      </Container>
    );
  }

  if (productError) {
    return <div>Error loading product.</div>;
  }

  return (
    <Container maxWidth={settings.themeStretch ? false : "lg"}>
      <CustomBreadcrumbs
        heading="Modifier"
        links={[
          { name: "Tableau de bord", href: paths.dashboard.root },
          {
            name: "Produit",
            href: paths.dashboard.admin.product.root,
          },
          { name: currentProduct?.name || "Product" },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <ProductNewEditForm currentProduct={currentProduct} />
    </Container>
  );
}
