import React from 'react';
import { List, ListItem, ListItemText, Avatar, Typography, Button, Card, Modal, Checkbox } from '@mui/material';
import { ProductChoiceItem } from './AddEditDuplicatePromoCodeView';
import { DEFAULT_IMAGE_URL } from '@/config-global';

interface SelectVariationsModalProps {
    title: string;
    variationsModal: boolean;
    setVariationsModal: (value: boolean) => void;
    variationsChoices: ProductChoiceItem[];
    setVariationsChoices: (value: ProductChoiceItem[]) => void;
    selectedVariations: ProductChoiceItem[];
    setSelectedVariations: (value: ProductChoiceItem[]) => void;
    handleAddSelectedVariation: (variation: ProductChoiceItem) => void;
}

const SelectVariationsModal: React.FC<SelectVariationsModalProps> = ({ title, variationsModal, setVariationsModal, variationsChoices, setVariationsChoices, selectedVariations, setSelectedVariations, handleAddSelectedVariation }) => {

    const isValidImagePath = (path: string): string => {
        const img = new Image();
        img.src = path;
        return img.complete && img.naturalWidth !== 0 ? path : DEFAULT_IMAGE_URL!;
    };

    const toggleVariationSelection = (variation: ProductChoiceItem) => {
        const isSelected = selectedVariations.some((item: ProductChoiceItem) => item.id === variation.id);
        if (isSelected) {
            setSelectedVariations(selectedVariations.filter((item: ProductChoiceItem) => item.id !== variation.id));
        } else {
            handleAddSelectedVariation(variation);
        }
    };

    return (
        <Modal
            open={variationsModal && variationsChoices && variationsChoices.length > 0}
            onClose={() => {
                setVariationsChoices([]);
                setVariationsModal(false);
            }}
            aria-labelledby="modal-modal-title"
            aria-describedby="modal-modal-description"
        >
            <Card sx={{
                position: 'absolute',
                top: '50%',
                left: '50%',
                transform: 'translate(-50%, -50%)',
                maxHeight: '80vh',
                maxWidth: '80vw',
                overflow: 'hidden',
                display: 'flex',
                flexDirection: 'column',
                boxShadow: 24,
                p: 2,
            }}>
                <Typography id="modal-modal-title" variant="h6" component="h2" sx={{ mb: 1, ml: 3 }}>
                    {title}
                </Typography>

                <List sx={{ overflowY: 'auto', maxHeight: 'calc(100% - 64px)', p: 2 }}>
                    {variationsChoices?.map((variation: ProductChoiceItem) => {
                        const isChecked = selectedVariations.some((item: ProductChoiceItem) => item.id === variation.id);
                        return (
                            <ListItem key={variation.id} onClick={() => toggleVariationSelection(variation)}>
                                <Checkbox
                                    edge="start"
                                    checked={isChecked}
                                    tabIndex={-1}
                                    disableRipple
                                    sx={{ mr: 2 }}
                                />
                                {variation.mainImagePath && (
                                    <Avatar
                                        src={isValidImagePath(variation.mainImagePath)}
                                        alt={variation.name}
                                    />
                                )}
                                <ListItemText
                                    primary={`${variation.name}`}
                                    secondary={`ID: ${variation.id}`}
                                />
                            </ListItem>
                        );
                    })}
                </List>
                <Button
                    onClick={() => {
                        setVariationsChoices([]);
                        setVariationsModal(false);
                    }}
                    sx={{
                        backgroundColor: 'black',
                        color: 'white',
                        '&:hover': {
                            backgroundColor: 'darkgray',
                        }
                    }}
                >
                    Fermer
                </Button>
            </Card>
        </Modal>
    );
};

export default SelectVariationsModal;
