import React from 'react';
import { List, ListItem, ListItemText, IconButton, Avatar, Box } from '@mui/material';
import CloseIcon from '@mui/icons-material/Close';
import { ProductChoiceItem } from './AddEditDuplicatePromoCodeView';
import { DEFAULT_IMAGE_URL } from '@/config-global';

interface SelectedProductsListProps {
  selectedProducts: ProductChoiceItem[];
  onRemove: (id: string) => void;
}

const SelectedProductsList: React.FC<SelectedProductsListProps> = ({ selectedProducts, onRemove }) => {
  const isValidImagePath = (path: string): string => {
    const img = new Image();
    img.src = path;
    return img.complete && img.naturalWidth !== 0 ? path : DEFAULT_IMAGE_URL!;
  };

  return (
    <Box>
      <List>
        {selectedProducts.map((product) => (
          <ListItem
            key={product.id}
            sx={{
              borderBottom: '1px solid #e0e0e0',
              paddingY: 1,
              position: 'relative',
            }}
          >
            <Avatar alt={product.name} src={isValidImagePath(product.mainImagePath)} sx={{ marginRight: 2 }} />
            <ListItemText primary={product.name} secondary={product.ugs} />
            <IconButton
              edge="end"
              aria-label="remove"
              onClick={() => onRemove(product.id)}
              sx={{
                position: 'absolute',
                top: 8,
                right: 8,
                color: 'red',
              }}
            >
              <CloseIcon />
            </IconButton>
          </ListItem>
        ))}
      </List>
    </Box>
  );
};

export default SelectedProductsList;
