import React from 'react';
import { List, ListItem, ListItemText, Avatar, Card, CardHeader, CardContent, Typography } from '@mui/material';
import { DEFAULT_IMAGE_URL } from '@/config-global';
import { ProductChoiceItem } from '../add-edit-duplicate/AddEditDuplicatePromoCodeView';

interface PromoCodeCardProductsListProps {
  title: string;
  products: ProductChoiceItem[];
}

const PromoCodeCardProductsList: React.FC<PromoCodeCardProductsListProps> = ({ title, products }) => {
  const isValidImagePath = (path: string): string => {
    const img = new Image();
    img.src = path;
    return img.complete && img.naturalWidth !== 0 ? path : DEFAULT_IMAGE_URL!;
  };

  return (
    <Card>
      <CardHeader title={title} />
      <CardContent sx={{ maxHeight: 500, overflowY: 'auto' }}>
        <List>
          {products && products.map((product) => (
            <ListItem
              key={product.id}
              sx={{
                borderBottom: '1px solid #e0e0e0',
                paddingY: 1,
                position: 'relative',
              }}
            >
              <Avatar alt={product.name} src={isValidImagePath(product.mainImagePath)} sx={{ marginRight: 2 }} />
              <ListItemText primary={product.name} secondary={product.ugs} />
            </ListItem>
          ))}
        </List>
      </CardContent>
    </Card>
  );
};

export default PromoCodeCardProductsList;
