'use client';
import React, { useState } from 'react';
import Typography from '@mui/material/Typography';
import Button from '@mui/material/Button';
import FormControl from '@mui/material/FormControl';
import { Card, CardMedia, CardContent } from '@mui/material';
import TextField from '@mui/material/TextField';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs/custom-breadcrumbs';
import { paths } from '@/routes/paths';
import AddMediaButton from '../media/Add-media-button';


const PurchaseCard: React.FC = () => {
  const [cardColor, setCardColor] = useState('#F0FFF0'); // Couleur par défaut
  const [image, setImage] = useState<File | null>(null);
  const [title, setTitle] = useState("Un bon d'achat vous attend");

  const handleColorChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    setCardColor(event.target.value);
  };

  const handleImageChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    const files = event.target.files;
    if (files && files.length > 0) {
      const selectedImage = files[0];
      setImage(selectedImage);
    }
  };

  const handleTitleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    setTitle(event.target.value);
  };

  return (
    <div>
      <CustomBreadcrumbs
        style={{ marginBottom: '30px' }}
        links={[
          {
            name: 'Tableau de bord',
            href: paths.dashboard.root,
          },
          {
            name: 'les bons d\'achats ',
            href: paths.purchase.root,

          },

          {
            name: 'Ajouter un bon d\'achat',
          },
        ]}
        sx={{
          mb: { xs: 2, md: 10 },
        }}
      />
      <Typography variant="h6" style={{ marginBottom: '10px' }}>Ajouter un nouveau modéle bon d'achat</Typography>
      <FormControl defaultValue=""></FormControl>
      <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: '40px' }}>
        <div style={{ width: '45%', padding: '20px', border: '1px solid #ccc', borderRadius: '8px' }}>
          <Typography variant="h6" style={{ marginBottom: '30px' }}>Personnaliser le bon d'achat</Typography>
          <FormControl defaultValue="">
            
            <input
              accept="image/*"
              id="contained-button-file"
              type="file"
              onChange={handleImageChange}
              style={{ display: 'none' }}
            />
             <AddMediaButton  variant="outlined" color="success" size="small" sx={{ mt: 1 , marginBottom: '40px' }}  />
              

            <TextField
              id="outlined-valeur-code"
              type="color"
              label="Couleur de la carte"
              variant="outlined"
              InputLabelProps={{ shrink: true }}
              value={cardColor}
              onChange={handleColorChange}
              style={{ marginBottom: '40px' }}
            />
            <TextField
              id="outlined-valeur-code"
              type="text"
              label="titre de la carte"
              variant="outlined"
              InputLabelProps={{ shrink: true }}
              value={title}
              onChange={handleTitleChange}
              style={{ marginBottom: '40px' }}
            />


          </FormControl>
        </div>
        <div style={{ width: '45%', padding: '20px', border: '1px solid #ccc', borderRadius: '8px' }}>
          <Typography variant="h6" style={{ marginBottom: '30px' }}>Prévisualisation</Typography>
          <Card variant="outlined" style={{ width: 320, marginBottom: '40px', backgroundColor: cardColor }}>

            <Typography variant="subtitle1" align="center" gutterBottom style={{ marginBottom: '15px' }}>
              {title}
            </Typography>
            <CardMedia
              component="img"
              height="140"
              image={image ? URL.createObjectURL(image) : 'https://img.freepik.com/free-photo/happy-birthday-card-with-flowers-assortment_23-2149077343.jpg'}
            />
            <CardContent>
              <Typography variant="body2" color="textSecondary" component="p">
                Légende: Légende par défaut
              </Typography>
              <Typography variant="body2" color="textSecondary" component="p">
                Description: Description par défaut
              </Typography>
              <Typography variant="body2" color="textSecondary" component="p">
                Montant: 50 €
              </Typography>
            </CardContent>
          </Card>
        </div>

      </div>
      <Button variant="contained" component="span" color='primary' style={{ marginBottom: '20px', marginLeft: '900px' }}>
        Enregistrer
      </Button>
    </div>
  );
};

export default PurchaseCard;
