// src/shared/sections/referral/Referral.tsx
import Grid from "@mui/material/Unstable_Grid2";
import Card from "@mui/material/Card";
import Stack from "@mui/material/Stack";
import CardHeader from "@mui/material/CardHeader";
import Typography from "@mui/material/Typography";
import Switch from "@mui/material/Switch";
import { useResponsive } from "@/hooks/use-responsive";
import FormProvider from "@/components/hook-form";
import FormControl from "@mui/material/FormControl";
import FormLabel from "@mui/material/FormLabel";
import React, { useCallback, useEffect } from "react";
import TextField from "@mui/material/TextField";
import MenuItem from "@mui/material/MenuItem";
import {
  getAllReferralPromoCodes,
  getReferralSettings,
  updateOrCreateReferralSettings,
} from "@/shared/api/referral"; // Importer la méthode
import { IReferralSettingsDTO } from "@/shared/types/referral"; // Importer le type

import InfoOutlinedIcon from "@mui/icons-material/InfoOutlined";
import LoadingButton from "@mui/lab/LoadingButton";
import { Alert, Snackbar } from "@mui/material";

type CheckboxStateKeys =
  | "referralProgramActivatedEnabled"
  | "ipVerificationEnabled"
  | "discountOnFirstPurchaseEnabled"
  | "couponAfterFirstPurchaseEnabled";

export default function Referral() {
  const mdUp = useResponsive("up", "md");
  const [checkboxStates, setCheckboxStates] = React.useState({
    id: null,
    referralProgramActivatedEnabled: false,
    ipVerificationEnabled: false,
    discountOnFirstPurchaseEnabled: false,
    couponAfterFirstPurchaseEnabled: false,
    promoCodeOnFirstPurchase: { id: 0, code: "" },
    promoCodeAfterFirstPurchase: { id: 0, code: "" },
    promoCodeOnFirstPurchaseForReferrer: { id: 0, code: "" },
    promoCodeAfterFirstPurchaseForReferrer: { id: 0, code: "" },
  });
  const [
    selectedPromoCodeOnFirstPurchase,
    setSelectedPromoCodeOnFirstPurchase,
  ] = React.useState("");
  const [
    selectedPromoCodeAfterFirstPurchase,
    setSelectedPromoCodeAfterFirstPurchase,
  ] = React.useState("");
  const [
    selectedPromoCodeOnFirstPurchaseForReferrer,
    setSelectedPromoCodeOnFirstPurchaseForReferrer,
  ] = React.useState("");
  const [
    selectedPromoCodeAfterFirstPurchaseForReferrer,
    setSelectedPromoCodeAfterFirstPurchaseForReferrer,
  ] = React.useState("");

  const [referralPromoCodes, setReferralPromoCodes] = React.useState<
    Array<{ id: number; code: string }>
  >([]);
  const [loading, setLoading] = React.useState(false);
  const [snackbarOpen, setSnackbarOpen] = React.useState(false);
  const [snackbarMessage, setSnackbarMessage] = React.useState("");

  const handleCheckboxChange = (name: CheckboxStateKeys) => {
    let newCheckboxStates = { ...checkboxStates };

    if (name === "referralProgramActivatedEnabled") {
      if (!checkboxStates.referralProgramActivatedEnabled) {
        newCheckboxStates = {
          ...newCheckboxStates,
          referralProgramActivatedEnabled: true,
          ipVerificationEnabled: false,
          discountOnFirstPurchaseEnabled: false,
          couponAfterFirstPurchaseEnabled: false,
        };
      } else {
        newCheckboxStates.referralProgramActivatedEnabled = false;
      }
    } else {
      newCheckboxStates = {
        ...newCheckboxStates,
        [name]: !checkboxStates[name],
      };
    }
    setCheckboxStates(newCheckboxStates);
  };

  const getPromosCode = useCallback(async () => {
    const promoCodes = await getAllReferralPromoCodes();
    setReferralPromoCodes(promoCodes);
  }, []);

  const fetchReferralSettings = useCallback(async () => {
    try {
      const settings = await getReferralSettings();
      setCheckboxStates({
        id: settings.id,
        referralProgramActivatedEnabled: settings.referralProgramActivatedEnabled,
        ipVerificationEnabled: settings.ipVerificationEnabled,
        discountOnFirstPurchaseEnabled: settings.discountOnFirstPurchaseEnabled,
        couponAfterFirstPurchaseEnabled: settings.couponAfterFirstPurchaseEnabled,
        promoCodeOnFirstPurchase: settings.promoCodeOnFirstPurchase || {
          id: 0,
          code: "",
        },
        promoCodeAfterFirstPurchase: settings.promoCodeAfterFirstPurchase || {
          id: 0,
          code: "",
        },
        promoCodeOnFirstPurchaseForReferrer:
          settings.promoCodeOnFirstPurchaseForReferrer || { id: 0, code: "" },
        promoCodeAfterFirstPurchaseForReferrer:
          settings.promoCodeAfterFirstPurchaseForReferrer || {
            id: 0,
            code: "",
          },
      });

      if (settings.promoCodeOnFirstPurchase?.code) {
        setSelectedPromoCodeOnFirstPurchase(
          settings.promoCodeOnFirstPurchase.code
        );
      }
      if (settings.promoCodeAfterFirstPurchase?.code) {
        setSelectedPromoCodeAfterFirstPurchase(
          settings.promoCodeAfterFirstPurchase.code
        );
      }
      if (settings.promoCodeOnFirstPurchaseForReferrer?.code) {
        setSelectedPromoCodeOnFirstPurchaseForReferrer(
          settings.promoCodeOnFirstPurchaseForReferrer.code
        );
      }
      if (settings.promoCodeAfterFirstPurchaseForReferrer?.code) {
        setSelectedPromoCodeAfterFirstPurchaseForReferrer(
          settings.promoCodeAfterFirstPurchaseForReferrer.code
        );
      }
    } catch (error) {
      console.error("Failed to fetch referral settings:", error);
    }
  }, []);

  useEffect(() => {
    fetchReferralSettings();
    getPromosCode();
  }, []);
  const handleSave = async () => {
    setLoading(true);
    const referralSettingsDTO: IReferralSettingsDTO = {
      id: checkboxStates.id,
      referralProgramActivatedEnabled: checkboxStates.referralProgramActivatedEnabled,
      ipVerificationEnabled: checkboxStates.ipVerificationEnabled,
      discountOnFirstPurchaseEnabled: checkboxStates.discountOnFirstPurchaseEnabled,
      couponAfterFirstPurchaseEnabled: checkboxStates.couponAfterFirstPurchaseEnabled,
      promoCodeOnFirstPurchase: referralPromoCodes.find(
        (promoCode) => promoCode.code === selectedPromoCodeOnFirstPurchase
      ) || { id: 0, code: "" },
      promoCodeAfterFirstPurchase: referralPromoCodes.find(
        (promoCode) => promoCode.code === selectedPromoCodeAfterFirstPurchase
      ) || { id: 0, code: "" },
      promoCodeOnFirstPurchaseForReferrer: referralPromoCodes.find(
        (promoCode) =>
          promoCode.code === selectedPromoCodeOnFirstPurchaseForReferrer
      ) || { id: 0, code: "" },
      promoCodeAfterFirstPurchaseForReferrer: referralPromoCodes.find(
        (promoCode) =>
          promoCode.code === selectedPromoCodeAfterFirstPurchaseForReferrer
      ) || { id: 0, code: "" },
    };

    try {
      await updateOrCreateReferralSettings(referralSettingsDTO);
      fetchReferralSettings();
      setSnackbarMessage(
        "Les paramètres ont été enregistrés avec succès !"
      );
      setSnackbarOpen(true);
    } catch (error) {
      console.error("Erreur lors de la mise à jour :", error);
    } finally {
      setLoading(false); // Cacher le loader une fois l'opération terminée
    }
  };

  const handlePromoCodeChange = (
    fieldName: string,
    e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>
  ) => {
    const { value } = e.target;

    // Mettre à jour l'état local sans envoyer la requête immédiatement
    switch (fieldName) {
      case "promoCodeOnFirstPurchase":
        setSelectedPromoCodeOnFirstPurchase(value);
        break;
      case "promoCodeAfterFirstPurchase":
        setSelectedPromoCodeAfterFirstPurchase(value);
        break;
      case "promoCodeOnFirstPurchaseForReferrer":
        setSelectedPromoCodeOnFirstPurchaseForReferrer(value);
        break;
      case "promoCodeAfterFirstPurchaseForReferrer":
        setSelectedPromoCodeAfterFirstPurchaseForReferrer(value);
        break;
      default:
        break;
    }
  };

  const renderBasic = (
    <>
      {mdUp && (
        <Grid md={4} sx={{ marginTop: "70px" }}>
          <Typography variant="h6" sx={{ mb: 0.5 }}>
            Parrainage
          </Typography>
          <Typography variant="body2" sx={{ color: "text.secondary" }}>
            Configuration des règles de parrainage pour récompenser les parrains
            et les parrainés
          </Typography>
        </Grid>
      )}

      <Grid xs={12} md={8} sx={{ marginTop: "70px" }}>
        <Card>
          {!mdUp && <CardHeader title="Nouvelle règle de parrainage" />}

          <Stack spacing={3} sx={{ p: 4 }}>
            <FormControl>
              <FormLabel
                id="referral-switch-label"
                sx={{ mb: 1, fontWeight: "bold" }}
              >
                Activation du programme de parrainage
              </FormLabel>
              <Stack direction="row" alignItems="center" spacing={1}>
                <Switch
                  checked={checkboxStates.referralProgramActivatedEnabled}
                  onChange={() =>
                    handleCheckboxChange("referralProgramActivatedEnabled")
                  }
                  inputProps={{ "aria-label": "controlled" }}
                />
                <Typography variant="body1">
                  Activer le programme de parrainage
                </Typography>
              </Stack>
            </FormControl>

            {checkboxStates.referralProgramActivatedEnabled && (
              <FormControl>
                <Stack spacing={1}>
                  <FormControl>
                    <FormLabel
                      id="reward-type-label"
                      sx={{ mb: 1, fontWeight: "bold" }}
                    >
                      Vérification IP contre les fraudes
                    </FormLabel>
                    <Stack direction="row" alignItems="center" spacing={1}>
                      <Switch
                        checked={checkboxStates.ipVerificationEnabled}
                        onChange={() =>
                          handleCheckboxChange("ipVerificationEnabled")
                        }
                        inputProps={{ "aria-label": "controlled" }}
                      />
                      <Typography variant="body1">
                        Activer la vérification IP pour éviter les fraudes
                      </Typography>
                    </Stack>
                  </FormControl>

                  <FormControl>
                    <FormLabel
                      id="reward-type-label"
                      sx={{ mb: 1, fontWeight: "bold" }}
                    >
                      Type de récompense pour les parrainés
                    </FormLabel>
                    <Stack spacing={1}>
                      <Stack direction="row" alignItems="center" spacing={1}>
                        <Switch
                          checked={checkboxStates.discountOnFirstPurchaseEnabled}
                          onChange={() =>
                            setCheckboxStates((prevState) => ({
                              ...prevState,
                              discountOnFirstPurchaseEnabled: true,
                              couponAfterFirstPurchaseEnabled: false,
                            }))
                          }
                          inputProps={{ "aria-label": "controlled" }}
                        />
                        <Typography variant="body1">
                          Remise sur le premier achat
                        </Typography>
                      </Stack>
                      <Stack direction="row" alignItems="center" spacing={1}>
                        <Switch
                          checked={
                            checkboxStates.couponAfterFirstPurchaseEnabled
                          }
                          onChange={() =>
                            setCheckboxStates((prevState) => ({
                              ...prevState,
                              couponAfterFirstPurchaseEnabled: true,
                              discountOnFirstPurchaseEnabled: false,
                            }))
                          }
                          inputProps={{ "aria-label": "controlled" }}
                        />
                        <Typography variant="body1">
                          Coupon après le premier achat
                        </Typography>
                      </Stack>
                    </Stack>
                  </FormControl>
                </Stack>
              </FormControl>
            )}
          </Stack>
        </Card>
      </Grid>

      {checkboxStates.discountOnFirstPurchaseEnabled &&
        checkboxStates.referralProgramActivatedEnabled && (
          <Grid xs={12} md={10} sx={{ width: "80%", mt: 4 }}>
            <Card>
              <Stack spacing={2} sx={{ p: 4 }}>
                <FormControl fullWidth>
                  <Typography
                    variant="h6"
                    sx={{
                      fontWeight: "bold",
                      textAlign: "left",
                      mb: 2,
                    }}
                  >
                    Remise sur le premier achat
                  </Typography>
                  <Typography
                    variant="caption"
                    sx={{
                      color: "red",
                      mb: 2,
                      display: "flex",
                      alignItems: "center", // Alignement vertical
                      textAlign: "left",
                      fontSize: "0.9rem", // Ajustement de la taille
                    }}
                  >
                    <InfoOutlinedIcon
                      sx={{
                        color: "red",
                        fontSize: "1rem", // Même taille que le texte
                        mr: 0.5, // Marge à droite pour espacer l'icône du texte
                      }}
                    />
                    Ce coupon sera automatiquement appliqué au premier achat de
                    l'utilisateur référé.
                  </Typography>

                  <Typography
                    variant="body2"
                    color="text.secondary"
                    sx={{
                      mb: 3,
                      lineHeight: 1.6,
                      fontSize: "0.9rem",
                    }}
                  >
                    Page des coupons : créez manuellement un coupon en
                    choisissant les options que vous souhaitez. Assurez-vous
                    qu'il n'y a pas de limite ou de restriction par e-mail.
                    Ensuite, sélectionnez le code promo dans la liste ci-dessous
                  </Typography>
                  <FormControl
                    variant="outlined"
                    fullWidth
                    sx={{ maxWidth: "400px", mb: 3 }}
                  >
                    <TextField
                      id="select-discount-type"
                      select
                      label="Choisissez un coupon pour le parrainé"
                      InputLabelProps={{ shrink: true }}
                      value={selectedPromoCodeOnFirstPurchase}
                      onChange={(e) =>
                        handlePromoCodeChange("promoCodeOnFirstPurchase", e)
                      }
                    >
                      {referralPromoCodes.map((promoCode) => (
                        <MenuItem key={promoCode.id} value={promoCode.code}>
                          {promoCode.code}
                        </MenuItem>
                      ))}
                    </TextField>
                  </FormControl>
                  <FormControl
                    variant="outlined"
                    fullWidth
                    sx={{ maxWidth: "400px", mb: 3 }}
                  >
                    <TextField
                      id="select-discount-type"
                      select
                      label="Choisissez un coupon pour le parrain"
                      InputLabelProps={{
                        shrink: true,
                      }}
                      value={selectedPromoCodeOnFirstPurchaseForReferrer}
                      onChange={(e) =>
                        handlePromoCodeChange(
                          "promoCodeOnFirstPurchaseForReferrer",
                          e
                        )
                      }
                    >
                      {referralPromoCodes.map((promoCode) => (
                        <MenuItem key={promoCode.id} value={promoCode.code}>
                          {promoCode.code}
                        </MenuItem>
                      ))}
                    </TextField>
                  </FormControl>
                </FormControl>
              </Stack>
            </Card>
          </Grid>
        )}

      {checkboxStates.couponAfterFirstPurchaseEnabled &&
        checkboxStates.referralProgramActivatedEnabled && (
          <Grid xs={12} md={10} sx={{ width: "80%" }}>
            <Card>
              <Stack spacing={2} sx={{ p: 3 }}>
                <FormControl defaultValue="">
                  <Typography
                    variant="h6"
                    sx={{
                      fontWeight: "bold",
                      textAlign: "left",
                      mb: 2,
                    }}
                  >
                    Coupon après le premier achat
                  </Typography>
                  <Typography
                    variant="caption"
                    sx={{
                      color: "red",
                      mb: 2,
                      display: "flex", // Utilisation de flex pour aligner
                      alignItems: "center", // Alignement vertical
                      textAlign: "left",
                      fontSize: "0.9rem", // Ajustement de la taille
                    }}
                  >
                    <InfoOutlinedIcon
                      sx={{
                        color: "red",
                        fontSize: "1rem", // Même taille que le texte
                        mr: 0.5, // Marge à droite pour espacer l'icône du texte
                      }}
                    />
                    ce coupon sera envoyé une fois que l'utilisateur référé aura
                    effectué un achat et que la commande sera marquée comme
                    terminée.
                  </Typography>
                  <Typography
                    variant="body2"
                    color="text.secondary"
                    sx={{
                      mb: 3,
                      lineHeight: 1.6,
                      fontSize: "0.9rem",
                    }}
                  >
                    Sélectionnez le code promo dans la liste ci-dessous
                  </Typography>
                  <FormControl
                    variant="outlined"
                    fullWidth
                    sx={{ maxWidth: "400px", mb: 3 }}
                  >
                    <TextField
                      id="select-coupon-after-first-purchase"
                      select
                      label="Choisissez un coupon pour le parrainé"
                      InputLabelProps={{
                        shrink: true,
                      }}
                      value={selectedPromoCodeAfterFirstPurchase}
                      onChange={(e) =>
                        handlePromoCodeChange("promoCodeAfterFirstPurchase", e)
                      }
                    >
                      {referralPromoCodes.map((promoCode) => (
                        <MenuItem key={promoCode.id} value={promoCode.code}>
                          {promoCode.code}
                        </MenuItem>
                      ))}
                    </TextField>
                  </FormControl>
                  <FormControl
                    variant="outlined"
                    fullWidth
                    sx={{ maxWidth: "400px", mb: 3 }}
                  >
                    <TextField
                      id="select-coupon-after-first-purchase"
                      select
                      label="Choisissez un coupon pour le parrain"
                      InputLabelProps={{
                        shrink: true,
                      }}
                      value={selectedPromoCodeAfterFirstPurchaseForReferrer}
                      onChange={(e) =>
                        handlePromoCodeChange(
                          "promoCodeAfterFirstPurchaseForReferrer",
                          e
                        )
                      } // Passer l'identifiant du champ
                    >
                      {referralPromoCodes.map((promoCode) => (
                        <MenuItem key={promoCode.id} value={promoCode.code}>
                          {promoCode.code}
                        </MenuItem>
                      ))}
                    </TextField>
                  </FormControl>
                </FormControl>
              </Stack>
            </Card>
          </Grid>
        )}
    </>
  );

  const renderActions = (
    <>
      {mdUp && <Grid md={4} />}
      <Grid
        xs={12}
        md={8}
        sx={{ display: "flex", justifyContent: "end", py: 4 }}
      >
        <LoadingButton
          onClick={handleSave}
          variant="contained"
          size="large"
          sx={{ ml: 2 }}
          loading={loading}
        >
          Enregistrer les modifications
        </LoadingButton>
      </Grid>
    </>
  );

  return (
    <Grid container spacing={3}>
      {renderBasic}
      {renderActions}
      <Snackbar
        open={snackbarOpen}
        autoHideDuration={3000} // Il se ferme après 4 secondes
        onClose={() => setSnackbarOpen(false)} 
        anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
      >
        <Alert
          onClose={() => setSnackbarOpen(false)}
          severity="success"
          sx={{ width: "100%" }}
        >
          {snackbarMessage}
        </Alert>
      </Snackbar>
    </Grid>
  );
}