"use client";

import Grid from "@mui/material/Unstable_Grid2";
import Card from "@mui/material/Card";
import Stack from "@mui/material/Stack";
import Typography from "@mui/material/Typography";
import Switch from "@mui/material/Switch";
import FormControl from "@mui/material/FormControl";
import FormLabel from "@mui/material/FormLabel";
import TextField from "@mui/material/TextField";
import { useEffect, useState } from "react";

// Import des icônes
import FacebookIcon from "@mui/icons-material/Facebook";
import InstagramIcon from "@mui/icons-material/Instagram";
import WhatsAppIcon from "@mui/icons-material/WhatsApp";
import XIcon from "@mui/icons-material/X";
import { ReferralShareSettingsDTO } from "@/shared/types/referral";
import {
  getReferralShareSettings,
  updateOrCreateReferralShareSettings,
} from "@/shared/api/referral";
import LoadingButton from "@mui/lab/LoadingButton";
import { Alert, Snackbar } from "@mui/material";

export default function RewardBox() {
  const [isLoading, setIsLoading] = useState(false); // État pour gérer le chargement

  const [formValues, setFormValues] = useState<ReferralShareSettingsDTO>({
    id: 0,
    message: "vous recevrez",
    shareViaFacebookEnabled: false,
    shareViaInstagramEnabled: false,
    shareViaTwitterEnabled: false,
    shareViaWhatsappEnabled: false,
  });

  // Fonction pour récupérer les paramètres existants
  const fetchReferralSettings = async () => {
    try {
      const settings = await getReferralShareSettings();
      setFormValues({
        id: settings.id,
        message: settings.message,
        shareViaFacebookEnabled: settings.shareViaFacebookEnabled,
        shareViaTwitterEnabled: settings.shareViaTwitterEnabled,
        shareViaInstagramEnabled: settings.shareViaInstagramEnabled,
        shareViaWhatsappEnabled: settings.shareViaWhatsappEnabled,
      });
    } catch (error) {
      console.error("Erreur lors de la récupération des paramètres :", error);
    }
  };
  const [openSnackbar, setOpenSnackbar] = useState(false);
  // Appeler les paramètres existants au montage
  useEffect(() => {
    fetchReferralSettings();
  }, []);

  const handleSave = async () => {
    setIsLoading(true); // Démarrer le chargement
    try {
      await updateOrCreateReferralShareSettings(formValues);
      fetchReferralSettings();
      setOpenSnackbar(true);
    } catch (error) {
      console.error("Erreur lors de la mise à jour :", error);
    } finally {
      setIsLoading(false);
    }
  };

  const handleChange = (
    field: keyof ReferralShareSettingsDTO,
    value: boolean | string
  ) => {
    const updatedValues = {
      ...formValues,
      [field]: value,
    };
    setFormValues(updatedValues);
  };

  const renderBasic = (
    <>
      <Grid md={4} sx={{ marginTop: "70px" }}>
        <Typography variant="h6" sx={{ mb: 0.5 }}>
          Boîte de récompense
        </Typography>
        <Typography variant="body2" sx={{ color: "text.secondary" }}>
          Paramètres pour afficher les récompenses sous forme de coupons.
        </Typography>
      </Grid>

      <Grid xs={12} md={8} sx={{ marginTop: "70px" }}>
        <Card>
          <Stack spacing={3} sx={{ p: 3 }}>
            <FormLabel id="referral-switch-label" sx={{ fontWeight: "bold" }}>
              Partager via
            </FormLabel>

            {/* Facebook */}
            <div
              style={{
                display: "flex",
                alignItems: "center",
                gap: "8px",
                color: "#1877F2",
              }}
            >
              <Switch
                checked={formValues.shareViaFacebookEnabled}
                onChange={(e) =>
                  handleChange("shareViaFacebookEnabled", e.target.checked)
                }
              />
              <FacebookIcon fontSize="large" />
              <Typography sx={{ color: "#1877F2" }}>Facebook</Typography>
            </div>

            {/* Twitter */}
            <div
              style={{
                display: "flex",
                alignItems: "center",
                gap: "8px",
                color: "#000000",
              }}
            >
              <Switch
                checked={formValues.shareViaTwitterEnabled}
                onChange={(e) =>
                  handleChange("shareViaTwitterEnabled", e.target.checked)
                }
              />
              <XIcon fontSize="large" />
              <Typography sx={{ color: "#000000" }}>Twitter</Typography>
            </div>

            {/* Instagram */}
            <div
              style={{
                display: "flex",
                alignItems: "center",
                gap: "8px",
                color: "#C13584",
              }}
            >
              <Switch
                checked={formValues.shareViaInstagramEnabled}
                onChange={(e) =>
                  handleChange("shareViaInstagramEnabled", e.target.checked)
                }
              />
              <InstagramIcon fontSize="large" />
              <Typography sx={{ color: "#C13584" }}>Instagram</Typography>
            </div>

            {/* WhatsApp */}
            <div
              style={{
                display: "flex",
                alignItems: "center",
                gap: "8px",
                color: "#25D366",
              }}
            >
              <Switch
                checked={formValues.shareViaWhatsappEnabled}
                onChange={(e) =>
                  handleChange("shareViaWhatsappEnabled", e.target.checked)
                }
              />
              <WhatsAppIcon fontSize="large" />
              <Typography sx={{ color: "#25D366" }}>WhatsApp</Typography>
            </div>
          </Stack>
        </Card>
      </Grid>

      <Grid xs={12} md={12}>
        <Card>
          <Stack spacing={2} sx={{ p: 3 }}>
            <FormControl>
              <Typography
                variant="h6"
                sx={{ fontWeight: "bold", textAlign: "left", mb: 2 }}
              >
                Boîte de récompense
              </Typography>
              <FormLabel style={{ marginBottom: "5px" }}>
                Le message à afficher dans le checkout
              </FormLabel>
              <TextField
                value={formValues.message}
                onChange={(e) => handleChange("message", e.target.value)}
              />
            </FormControl>
            <Stack direction="row" sx={{ justifyContent: "flex-end", mt: 2 }}>
              <LoadingButton
                loading={isLoading}
                onClick={handleSave}
                variant="contained"
                sx={{ ml: 2 }}
              >
                Enregistrer les modifications
              </LoadingButton>
            </Stack>
          </Stack>
        </Card>
      </Grid>
  
    </>
  );

  return (
    <Grid container spacing={3}>
      {formValues.id !== null ? (
        <>
        {renderBasic}

         <Snackbar
        open={openSnackbar}
        autoHideDuration={3000} 
        anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
        onClose={() => setOpenSnackbar(false)} // Fermer la Snackbar
      >
        <Alert onClose={() => setOpenSnackbar(false)} severity="success" sx={{ width: "100%" }}>
          Paramètres sauvegardés avec succès !
        </Alert>
      </Snackbar>
      </>
      ) : (
        <Typography>Chargement...</Typography>
      )}
    </Grid>
  );
}
