'use client';

import { useState, useCallback } from 'react';
import Tab from '@mui/material/Tab';
import Tabs from '@mui/material/Tabs';
import Container from '@mui/material/Container';
import { _userAbout, _userPlans, _userPayment, _userInvoices, _userAddressBook } from '@/shared/_mock';
import { useSettingsContext } from '@/components/settings';
import OrderColissimoListView from './orders/OrderColissimoListView';
import ColisColissimoTableView from './colis/ColisColissimoTableView';
import HistoricBordereauColissimoTableView from './historicBordereau/HistoricBordereauColissimoTableView';
import ConfigVendorCOView from './vendor/ConfigVendorCOView';

const TABS = [
  {
    value: '1',
    label: 'Vendeur',
  },
  {
    value: '2',
    label: 'Commandes',
  },
  {
    value: '3',
    label: "Colis",
  },
  {
    value: '4',
    label: 'Historiques des bordereaux',
  },
];

interface ShippingMainViewProps {
  defaultValue?: string;
}

export default function ColissimoMainView({ defaultValue }: ShippingMainViewProps) {
  const settings = useSettingsContext();

  const [currentTab, setCurrentTab] = useState<string>(defaultValue || '1');

  const handleChangeTab = useCallback((event: React.SyntheticEvent, newValue: string) => {
    setCurrentTab(newValue);
  }, []);

  return (
    <Container maxWidth={settings.themeStretch ? false : 'lg'}>

      <Tabs
        value={currentTab}
        onChange={handleChangeTab}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      >
        {TABS.map((tab) => (
          <Tab key={tab?.value} label={tab?.label} value={tab?.value} />
        ))}
      </Tabs>

      {currentTab === '1' && <ConfigVendorCOView />}

      {currentTab === '2' && <OrderColissimoListView />}

      {currentTab === '3' && <ColisColissimoTableView />}

      {currentTab === '4' && <HistoricBordereauColissimoTableView />}

    </Container>
  );
}
