'use client';

import { useState, useCallback } from 'react';
import Card from '@mui/material/Card';
import Table from '@mui/material/Table';
import Grid from '@mui/material/Grid';
import Container from '@mui/material/Container';
import TableBody from '@mui/material/TableBody';
import { useTheme } from '@mui/material/styles';
import TableContainer from '@mui/material/TableContainer';
import LocalizationProvider from '@/shared/locales/localization-provider';
import { paths } from '@/routes/paths';
import { TableHeadCustom } from '@/shared/components/table';
import { useRouter } from '@/hooks';
import { useBoolean } from '@/hooks';
import { historicBordereauColissimoList } from '@/shared/_mock/_shipping';
import Scrollbar from '@/shared/components/scrollbar';
import { useSnackbar } from '@/components/snackbar';
import { useSettingsContext } from '@/shared/components/settings';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs';
import { useTable, emptyRows, TableNoData, TablePaginationCustom, TableEmptyRows, } from '@/shared/components/table';
import { IHistoricBordereauColissimoItem } from '@/contexts/types/Shipping';
import HistoricBordereauColissimoTableRow from './HistoricBordereauColissimoTableRow';

const TABLE_HEAD = [
  { id: "id", label: "Bordereau ID", width: 150 },
  { id: "colisNumber", label: "Nombre de colis", with: 150 },
  { id: "orderIds", label: "IDs de commande", width: 250, align: "left" },
  { id: "trackingNumber", label: "Numéro de suivi", width: 250, align: "left" },
  { id: "createdAt", label: "Date de création", width: 150 },
  { id: "", width: 100 },
];


export default function HistoricBordereauColissimoTableView() {

  const settings = useSettingsContext();
  const table = useTable({ defaultOrderBy: 'id' });
  const [tableData, setTableData] = useState<IHistoricBordereauColissimoItem[]>(historicBordereauColissimoList);

  const denseHeight = table.dense ? 56 : 56 + 20;
  const notFound = (!tableData.length) || !tableData.length;

  const [selectedHistoricItem, setSelectedHistoricItem] = useState<IHistoricBordereauColissimoItem | null>(null);
  const handelSelectedHistoricItem = (historicItem: any) => {
    setSelectedHistoricItem(historicItem);
  };
  const handleViewRow = useCallback(
    (id: string) => {
      const historicItem = tableData.find((h) => h.id === id);
      handelSelectedHistoricItem(historicItem)
    },
    [tableData]
  );

  return (
    <>
      <LocalizationProvider >
        <Container maxWidth={settings.themeStretch ? false : 'lg'}>
          <Grid container alignItems="center" justifyContent="space-between">
            <CustomBreadcrumbs
              heading="Historique des bordereaux"
              links={[
                { name: 'Dashboard', href: paths.dashboard.root, },
                { name: 'Livraison', href: paths.dashboard.admin.shipping.general.root, },
                { name: "Colissimo", }
              ]}
              sx={{
                mb: { xs: 3, md: 5 },
              }}
            />
          </Grid>

          <Card>
            <TableContainer sx={{ position: 'relative', overflow: 'unset' }}>
              <Scrollbar>
                <Table size={table.dense ? 'small' : 'medium'} sx={{ minWidth: 800 }}>
                  <TableHeadCustom
                    order={table.order}
                    orderBy={table.orderBy}
                    headLabel={TABLE_HEAD}
                    rowCount={tableData.length}
                    onSort={table.onSort}
                  />
                  <TableBody>
                    {tableData
                      .slice(
                        table.page * table.rowsPerPage,
                        table.page * table.rowsPerPage + table.rowsPerPage
                      )
                      .map((row, index) => (
                        <HistoricBordereauColissimoTableRow
                          key={row.id}
                          row={row}
                          selected={table.selected.includes(row.id)}
                          onSelectRow={() => table.onSelectRow(row.id)}
                          onViewRow={() => handleViewRow(row.id)}
                          selectedHistoricItem={selectedHistoricItem}
                        />
                      ))}

                    <TableEmptyRows
                      height={denseHeight}
                      emptyRows={emptyRows(table.page, table.rowsPerPage, tableData.length)}
                    />

                    <TableNoData notFound={notFound} />
                  </TableBody>

                </Table>
              </Scrollbar>
            </TableContainer>

            <TablePaginationCustom
              count={tableData.length}
              page={table.page}
              rowsPerPage={table.rowsPerPage}
              onPageChange={table.onChangePage}
              onRowsPerPageChange={table.onChangeRowsPerPage}
              dense={table.dense}
              onChangeDense={table.onChangeDense}
            />
          </Card>
        </Container>
      </LocalizationProvider>
    </>

  );
}
