"use client"

import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Chip from '@mui/material/Chip';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider, {
    RHFTextField,
    RHFAutocomplete,
} from '@/components/hook-form';
import LoadingButton from '@mui/lab/LoadingButton';
import { countries } from '@/shared/assets/data/countries'
import { Box, FormControl, IconButton, InputAdornment, InputLabel, MenuItem, OutlinedInput, Select } from '@mui/material';
import { Visibility, VisibilityOff } from '@mui/icons-material';
import { useState } from 'react';


const languagesColissimo = [
    { value: "fr_FR", label: "Français" },
    { value: "de_DE", label: "Allemand" },
    { value: "en_GB", label: "Anglais" },
    { value: "es_ES", label: "Espagnol" },
    { value: "it_IT", label: "Italien" },
    { value: "nl_NL", label: "Néerlandais" }
];

export default function ConfigVendorCOView() {

    const mdUp = useResponsive('up', 'md');
    const { enqueueSnackbar } = useSnackbar();

    const NewShippingMethodSchema = Yup.object().shape({
        expediteur: Yup.string().required('Ce champ est requis'),
        rue: Yup.string().required('Ce champ est requis'),
        codePostal: Yup.string().required('Ce champ est requis'),
        ville: Yup.string().required('Ce champ est requis'),
        country: Yup.string().required('Ce champ est requis'),
        phone1: Yup.string().required('Ce champ est requis'),
        phone2: Yup.string(),
        contractNumber: Yup.string(),
        accountPassword: Yup.string(),
        mail: Yup.string().email('Veuillez saisir une adresse e-mail valide').required('Ce champ est requis'),
    });

    const methods = useForm({
        resolver: yupResolver(NewShippingMethodSchema),
    });

    const {
        reset,
        handleSubmit,
        formState: { isSubmitting },
    } = methods;

    const onSubmit = handleSubmit(async (data) => {
        try {
            await new Promise((resolve) => setTimeout(resolve, 500));
            reset();
            enqueueSnackbar('Config success!', { variant: 'success' });
            console.info('Form Data:', data);
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Failed to configure vendeur.', { variant: 'error' });
        }
    });

    const [showPassword, setShowPassword] = useState(false);

    const handleClickShowPassword = () => setShowPassword((show) => !show);

    const handleMouseDownPassword = (event: React.MouseEvent<HTMLButtonElement>) => {
        event.preventDefault();
    };

    const renderShipper = (
        <>
            <Grid xs={12} md={12}>
                <Card>
                    <CardHeader title="Coordonnées d'expédition" />
                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Box display="flex" flexDirection="column" alignItems="flex-start">
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="companyName" label="Nom de l'entreprise" />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="lastName" label="Nom de famille" />
                                <RHFTextField name="firstName" label="Prénom" sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="line0" label="Ligne d'adresse 0" />
                                <RHFTextField name="line1" label="Ligne d'adresse 1" sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="line2" label="Ligne d'adresse 2" />
                                <RHFTextField name="line3" label="Ligne d'adresse 3" sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFAutocomplete
                                    name="countryCode"
                                    label="Pays"
                                    placeholder="+ Pays"
                                    sx={{ width: "70vh" }}
                                    freeSolo
                                    disableCloseOnSelect
                                    options={countries.map(country => country.label)}
                                    getOptionLabel={(option) => option}
                                    renderOption={(props, option) => (
                                        <li {...props} key={option}>
                                            {option}
                                        </li>
                                    )}
                                    renderTags={(selected, getTagProps) =>
                                        selected.map((option, index) => (
                                            <Chip
                                                {...getTagProps({ index })}
                                                key={option}
                                                label={option}
                                                size="small"
                                                color="success"
                                                variant="soft"
                                            />
                                        ))
                                    }
                                />
                                <RHFTextField name="city" label="Ville" sx={{ ml: 2, width: "50vh" }} />
                                <RHFTextField name="zipCode" label="Code Postal" sx={{ ml: 2, width: "30vh" }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="phoneNumber" label="Téléphone" type='number' />
                                <RHFTextField name="mobileNumber" label="Téléphone 2" type='number' sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="doorCode1" label="Code de porte 1" />
                                <RHFTextField name="doorCode2" label="Code de porte 2" sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="email" label="Adresse e-mail" type='email' />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="intercom" label="Interphone" />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <FormControl sx={{ width: "70vh" }}>
                                    <InputLabel id="language-label">Langue</InputLabel>
                                    <Select
                                        labelId="language-label"
                                        name="language"
                                        label="Langue"
                                        defaultValue="fr_FR"
                                    >
                                        {languagesColissimo.map((language) => (
                                            <MenuItem key={language.value} value={language.value}>
                                                {language.label}
                                            </MenuItem>
                                        ))}
                                    </Select>
                                </FormControl>
                                <RHFTextField name="stateOrProvinceCode" label="Code de l'état ou de la province" sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="contractNumber" label="Numéro de contrat" sx={{ width: "50%" }} />
                                <FormControl variant="outlined" sx={{width: '50%', ml: 2}}>
                                    <InputLabel htmlFor="outlined-adornment-password">Password</InputLabel>
                                    <OutlinedInput
                                        id="outlined-adornment-password"
                                        type={showPassword ? 'text' : 'password'}
                                        endAdornment={
                                            <InputAdornment position="end">
                                                <IconButton
                                                    aria-label="toggle password visibility"
                                                    onClick={handleClickShowPassword}
                                                    onMouseDown={handleMouseDownPassword}
                                                    edge="end"
                                                >
                                                    {showPassword ? <VisibilityOff /> : <Visibility />}
                                                </IconButton>
                                            </InputAdornment>
                                        }
                                        label="Password"
                                    />
                                </FormControl>
                            </Box>
                        </Box>
                    </Stack>
                </Card>
            </Grid>
        </>
    );


    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );


    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderShipper}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
