'use client';

import { useState, useCallback } from 'react';
import Tab from '@mui/material/Tab';
import Tabs from '@mui/material/Tabs';
import Container from '@mui/material/Container';
import { useSettingsContext } from '@/components/settings';
import ShippingMethodTableView from './shippingMethod/list/ShippingMethodTableView';
import ShippingAreaTableView from './shippingAreas/ShippingAreaTableView';
import DeliveryRulesView from './deliveryRules/DeliveryRulesView';
import ShippingClassTableView from './shippingClass/ShippingClassTableView';

const TABS = [
  {
    value: '1',
    label: 'Méthodes de livraison',
  },
  {
    value: '2',
    label: "Zones d'expédition",
  },
  {
    value: '3',
    label: 'Régles de livraison',
  },
  {
    value: '4',
    label: "Classes d'expédition",
  },
];


interface ShippingMainViewProps {
  defaultValue?: string;
}

export default function ShippingMainView({ defaultValue }: ShippingMainViewProps) {
  const settings = useSettingsContext();

  const [currentTab, setCurrentTab] = useState<string>(defaultValue || '1');

  const handleChangeTab = useCallback((event: React.SyntheticEvent, newValue: string) => {
    setCurrentTab(newValue);
  }, []);

  return (
    <Container maxWidth={settings.themeStretch ? false : 'lg'}>

      <Tabs
        value={currentTab}
        onChange={handleChangeTab}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      >
        {TABS.map((tab) => (
          <Tab key={tab?.value} label={tab?.label} value={tab?.value} />
        ))}
      </Tabs>

      {currentTab === '1' && <ShippingMethodTableView />}

      {currentTab === '2' && <ShippingAreaTableView />}

      {currentTab === '3' && <DeliveryRulesView />}

      {currentTab === '4' && <ShippingClassTableView />}

    </Container>
  );
}
