import Button from '@mui/material/Button';
import MenuItem from '@mui/material/MenuItem';
import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import IconButton from '@mui/material/IconButton';
import { useBoolean } from '@/hooks';
import Iconify from '@/shared/components/iconify';
import ConfirmDialog from '@/shared/components/confirm-dialog';
import CustomPopover, { usePopover } from '@/shared/components/custom-popover';
import { ShippingClass } from '@/contexts/types/Shipping';
import React from 'react';

type Props = {
  row: ShippingClass;
  onViewRow: VoidFunction;
  onEditRow: VoidFunction;
  onDeleteRow: VoidFunction;
};

export default function ShippingClassTableRow({
  row,
  onViewRow,
  onEditRow,
  onDeleteRow,
}: Props) {
  const { name, code, description } = row;
  const confirm = useBoolean();
  const popover = usePopover();

  return (
    <>
      <TableRow hover onClick={() => { onViewRow(); }} sx={{ width: '100%' }}>
        <TableCell sx={{ width: '300px' }}> {name} </TableCell>

        <TableCell sx={{ width: '170px' }}>{code}</TableCell>

        <TableCell sx={{ width: '350px' }}>{description}</TableCell>

        <TableCell sx={{ display: 'flex', justifyContent: 'flex-end', alignItems: 'center', px: 1, textAlign: 'right' }}>
          <IconButton color={popover.open ? 'inherit' : 'default'} onClick={popover.onOpen}>
            <Iconify icon="eva:more-vertical-fill" />
          </IconButton>
        </TableCell>

      </TableRow>

      <CustomPopover
        open={popover.open}
        onClose={popover.onClose}
        arrow="right-top"
        sx={{ width: 160 }}
      >
        <MenuItem
          onClick={() => {
            onEditRow();
            popover.onClose();
          }}
         
        >

          <Iconify icon="solar:pen-bold" />
          Modifier
        </MenuItem>
        <MenuItem
          onClick={() => {
            confirm.onTrue();
            popover.onClose();
          }}
          sx={{ color: 'error.main' }}
        >
          <Iconify icon="solar:trash-bin-trash-bold" />
          Supprimer
        </MenuItem>

      </CustomPopover>


      <ConfirmDialog
        open={confirm.value}
        onClose={confirm.onFalse}
        title="Delete"
        content="Are you sure want to delete?"
        action={
          <Button variant="contained" color="error" onClick={onDeleteRow}>
            Delete
          </Button>
        }
      />
    </>
  );
}
