"use client"

import { useState } from 'react';
import Chip from '@mui/material/Chip';
import Box from '@mui/material/Box';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import Radio from '@mui/material/Radio';
import RadioGroup from '@mui/material/RadioGroup';
import FormControlLabel from '@mui/material/FormControlLabel';
import FormControl from '@mui/material/FormControl';
import FormLabel from '@mui/material/FormLabel';
import InputAdornment from '@mui/material/InputAdornment';
import { useResponsive } from '@/hooks/use-responsive';
import {RHFTextField,RHFAutocomplete} from '@/components/hook-form';
import { CalculationType, calculationTypeLabels } from '@/contexts/types/Shipping'
import { Control, Controller } from 'react-hook-form';
import { AutocompleteChangeReason } from '@mui/material';

interface DetailsFlatRateProps {
    control: Control<any>;
}

export default function DetailsFlatRate({ control }: DetailsFlatRateProps) {
    const calculationType = Object.values(CalculationType);

    const mdUp = useResponsive('up', 'md');

    const [selectedCalculationType, setSelectedCalculationType] = useState(CalculationType.BY_CLASS);

    const handleChangeCalculationType = (
        event: React.SyntheticEvent,
        value: string | string[],
        reason: AutocompleteChangeReason,
        onChange: any
    ) => {
        const newValue = Array.isArray(value) ? value[0] : value;
        if (Object.values(CalculationType).includes(newValue as CalculationType)) {
            setSelectedCalculationType(newValue as CalculationType);
            onChange(newValue as CalculationType);
        } else {
            console.error('Invalid shipping method type:', newValue);
        }
    };

    return (
        <>
            {mdUp && (
                <Grid md={4}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Détails Forfait
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Saisissez les informations du méthode de livraison de type Forfait
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp && <CardHeader title="Détails" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <FormControl>
                            <FormLabel id="demo-row-radio-buttons-group-label">État de la TVA</FormLabel>
                            <Controller
                                name="tvaStatut"
                                control={control}
                                defaultValue={true}
                                render={({ field }) => (
                                    <RadioGroup
                                        row
                                        aria-labelledby="demo-row-radio-buttons-group-label"
                                        value={field.value}
                                        onChange={(event) => field.onChange(event.target.value === 'true')}
                                    >
                                        <FormControlLabel value={true} control={<Radio />} label="Taxable" />
                                        <FormControlLabel value={false} control={<Radio />} label="Aucune" />
                                    </RadioGroup>
                                )}
                            />
                        </FormControl>
                        <Controller
                            name="cost"
                            control={control}
                            render={({ field }) => (
                                <RHFTextField
                                    {...field}
                                    label="Coût"
                                    placeholder="0.00"
                                    type="number"
                                    InputLabelProps={{ shrink: true }}
                                    InputProps={{
                                        startAdornment: (
                                            <InputAdornment position="start">
                                                <Box component="span" sx={{ color: 'text.disabled' }}>
                                                    €
                                                </Box>
                                            </InputAdornment>
                                        ),
                                    }}
                                />
                            )}
                        />
                        <Controller
                            name="costHeavyShippingClass"
                            control={control}
                            render={({ field }) => (
                                <RHFTextField
                                    {...field}
                                    label="Coût pour la classe d’expédition « Lourd »"
                                    placeholder="0.00"
                                    type="number"
                                    InputLabelProps={{ shrink: true }}
                                    InputProps={{
                                        startAdornment: (
                                            <InputAdornment position="start">
                                                <Box component="span" sx={{ color: 'text.disabled' }}>
                                                    €
                                                </Box>
                                            </InputAdornment>
                                        ),
                                    }}
                                />
                            )}
                        />
                        <Controller
                            name="costNoShippingClass"
                            control={control}
                            render={({ field }) => (
                                <RHFTextField
                                    {...field}
                                    label="Coût pour aucune classe d’expédition"
                                    placeholder="0.00"
                                    type="number"
                                    InputLabelProps={{ shrink: true }}
                                    InputProps={{
                                        startAdornment: (
                                            <InputAdornment position="start">
                                                <Box component="span" sx={{ color: 'text.disabled' }}>
                                                    €
                                                </Box>
                                            </InputAdornment>
                                        ),
                                    }}
                                />
                            )}
                        />
                        <Controller
                            name="calculationType"
                            control={control}
                            render={({ field }) => (
                                <RHFAutocomplete
                                    {...field}
                                    label="Type de calcul"
                                    placeholder="+ Type de calcul"
                                    defaultValue={calculationType[0]}
                                    disableClearable
                                    options={Object.values(CalculationType)}
                                    getOptionLabel={(option) => calculationTypeLabels[option as CalculationType]}
                                    onChange={(event, value, reason) => handleChangeCalculationType(event, value, reason, field.onChange)}
                                    value={selectedCalculationType}
                                    renderOption={(props, option) => (
                                        <li {...props} key={option}>
                                            {calculationTypeLabels[option]}
                                        </li>
                                    )}
                                    renderTags={(selected, getTagProps) =>
                                        selected.map((option, index) => (
                                            <Chip
                                                {...getTagProps({ index })}
                                                key={option}
                                                label={calculationTypeLabels[option as CalculationType]}
                                                size="small"
                                                color="info"
                                                variant="soft"
                                            />
                                        ))
                                    }
                                />
                            )}
                        />
                    </Stack>
                </Card>
            </Grid>
        </>
    );
}
