"use client"

import { useState } from 'react';
import Chip from '@mui/material/Chip';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import { AutocompleteChangeReason } from '@mui/material/Autocomplete';
import { useResponsive } from '@/hooks/use-responsive';
import Box from '@mui/material/Box';
import InputAdornment from '@mui/material/InputAdornment';
import {
    RHFTextField,
    RHFAutocomplete,
} from '@/components/hook-form';
import { RequiresFreeShipping, requiresFreeShippingLabels } from '@/contexts/types/Shipping'
import Checkbox from '@mui/material/Checkbox';
import { Control, Controller } from 'react-hook-form';

interface DetailsFreeShippingProps {
    control: Control<any>;
}

export default function DetailsFreeShipping({ control }: DetailsFreeShippingProps) {
    const mdUp = useResponsive('up', 'md');
    const [checked, setChecked] = useState(true);
    const [selectedRequis, setSelectedRequis] = useState(RequiresFreeShipping.NOTHING);

    const handleChangeRule = (event: React.ChangeEvent<HTMLInputElement>, onChange: any) => {
        setChecked(event.target.checked);
        onChange(event.target.checked);
    };

    const handleChangeRequis = (
        event: React.SyntheticEvent,
        value: string | string[],
        reason: AutocompleteChangeReason,
        onChange: any
    ) => {
        const newValue = Array.isArray(value) ? value[0] : value;
        if (Object.values(RequiresFreeShipping).includes(newValue as RequiresFreeShipping)) {
            setSelectedRequis(newValue as RequiresFreeShipping);
            onChange(newValue as RequiresFreeShipping);
        } else {
            console.error('Invalid shipping method type:', newValue);
        }
    };

    const renderRequisComponents = (
        <>
            <Controller
                name="minOrderAmount"
                control={control}
                render={({ field }) => (
                    <RHFTextField
                        {...field}
                        label="Montant minimum de commande"
                        placeholder="0.00"
                        type="number"
                        InputLabelProps={{ shrink: true }}
                        InputProps={{
                            startAdornment: (
                                <InputAdornment position="start">
                                    <Box component="span" sx={{ color: 'text.disabled' }}>
                                        €
                                    </Box>
                                </InputAdornment>
                            ),
                        }}
                    />
                )}
            />
            <Grid container alignItems="center" spacing={1}>
                <Grid>
                    <Controller
                        name="applyMinOrderRuleBeforePromoCodeDiscount"
                        control={control}
                        render={({ field }) => (
                            <Checkbox
                                {...field}
                                checked={field.value}
                                onChange={(event) => handleChangeRule(event, field.onChange)}
                                
                                inputProps={{ 'aria-label': 'primary checkbox' }}
                            />
                        )}
                    />
                </Grid>
                <Grid>
                    <Typography>Appliquer la règle de commande minimale avant la remise avec code promo</Typography>
                </Grid>
            </Grid>
        </>
    );

    const renderDetails = () => {
        switch (selectedRequis) {
            case RequiresFreeShipping.NOTHING:
            case RequiresFreeShipping.PROMO_CODE:
                return null;
            case RequiresFreeShipping.MINIMUM_ORDER_AMOUNT:
            case RequiresFreeShipping.PROMO_CODE_OR_MINIMUM_ORDER_AMOUNT:
            case RequiresFreeShipping.PROMO_CODE_AND_MINIMUM_ORDER_AMOUNT:
                return <>{renderRequisComponents}</>;
            default:
                return null;
        }
    };

    return (
        <>
            {mdUp && (
                <Grid md={4}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Détails Livraison gratuite
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Saisissez les informations du méthode de livraison de type Livraison gratuite
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp && <CardHeader title="Détails" />}
                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Controller
                            name="requires"
                            control={control}
                            defaultValue={RequiresFreeShipping.NOTHING}
                            render={({ field }) => (
                                <RHFAutocomplete
                                    {...field}
                                    label="La livraison gratuite requiert"
                                    placeholder="+ La livraison gratuite requiert"
                                    disableClearable
                                    options={Object.values(RequiresFreeShipping)}
                                    getOptionLabel={(option) => requiresFreeShippingLabels[option as RequiresFreeShipping]}
                                    onChange={(event, value, reason) => handleChangeRequis(event, value, reason, field.onChange)}
                                    value={selectedRequis}
                                    renderOption={(props, option: RequiresFreeShipping) => (
                                        <li {...props} key={option}>
                                            {requiresFreeShippingLabels[option]}
                                        </li>
                                    )}
                                    renderTags={(selected, getTagProps) =>
                                        selected.map((option, index) => (
                                            <Chip
                                                {...getTagProps({ index })}
                                                key={option}
                                                label={requiresFreeShippingLabels[option]}
                                                size="small"
                                                color="info"
                                                variant="soft"
                                            />
                                        ))
                                    }
                                />
                            )}
                        />
                        {renderDetails()}
                    </Stack>
                </Card>
            </Grid>
        </>
    );
}
