import { useState } from 'react';
import { Control, Controller } from 'react-hook-form';
import {Box, Button, Card, CardHeader, Checkbox, Container, Grid, IconButton, InputAdornment, Modal, Paper, Stack, Table, TableBody, 
    TableCell, TableContainer, TableHead, TableRow, TextField, Typography, Chip, Autocomplete,Alert,Snackbar
} from '@mui/material';
import { Add as AddIcon, Delete as DeleteIcon, Edit as EditIcon } from '@mui/icons-material';
import { useResponsive, useBoolean } from '@/hooks';
import ConfirmDialog from '@/shared/components/confirm-dialog';
import { DeliveryCostMondialRelay, MondialRelayMode, MondialRelayModeLabels } from '@/contexts/types/Shipping';
import { RHFTextField } from '@/components/hook-form';


const modalStyle = {
    position: 'absolute',
    top: '50%',
    left: '50%',
    transform: 'translate(-50%, -50%)',
    width: 600,
    bgcolor: 'background.paper',
    boxShadow: 24,
    p: 4,
    borderRadius: 3,
};

const modalContentStyle = {
    display: 'flex',
    flexDirection: 'column',
    gap: 2,
};

interface DetailsMondialRelayProps {
    control: Control<any>;
    dataDeliveryCostMondialRelay: DeliveryCostMondialRelay[];
    setDataDeliveryCostMondialRelay: React.Dispatch<React.SetStateAction<DeliveryCostMondialRelay[]>>;
}

export default function DetailsMondialRelay({ control, dataDeliveryCostMondialRelay, setDataDeliveryCostMondialRelay }: DetailsMondialRelayProps) {
    const mdUp = useResponsive('up', 'md');
    const [alertErrorMessage, setAlertErrorMessage] = useState('');
    const [openAlertErrorMessage, setOpenAlertErrorMessage] = useState(false);

    const [formDataCostMondialRelay, setFormDataCostMondialRelay] = useState<DeliveryCostMondialRelay>({
        id: null,
        weightCart: null,
        weightPackaging: null,
        cost: null,
    });

    const [selectedMondialRelayMode, setSelectedMondialRelayMode] = useState<MondialRelayMode>(MondialRelayMode.MED);

    const [openCostModal, setOpenCostModal] = useState(false);
    const [isEdit, setIsEdit] = useState(false);

    const handleOpenCostModal = (edit: boolean, index: number | null = null) => {
        setIsEdit(edit);
        if (edit && index !== null) {
            const row = dataDeliveryCostMondialRelay[index];
            if (row) {
                setFormDataCostMondialRelay({
                    id: row.id,
                    weightCart: row.weightCart,
                    weightPackaging: row.weightPackaging,
                    cost: row.cost,
                });
            }
        } else {
            setFormDataCostMondialRelay({
                id: null,
                weightCart: null,
                weightPackaging: null,
                cost: null,
            });
        }
        setOpenCostModal(true);
    };

    const handleSaveCostMondialRelay = () => {

        if (formDataCostMondialRelay.weightCart === null || formDataCostMondialRelay.weightCart < 0) {
            setAlertErrorMessage('Veuillez saisir un poids du panier valide');
            setOpenAlertErrorMessage(true);
            return;
        }

        if (formDataCostMondialRelay.cost === null || formDataCostMondialRelay.cost < 0) {
            setAlertErrorMessage('Veuillez saisir un prix valide');
            setOpenAlertErrorMessage(true);
            return;
        }

        dataDeliveryCostMondialRelay.forEach((item) => {
            if (item.weightPackaging === null || item.weightPackaging <= 0) {
                item.weightPackaging = 0;
            }
        });

        if (formDataCostMondialRelay.id !== null) {
            const updatedList = dataDeliveryCostMondialRelay.map((item) => (item.id === formDataCostMondialRelay.id ? formDataCostMondialRelay : item));
            setDataDeliveryCostMondialRelay(updatedList);
        } else {
            setDataDeliveryCostMondialRelay([...dataDeliveryCostMondialRelay, { ...formDataCostMondialRelay, id: Date.now().toString() }]);
        }
        setOpenCostModal(false);
    };

    const handleRowCheckboxChange = (index: number, checked: boolean, list: DeliveryCostMondialRelay[], setList: React.Dispatch<React.SetStateAction<DeliveryCostMondialRelay[]>>) => {
        const updatedList = [...list];
        updatedList[index].checked = checked;
        setList(updatedList);
    };

    const handleDeleteSelectedRows = (list: DeliveryCostMondialRelay[], setList: React.Dispatch<React.SetStateAction<DeliveryCostMondialRelay[]>>) => {
        const updatedList = list.filter((item) => !item.checked);
        setList(updatedList);
        confirmDeleteCost.onFalse();
    };

    const confirmDeleteCost = useBoolean();

    const handleDeleteCost = (index: number) => {
        handleRowCheckboxChange(index, true, dataDeliveryCostMondialRelay, setDataDeliveryCostMondialRelay);
        confirmDeleteCost.onTrue();
    };

    const handleChangeMondialRelayMode = (event: any, value: any, reason: any, onChange: any) => {
        setSelectedMondialRelayMode(value);
        onChange(value);
    };

    const renderCostModal = (open: boolean, handleClose: () => void, title: string, handleSave: () => void) => (
        <Modal open={open} onClose={handleClose}>
            <Box sx={modalStyle}>
                <Typography variant="h6" align="center" sx={{ mt: 2, mb: 3 }} gutterBottom>
                    {title}
                </Typography>
                <Box sx={modalContentStyle}>
                    <TextField
                        label="Poids du panier jusqu'à (g)"
                        placeholder="0.00"
                        type="number"
                        sx={{ m: 1, width: '95%' }}
                        InputLabelProps={{ shrink: true }}
                        InputProps={{ startAdornment: <InputAdornment position="start">g</InputAdornment> }}
                        value={formDataCostMondialRelay.weightCart ?? ''}
                        onChange={(e) => setFormDataCostMondialRelay({ ...formDataCostMondialRelay, weightCart: e.target.value ? Number(e.target.value) : null })}
                    />
                    <TextField
                        label="Poids d'emballage (g)"
                        placeholder="0.00"
                        type="number"
                        sx={{ m: 1, width: '95%' }}
                        InputLabelProps={{ shrink: true }}
                        InputProps={{ startAdornment: <InputAdornment position="start">g</InputAdornment> }}
                        value={formDataCostMondialRelay.weightPackaging ?? ''}
                        onChange={(e) => setFormDataCostMondialRelay({ ...formDataCostMondialRelay, weightPackaging: e.target.value ? Number(e.target.value) : null })}
                    />
                    <TextField
                        label="Prix (EUR €)"
                        placeholder="0.00"
                        type="number"
                        sx={{ m: 1, width: '95%' }}
                        InputLabelProps={{ shrink: true }}
                        InputProps={{ startAdornment: <InputAdornment position="start">€</InputAdornment> }}
                        value={formDataCostMondialRelay.cost ?? ''}
                        onChange={(e) => setFormDataCostMondialRelay({ ...formDataCostMondialRelay, cost: e.target.value ? Number(e.target.value) : null })}
                    />
                    <Box sx={{ display: 'flex', justifyContent: 'center', mt: 4 }}>
                        <Button onClick={handleClose} sx={{ mr: 1 }} variant="outlined" color="inherit">Annuler</Button>
                        <Button onClick={handleSave} variant="contained" color="inherit">{title.split(' ')[0]}</Button>
                    </Box>
                </Box>
            </Box>
        </Modal>
    );

    return (
        <Container>
            {mdUp && (
                <Grid xs={12} md={4} sx={{ mt: 4 }}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Détails Mondial Relay
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Saisissez les informations du méthode de livraison de type Mondial Relay
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp && <CardHeader title="Détails" />}
                    <Stack spacing={3} sx={{ p: 3 }}>
                        <RHFTextField
                            name="amountFreeShipping"
                            label="Offrir la livraison à partir de ce montant (optionnel)"
                            placeholder="0.00"
                            type="number"
                            InputLabelProps={{ shrink: true }}
                            InputProps={{
                                startAdornment: (
                                    <InputAdornment position="start">
                                        <Box component="span" sx={{ color: 'text.disabled' }}>
                                            €
                                        </Box>
                                    </InputAdornment>
                                ),
                            }}
                        />
                        <RHFTextField name="nameFreeShipping" label="Nom si la livraison est offerte" />

                        <Controller
                            name="mondialRelayMode"
                            control={control}
                            defaultValue={MondialRelayMode.MED}
                            render={({ field }) => (
                                <Autocomplete
                                    disabled
                                    {...field}
                                    options={Object.values(MondialRelayMode)}
                                    getOptionLabel={(option) => MondialRelayModeLabels[option as MondialRelayMode]}
                                    onChange={(event, value, reason) => handleChangeMondialRelayMode(event, value, reason, field.onChange)}
                                    value={selectedMondialRelayMode}
                                    renderInput={(params) => <TextField {...params} label="Mode de livraison" placeholder="+ Mode de livraison" />}
                                    renderOption={(props, option) => (
                                        <li {...props} key={option}>
                                            {MondialRelayModeLabels[option as MondialRelayMode]}
                                        </li>
                                    )}
                                    renderTags={(selected, getTagProps) =>
                                        selected.map((option, index) => (
                                            <Chip
                                                {...getTagProps({ index })}
                                                key={option}
                                                label={MondialRelayModeLabels[option as MondialRelayMode]}
                                                size="small"
                                                color="info"
                                                variant="soft"
                                            />
                                        ))
                                    }
                                />
                            )}
                        />
                        <Box sx={{ display: 'flex', alignItems: 'center', gap: 1 }}>
                            <Button
                                variant="outlined"
                                size="small"
                                sx={{ color: '#808080', width: '15%' }}
                                onClick={() => handleOpenCostModal(false)}
                                startIcon={<AddIcon />}
                            >
                                Ajouter
                            </Button>
                            <Button
                                variant="outlined"
                                size="small"
                                sx={{ color: '#808080', width: '15%' }}
                                onClick={() => handleDeleteSelectedRows(dataDeliveryCostMondialRelay, setDataDeliveryCostMondialRelay)}
                                startIcon={<DeleteIcon />}
                            >
                                Supprimer
                            </Button>
                        </Box>
                        <TableContainer component={Paper} sx={{ mt: 1, maxHeight: '500px' }}>
                            <Table sx={{ minWidth: 650 }} aria-label="simple table">
                                <TableHead>
                                    <TableRow>
                                        <TableCell align="center">
                                            <Checkbox
                                                indeterminate={dataDeliveryCostMondialRelay.length > 0 && dataDeliveryCostMondialRelay.some(item => item.checked)}
                                                checked={dataDeliveryCostMondialRelay.length > 0 && dataDeliveryCostMondialRelay.every(item => item.checked)}
                                                onChange={(event) => {
                                                    const checked = event.target.checked;
                                                    const updatedList = dataDeliveryCostMondialRelay.map(item => ({ ...item, checked }));
                                                    setDataDeliveryCostMondialRelay(updatedList);
                                                }}
                                            />
                                        </TableCell>
                                        <TableCell align="center">Poids du panier jusqu'à (g)</TableCell>
                                        <TableCell align="center">Poids d'emballage (g)</TableCell>
                                        <TableCell align="center">Prix (EUR €)</TableCell>
                                        <TableCell align="center">Actions</TableCell>
                                    </TableRow>
                                </TableHead>
                                <TableBody>
                                    {dataDeliveryCostMondialRelay.map((row, index) => (
                                        <TableRow key={index} sx={{ '&:last-child td, &:last-child th': { border: 0 } }}>
                                            <TableCell component="th" scope="row" align="center">
                                                <Checkbox
                                                    checked={row.checked || false}
                                                    onChange={(event) => handleRowCheckboxChange(index, event.target.checked, dataDeliveryCostMondialRelay, setDataDeliveryCostMondialRelay)}
                                                />
                                            </TableCell>
                                            <TableCell align="center">{row.weightCart} g</TableCell>
                                            <TableCell align="center">{row.weightPackaging} g</TableCell>
                                            <TableCell align="center">{row.cost} €</TableCell>
                                            <TableCell align="center">
                                                <Box>
                                                    <IconButton onClick={() => handleOpenCostModal(true, index)}>
                                                        <EditIcon sx={{ color: 'green' }} />
                                                    </IconButton>
                                                    <IconButton onClick={() => handleDeleteCost(index)}>
                                                        <DeleteIcon sx={{ color: 'red' }} />
                                                    </IconButton>
                                                </Box>
                                            </TableCell>
                                        </TableRow>
                                    ))}
                                </TableBody>
                            </Table>
                        </TableContainer>
                    </Stack>
                </Card>
            </Grid>

            <Snackbar open={openAlertErrorMessage} autoHideDuration={3000}
                onClose={() => setOpenAlertErrorMessage(false)} anchorOrigin={{ vertical: 'top', horizontal: 'right' }}>
                <Alert
                    onClose={() => setOpenAlertErrorMessage(false)}
                    severity="error"
                    variant="filled"
                    sx={{ width: '100%' }}
                >
                    {alertErrorMessage}
                </Alert>
            </Snackbar>

            <ConfirmDialog
                open={confirmDeleteCost.value}
                onClose={confirmDeleteCost.onFalse}
                title="Supprimer frais"
                content="Voulez-vous vraiment supprimer?"
                action={
                    <Button variant="contained" color="error" onClick={() => handleDeleteSelectedRows(dataDeliveryCostMondialRelay, setDataDeliveryCostMondialRelay)}>
                        Supprimer
                    </Button>
                }
            />

            {renderCostModal(openCostModal, () => setOpenCostModal(false), isEdit ? "Modifier frais de livraison" : "Ajouter frais de livraison", handleSaveCostMondialRelay)}
        </Container>
    );
}
