"use client"

import { useState } from 'react';
import Box from '@mui/material/Box';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';
import Radio from '@mui/material/Radio';
import RadioGroup from '@mui/material/RadioGroup';
import FormControlLabel from '@mui/material/FormControlLabel';
import FormControl from '@mui/material/FormControl';
import FormLabel from '@mui/material/FormLabel';
import InputAdornment from '@mui/material/InputAdornment';
import { useResponsive } from '@/hooks/use-responsive';
import {RHFTextField} from '@/components/hook-form';
import { Control, Controller } from 'react-hook-form';

interface DetailsPointOfSaleProps {
    control: Control<any>;
}

export default function DetailsPointOfSale({control}: DetailsPointOfSaleProps) {

    const mdUp = useResponsive('up', 'md');

    return (
        <>
            {mdUp && (
                <Grid md={4}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Détails Point de vente
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Saisissez les informations du méthode de livraison de type Point de vente
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp && <CardHeader title="Détails" />}


                    <Stack spacing={3} sx={{ p: 3 }}>
                    <FormControl>
                            <FormLabel id="demo-row-radio-buttons-group-label">État de la TVA</FormLabel>
                            <Controller
                                name="tvaStatut"
                                control={control}
                                defaultValue={true} // or false, depending on your initial state
                                render={({ field }) => (
                                    <RadioGroup
                                        row
                                        aria-labelledby="demo-row-radio-buttons-group-label"
                                        value={field.value} // Use the boolean value directly
                                        onChange={(event) => field.onChange(event.target.value === 'true')}
                                    >
                                        <FormControlLabel value={true} control={<Radio />} label="Taxable" />
                                        <FormControlLabel value={false} control={<Radio />} label="Aucune" />
                                    </RadioGroup>
                                )}
                            />
                        </FormControl>
                        <RHFTextField
                            name="cost"
                            label="Coût"
                            placeholder="0.00"
                            type="number"
                            InputLabelProps={{ shrink: true }}
                            InputProps={{
                                startAdornment: (
                                <InputAdornment position="start">
                                    <Box component="span" sx={{ color: 'text.disabled' }}>
                                    €
                                    </Box>
                                </InputAdornment>
                                ),
                            }}
                        />
                    </Stack>
                </Card>
            </Grid>
        </>
    );
}
