'use client';

import { useState, useCallback } from 'react';
import Tab from '@mui/material/Tab';
import Tabs from '@mui/material/Tabs';
import Container from '@mui/material/Container';
import { _userAbout, _userPlans, _userPayment, _userInvoices, _userAddressBook } from '@/shared/_mock';
import { useSettingsContext } from '@/components/settings';
import ConfigEmailView from './emails/ConfigEmailView';
import ConfigCompteModialRelay from './compte/ConfigCompteMondialRelay';
import ConfigVendorMRView from './vendor/ConfigVendorMRView';
import MondialRelayOrderListView from './orders/MondialRelayOrderListView';
import MondialRelayExpeditionListView from './expeditions/expeditionMondialRelay-list-view';

const TABS = [
  {
    value: '1',
    label: 'Compte',
  },
  {
    value: '2',
    label: 'Vendeur',
  },
  {
    value: '3',
    label: 'Emails',
  },
  {
    value: '4',
    label: 'Commandes',
  },
  {
    value: '5',
    label: 'Expéditions',
  },
];


interface ShippingMainViewProps {
  defaultValue?: string;
}

export default function MondialRelayMainView({ defaultValue }: ShippingMainViewProps) {
  const settings = useSettingsContext();

  const [currentTab, setCurrentTab] = useState<string>(defaultValue || '1');

  const handleChangeTab = useCallback((event: React.SyntheticEvent, newValue: string) => {
    setCurrentTab(newValue);
  }, []);

  return (
    <Container maxWidth={settings.themeStretch ? false : 'lg'}>

      <Tabs
        value={currentTab}
        onChange={handleChangeTab}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      >
        {TABS.map((tab) => (
          <Tab key={tab?.value} label={tab?.label} value={tab?.value} />
        ))}
      </Tabs>

      {currentTab === '1' && <ConfigCompteModialRelay />}

      {currentTab === '2' && <ConfigVendorMRView />}

      {currentTab === '3' && <ConfigEmailView />}

      {currentTab === '4' && <MondialRelayOrderListView />}

      {currentTab === '5' && <MondialRelayExpeditionListView />}

    </Container>
  );
}
