import { GridCellParams } from "@mui/x-data-grid";
import ListItemText from "@mui/material/ListItemText";
import { fTime, fDate } from "@/utils/format-time";
import Label from "@/shared/components/label";
import { IOrderMondialRelayStatus } from "@/contexts/types/Shipping";


type ParamsProps = {
  params: GridCellParams;
};

export function RenderCellOrderNumber({ params }: ParamsProps) {
  return <>{params.row.id}</>;
}

export function RenderCellExpeditionNumber({ params }: ParamsProps) {
  return <>{params.row.expeditionNumber}</>;
}

export function RenderCellExpedition({ params }: ParamsProps) {
  return <>{params.row.expedition}</>;
}

export function RenderCellAdress({ params }: ParamsProps) {
  return <>{params.row.address}</>;
}

export function RenderCellDateCreation({ params }: ParamsProps) {
  return (
    <ListItemText
      primary={fDate(params.row.dateCreation)}
      secondary={fTime(params.row.dateCreation)}
      primaryTypographyProps={{ typography: "body2", noWrap: true }}
      secondaryTypographyProps={{
        mt: 0.5,
        component: "span",
        typography: "caption",
      }}
    />
  );
}

export function RenderCellShippingMode({ params }: ParamsProps) {
  return <>{params.row.shippingMode}</>;
}

export function RenderCellStatus({ params }: ParamsProps) {
  return (
    <Label
      variant="soft"
      color={(params.row.status === IOrderMondialRelayStatus.Pending && "secondary") || (params.row.status === IOrderMondialRelayStatus.WaitingForPayment && "warning") || (params.row.status === IOrderMondialRelayStatus.InProgress && "primary") || "default"}
    >
      {params.row.status}
    </Label>
  );
}

export function RenderCellDelivery({ params }: ParamsProps) {
  return <>{params.row.delivery}</>;
}