import React, { useCallback, useMemo } from "react";
import Stack from "@mui/material/Stack";
import TextField from "@mui/material/TextField";
import InputAdornment from "@mui/material/InputAdornment";
import Iconify from "../../../../components/iconify";
import {Grid} from "@mui/material";
import { ISupplierItemTableFilters } from "@/contexts/types/supplierOrder";
import { ISupplierItemTableFilterValue } from "@/contexts/types/supplierOrder";

// ----------------------------------------------------------------------

type Props = {
  filters: ISupplierItemTableFilters;
  onFilters: (name: string, value: ISupplierItemTableFilterValue) => void;
};

export default function SupplierTableToolbar({
  filters,
  onFilters,
}: Props) {
  const handleFilterName = useCallback(
    (event: React.ChangeEvent<HTMLInputElement>) => {
      onFilters("name", event.target.value);
    },
    [onFilters]
  );


  return (
    <>
      <Stack
        spacing={2}
        alignItems={{ xs: "flex-end", md: "center" }}
        direction={{
          xs: "column",
          md: "row",
        }}
        sx={{
          p: 2.5,
          pr: { xs: 2.5, md: 1 },
        }}
      >
          <Grid item xs={12} md={7}>
            <TextField
              fullWidth
              value={filters.name}
              onChange={handleFilterName}
              placeholder="Chercher par nom ou adresse..."
              InputProps={{
                startAdornment: (
                  <InputAdornment position="start">
                    <Iconify
                      icon="eva:search-fill"
                      sx={{ color: "text.disabled" }}
                    />
                  </InputAdornment>
                ),
              }}
            />
          </Grid>
      </Stack>
    </>
  );
}
