import TableRow from "@mui/material/TableRow";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import Menu from "@mui/material/Menu";
import MenuItem from "@mui/material/MenuItem";
import Stack from "@mui/material/Stack";
import MoreVertIcon from "@mui/icons-material/MoreVert";
import UnarchiveIcon from "@mui/icons-material/Unarchive";
import { useState } from "react";
import { SupplierDTO } from "@/contexts/types/supplierOrder";
import CustomPopover, { usePopover } from "@/shared/components/custom-popover";

// ----------------------------------------------------------------------

type Props = {
  selected: boolean;
  onEditRow: VoidFunction;
  row: SupplierDTO;
  onSelectRow: VoidFunction;
  onDeleteRow: VoidFunction;
  onUnarchiveRow: VoidFunction;
};

export default function UserTableRow({
  row,
  selected,
  onEditRow,
  onSelectRow,
  onDeleteRow,
  onUnarchiveRow,
}: Props) {
  const {
    supplierName,
    supplierLastName,
    supplierEmail,
    supplierPhoneNumber,
    companyCity,
    companyStreet,
    companyCountry,
  } = row;

  // State pour gérer le menu contextuel
  const [anchorEl, setAnchorEl] = useState<null | HTMLElement>(null);

  const handleOpenMenu = (event: React.MouseEvent<HTMLElement>) => {
    setAnchorEl(event.currentTarget);
  };
  const popover = usePopover();
  const handleCloseMenu = () => {
    setAnchorEl(null);
    popover.onClose();
  };

  return (
    <TableRow hover selected={selected} className="cursor-pointer">
      {/* Nom et prénom */}
      <TableCell sx={{ whiteSpace: "nowrap" }}>{supplierName+" "+supplierLastName}</TableCell>

      {/* Email */}
      <TableCell sx={{ whiteSpace: "nowrap" }}>{supplierEmail}</TableCell>

      {/* Téléphone */}
      <TableCell sx={{ whiteSpace: "nowrap" }}>{supplierPhoneNumber}</TableCell>

      {/* Adresse */}
      <TableCell sx={{ whiteSpace: "nowrap" }}>
        {`${companyStreet}, ${companyCity}, ${companyCountry}`}
      </TableCell>

      {/* Actions */}
      <TableCell sx={{ whiteSpace: "nowrap" }}>
      <Stack direction="row" spacing={1}>
          <IconButton color={popover.open ? "primary" : "default"} onClick={popover.onOpen}>
            <MoreVertIcon color="action" />
          </IconButton>
          <CustomPopover open={popover.open} onClose={popover.onClose}>
            <MenuItem
              onClick={() => {
                onUnarchiveRow();
                handleCloseMenu();
              }}
              sx={{ color: "success.main" }}
            >
              <UnarchiveIcon fontSize="small" sx={{ mr: 1 }} color="success" />
              Désarchiver
            </MenuItem>
          </CustomPopover>
        </Stack>
      </TableCell>
    </TableRow>
  );
}
