import { Box, Button, MenuItem, Modal, Select, SelectChangeEvent, Stack, TextField, Typography } from "@mui/material";
import { useState } from "react";


type CustomModalProps = {
    open: boolean;
    onClose: () => void;
    idCommand: string;
    idProduct: string;
    variation: string;
    type: string;
    productName: string;
}

export default function SaleOrderGapModal({ open, onClose, idCommand, idProduct, variation, type, productName}: CustomModalProps) {

    const [gap, setGap] = useState<string>('normale');
    const [gapValue, setGapValue] = useState<string>('0');


    const handleGapChange = (event: SelectChangeEvent<string>) => {
        setGap(event.target.value as string);
    };

    const handleGapDetailsChange = (event: React.ChangeEvent<HTMLInputElement>) => {
        setGapValue(event.target.value);
    };

    const typeMapping: { [key: string]: string } = {
        size: "Taille",
        color: "Couleur"
    };

    const colorMapping: { [key: string]: string } = {
        Blue: "Bleu",
        Green: "Vert",
        Red: "Rouge",
        Yellow: "Jaune",
        Black: "Noir",
        White: "Blanc",
        Orange: "Orange",
        Pink: "Rose",
        Purple: "Violet",
        Brown: "Marron",

    };

    const translatedType = typeMapping[type] || type;
    const translatedVariation = type === "color" ? colorMapping[variation] || variation : variation;

    return (
        <Modal
            className="flex items-center justify-center"
            open={open}
            onClose={onClose}
            aria-labelledby="modal-title"
            aria-describedby="modal-description"
        >
            <div className="bg-white rounded-lg shadow p-6 flex flex-col justify-center items-center">
                <Typography variant="body2" id="modal-description" sx={{ mb: 2, fontSize: 20 }}>
                   Déclaration des écarts
                </Typography>
                <span className="font-bold">{productName}</span>
                <span>{translatedType}</span> <span className="font-bold">{translatedVariation}</span>
                <Box sx={{ width: 300, mb: 2 }}>
                    <Select
                        value={gap}
                        onChange={handleGapChange}
                        fullWidth
                    >
                        <MenuItem value="superieur">Quantité supérieure</MenuItem>
                        <MenuItem value="normale">Quantité normale</MenuItem>
                        <MenuItem value="inferieur">Quantité inférieure</MenuItem>
                    </Select>
                </Box>
                {gap === 'inferieur' && (
                    <Box sx={{ width: 300, mb: 2 }}>
                        <TextField
                            label="Détails de l'écart"
                            value={gapValue}
                            onChange={handleGapDetailsChange}
                            fullWidth
                        />
                    </Box>
                )}
                <Stack direction="row" spacing={2}>
                    <Button variant="contained" color="error" onClick={onClose}>Annuler</Button>
                    <Button variant="contained" color="info" onClick={onClose}>Enregistrer</Button>
                </Stack>
            </div>
        </Modal>
    )


}