import { IInvoice } from "@/shared/types/invoice";
import { Box, Button, MenuItem, Modal, Select, Typography, SelectChangeEvent, Stack } from "@mui/material";
import { useState } from "react";

interface CustomModalProps {
    open: boolean;
    onClose: () => void;
    message: string;
    rowStatus: string;
    setRowStatus: (status: string) => void;
}

export default function SaleOrderEditStatusModal({ open, onClose, message, rowStatus, setRowStatus }: CustomModalProps) {

    const handleStatusChange = (event: SelectChangeEvent<string>) => {
        setRowStatus(event.target.value as string);
        console.log(event.target.value);
    };

    return (
        <Modal
            className="flex items-center justify-center"
            open={open}
            onClose={onClose}
            aria-labelledby="modal-title"
            aria-describedby="modal-description"
        >
            <div className="bg-white rounded-lg shadow p-6 flex flex-col justify-center items-center">
                <Typography variant="body2" id="modal-description" sx={{ mb: 2, fontSize: 20 }}>
                    {message}
                </Typography>
                <Box sx={{ width: 300, mb: 2 }}>
                    <Select
                        value={rowStatus}
                        onChange={handleStatusChange}
                        fullWidth
                    >
                        <MenuItem value="A faire">A faire</MenuItem>
                        <MenuItem value="En cours">En cours</MenuItem>
                        <MenuItem value="Terminée">Terminée</MenuItem>
                    </Select>
                </Box>
                <Stack direction="row" spacing={2}>
                    <Button variant="contained" color="error" onClick={onClose}>Annuler</Button>
                    <Button variant="contained" color="info" onClick={onClose}>Enregistrer</Button>
                </Stack>
            </div>
        </Modal>
    );
}
