import React, { useState } from 'react';
import { Button, Dialog, DialogActions, DialogContent, DialogTitle, FormControl, InputLabel, MenuItem, Select } from '@mui/material';

type Driver = {
  id: string;
  name: string;
};

type Supplier = {
  id: string;
  name: string;
};

interface SaleOrderEditStatusModalProps {
  open: boolean;
  onClose: () => void;
  drivers: Driver[];
  suppliers: Supplier[];
  onConfirm: (driverId: string, supplierId: string) => void;
}

const SaleOrderEditStatusModal: React.FC<SaleOrderEditStatusModalProps> = ({ open, onClose, drivers, suppliers, onConfirm }) => {
  const [selectedDriver, setSelectedDriver] = useState('');
  const [selectedSupplier, setSelectedSupplier] = useState('');

  const handleConfirm = () => {
    onConfirm(selectedDriver, selectedSupplier);
    onClose();
  };

  return (
    <Dialog open={open} onClose={onClose}>
      <DialogTitle>Confirmer la commande</DialogTitle>
      <DialogContent>
        <FormControl fullWidth margin="normal" variant="outlined">
          <InputLabel id="chauffeur-label">Chauffeur</InputLabel>
          <Select
            labelId="chauffeur-label"
            value={selectedDriver}
            onChange={(e) => setSelectedDriver(e.target.value)}
            label="Chauffeur"
          >
            {drivers.map((driver) => (
              <MenuItem key={driver.id} value={driver.id}>
                {driver.name}
              </MenuItem>
            ))}
          </Select>
        </FormControl>

        <FormControl fullWidth margin="normal" variant="outlined">
          <InputLabel id="fournisseur-label">Fournisseur</InputLabel>
          <Select
            labelId="fournisseur-label"
            value={selectedSupplier}
            onChange={(e) => setSelectedSupplier(e.target.value)}
            label="Fournisseur"
          >
            {suppliers.map((supplier) => (
              <MenuItem key={supplier.id} value={supplier.id}>
                {supplier.name}
              </MenuItem>
            ))}
          </Select>
        </FormControl>
      </DialogContent>
      <DialogActions>
        <Button onClick={onClose} color="primary">
          Annuler
        </Button>
        <Button onClick={handleConfirm} color="primary">
          Confirmer
        </Button>
      </DialogActions>
    </Dialog>
  );
};

export default SaleOrderEditStatusModal;
