import { useCallback } from "react";
import Box from "@mui/material/Box";
import Chip from "@mui/material/Chip";
import Paper from "@mui/material/Paper";
import Button from "@mui/material/Button";
import Stack, { StackProps } from "@mui/material/Stack";
import Iconify from "@/shared/components/iconify";
import { shortDateLabel } from "@/shared/components/custom-date-range-picker";
import {
  ISaleOrderTableFilters,
  ISaleOrderTableFilterValue,
} from "@/shared/types/saleOrder";
import { toDate } from "date-fns";

// ----------------------------------------------------------------------

type Props = StackProps & {
  filters: ISaleOrderTableFilters;
  onFilters: (name: string, value: ISaleOrderTableFilterValue) => void;
  //
  onResetFilters: VoidFunction;
  //
  results: number;
};

export default function SaleOrderTableFiltersResult({
  filters,
  onFilters,
  //
  onResetFilters,
  //
  results,
  ...other
}: Props) {
  const shortLabel = shortDateLabel(filters.creationDate, filters.creationDate);

  const handleRemoveName = useCallback(() => {
    onFilters("name", "");
  }, [onFilters]);

  const handleRemoveDate = useCallback(() => {
    onFilters("creationDate", null);
  }, [onFilters]);

  return (
    <Stack spacing={1.5} {...other}>
      <Box sx={{ typography: "body2" }}>
        <strong>{results}</strong>
        <Box component="span" sx={{ color: "text.secondary", ml: 0.25 }}>
          Résultat trouvé
        </Box>
      </Box>

      <Stack
        flexGrow={1}
        spacing={1}
        direction="row"
        flexWrap="wrap"
        alignItems="center"
      >
        {filters.creationDate && (
          <Block label="Date de Creation:">
            <Chip
            size="small"
            label={filters.creationDate ? filters.creationDate.toDateString() : "No Date Selected"}
            onDelete={filters.creationDate ? handleRemoveDate : undefined}
          />
          </Block>
        )}

        {!!filters.name && (
          <Block label="Fournisseur:">
            <Chip label={filters.name} size="small" onDelete={handleRemoveName} />
          </Block>
        )}

        <Button
          color="error"
          onClick={onResetFilters}
          startIcon={<Iconify icon="solar:trash-bin-trash-bold" />}
        >
          Supprimer
        </Button>
      </Stack>

    </Stack>
  );
}

// ----------------------------------------------------------------------

type BlockProps = StackProps & {
  label: string;
};

function Block({ label, children, sx, ...other }: BlockProps) {
  return (
    <Stack
      component={Paper}
      variant="outlined"
      spacing={1}
      direction="row"
      sx={{
        p: 1,
        borderRadius: 1,
        overflow: "hidden",
        borderStyle: "dashed",
        ...sx,
      }}
      {...other}
    >
      <Box component="span" sx={{ typography: "subtitle2" }}>
        {label}
      </Box>

      <Stack spacing={1} direction="row" flexWrap="wrap">
        {children}
      </Stack>
    </Stack>
  );
}




