import { useCallback } from "react";
import Stack from "@mui/material/Stack";
import TextField from "@mui/material/TextField";
import InputAdornment from "@mui/material/InputAdornment";
import { DatePicker } from "@mui/x-date-pickers/DatePicker";
import Iconify from "@/shared/components/iconify";
import { usePopover } from "@/shared/components/custom-popover";
import {
  ISaleOrderTableFilters,
  ISaleOrderTableFilterValue,
} from "@/shared/types/saleOrder";


type Props = {
  filters: ISaleOrderTableFilters;
  onFilters: (name: string, value: ISaleOrderTableFilterValue) => void;
  //
  serviceOptions: string[];
};

export default function SaleOrderTableToolbar({
  filters,
  onFilters,
}: Props) {
  const popover = usePopover();

  const handleFilterName = useCallback(
    (event: React.ChangeEvent<HTMLInputElement>) => {
      onFilters("name", event.target.value);
    },
    [onFilters]
  );

  const handleFilterDate = useCallback(
    (newValue: Date | null) => {
      onFilters("creationDate", newValue);
    },
    [onFilters]
  );

  return (
    <>
      <Stack
        spacing={2}
        alignItems={{ xs: "flex-end", md: "center" }}
        direction={{
          xs: "column",
          md: "row",
        }}
        sx={{
          p: 2.5,
          pr: { xs: 2.5, md: 1 },
        }}
      >
        <DatePicker
          label="Filtrer par Date de Creation"
          value={filters.creationDate}
          onChange={(newValue) => handleFilterDate(newValue)}
          slotProps={{ textField: { fullWidth: true } }}
          sx={{
            maxWidth: { md: 300 },
          }}
        />

        <Stack
          direction="row"
          alignItems="center"
          spacing={2}
          flexGrow={1}
          sx={{ width: 1 }}
        >
          <TextField
            fullWidth
            value={filters.name}
            onChange={handleFilterName}
            placeholder="Chercher par fournisseur"
            InputProps={{
              startAdornment: (
                <InputAdornment position="start">
                  <Iconify
                    icon="eva:search-fill"
                    sx={{ color: "text.disabled" }}
                  />
                </InputAdornment>
              ),
            }}
          />

        </Stack>
      </Stack>
    </>
  );
}
