import Stack from "@mui/material/Stack";
import Button from "@mui/material/Button";
import Divider from "@mui/material/Divider";
import IconButton from "@mui/material/IconButton";
import Typography from "@mui/material/Typography";
import { useBoolean } from "@/hooks/use-boolean";
import { useResponsive } from "@/hooks/use-responsive";
import { _addressBooks } from "@/shared/_mock";
import Iconify from "@/components/iconify";
import { useCallback, useEffect, useState } from "react";
import { useGetNotArchivedSuppliers } from "@/shared/api/supplier";
import { Driver } from "@/contexts/types/driver";
import DriverSupplierListDialog, { DialogItem } from "./DriverSupplierComponents/driver-supplier-list-dialog";
import { getAllDrivers } from "@/shared/api/supplierOrders";
import { IDriverSupplierItem, SupplierDTO } from "@/contexts/types/supplierOrder";
import AddSupplierDialog from "./add-supplier-dialog";
import AddDriverDialog from "./driver-dialog";
import { enqueueSnackbar } from "@/shared/components/snackbar";


type Props = {
  isEdit: boolean;
  supplierId?: string;
  setSupplierId?: (supplierId: string) => void;
  supplierName?: string;
  setSupplierName?: (supplierName: string) => void;
  driverId?: string;
  setDriverId?: (driverId: string) => void;
};

export default function SupplierOrderNewEditAddress({ isEdit, supplierId, setSupplierId, supplierName, setSupplierName, driverId, setDriverId }: Props) {

  const mdUp = useResponsive("up", "md");
  const [selectedSupplier, setSelectedSupplier] = useState<SupplierDTO | null>(null);
  const [selectedDriver, setSelectedDriver] = useState<IDriverSupplierItem | null>(null);
  const [driversList, setDriversList] = useState<IDriverSupplierItem[]>([]);
  const [openDriverDialog, setOpenDriverDialog] = useState(false);
  const { suppliersData, mutate: mutateSuppliers } = useGetNotArchivedSuppliers();
  const { driversData, mutateDrivers } = getAllDrivers();
  const from = useBoolean();
  const to = useBoolean();

  useEffect(() => {
    if (driversData && driversData.length > 0) {
      const driversDetails: IDriverSupplierItem[] = driversData.map(mapDriverToDriverSupplierItem);
      setDriversList(driversDetails);
    }
  }, [driversData, driverId]);

  const ConcatFullAddress = (supplier: SupplierDTO): string => {
    return `${supplier.companyStreet}, ${supplier.companyCity}, ${supplier.companyCountry}`;
  };
  const mapDriverToDriverSupplierItem = (driver: Driver): IDriverSupplierItem => {
    return {
      id: String(driver.id),
      name: `${driver.firstName} ${driver.lastName}`.trim(),
      fullAddress: driver.street && driver.city && driver.country
        ? `${driver.street}, ${driver.city}, ${driver.country}`
        : "",
      phoneNumber: driver.phoneNumber,
      addressType: "driver",
    };
  }

  useEffect(() => {
    console.log("Supplier ID:", supplierId);
    console.log("Driver ID:", driverId);
    console.log("Suppliers List:", suppliersData);
    console.log("Drivers List:", driversList);

    if (isEdit) {
      if (suppliersData.length > 0 && driversList.length > 0) {

        const supplier = suppliersData.find(supplier => supplier.id == supplierId);
        const driver = driversList.find(driver => driver.id == driverId);

        console.log("Selected Supplier:", supplier);
        console.log("Selected Driver:", driver);

        setSelectedSupplier(supplier || null);
        setSelectedDriver(driver || null);
      }
    } else {
      setSelectedSupplier(suppliersData[0] || null);
      setSelectedDriver(driversList[0] || null);
    }
  }, [isEdit, supplierId, driverId, suppliersData, driversList]);

  const onChangeSupplier = (newSupplierId: string) => {
    if (setSupplierId) {
      setSupplierId(newSupplierId);
    }
    setSelectedSupplier(suppliersData.find(supplier => supplier.id === newSupplierId) || null);
    if (setSupplierName) {
      setSupplierName(`${selectedSupplier?.supplierName} ${selectedSupplier?.supplierLastName}`);
    }
  };

  const onChangeDriver = (newDriverId: string) => {
    if (setDriverId) {
      setDriverId(String(newDriverId));
    }
    setSelectedDriver(driversList.find(driver => driver.id === newDriverId) || null);
  };
  const [openSupplierDialog, setOpenSupplierDialog] = useState(false);
  const handleOpenSupplierDialog = useCallback(() => {
    setOpenSupplierDialog(true);
  }, []);
  const handleCloseSupplierDialog = useCallback(() => {
    setOpenSupplierDialog(false);
  }, []);
  const handleSupplierAdded = useCallback(async () => {
    // Rafraîchir la liste des fournisseurs
    await mutateSuppliers();
  }, [mutateSuppliers]);



  const handleOpenDriverDialog = useCallback(() => {
    setOpenDriverDialog(true);
  }, []);
  const handleCloseDriverDialog = useCallback(() => {
    setOpenDriverDialog(false);
  }, []);
  const handleDriverAdded = useCallback(async () => {
    try {

      await mutateDrivers();

      handleCloseDriverDialog();

      enqueueSnackbar('Chauffeur ajouté avec succès', { variant: 'success' });
    } catch (error) {
      console.error('Erreur lors du rafraîchissement des chauffeurs:', error);
      enqueueSnackbar('Erreur lors de l\'ajout du chauffeur', { variant: 'error' });
    }
  }, [mutateDrivers, handleCloseDriverDialog, enqueueSnackbar]);

  const handelAddSupplier = useCallback(() => {
    handleOpenSupplierDialog();
  }, []);
  const handelAddDriver = useCallback(() => {
    handleOpenDriverDialog();
  }, []);

  const fournisseur: DialogItem[] = suppliersData.map(item => ({
    id: item.id,
    name: item.supplierLastName + " " + item.supplierName,
    company: item.companyCountry,
    fullAddress: ConcatFullAddress(item),
    phoneNumber: item.companyPhoneNumber
  }));
  const driver: DialogItem[] = driversData.map(item => ({
    id: String(item.id),
    name: item.firstName + " " + item.lastName,
    phoneNumber: item.phoneNumber
  }));

  return (
    <>
      <Stack
        spacing={{ xs: 3, md: 5 }}
        direction={{ xs: "column", md: "row" }}
        divider={
          <Divider
            flexItem
            orientation={mdUp ? "vertical" : "horizontal"}
            sx={{ borderStyle: "dashed" }}
          />
        }
        sx={{ p: 3 }}
      >
        <Stack sx={{ width: 1 }}>
          <Stack direction="row" alignItems="center" sx={{ mb: 1 }}>
            <Typography
              variant="h6"
              sx={{ color: "text.disabled", flexGrow: 1 }}
            >
              Fournisseur {selectedSupplier?.id ? "sélectionné: " : "non sélectionné"} {selectedSupplier?.id}
            </Typography>
            <IconButton onClick={from.onTrue}>
              <Iconify
                icon={selectedSupplier?.id && selectedSupplier.id != "" ? "solar:pen-bold" : "mingcute:add-line"}
              />
            </IconButton>
          </Stack>

          {selectedSupplier && selectedSupplier.id != null && selectedSupplier.id != "" ? (
            <Stack spacing={1}>
              <div key={selectedSupplier.id}>
                <Typography variant="subtitle2" sx={{ color: "primary.main" }}>
                  {`${selectedSupplier.supplierLastName}  ${selectedSupplier.supplierName}`}
                </Typography>
                <Typography variant="body2">{ConcatFullAddress(selectedSupplier)}</Typography>
                <Typography variant="body2">{selectedSupplier?.supplierPhoneNumber}</Typography>
              </div>
            </Stack>
          ) : (
            <Typography typography="caption" sx={{ color: "error.main" }}>
              Fournisseur non trouvé
            </Typography>
          )}

        </Stack>
        <Stack sx={{ width: 1 }}>
          <Stack direction="row" alignItems="center" sx={{ mb: 1 }}>
            <Typography
              variant="h6"
              sx={{ color: "text.disabled", flexGrow: 1 }}
            >
              Chauffeur {selectedDriver?.id != "" ? "sélectionné: " : "non sélectionné"} {selectedDriver?.id}
            </Typography>

            <IconButton onClick={to.onTrue}>
              <Iconify
                icon={selectedDriver?.id && selectedDriver.id != "" ? "solar:pen-bold" : "mingcute:add-line"}
              />
            </IconButton>
          </Stack>

          {selectedDriver?.id && selectedDriver.id != null && selectedDriver.id != "" ? (
            <Stack spacing={1}>
              <div key={selectedDriver?.id}>
                <Typography variant="subtitle2" sx={{ color: "primary.main" }}>
                  {selectedDriver.name}
                </Typography>
                <Typography variant="body2">{selectedDriver?.fullAddress}</Typography>
                <Typography variant="body2">{selectedDriver.phoneNumber}</Typography>
              </div>
            </Stack>
          ) : (
            <Typography typography="caption" sx={{ color: "error.main" }}>
              Chauffeur non trouvé
            </Typography>
          )}
        </Stack>
      </Stack>

      <DriverSupplierListDialog
        title="Fournisseurs"
        open={from.value}
        onClose={from.onFalse}
        selected={(selectedId: string) => selectedSupplier?.id === selectedId}
        onSelect={(address) => onChangeSupplier(address?.id!)}
        defaultSelectedId={selectedSupplier?.id || null}
        setSelectedId={onChangeSupplier}
        list={fournisseur}
        action={
          <Button
            size="small"
            startIcon={<Iconify icon="mingcute:add-line" />}
            sx={{ alignSelf: "flex-end" }}
            onClick={handelAddSupplier}
          >
            Nouveau fournisseur
          </Button>
        }
      />

      <DriverSupplierListDialog
        title="Chauffeurs"
        open={to.value}
        onClose={to.onFalse}
        selected={(selectedId: string) => selectedDriver?.id === selectedId}
        onSelect={(address) => onChangeDriver(address?.id!)}
        defaultSelectedId={selectedDriver?.id || null}
        setSelectedId={onChangeDriver}
        list={driver}
        action={
          <Button
            size="small"
            startIcon={<Iconify icon="mingcute:add-line" />}
            sx={{ alignSelf: "flex-end" }}
            onClick={handelAddDriver}
          >
            Nouveau chauffeur
          </Button>
        }
      />
      <AddSupplierDialog
        open={openSupplierDialog}
        onClose={handleCloseSupplierDialog}
        onSuccess={handleSupplierAdded}
      />
      <AddDriverDialog
        open={openDriverDialog}
        onClose={handleCloseDriverDialog}
        onSuccess={handleDriverAdded}
      />
    </>
  );
}
