"use client";

import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import OrdereNewEditForm from "./ordernew-edit-form";
import { useEffect, useState } from "react";
import { Alert, CircularProgress, Grid, Stack } from "@mui/material";
import { SnackbarProvider } from "@/components/snackbar";
import { getSupplierOrderById } from "@/shared/api/supplierOrders";
import { SupplierOrder } from "@/contexts/types/supplierOrder";
import { LoadingScreen } from "@/shared/components/loading-screen";


type Props = {
  supplierOrderId?: string;
};

export default function SupplierOrderNewEditView({ supplierOrderId }: Props) {
  const settings = useSettingsContext();
  const [loading, setLoading] = useState(false);
  const [supplierOrder, setSupplierOrder] = useState<SupplierOrder | null>(null);
  const { supplierOrderData, supplierOrderLoading, supplierOrderError } = getSupplierOrderById(supplierOrderId!);

  useEffect(() => {
    if (supplierOrderData) {
      setSupplierOrder(supplierOrderData);
    }
  }, [supplierOrderData]);

  if (supplierOrderLoading) {
    return (
      <Grid container spacing={3} sx={{ justifyContent: 'center', alignItems: 'center', height: '100vh' }}>
        <LoadingScreen />
      </Grid>
    );
  }

  if (supplierOrderError) {
    return (
      <Grid container spacing={3} sx={{ justifyContent: 'center', alignItems: 'center', height: '100vh' }}>
        <Alert severity="error">Problème lors de la récupération des données de la commande d'achat. Veuillez réessayer plus tard.</Alert>
      </Grid>
    );
  }

  return (
    <SnackbarProvider>
      <Container maxWidth={settings.themeStretch ? false : "lg"}>
        <CustomBreadcrumbs
          heading={supplierOrderId ? "Modifier une Commande" : "Créer une Commande"}
          links={[
            {
              name: "Tableau de bord",
              href: paths.dashboard.root,
            },
            {
              name: "Commandes d'achat",
              href: paths.dashboard.admin.supplierOrder.root,
            },
            {
              name: supplierOrderId ? "Modifier une commande: " : "Nouvelle Commande",
            },
          ]}
          rollbackLink={paths.dashboard.admin.supplierOrder.root} 

          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />
        {
          loading ? (
            <Stack alignItems="center" justifyContent="center" sx={{ py: 5 }}>
              <CircularProgress />
            </Stack>
          ) :
            <OrdereNewEditForm currentSupplierOrder={supplierOrder!} />
        }
      </Container>
    </SnackbarProvider>
  );
}
