import { Controller, useFormContext } from "react-hook-form";
import Stack from "@mui/material/Stack";
import MenuItem from "@mui/material/MenuItem";
import { RHFSelect } from "@/shared/components/hook-form";
import { SupplierOrderStatus, supplierOrderStatusLabels, SupplierOrderType, supplierOrderTypeLabels } from "@/contexts/types/supplierOrder";
import { DateTimePicker } from "@mui/x-date-pickers";


export default function SupplierOrderNewEditStatusDate() {
  const { control, watch } = useFormContext();

  return (
    <Stack
      spacing={2}
      direction={{ xs: "column", sm: "row" }}
      sx={{ p: 3, bgcolor: "background.neutral" }}
    >
      <Controller
        name="supplierOrderStatus"
        control={control}
        defaultValue={watch("supplierOrderStatus") || SupplierOrderStatus.TO_BE_COLLECTED}
        render={({ field }) => (
          <RHFSelect
            fullWidth
            label="Statut"
            InputLabelProps={{ shrink: true }}
            PaperPropsSx={{ textTransform: "capitalize" }}
            {...field}
          >
            {Object.values(SupplierOrderStatus).map((status) => (
              <MenuItem key={status} value={status}>
                {supplierOrderStatusLabels[status]}
              </MenuItem>
            ))}
          </RHFSelect>
        )}
      />

      <Controller
        name="supplierOrderType"
        control={control}
        defaultValue={watch("supplierOrderType") || SupplierOrderType.PURCHASES}
        render={({ field }) => (
          <RHFSelect
            fullWidth
            label="Type"
            InputLabelProps={{ shrink: true }}
            PaperPropsSx={{ textTransform: "capitalize" }}
            {...field}
          >
            {Object.values(SupplierOrderType)
              .map((type) => (
                <MenuItem key={type} value={type}>
                  {supplierOrderTypeLabels[type]}
                </MenuItem>
              ))}
          </RHFSelect>
        )}
      />

      <Controller
        name="createdAt"
        control={control}
        render={({ field, fieldState: { error } }) => (
          <DateTimePicker
            label="Date de création"
            value={field.value}
            onChange={(newValue) => {
              field.onChange(newValue);
            }}
            format="yyyy/MM/dd HH:mm:ss"
            slotProps={{
              textField: {
                fullWidth: true,
                error: !!error,
                helperText: error?.message,
              },
            }}
          />
        )}
      />

      <Controller
        name="deliveryDate"
        control={control}
        render={({ field, fieldState: { error } }) => (
          <DateTimePicker
            label="Date de livraison"
            value={field.value}
            onChange={(newValue) => {
              field.onChange(newValue);
            }}
            format="yyyy/MM/dd HH:mm:ss"
            slotProps={{
              textField: {
                fullWidth: true,
                error: !!error,
                helperText: error?.message,
              },
            }}
          />
        )}
      />

    </Stack>
  );
}
