import { SupplierOrderStatus, supplierOrderStatusLabels } from "@/contexts/types/supplierOrder";
import { Box, Button, MenuItem, Modal, Select, Typography, SelectChangeEvent, Stack } from "@mui/material";
import { useSnackbar } from "notistack";

interface CustomModalProps {
    open: boolean;
    onClose: () => void;
    message: string;
    rowStatus: SupplierOrderStatus;
    setRowStatus: (status: SupplierOrderStatus) => void;
    onUpdateSupplierOrderStatus: () => void;
}

export default function SupplierOrderEditStatusModal({ 
    open, 
    onClose, 
    message, 
    rowStatus, 
    setRowStatus, 
    onUpdateSupplierOrderStatus 
}: CustomModalProps) {

    const { enqueueSnackbar } = useSnackbar();

    const handleStatusChange = (event: SelectChangeEvent<SupplierOrderStatus>) => {
        setRowStatus(event.target.value as SupplierOrderStatus);
    };

    const handleSave = () => {
        onUpdateSupplierOrderStatus();
        onClose();
        enqueueSnackbar("Statut de la commande modifié avec succès", { variant: "success" });
    };

    return (
        <Modal
            className="flex items-center justify-center"
            open={open}
            onClose={onClose}
            aria-labelledby="modal-title"
            aria-describedby="modal-description"
        >
            <div className="bg-white rounded-lg shadow p-6 flex flex-col justify-center items-center">
                <Typography variant="body2" id="modal-description" sx={{ mb: 2, fontSize: 20 }}>
                    {message}
                </Typography>
                <Box sx={{ width: 300, mb: 2 }}>
                    <Select
                        value={rowStatus}
                        onChange={handleStatusChange}
                        fullWidth
                    >
                        {Object.keys(SupplierOrderStatus).map((key) => (
                            <MenuItem key={key} value={SupplierOrderStatus[key as keyof typeof SupplierOrderStatus]}>
                                {supplierOrderStatusLabels[SupplierOrderStatus[key as keyof typeof SupplierOrderStatus]]}
                            </MenuItem>
                        ))}
                    </Select>
                </Box>
                <Stack direction="row" spacing={2}>
                    <Button variant="contained" color="error" onClick={onClose}>Annuler</Button>
                    <Button variant="contained" color="info" onClick={handleSave}>Enregistrer</Button>
                </Stack>
            </div>
        </Modal>
    );
}
