"use client";
import { useCallback, useState, useEffect } from "react";
import Button from "@mui/material/Button";
import Container from "@mui/material/Container";
import Card from "@mui/material/Card";
import Table from "@mui/material/Table";
import TableBody from "@mui/material/TableBody";
import TableContainer from "@mui/material/TableContainer";
import Tab from "@mui/material/Tab";
import Tabs from "@mui/material/Tabs";
import { alpha } from "@mui/material/styles";
import Iconify from "@/components/iconify";
import Scrollbar from "@/components/scrollbar";
import { ConfirmDialog } from "../../../components/custom-dialog";
import { useSettingsContext } from "@/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import {
  useTable,
  emptyRows,
  TableNoData,
  TableEmptyRows,
  TableHeadCustom,
  TableSelectedAction,
  TablePaginationCustom,
} from "../../../components/table";

import {
  IUser,
  IRole,
  IUserTableFilters,
  IUserTableFilterValue,
  SearchUsersParams,
} from "../../../types/user";
import { useBoolean } from "@/hooks/use-boolean";
import RouterLink from "@/routes/router-link";
import { paths } from "@/routes/paths";
import {
  exportUsers,
  useGetRoles,
  useSearchUsers,
  useUserCountsByStatus,
} from "@/shared/api/user";

import UserTableRow from "./user-table-row";
import UserTableToolbar from "./user-table-toolbar";
import UserTableFiltersResult from "./user-table-filters-result";
import { isEqual } from "lodash";
import Label from "@/shared/components/label";
import { useRouter } from "next/navigation";
import Snackbar from "@mui/material/Snackbar"; // Import du composant Snackbar
import Alert from "@mui/material/Alert"; // Import du composant Alert
import { CircularProgress, Grid, TableCell, TableRow } from "@mui/material";
import LoadingButton from "@mui/lab/LoadingButton";

// ----------------------------------------------------------------------

const STATUS_OPTIONS = [
  { value: "", label: "Tous" },
  { value: "APPROVED", label: "Approuvé" },
  { value: "PENDING", label: "En attente" },
  { value: "BANNED", label: "Banni" },
  { value: "DELETED", label: "Supprimé" },
];

const TABLE_HEAD = [
  { id: "uid", label: "Uid", width: 50 },
  { id: "firstName", label: "Nom" },
  { id: "pseudo", label: "Pseudo", width: 180 },
  { id: "createdAt", label: "Date de création", width: 180 },
  { id: "phoneNumber", label: "Numéro de téléphone", width: 250 },
  { id: "", label: "Tag", width: 90 },
  { id: "", label: "Rôle", width: 180 },
  { id: "status", label: "Statut", width: 100 },
  { id: "", width: 88 },
];

const defaultFilters: IUserTableFilters = {
  keyword: "",
  roles: [],
  status: "",
  tags: [],
  startDate: "",
  endDate: "",
};

// ----------------------------------------------------------------------

export default function AllUsersView() {
  const table = useTable();
  const settings = useSettingsContext();
  const router = useRouter();
  const confirm = useBoolean();

  // Etat pour les messages d'alerte (snackbar)
  const [snackbarOpen, setSnackbarOpen] = useState(false);
  const [snackbarMessage, setSnackbarMessage] = useState("");
  const [snackbarSeverity, setSnackbarSeverity] = useState<
    "success" | "error" | "info" | "warning"
  >("success");

  const handleSnackbarClose = useCallback(() => {
    setSnackbarOpen(false);
  }, []);

  const handleSnackbarOpen = useCallback(
    (message: string, severity: "success" | "error" | "info" | "warning") => {
      setSnackbarMessage(message);
      setSnackbarSeverity(severity);
      setSnackbarOpen(true);
    },
    []
  );

  const [tableData, setTableData] = useState<IUser[]>([]);
  const [rolesData, setRolesData] = useState<IRole[]>([]);
  const [statusCounts, setStatusCounts] = useState<{ [key: string]: number }>({
    APPROVED: 0,
    PENDING: 0,
    BANNED: 0,
    DELETED: 0,
  });
 const defaultFiltersLocalStorage: IUserTableFilters = localStorage.getItem("lastUsersFilters")
    ?
    JSON.parse(localStorage.getItem("lastUsersFilters")!)
    :
    {
      keyword: "",
      roles: [],
      status: "",
      tags: [],
      startDate: "",
      endDate: "",
    };
    
  const [filters, setFilters] = useState(defaultFiltersLocalStorage);

  useEffect(() => {
    localStorage.removeItem("lastUsersFilters")
    localStorage.setItem("lastUsersFilters", JSON.stringify(filters));
  }, [filters]);
  

  
  const {
    users,
    totalUsers,
    totalPages,
    pageNumber,
    pageSize,
    loading,
    revalidate,
  } = useSearchUsers({
    keyword: filters.keyword,
    status: filters.status,
    roles: filters.roles,
    startDate: filters.startDate,
    endDate: filters.endDate,
    tags: filters.tags,
    page: table.page,
    size: table.rowsPerPage,
    sortBy: table.orderBy,
    sortDir: table.order,
  });

  const { roleData, roleError } = useGetRoles();
  const { userCounts, userCountsError } = useUserCountsByStatus(filters);

  useEffect(() => {
    if (users && users.length > 0) {
      setTableData(users);
    }
  }, [users, table.page, table.rowsPerPage]);

  useEffect(() => {
    if (roleData && Array.isArray(roleData)) {
      setRolesData(roleData as IRole[]);
    } else {
      handleSnackbarOpen("Erreur lors de la récupération des rôles", "error");
    }
  }, [roleData, handleSnackbarOpen]);

  useEffect(() => {
    if (users && users.length > 0) {
      setTableData(users);
    }
  }, [users, table.page, table.rowsPerPage]);
  useEffect(() => {
    if (roleData && Array.isArray(roleData)) {
      setRolesData(roleData as IRole[]);
    } else {
      handleSnackbarOpen("Erreur lors de la récupération des rôles", "error");
    }
  }, [roleData, handleSnackbarOpen]);

  useEffect(() => {
    if (userCountsError) {
      console.error("Error fetching status counts:", userCountsError);
      return;
    }
    if (Array.isArray(userCounts)) {
      const statusObj = userCounts.reduce<{ [key: string]: number }>(
        (acc, [status, count]) => {
          acc[status] = count;
          return acc;
        },
        {}
      );

      setStatusCounts(statusObj);
    } else {
      console.error(
        "Expected counts to be an array, but received:",
        userCounts
      );
    }
  }, [filters, userCounts, userCountsError]);

  useEffect(() => {
    if (
      filters.keyword ||
      filters.roles ||
      filters.tags ||
      filters.startDate ||
      filters.endDate
    ) {
      revalidate();
    }
  }, [filters, revalidate]);

  const dataInPage = tableData.slice(
    table.page * table.rowsPerPage,
    table.page * table.rowsPerPage + table.rowsPerPage
  );

  const denseHeight = table.dense ? 56 : 56 + 20;

  const canReset = !isEqual(defaultFilters, filters);

  const notFound = totalUsers === 0 && canReset;

  const handleFilters = useCallback(
    (name: string, value: IUserTableFilterValue) => {
      table.onResetPage();
      setFilters((prevState) => ({
        ...prevState,
        [name]: value,
      }));
    },
    [table]
  );

  const handleResetFilters = useCallback(() => {
    setFilters(defaultFilters);
  }, []);
  const handleDeleteRow = useCallback(
    (id: string) => {
      const updatedTableData = tableData.map((row) => {
        if (row.id === id) {
          handleSnackbarOpen(
            `L'utilisateur ${row.firstName} est supprimé avec succès!`,
            "success"
          );
          return { ...row, status: "DELETED" };
        }
        return row;
      });
      setTableData(updatedTableData);
    },
    [tableData, handleSnackbarOpen]
  );

  const handleDeleteRows = useCallback(() => {
    const deleteRows = tableData.filter(
      (row) => !table.selected.includes(row.id)
    );
    handleSnackbarOpen("Suppression réussie!", "success");
    setTableData(deleteRows);
    table.onUpdatePageDeleteRows({
      totalRowsInPage: dataInPage.length,
      totalRowsFiltered: totalUsers,
    });
  }, [totalUsers, dataInPage.length, table, tableData, handleSnackbarOpen]);

  const handleUpdateUser = useCallback(
    (updatedUser: IUser) => {
      setTableData((prevTableData) =>
        prevTableData.map((user) =>
          user.id === updatedUser.id ? { ...user, ...updatedUser } : user
        )
      );
      handleSnackbarOpen(
        `L'utilisateur ${updatedUser.firstName} est mis à jour avec succès!`,
        "success"
      );
    },
    [handleSnackbarOpen]
  );

  const handleEditRow = useCallback(
    (id: string) => {
      router.push(paths.dashboard.admin.user.edit(id));
    },
    [router, handleSnackbarOpen]
  );
  const [loadingExport, setLoadingExport] = useState(false);
  const handleExport = async () => {
    setLoadingExport(true);
    try {
      const exportParams: SearchUsersParams = {
        keyword: filters.keyword || undefined,
        status: filters.status || undefined,
        roles: filters.roles.length > 0 ? filters.roles : undefined,
        tags: filters.tags.length > 0 ? filters.tags : undefined,
        startDate: filters.startDate || undefined,
        endDate: filters.endDate || undefined,
        sortBy: table.orderBy || undefined,
        sortDir: table.order || undefined,
      };

      const filterParts = [];
      if (filters.keyword)
        filterParts.push(`indice_chercher:${filters.keyword}`);
      if (filters.status) filterParts.push(`status-${filters.status}`);
      if (filters.roles.length > 0)
        filterParts.push(`roles-${filters.roles.join("-")}`);
      if (filters.tags.length > 0)
        filterParts.push(`tags-${filters.tags.join("-")}`);
      if (filters.startDate && filters.endDate) {
        filterParts.push(
          `cree entre-${filters.startDate} j'usqua-${filters.endDate}`
        );
      }

      const fileName = `users_${filterParts.join("_") || "all"}.csv`;

      const blob = await exportUsers(exportParams);

      const url = window.URL.createObjectURL(blob);
      const a = document.createElement("a");
      a.href = url;
      a.download = fileName;
      a.click();
      window.URL.revokeObjectURL(url);

      handleSnackbarOpen("Fichier exporté avec succès", "success");
    } catch (error) {
      console.error("Error exporting users:", error);

      handleSnackbarOpen(
        "Erreur lors de l'exportation des utilisateurs",
        "error"
      );
    } finally {
      setLoadingExport(false);
    }
  };

  return (
    <>
      <Container maxWidth={settings.themeStretch ? false : "lg"}>
        <CustomBreadcrumbs
          heading="Liste des utilisateurs"
          links={[
            { name: "Tableau de bord", href: paths.dashboard.root },
            { name: "Utilisateur", href: paths.dashboard.admin.user.all_users },
            { name: "Liste" },
          ]}
          action={
            <div className="flex gap-4">
              <Button
                component={RouterLink}
                href={paths.dashboard.admin.user.new}
                variant="contained"
                startIcon={<Iconify icon="mingcute:add-line" />}
              >
                Nouveau utilisateur
              </Button>

              <LoadingButton
                onClick={handleExport}
                loading={loadingExport}
                variant="contained"
                startIcon={<Iconify icon="eva:download-fill" />}
              >
                Exporter
              </LoadingButton>
            </div>
          }
          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />

        <Card>
          {loading ? (
            <Grid
              style={{
                display: "flex",
                justifyContent: "center",
                alignItems: "center",
              }}
            >
              <CircularProgress />
            </Grid>
          ) : (
            <Tabs
              value={filters.status}
              onChange={(event, newValue) => handleFilters("status", newValue)}
              sx={{
                px: 2.5,
                boxShadow: (theme) =>
                  `inset 0 -2px 0 0 ${alpha(theme.palette.grey[500], 0.08)}`,
              }}
            >
              {STATUS_OPTIONS.map((tab) => {
                const count =
                  statusCounts[tab.value as keyof typeof statusCounts] || 0;
                return (
                  <Tab
                    key={tab.value}
                    iconPosition="end"
                    value={tab.value}
                    label={tab.label}
                    icon={
                      <Label
                        variant={
                          ((tab.value === "all" ||
                            tab.value === filters.status) &&
                            "filled") ||
                          "soft"
                        }
                        color={
                          (tab.value === "APPROVED" && "success") ||
                          (tab.value === "PENDING" && "warning") ||
                          (tab.value === "BANNED" && "error") ||
                          (tab.value === "DELETED" && "default") ||
                          "default"
                        }
                      >
                        {tab.value === ""
                          ? Object.values(statusCounts).reduce(
                              (acc, count) => acc + count,
                              0
                            )
                          : count}
                      </Label>
                    }
                  />
                );
              })}
            </Tabs>
          )}

          <UserTableToolbar
            filters={filters}
            onFilters={handleFilters}
            roleOptions={rolesData}
          />

          {canReset && (
            <UserTableFiltersResult
              filters={filters}
              onFilters={handleFilters}
              onResetFilters={handleResetFilters}
              results={totalUsers}
              sx={{ p: 2.5, pt: 0 }}
            />
          )}

          <TableContainer sx={{ position: "relative", overflow: "unset" }}>
            <TableSelectedAction
              dense={table.dense}
              numSelected={table.selected.length}
              rowCount={totalUsers}
              onSelectAllRows={(checked) =>
                table.onSelectAllRows(
                  checked,
                  tableData.map((row) => row.id)
                )
              }
            />

            <Scrollbar>
              <Table
                size={table.dense ? "small" : "medium"}
                sx={{ minWidth: 960 }}
              >
                <TableHeadCustom
                  order={table.order}
                  orderBy={table.orderBy}
                  headLabel={TABLE_HEAD}
                  rowCount={totalUsers}
                  numSelected={table.selected.length}
                  onSort={table.onSort}
                />
                <TableBody>
                  {loading ? (
                    <TableRow>
                      <TableCell
                        colSpan={TABLE_HEAD.length}
                        style={{ textAlign: "center", padding: "20px" }}
                      >
                        <CircularProgress />
                      </TableCell>
                    </TableRow>
                  ) : (
                    <>
                      {notFound ? (
                        <TableNoData notFound={notFound} />
                      ) : (
                        tableData.map((row) => (
                          <UserTableRow
                            key={row.id}
                            row={row}
                            selected={table.selected.includes(row.id)}
                            onSelectRow={() => table.onSelectRow(row.id)}
                            onDeleteRow={() => handleDeleteRow(row.id)}
                            onEditRow={() => handleEditRow(row.id)}
                            onUpdateUser={handleUpdateUser}
                          />
                        ))
                      )}

                      <TableEmptyRows
                        height={denseHeight}
                        emptyRows={emptyRows(
                          table.page,
                          table.rowsPerPage,
                          totalUsers
                        )}
                      />
                    </>
                  )}
                </TableBody>
              </Table>
            </Scrollbar>
          </TableContainer>

          <TablePaginationCustom
            count={totalUsers}
            page={pageNumber}
            rowsPerPage={pageSize}
            onPageChange={table.onChangePage}
            onRowsPerPageChange={table.onChangeRowsPerPage}
            dense={table.dense}
            onChangeDense={table.onChangeDense}
          />
        </Card>
      </Container>

      <ConfirmDialog
        open={confirm.value}
        onClose={confirm.onFalse}
        title="Supprimer"
        content={
          <>
            Êtes-vous sûr de vouloir supprimer{" "}
            <strong>{table.selected.length}</strong> éléments?
          </>
        }
        action={
          <Button
            variant="contained"
            color="error"
            onClick={() => {
              handleDeleteRows();
              confirm.onFalse();
            }}
          >
            Supprimer
          </Button>
        }
      />

      <Snackbar
        open={snackbarOpen}
        autoHideDuration={3000}
        onClose={handleSnackbarClose}
        anchorOrigin={{ vertical: "top", horizontal: "right" }}
      >
        <Alert onClose={handleSnackbarClose} severity={snackbarSeverity}>
          {snackbarMessage}
        </Alert>
      </Snackbar>
    </>
  );
}

// ----------------------------------------------------------------------
