import React, { useEffect, useState } from "react";
import {
  Button,
  Card,
  CardContent,
  CardHeader,
  FormControl,
  Grid,
  InputLabel,
  MenuItem,
  Select,
  List,
} from "@mui/material";
import Checkbox from "@mui/material/Checkbox";
import { useGetRoles } from "@/shared/api/user";
import AddRoleDialog from "./popUp/AddRoleDialog";
import AddPermissionDialog from "./popUp/AddPermissionDialog";
import DeletePermissionDialog from "./popUp/DeletePermissionDialog";
import { Add } from "@mui/icons-material";
import DeleteIcon from "@mui/icons-material/Delete";
import { IRole } from "@/shared/types/user";

export default function UserRoleEditor() {
  const [rolesData, setRolesData] = useState<IRole[]>([]);
  const { roleData, roleError } = useGetRoles();

  const refreshRoles = () => {
    if (roleData && Array.isArray(roleData)) {
      setRolesData(roleData as IRole[]);
    } else {
      console.error("Les rôles ne sont pas un tableau", roleData);
    }
  };

  useEffect(() => {
    refreshRoles();
  }, [roleData]);

  const [openAddRoleDialog, setOpenAddRoleDialog] = useState(false);
  const [openDeletePermissionDialog, setOpenDeletePermissionDialog] =
    useState(false);
  const [openAddPermissionDialog, setOpenAddPermissionDialog] = useState(false);

  const handleOpenAddRoleDialog = () => {
    setOpenAddRoleDialog(true);
  };

  const handleCloseAddRoleDialog = () => {
    setOpenAddRoleDialog(false);
  };

  const handleOpenAddPermissionDialog = () => {
    setOpenAddPermissionDialog(true);
  };

  const handleCloseAddPermissionDialog = () => {
    setOpenAddPermissionDialog(false);
  };

  const handleOpenDeletePermissionDialog = () => {
    setOpenDeletePermissionDialog(true);
  };

  const handleCloseDeletePermissionDialog = () => {
    setOpenDeletePermissionDialog(false);
  };

  return (
    <Grid container spacing={2}>
      <Grid item xs={12} sm={8}>
        <Card>
          <CardHeader
            title={`Sélectionnez un rôle et modifiez ses permissions`}
          />
          <CardContent>
            <Grid container spacing={1}>
              <Grid item xs={12} sm={6}>
                <FormControl fullWidth>
                  <InputLabel id="select-label">Rôle</InputLabel>
                  <Select
                    label="Rôle"
                    labelId="select-label"
                    MenuProps={{
                      PaperProps: {
                        sx: { maxHeight: 240 },
                      },
                    }}
                  >
                    {rolesData.map((option) => (
                      <MenuItem key={option.name} value={option.name}>
                        {option.value}
                      </MenuItem>
                    ))}
                  </Select>
                </FormControl>
              </Grid>
            </Grid>
            <Grid
              container
              spacing={2}
              sx={{ overflow: "auto", maxHeight: 500, marginTop: 2 }}
            >
              <Grid item xs={12} sm={6}>
                <List></List>
              </Grid>
              <Grid item xs={12} sm={6}>
                <List></List>
              </Grid>
            </Grid>
          </CardContent>
        </Card>
      </Grid>
      <Grid item xs={12} sm={4}>
        <Card>
          <CardHeader title={`Actions`} />
          <CardContent>
            <Grid container direction="column" spacing={1}>
              <Grid item xs={12}>
                <Button
                  variant="contained"
                  onClick={handleOpenAddRoleDialog}
                  startIcon={<Add />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                >
                  Ajouter un rôle
                </Button>
                <AddRoleDialog
                  open={openAddRoleDialog}
                  handleClose={handleCloseAddRoleDialog}
                  refreshRoles={refreshRoles}
                  setRolesData={setRolesData}
                />
              </Grid>
              <Grid item xs={12}>
                <Button
                  variant="contained"
                  startIcon={<Add />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                  onClick={handleOpenAddPermissionDialog}
                >
                  Ajouter une permission
                </Button>
                <AddPermissionDialog
                  open={openAddPermissionDialog}
                  handleClose={handleCloseAddPermissionDialog}
                />
              </Grid>
              <Grid item xs={12}>
                <Button
                  variant="contained"
                  startIcon={<DeleteIcon />}
                  sx={{ width: "100%", justifyContent: "flex-start" }}
                  onClick={handleOpenDeletePermissionDialog}
                >
                  Supprimer une permission
                </Button>
                <DeletePermissionDialog
                  open={openDeletePermissionDialog}
                  handleClose={handleCloseDeletePermissionDialog}
                />
              </Grid>
            </Grid>
          </CardContent>
        </Card>
      </Grid>
    </Grid>
  );
}
