
export enum LiveStatus {
  ONGOING = 'ONGOING',
  COMING = 'COMING',
  REPLAY = 'REPLAY',
  REVIEW = 'REVIEW',
  ARCHIVED = 'ARCHIVED',
  ALL = 'ALL'
}

export enum LiveProductStatus {
  PRESENTED = "PRESENTED",
  NOT_PRESENTED = "NOT_PRESENTED",
  IN_PRESENTATION = "IN_PRESENTATION"
}

export type ILive = {
  id: string;
  title: string;
  chatName: string;
  description: string;
  startDate: Date;
  keyWord: string[];
  staging: boolean;
  enableChat: boolean;
  enableLive: boolean;
  startedAt?: Date;
  status?: LiveStatus;
  videoLink?: string;
  externalVideo: boolean;
  image: string | null | File;
  videoFormat: string;
  products?: ILiveProduct[];
  keysWork?: {
    id: number
    keyStream: string,
    rtmpServerAddress: string,
    hlsServerAddress: string,
  }
}




export type ILiveItem = {
  id: string;
  title: string;
  chatName: string;
  description: string;
  startDate: Date;
  status: LiveStatus;
  keyWord: string[];
  staging: boolean;
  enableChat: boolean;
  enableLive: boolean;
  image: string;
  videoFormat: string;
};


export type ILiveComment = {
  parent?: ILiveComment;
  id?: string;
  content: string;
  type?: string;
  pinned?: boolean;
  admin?: boolean;
  senderName: string;
  liveStream: string;
}


export type TimeStampProduct = {
  id: string;
  startTime?: number;
  endTime?: number;
  liveProductId?: string;
}

export type ILiveProduct = {
  id: string;
  title: string;
  sku: string;
  image: string;
  price: number;
  isPresented: boolean;
  productId?: string;
  status: LiveProductStatus;
  timeStampProduct: TimeStampProduct[];
}


export interface IProductListItem {
  id: string;
  name: string;
  ugs: string;
  regularPrice?: number;
  mainImagePath: string;
}

export type ILiveStatistic = {
  timestamp: Date;
  purchases: number;
  numberOfMessages: number;
  numberOfViewers: number;
}

export type ILiveStatisticsSummary = {
  totalMessages: number;
  totalPurchases: number;
  totalViewers: number;
  statistics: ILiveStatistic[];
}


export type AllLivesAnalytics = {
  numberOfLives: number;
  numberOfViewers: number;
  numberOfMessages: number;
  numberOfPurchases: number;
  totalIncome: number;
  viewHours: number;
}

export type IMultipleLivesStatisticsSummary = {
  stats: {
    id: string;
    title: string;
    startDate: string;
    viewers: number;
    revenu: number;
    messages: number;
    cartAdditions: number;
    watchingHours: number;
  }[];
  total: {
    totalCartAdditions: number;
    totalMessages: number;
    totalRevenu: number;
    totalViewers: number;
    totalWatchingHours: number;
    avgWatchingHours: number;
  }
}


export type ILiveTableFilterValues = string | Date | string[] | null | undefined;



export type ILiveTableFilter = {
  startDate: Date | null;
  status: string | LiveStatus;
  tags: string[];
};



export type ILiveTableSort = {
  order: 'asc' | 'desc';
  orderBy: string;
};