// ----------------------------------------------------------------------

import { NoteType } from "@/contexts/types/main-order";
import { IAddressItem } from "./user";
import { ProductType } from "./product";

export type IOrderTableFilterValue = string | Date | null;

export type IOrderTableFilters = {
  keyword: string;
  status: string;
  startDate: Date|null;
  endDate: Date|null ;
};

export enum IOrderStatus {
  Ongoing = "En cours",
  Completed = "Terminée",
  Cancelled = "Annulée",
  Deleted = "Supprimée",
  Pending = "En attente",
  Refunded = "Remboursée",
  PARTIALLY_REFUNDED = "Remboursé partiellement"
}



export interface CreateOrderFromBORequest {
  clientId: number;
  clientUid: number;
  whoCreatedCommand : number;
  createdAt: string;
  orderStatus: string;
  note: string;
  noteType: string;
  productCommandQts: ProductToCreateCommandBo[];
}
export interface ProductToCreateCommandBo {
  idProduct: number;
  quantity: number;
  unitPrice: number;
  productName:string;
  type:ProductType;
  image: string;
  ugs: string;
}
export enum OrderStatus {
  FAILED = "FAILED",
  ON_HOLD = "ON_HOLD",
  IN_PROGRESS = "IN_PROGRESS",
  FINISHED = "FINISHED",
  CANCELED = "CANCELED",
  PARTIALLY_REFUNDED = "PARTIALLY_REFUNDED",
  REFUNDED = "REFUNDED",
  DELETED = "DELETED",
}

export interface OrderStatusHistoryDTO {
  id: number;
  oldOrderStatus: OrderStatus;
  newOrderStatus: OrderStatus;
  createdAt: Date;
  userId: number;
  userFullName: string;
  orderId: number;
}
const orderStatusTranslations: Record<OrderStatus, string> = {
  [OrderStatus.FAILED]: "Échoué",
  [OrderStatus.ON_HOLD]: "En attente",
  [OrderStatus.IN_PROGRESS]: "En cours",
  [OrderStatus.FINISHED]: "Terminé",
  [OrderStatus.CANCELED]: "Annulé",
  [OrderStatus.REFUNDED]: "Remboursé",
  [OrderStatus.PARTIALLY_REFUNDED]: "Remboursé partiellement",
  [OrderStatus.DELETED]: "Supprimé",
};
export function getStatusInFrench(status: OrderStatus): string {
  return orderStatusTranslations[status];
}


// ----------------------------------------------------------------------

export type IOrderHistory = {
  orderTime: Date;
  paymentTime: Date;
  deliveryTime: Date;
  completionTime: Date;
  timeline: {
    title: string;
    time: Date;
  }[];
};

export enum ShippingMethod {
  LivraisonGratuite = "FreeShipping",
  TarifFixe = "FlatRate",
  PointDeVente = "PointOfSale",
  ColissimoSansSignature = "ColissimoWithoutSignature",
  ColissimoAvecSignature = "ColissimoWithSignature",
  MondialRelay = "MondialRelay"
 }

export type IOrderShippingAddress = {
  fullAddress: string;
  villeShip: string;
  codePostal: number;
  modeExpedition: string;
  trackingNumber: string;
};

export type IOrderPayment = {
  cardType: string;
  cardNumber: string;
};

export type IOrderDelivery = {
  shipAdress: string;
  ville: string;
  codePostal: number;
};
export type IOrderStatistic = {
  startDate: any;
  timestod: Date;
  timespre: Date;
};

export type IOrderCustomer = {
  id: string;
  name: string;
  email: string;
  avatarUrl: string;
  numberphone: string;
};

export type IOrderProductItem = {
  id: string;
  sku: string;
  name: string;
  price: number;
  coverUrl: string;
  quantity: number;
  origine: string;
};

export type IOrderItem = {
  id: string;
  taxes: number;
  status: string;
  origine: string;
  shipping: number;
  discount: number;
  subTotal: number;
  orderNumber: string;
  totalAmount: number;
  totalQuantity: number;
  history: IOrderHistory;
  customer: IOrderCustomer;
  delivery: IOrderDelivery;
  items: IOrderProductItem[];
  createdAt: Date;
};


export interface UpdateOrderLineRequest {
  id: number;
  idProduct: number;
  productName: string;
  unitPrice: number;
  qts: number;
}

export interface OrderToUpdateResponse {
  id: number;
  createdAt: string;
  orderStatus: OrderStatus;
  clientFullName: string;
  note: UpdateNoteRequest[];
  shippingAddress: IAddressItem;
  billingAddress: IAddressItem;
  updateOrderLineRequests: UpdateOrderLineRequest[];
  total: number;
  subTotal: number;
  userWhoUpdate:number;
}

export interface UpdateNoteRequest {
  id: number;
  note: string;
  noteType: NoteType;
}


