// ----------------------------------------------------------------------

import { SupplierOrderStatus } from "@/contexts/types/supplierOrder";
import { list } from "postcss";

export type ISupplierOrderTableFilterValue = string | string[] | Date | SupplierOrderStatus | null;

export type IOrderTableFilters = {
  name: string;
  status: string | SupplierOrderStatus;
  startDate: Date | null;
  endDate: Date | null;
  supplier: string[];
};

export type ISupplierOrderTableFilters = {
  name: string;
  status: string;
  startDate: Date | null;
  endDate: Date | null;
  supplier: string[];
};

export enum IOrderSupplierStatus {
  Completed = "livré",
  Pending = "à collecter",
  Ongoing= "réceptionné"
}

export enum IOrderStatus {
  Completed = "livré",
  Pending = "à collecter",
  Ongoing= "réceptionné"
}
// ----------------------------------------------------------------------

export type IOrderHistory = {
  orderTime: Date;
  paymentTime: Date;
  deliveryTime: Date;
  completionTime: Date;
  timeline: {
    title: string;
    time: Date;
  }[];
};

export type IOrderShippingAddress = {
  fullAddress: string;
  villeShip: string;
  codePostal: number;
  modeExpedition: string;
  trackingNumber: string;
};

export type IOrderPayment = {
  cardType: string;
  cardNumber: string;
};

export type IOrderDelivery = {
  shipAdress: string;
  ville: string;
  codePostal: number;
};
export type IOrderStatistic = {
  startDate: any;
  timestod: Date;
  timespre: Date;
};



export type IOrderSupplier = {
  phone?: String;
  id?: string;
  name?: string;
  email?: string;
  numberphone?: string;
  avatarUrl?: string;
};


export type IOrderItem = {
  id: string;
  taxes: number;
  status: string;
  origine: string;
  shipping: number;
  discount: number;
  subTotal: number;
  orderNumber: string;
  totalAmount: number;
  totalQuantity: number;
  history: IOrderHistory;
  customer: IOrderCustomer;
  delivery: IOrderDelivery;
  items: IOrderProductItem[];
  createdAt: Date;
};

export type IOrderStatusHistory = {
  status: string;
  date: string;
};

export type ISupplierOrderItem = {
  id: string;
  orderNumber: string;
  createdAt: Date;
  deliveryDate: Date; 
  status: string;
  customer: IOrderSupplier;
  items?: IOrderProductItem[];
  fullAddress: string;
  taxes?: number; 
  statusHistory?: IOrderStatusHistory[]; 
};


export type SupplierOrderTableFilters2 = {
  name: string;
  status: string;
  startDate: Date | null;
  endDate: Date | null;
  supplier: string[];
  deliveryDate : Date | null;
};

export type ISupplierOrderTableFilters2 = {
  name: string;
  status: SupplierOrderStatus;
  startDate: Date | null;
  endDate: Date | null;
  supplier: string[];
  deliveryDate : Date | null;
};















export type IOrderItemDetail = {
  productName: string;
  quantity: number;
};

export type IOrderStatusHistoryDetail = {
  oldStatus: string;
  newStatus: string;
  modificationDate: string; 
};

export type ISupplierOrderDetails = {
  orderId: string;
  creationDate: string; 
  deliveryDate: string; 
  supplierFirstName: string;
  supplierLastName: string;
  supplierAddress: string;
  supplierStreet: string;
  supplierCity: string;
  supplierCountry: string;
  supplierPhone: string;
  supplierEmail: string;
  status:string;
  orderItems: IOrderItemDetail[];
  orderHistory: IOrderStatusHistoryDetail[];
  comment: string;
};

export type IOrderCustomer = {
  name: string;
  email: string;
  avatarUrl?: string;
  address: string; 
  numberphone: string;
};

export type IOrderProductItem = {
  [x: string]: any;
  id: string;
  sku: string;
  name: string;
  price: number;
  coverUrl: string;
  quantity: number;
  origine: string;
};

export type StatusHistoryItem = {
  oldstatus: string;
  newstatus: string;
  date: string;
};
