import { CustomFile } from "../components/upload";

// ----------------------------------------------------------------------

export type IUserTableFilterValue = string | string[];

export type IUserTableFilters = {
  keyword: string;
  roles: string[];
  status: string;
  tags: string[];
  startDate?: string ;
  endDate?: string ;
};

export type ISupplierTableFilters = {
  name: string;
};

// ----------------------------------------------------------------------

export type IUserSocialLink = {
  facebook: string;
  instagram: string;
  linkedin: string;
  twitter: string;
};

export type IUserProfileCover = {
  name: string;
  role: string;
  coverUrl: string;
  avatarUrl: string;
};

export type IUserProfile = {
  id: string;
  role: string;
  quote: string;
  email: string;
  school: string;
  country: string;
  company: string;
  totalFollowers: number;
  totalFollowing: number;
  socialLinks: IUserSocialLink;
};

export type ClientWithCustomResponse = {
  id: number;
  uid: number ;
  firstName: string;
  lastName: string;
  userEmail:string;
  shippingAddress: IAddressItem | null;
  billingAddress: IAddressItem | null;
}
export type IUserProfileFollower = {
  id: string;
  name: string;
  country: string;
  avatarUrl: string;
};

export type IUserProfileGallery = {
  id: string;
  title: string;
  imageUrl: string;
  postedAt: Date;
};

export type IUserProfileFriend = {
  id: string;
  name: string;
  role: string;
  avatarUrl: string;
};

export type IUserProfilePost = {
  id: string;
  media: string;
  message: string;
  createdAt: Date;
  personLikes: {
    name: string;
    avatarUrl: string;
  }[];
  comments: {
    id: string;
    message: string;
    createdAt: Date;
    author: {
      id: string;
      name: string;
      avatarUrl: string;
    };
  }[];
};

export type IUserCard = {
  id: string;
  name: string;
  role: string;
  coverUrl: string;
  avatarUrl: string;
  totalPosts: number;
  totalFollowers: number;
  totalFollowing: number;
};

export type IUserItem = {
  id: string;
  name: string;
  city: string;
  role: string;
  email: string;
  state: string;
  status: string;
  loginActivity: string;
  address: string;
  country: string;
  zipCode: string;
  company: string;
  avatarUrl: string;
  phoneNumber: string;
  isVerified: boolean;
  pseudo: string;
  ref: string;
};
export type IUser = {
  id: string;
  email: string;
  pseudo: string;
  uid:number;
  password?: string;
  phoneNumber: string;
  firstName: string;
  lastName: string;
  imageUrl?: string ;
  tags?:string[],
  roles: IRole;
  createdAt?: Date;
  status: string;
  activityLog: boolean;
};
export type IRole = {
  id: number | null;
  name: string;
  value?:string;
  rolePermissions?: any[];
};

export enum AddressType {
  BILLING = "BILLING",
  SHIPPING = "SHIPPING",
}

export interface IClientItem extends IUser {
  howDidYouHearAboutUs : string,
  birthDate:Date | string;
  addresses: IAddressItem[];

}


export type IAddressItem = {
  id?: number;
  firstName: string;
  lastName: string;
  companyName: string;
  email: string;
  phoneNumber: number | null;
  street: string;
  home: string;
  city: string;
  zipCode: string;
  country: string;
  addressType: AddressType;
}
export type IAddress = {
  id?: number;
  firstName: string;
  lastName: string;
  companyName: string;
  email: string;
  phoneNumber: string | null;
  street: string;
  home: string;
  city: string;
  zipCode: string;
  country: string;
  mainAddress?:boolean;
  addressType: AddressType;
}
export type RequestLoginActivity = {
  email: string;
  activityLog:Boolean;
};
export type RequestChangeUserStatus = {
  email: string;
  status: string;
};
export type IAllUsersItem = {
  clients: IClientItem[];
  users: IUser[];
};
export interface AuthenticationRequest {
  username: string;
  password: string;
}

export type IUserAccount = {
  email: string;
  isPublic: boolean;
  displayName: string;
  city: string | null;
  state: string | null;
  about: string | null;
  country: string | null;
  address: string | null;
  zipCode: string | null;
  phoneNumber: string | null;
  photoURL: CustomFile | string | null;
};

export type IUserAccountBillingHistory = {
  id: string;
  price: number;
  createdAt: Date;
  invoiceNumber: string;
};
export type UpdatePasswordRequest = {
email: string;
password: string;
};
export type IUserAccountChangePassword = {
  oldPassword: string;
  newPassword: string;
  confirmNewPassword: string;
};
export interface TokenPayload {
  exp: number;
  iat: number;
  name: string;
  email: string;
  realm_access: {
    roles: string[];
  };
  isValid:Boolean;
}

export type SearchUsersParams ={
  keyword?: string;
  status?: string;
  roles?: string[];
  tags?: string[];
  startDate?: string ;
  endDate?: string;
  page?: number;
  size?: number;
  sortBy?: string;
  sortDir?: string;
}

export interface IUserPage {
  content: IUser[];
  pageable: {
    sort: {
      empty: boolean;
      sorted: boolean;
      unsorted: boolean;
    },
    offset: number;
    pageNumber: number;
    pageSize: number;
    unpaged: boolean;
    paged: boolean;
  },
  totalPages: number,
  totalElements: number,
  last: boolean;
  sort: {
    empty: boolean;
    sorted: boolean;
    unsorted: boolean;  };
}

export type ISupportAgent = {
  id: number;
  email: string;
  username: string;
  firstName: string;
  lastName: string;
  role: string;
  status: string;
}

export type UserCountByStatus = [string, number];

export type ChatUser = Record<string, any> | null;