import { format, getTime, formatDistanceToNow , isSameDay} from 'date-fns';
import { fr } from 'date-fns/locale';

// ----------------------------------------------------------------------

type InputValue = Date | string | number | null | undefined;

export function fDate(date: InputValue, newFormat?: string) {
  const fm = newFormat || 'dd MMM yyyy';
  return date ? format(new Date(date), fm) : '';
}

export function fTime(date: InputValue, newFormat?: string) {
  const fm = newFormat || 'p';

  return date ? format(new Date(date), fm, { locale: fr }) : '';
}

export function fDateTime(date: InputValue, newFormat?: string) {
  const fm = newFormat || 'dd MMM yyyy p';

  return date ? format(new Date(date), fm, { locale: fr }) : '';
}

export function fTimestamp(date: InputValue) {
  return date ? getTime(new Date(date)) : '';
}

export function fToNow(date: InputValue) {
  return date
    ? formatDistanceToNow(new Date(date), {
        addSuffix: true,
        locale: fr,
      })
    : '';
}

export function isBetween(inputDate: Date | string | number, startDate: Date, endDate: Date) {
  const date = new Date(inputDate);

  const results =
    new Date(date.toDateString()) >= new Date(startDate.toDateString()) &&
    new Date(date.toDateString()) <= new Date(endDate.toDateString());

  return results;
}

export function isAfter(startDate: Date | null, endDate: Date | null) {
  const results =
    startDate && endDate ? new Date(startDate).getTime() > new Date(endDate).getTime() : false;

  return results;
}

export const calculateSeconds = (date: Date): number => {
  const midnight = new Date(date);
  midnight.setHours(0, 0, 0, 0);

  const secondsFromMidnight = Math.floor((date.getTime() - midnight.getTime()) / 1000);
  return secondsFromMidnight;
};

export const secondsToTime = (seconds: number): Date => {
  const date = new Date();
  date.setHours(0, 0, 0, 0); // Set to midnight
  date.setSeconds(seconds);
  return date;
};

export function isToday(date: InputValue) {
  return date ? isSameDay(new Date(date), new Date()) : false;
}


export function differenceInSeconds(date1: Date, date2: Date): number {
  const millisecondsDifference = Math.abs(date1.getTime() - date2.getTime());
  return Math.floor(millisecondsDifference / 1000);
}

export function convertDateToUTC(date: Date) { return new Date(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate(), date.getUTCHours(), date.getUTCMinutes(), date.getUTCSeconds()); }


export const formatDateToString = (date: Date): string => {
  
  const year = date.getFullYear();
  const month = String(date.getMonth() + 1).padStart(2, '0');
  const day = String(date.getDate()).padStart(2, '0');

  return `${year}-${month}-${day}`;
};
