import { TokenPayload } from "@/shared/types/user";
import { jwtDecode } from "jwt-decode";



export const getTokenInfo = (token: string): TokenPayload => {
  try {
    const decodedToken = jwtDecode<TokenPayload>(token);
    const currentTime = Date.now() / 1000; 
    const isValid = decodedToken.exp > currentTime;
    return {
      exp: decodedToken.exp,
      iat: decodedToken.iat,
      name: decodedToken.name,
      email: decodedToken.email,
      realm_access: {
        roles: decodedToken.realm_access.roles,
      },
      isValid,
    };
  } catch (error) {
    console.error("Erreur lors de la désérialisation du token", error);
    return {
      exp: 0,
      iat: 0,
      name: '',
      email: '',
      realm_access: {
        roles: [],
      },
      isValid: false,
    };
  }
};


export function isValidToken(accessToken: string) {
  if (!accessToken) {
    return false;
  }
  try {
    const decoded = jwtDecode<TokenPayload>(accessToken);
    if (!decoded) {
      return false;
    }
    const currentTime = Date.now() / 1000;
    return decoded.exp > currentTime;
  } catch (error) {
    console.error('Error during token validation:', error);
    return false;
  }
}